/* This file is automatically generated by gen_gldispatch_mapi.py.  Do not modify. */

#ifndef _GLAPI_TMP_H_
#define _GLAPI_TMP_H_
typedef int GLclampx;
typedef void (APIENTRY  *GLDEBUGPROCKHR)(GLenum source,GLenum type,GLuint id,GLenum severity,GLsizei length,const GLchar *message,const void *userParam);
#endif /* _GLAPI_TMP_H_ */

#ifdef MAPI_TMP_DEFINES
#define GL_GLEXT_PROTOTYPES
#include "GL/gl.h"
#include "GL/glext.h"

GLAPI void APIENTRY glAccum(GLenum op, GLfloat value);
GLAPI void APIENTRY glActiveShaderProgram(GLuint pipeline, GLuint program);
GLAPI void APIENTRY glActiveTexture(GLenum texture);
GLAPI void APIENTRY glAlphaFunc(GLenum func, GLfloat ref);
GLAPI GLboolean APIENTRY glAreTexturesResident(GLsizei n, const GLuint *textures, GLboolean *residences);
GLAPI void APIENTRY glArrayElement(GLint i);
GLAPI void APIENTRY glAttachShader(GLuint program, GLuint shader);
GLAPI void APIENTRY glBegin(GLenum mode);
GLAPI void APIENTRY glBeginConditionalRender(GLuint id, GLenum mode);
GLAPI void APIENTRY glBeginQuery(GLenum target, GLuint id);
GLAPI void APIENTRY glBeginQueryIndexed(GLenum target, GLuint index, GLuint id);
GLAPI void APIENTRY glBeginTransformFeedback(GLenum primitiveMode);
GLAPI void APIENTRY glBindAttribLocation(GLuint program, GLuint index, const GLchar *name);
GLAPI void APIENTRY glBindBuffer(GLenum target, GLuint buffer);
GLAPI void APIENTRY glBindBufferBase(GLenum target, GLuint index, GLuint buffer);
GLAPI void APIENTRY glBindBufferRange(GLenum target, GLuint index, GLuint buffer, GLintptr offset, GLsizeiptr size);
GLAPI void APIENTRY glBindBuffersBase(GLenum target, GLuint first, GLsizei count, const GLuint *buffers);
GLAPI void APIENTRY glBindBuffersRange(GLenum target, GLuint first, GLsizei count, const GLuint *buffers, const GLintptr *offsets, const GLsizeiptr *sizes);
GLAPI void APIENTRY glBindFragDataLocation(GLuint program, GLuint color, const GLchar *name);
GLAPI void APIENTRY glBindFragDataLocationIndexed(GLuint program, GLuint colorNumber, GLuint index, const GLchar *name);
GLAPI void APIENTRY glBindFramebuffer(GLenum target, GLuint framebuffer);
GLAPI void APIENTRY glBindImageTexture(GLuint unit, GLuint texture, GLint level, GLboolean layered, GLint layer, GLenum access, GLenum format);
GLAPI void APIENTRY glBindImageTextures(GLuint first, GLsizei count, const GLuint *textures);
GLAPI void APIENTRY glBindProgramPipeline(GLuint pipeline);
GLAPI void APIENTRY glBindRenderbuffer(GLenum target, GLuint renderbuffer);
GLAPI void APIENTRY glBindSampler(GLuint unit, GLuint sampler);
GLAPI void APIENTRY glBindSamplers(GLuint first, GLsizei count, const GLuint *samplers);
GLAPI void APIENTRY glBindTexture(GLenum target, GLuint texture);
GLAPI void APIENTRY glBindTextureUnit(GLuint unit, GLuint texture);
GLAPI void APIENTRY glBindTextures(GLuint first, GLsizei count, const GLuint *textures);
GLAPI void APIENTRY glBindTransformFeedback(GLenum target, GLuint id);
GLAPI void APIENTRY glBindVertexArray(GLuint array);
GLAPI void APIENTRY glBindVertexBuffer(GLuint bindingindex, GLuint buffer, GLintptr offset, GLsizei stride);
GLAPI void APIENTRY glBindVertexBuffers(GLuint first, GLsizei count, const GLuint *buffers, const GLintptr *offsets, const GLsizei *strides);
GLAPI void APIENTRY glBitmap(GLsizei width, GLsizei height, GLfloat xorig, GLfloat yorig, GLfloat xmove, GLfloat ymove, const GLubyte *bitmap);
GLAPI void APIENTRY glBlendColor(GLfloat red, GLfloat green, GLfloat blue, GLfloat alpha);
GLAPI void APIENTRY glBlendEquation(GLenum mode);
GLAPI void APIENTRY glBlendEquationSeparate(GLenum modeRGB, GLenum modeAlpha);
GLAPI void APIENTRY glBlendEquationSeparatei(GLuint buf, GLenum modeRGB, GLenum modeAlpha);
GLAPI void APIENTRY glBlendEquationi(GLuint buf, GLenum mode);
GLAPI void APIENTRY glBlendFunc(GLenum sfactor, GLenum dfactor);
GLAPI void APIENTRY glBlendFuncSeparate(GLenum sfactorRGB, GLenum dfactorRGB, GLenum sfactorAlpha, GLenum dfactorAlpha);
GLAPI void APIENTRY glBlendFuncSeparatei(GLuint buf, GLenum srcRGB, GLenum dstRGB, GLenum srcAlpha, GLenum dstAlpha);
GLAPI void APIENTRY glBlendFunci(GLuint buf, GLenum src, GLenum dst);
GLAPI void APIENTRY glBlitFramebuffer(GLint srcX0, GLint srcY0, GLint srcX1, GLint srcY1, GLint dstX0, GLint dstY0, GLint dstX1, GLint dstY1, GLbitfield mask, GLenum filter);
GLAPI void APIENTRY glBlitNamedFramebuffer(GLuint readFramebuffer, GLuint drawFramebuffer, GLint srcX0, GLint srcY0, GLint srcX1, GLint srcY1, GLint dstX0, GLint dstY0, GLint dstX1, GLint dstY1, GLbitfield mask, GLenum filter);
GLAPI void APIENTRY glBufferData(GLenum target, GLsizeiptr size, const void *data, GLenum usage);
GLAPI void APIENTRY glBufferStorage(GLenum target, GLsizeiptr size, const void *data, GLbitfield flags);
GLAPI void APIENTRY glBufferSubData(GLenum target, GLintptr offset, GLsizeiptr size, const void *data);
GLAPI void APIENTRY glCallList(GLuint list);
GLAPI void APIENTRY glCallLists(GLsizei n, GLenum type, const void *lists);
GLAPI GLenum APIENTRY glCheckFramebufferStatus(GLenum target);
GLAPI GLenum APIENTRY glCheckNamedFramebufferStatus(GLuint framebuffer, GLenum target);
GLAPI void APIENTRY glClampColor(GLenum target, GLenum clamp);
GLAPI void APIENTRY glClear(GLbitfield mask);
GLAPI void APIENTRY glClearAccum(GLfloat red, GLfloat green, GLfloat blue, GLfloat alpha);
GLAPI void APIENTRY glClearBufferData(GLenum target, GLenum internalformat, GLenum format, GLenum type, const void *data);
GLAPI void APIENTRY glClearBufferSubData(GLenum target, GLenum internalformat, GLintptr offset, GLsizeiptr size, GLenum format, GLenum type, const void *data);
GLAPI void APIENTRY glClearBufferfi(GLenum buffer, GLint drawbuffer, GLfloat depth, GLint stencil);
GLAPI void APIENTRY glClearBufferfv(GLenum buffer, GLint drawbuffer, const GLfloat *value);
GLAPI void APIENTRY glClearBufferiv(GLenum buffer, GLint drawbuffer, const GLint *value);
GLAPI void APIENTRY glClearBufferuiv(GLenum buffer, GLint drawbuffer, const GLuint *value);
GLAPI void APIENTRY glClearColor(GLfloat red, GLfloat green, GLfloat blue, GLfloat alpha);
GLAPI void APIENTRY glClearDepth(GLdouble depth);
GLAPI void APIENTRY glClearDepthf(GLfloat d);
GLAPI void APIENTRY glClearIndex(GLfloat c);
GLAPI void APIENTRY glClearNamedBufferData(GLuint buffer, GLenum internalformat, GLenum format, GLenum type, const void *data);
GLAPI void APIENTRY glClearNamedBufferSubData(GLuint buffer, GLenum internalformat, GLintptr offset, GLsizeiptr size, GLenum format, GLenum type, const void *data);
GLAPI void APIENTRY glClearNamedFramebufferfi(GLuint framebuffer, GLenum buffer, GLint drawbuffer, GLfloat depth, GLint stencil);
GLAPI void APIENTRY glClearNamedFramebufferfv(GLuint framebuffer, GLenum buffer, GLint drawbuffer, const GLfloat *value);
GLAPI void APIENTRY glClearNamedFramebufferiv(GLuint framebuffer, GLenum buffer, GLint drawbuffer, const GLint *value);
GLAPI void APIENTRY glClearNamedFramebufferuiv(GLuint framebuffer, GLenum buffer, GLint drawbuffer, const GLuint *value);
GLAPI void APIENTRY glClearStencil(GLint s);
GLAPI void APIENTRY glClearTexImage(GLuint texture, GLint level, GLenum format, GLenum type, const void *data);
GLAPI void APIENTRY glClearTexSubImage(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void *data);
GLAPI void APIENTRY glClientActiveTexture(GLenum texture);
GLAPI GLenum APIENTRY glClientWaitSync(GLsync sync, GLbitfield flags, GLuint64 timeout);
GLAPI void APIENTRY glClipControl(GLenum origin, GLenum depth);
GLAPI void APIENTRY glClipPlane(GLenum plane, const GLdouble *equation);
GLAPI void APIENTRY glColor3b(GLbyte red, GLbyte green, GLbyte blue);
GLAPI void APIENTRY glColor3bv(const GLbyte *v);
GLAPI void APIENTRY glColor3d(GLdouble red, GLdouble green, GLdouble blue);
GLAPI void APIENTRY glColor3dv(const GLdouble *v);
GLAPI void APIENTRY glColor3f(GLfloat red, GLfloat green, GLfloat blue);
GLAPI void APIENTRY glColor3fv(const GLfloat *v);
GLAPI void APIENTRY glColor3i(GLint red, GLint green, GLint blue);
GLAPI void APIENTRY glColor3iv(const GLint *v);
GLAPI void APIENTRY glColor3s(GLshort red, GLshort green, GLshort blue);
GLAPI void APIENTRY glColor3sv(const GLshort *v);
GLAPI void APIENTRY glColor3ub(GLubyte red, GLubyte green, GLubyte blue);
GLAPI void APIENTRY glColor3ubv(const GLubyte *v);
GLAPI void APIENTRY glColor3ui(GLuint red, GLuint green, GLuint blue);
GLAPI void APIENTRY glColor3uiv(const GLuint *v);
GLAPI void APIENTRY glColor3us(GLushort red, GLushort green, GLushort blue);
GLAPI void APIENTRY glColor3usv(const GLushort *v);
GLAPI void APIENTRY glColor4b(GLbyte red, GLbyte green, GLbyte blue, GLbyte alpha);
GLAPI void APIENTRY glColor4bv(const GLbyte *v);
GLAPI void APIENTRY glColor4d(GLdouble red, GLdouble green, GLdouble blue, GLdouble alpha);
GLAPI void APIENTRY glColor4dv(const GLdouble *v);
GLAPI void APIENTRY glColor4f(GLfloat red, GLfloat green, GLfloat blue, GLfloat alpha);
GLAPI void APIENTRY glColor4fv(const GLfloat *v);
GLAPI void APIENTRY glColor4i(GLint red, GLint green, GLint blue, GLint alpha);
GLAPI void APIENTRY glColor4iv(const GLint *v);
GLAPI void APIENTRY glColor4s(GLshort red, GLshort green, GLshort blue, GLshort alpha);
GLAPI void APIENTRY glColor4sv(const GLshort *v);
GLAPI void APIENTRY glColor4ub(GLubyte red, GLubyte green, GLubyte blue, GLubyte alpha);
GLAPI void APIENTRY glColor4ubv(const GLubyte *v);
GLAPI void APIENTRY glColor4ui(GLuint red, GLuint green, GLuint blue, GLuint alpha);
GLAPI void APIENTRY glColor4uiv(const GLuint *v);
GLAPI void APIENTRY glColor4us(GLushort red, GLushort green, GLushort blue, GLushort alpha);
GLAPI void APIENTRY glColor4usv(const GLushort *v);
GLAPI void APIENTRY glColorMask(GLboolean red, GLboolean green, GLboolean blue, GLboolean alpha);
GLAPI void APIENTRY glColorMaski(GLuint index, GLboolean r, GLboolean g, GLboolean b, GLboolean a);
GLAPI void APIENTRY glColorMaterial(GLenum face, GLenum mode);
GLAPI void APIENTRY glColorP3ui(GLenum type, GLuint color);
GLAPI void APIENTRY glColorP3uiv(GLenum type, const GLuint *color);
GLAPI void APIENTRY glColorP4ui(GLenum type, GLuint color);
GLAPI void APIENTRY glColorP4uiv(GLenum type, const GLuint *color);
GLAPI void APIENTRY glColorPointer(GLint size, GLenum type, GLsizei stride, const void *pointer);
GLAPI void APIENTRY glCompileShader(GLuint shader);
GLAPI void APIENTRY glCompressedTexImage1D(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLint border, GLsizei imageSize, const void *data);
GLAPI void APIENTRY glCompressedTexImage2D(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLint border, GLsizei imageSize, const void *data);
GLAPI void APIENTRY glCompressedTexImage3D(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLsizei imageSize, const void *data);
GLAPI void APIENTRY glCompressedTexSubImage1D(GLenum target, GLint level, GLint xoffset, GLsizei width, GLenum format, GLsizei imageSize, const void *data);
GLAPI void APIENTRY glCompressedTexSubImage2D(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLsizei imageSize, const void *data);
GLAPI void APIENTRY glCompressedTexSubImage3D(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLsizei imageSize, const void *data);
GLAPI void APIENTRY glCompressedTextureSubImage1D(GLuint texture, GLint level, GLint xoffset, GLsizei width, GLenum format, GLsizei imageSize, const void *data);
GLAPI void APIENTRY glCompressedTextureSubImage2D(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLsizei imageSize, const void *data);
GLAPI void APIENTRY glCompressedTextureSubImage3D(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLsizei imageSize, const void *data);
GLAPI void APIENTRY glCopyBufferSubData(GLenum readTarget, GLenum writeTarget, GLintptr readOffset, GLintptr writeOffset, GLsizeiptr size);
GLAPI void APIENTRY glCopyImageSubData(GLuint srcName, GLenum srcTarget, GLint srcLevel, GLint srcX, GLint srcY, GLint srcZ, GLuint dstName, GLenum dstTarget, GLint dstLevel, GLint dstX, GLint dstY, GLint dstZ, GLsizei srcWidth, GLsizei srcHeight, GLsizei srcDepth);
GLAPI void APIENTRY glCopyNamedBufferSubData(GLuint readBuffer, GLuint writeBuffer, GLintptr readOffset, GLintptr writeOffset, GLsizeiptr size);
GLAPI void APIENTRY glCopyPixels(GLint x, GLint y, GLsizei width, GLsizei height, GLenum type);
GLAPI void APIENTRY glCopyTexImage1D(GLenum target, GLint level, GLenum internalformat, GLint x, GLint y, GLsizei width, GLint border);
GLAPI void APIENTRY glCopyTexImage2D(GLenum target, GLint level, GLenum internalformat, GLint x, GLint y, GLsizei width, GLsizei height, GLint border);
GLAPI void APIENTRY glCopyTexSubImage1D(GLenum target, GLint level, GLint xoffset, GLint x, GLint y, GLsizei width);
GLAPI void APIENTRY glCopyTexSubImage2D(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint x, GLint y, GLsizei width, GLsizei height);
GLAPI void APIENTRY glCopyTexSubImage3D(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLint x, GLint y, GLsizei width, GLsizei height);
GLAPI void APIENTRY glCopyTextureSubImage1D(GLuint texture, GLint level, GLint xoffset, GLint x, GLint y, GLsizei width);
GLAPI void APIENTRY glCopyTextureSubImage2D(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint x, GLint y, GLsizei width, GLsizei height);
GLAPI void APIENTRY glCopyTextureSubImage3D(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLint x, GLint y, GLsizei width, GLsizei height);
GLAPI void APIENTRY glCreateBuffers(GLsizei n, GLuint *buffers);
GLAPI void APIENTRY glCreateFramebuffers(GLsizei n, GLuint *framebuffers);
GLAPI GLuint APIENTRY glCreateProgram(void);
GLAPI void APIENTRY glCreateProgramPipelines(GLsizei n, GLuint *pipelines);
GLAPI void APIENTRY glCreateQueries(GLenum target, GLsizei n, GLuint *ids);
GLAPI void APIENTRY glCreateRenderbuffers(GLsizei n, GLuint *renderbuffers);
GLAPI void APIENTRY glCreateSamplers(GLsizei n, GLuint *samplers);
GLAPI GLuint APIENTRY glCreateShader(GLenum type);
GLAPI GLuint APIENTRY glCreateShaderProgramv(GLenum type, GLsizei count, const GLchar *const *strings);
GLAPI void APIENTRY glCreateTextures(GLenum target, GLsizei n, GLuint *textures);
GLAPI void APIENTRY glCreateTransformFeedbacks(GLsizei n, GLuint *ids);
GLAPI void APIENTRY glCreateVertexArrays(GLsizei n, GLuint *arrays);
GLAPI void APIENTRY glCullFace(GLenum mode);
GLAPI void APIENTRY glDebugMessageCallback(GLDEBUGPROC callback, const void *userParam);
GLAPI void APIENTRY glDebugMessageControl(GLenum source, GLenum type, GLenum severity, GLsizei count, const GLuint *ids, GLboolean enabled);
GLAPI void APIENTRY glDebugMessageInsert(GLenum source, GLenum type, GLuint id, GLenum severity, GLsizei length, const GLchar *buf);
GLAPI void APIENTRY glDeleteBuffers(GLsizei n, const GLuint *buffers);
GLAPI void APIENTRY glDeleteFramebuffers(GLsizei n, const GLuint *framebuffers);
GLAPI void APIENTRY glDeleteLists(GLuint list, GLsizei range);
GLAPI void APIENTRY glDeleteProgram(GLuint program);
GLAPI void APIENTRY glDeleteProgramPipelines(GLsizei n, const GLuint *pipelines);
GLAPI void APIENTRY glDeleteQueries(GLsizei n, const GLuint *ids);
GLAPI void APIENTRY glDeleteRenderbuffers(GLsizei n, const GLuint *renderbuffers);
GLAPI void APIENTRY glDeleteSamplers(GLsizei count, const GLuint *samplers);
GLAPI void APIENTRY glDeleteShader(GLuint shader);
GLAPI void APIENTRY glDeleteSync(GLsync sync);
GLAPI void APIENTRY glDeleteTextures(GLsizei n, const GLuint *textures);
GLAPI void APIENTRY glDeleteTransformFeedbacks(GLsizei n, const GLuint *ids);
GLAPI void APIENTRY glDeleteVertexArrays(GLsizei n, const GLuint *arrays);
GLAPI void APIENTRY glDepthFunc(GLenum func);
GLAPI void APIENTRY glDepthMask(GLboolean flag);
GLAPI void APIENTRY glDepthRange(GLdouble n, GLdouble f);
GLAPI void APIENTRY glDepthRangeArrayv(GLuint first, GLsizei count, const GLdouble *v);
GLAPI void APIENTRY glDepthRangeIndexed(GLuint index, GLdouble n, GLdouble f);
GLAPI void APIENTRY glDepthRangef(GLfloat n, GLfloat f);
GLAPI void APIENTRY glDetachShader(GLuint program, GLuint shader);
GLAPI void APIENTRY glDisable(GLenum cap);
GLAPI void APIENTRY glDisableClientState(GLenum array);
GLAPI void APIENTRY glDisableVertexArrayAttrib(GLuint vaobj, GLuint index);
GLAPI void APIENTRY glDisableVertexAttribArray(GLuint index);
GLAPI void APIENTRY glDisablei(GLenum target, GLuint index);
GLAPI void APIENTRY glDispatchCompute(GLuint num_groups_x, GLuint num_groups_y, GLuint num_groups_z);
GLAPI void APIENTRY glDispatchComputeIndirect(GLintptr indirect);
GLAPI void APIENTRY glDrawArrays(GLenum mode, GLint first, GLsizei count);
GLAPI void APIENTRY glDrawArraysIndirect(GLenum mode, const void *indirect);
GLAPI void APIENTRY glDrawArraysInstanced(GLenum mode, GLint first, GLsizei count, GLsizei instancecount);
GLAPI void APIENTRY glDrawArraysInstancedBaseInstance(GLenum mode, GLint first, GLsizei count, GLsizei instancecount, GLuint baseinstance);
GLAPI void APIENTRY glDrawBuffer(GLenum buf);
GLAPI void APIENTRY glDrawBuffers(GLsizei n, const GLenum *bufs);
GLAPI void APIENTRY glDrawElements(GLenum mode, GLsizei count, GLenum type, const void *indices);
GLAPI void APIENTRY glDrawElementsBaseVertex(GLenum mode, GLsizei count, GLenum type, const void *indices, GLint basevertex);
GLAPI void APIENTRY glDrawElementsIndirect(GLenum mode, GLenum type, const void *indirect);
GLAPI void APIENTRY glDrawElementsInstanced(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei instancecount);
GLAPI void APIENTRY glDrawElementsInstancedBaseInstance(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei instancecount, GLuint baseinstance);
GLAPI void APIENTRY glDrawElementsInstancedBaseVertex(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei instancecount, GLint basevertex);
GLAPI void APIENTRY glDrawElementsInstancedBaseVertexBaseInstance(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei instancecount, GLint basevertex, GLuint baseinstance);
GLAPI void APIENTRY glDrawPixels(GLsizei width, GLsizei height, GLenum format, GLenum type, const void *pixels);
GLAPI void APIENTRY glDrawRangeElements(GLenum mode, GLuint start, GLuint end, GLsizei count, GLenum type, const void *indices);
GLAPI void APIENTRY glDrawRangeElementsBaseVertex(GLenum mode, GLuint start, GLuint end, GLsizei count, GLenum type, const void *indices, GLint basevertex);
GLAPI void APIENTRY glDrawTransformFeedback(GLenum mode, GLuint id);
GLAPI void APIENTRY glDrawTransformFeedbackInstanced(GLenum mode, GLuint id, GLsizei instancecount);
GLAPI void APIENTRY glDrawTransformFeedbackStream(GLenum mode, GLuint id, GLuint stream);
GLAPI void APIENTRY glDrawTransformFeedbackStreamInstanced(GLenum mode, GLuint id, GLuint stream, GLsizei instancecount);
GLAPI void APIENTRY glEdgeFlag(GLboolean flag);
GLAPI void APIENTRY glEdgeFlagPointer(GLsizei stride, const void *pointer);
GLAPI void APIENTRY glEdgeFlagv(const GLboolean *flag);
GLAPI void APIENTRY glEnable(GLenum cap);
GLAPI void APIENTRY glEnableClientState(GLenum array);
GLAPI void APIENTRY glEnableVertexArrayAttrib(GLuint vaobj, GLuint index);
GLAPI void APIENTRY glEnableVertexAttribArray(GLuint index);
GLAPI void APIENTRY glEnablei(GLenum target, GLuint index);
GLAPI void APIENTRY glEnd(void);
GLAPI void APIENTRY glEndConditionalRender(void);
GLAPI void APIENTRY glEndList(void);
GLAPI void APIENTRY glEndQuery(GLenum target);
GLAPI void APIENTRY glEndQueryIndexed(GLenum target, GLuint index);
GLAPI void APIENTRY glEndTransformFeedback(void);
GLAPI void APIENTRY glEvalCoord1d(GLdouble u);
GLAPI void APIENTRY glEvalCoord1dv(const GLdouble *u);
GLAPI void APIENTRY glEvalCoord1f(GLfloat u);
GLAPI void APIENTRY glEvalCoord1fv(const GLfloat *u);
GLAPI void APIENTRY glEvalCoord2d(GLdouble u, GLdouble v);
GLAPI void APIENTRY glEvalCoord2dv(const GLdouble *u);
GLAPI void APIENTRY glEvalCoord2f(GLfloat u, GLfloat v);
GLAPI void APIENTRY glEvalCoord2fv(const GLfloat *u);
GLAPI void APIENTRY glEvalMesh1(GLenum mode, GLint i1, GLint i2);
GLAPI void APIENTRY glEvalMesh2(GLenum mode, GLint i1, GLint i2, GLint j1, GLint j2);
GLAPI void APIENTRY glEvalPoint1(GLint i);
GLAPI void APIENTRY glEvalPoint2(GLint i, GLint j);
GLAPI void APIENTRY glFeedbackBuffer(GLsizei size, GLenum type, GLfloat *buffer);
GLAPI GLsync APIENTRY glFenceSync(GLenum condition, GLbitfield flags);
GLAPI void APIENTRY glFinish(void);
GLAPI void APIENTRY glFlush(void);
GLAPI void APIENTRY glFlushMappedBufferRange(GLenum target, GLintptr offset, GLsizeiptr length);
GLAPI void APIENTRY glFlushMappedNamedBufferRange(GLuint buffer, GLintptr offset, GLsizeiptr length);
GLAPI void APIENTRY glFogCoordPointer(GLenum type, GLsizei stride, const void *pointer);
GLAPI void APIENTRY glFogCoordd(GLdouble coord);
GLAPI void APIENTRY glFogCoorddv(const GLdouble *coord);
GLAPI void APIENTRY glFogCoordf(GLfloat coord);
GLAPI void APIENTRY glFogCoordfv(const GLfloat *coord);
GLAPI void APIENTRY glFogf(GLenum pname, GLfloat param);
GLAPI void APIENTRY glFogfv(GLenum pname, const GLfloat *params);
GLAPI void APIENTRY glFogi(GLenum pname, GLint param);
GLAPI void APIENTRY glFogiv(GLenum pname, const GLint *params);
GLAPI void APIENTRY glFramebufferParameteri(GLenum target, GLenum pname, GLint param);
GLAPI void APIENTRY glFramebufferRenderbuffer(GLenum target, GLenum attachment, GLenum renderbuffertarget, GLuint renderbuffer);
GLAPI void APIENTRY glFramebufferTexture(GLenum target, GLenum attachment, GLuint texture, GLint level);
GLAPI void APIENTRY glFramebufferTexture1D(GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level);
GLAPI void APIENTRY glFramebufferTexture2D(GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level);
GLAPI void APIENTRY glFramebufferTexture3D(GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level, GLint zoffset);
GLAPI void APIENTRY glFramebufferTextureLayer(GLenum target, GLenum attachment, GLuint texture, GLint level, GLint layer);
GLAPI void APIENTRY glFrontFace(GLenum mode);
GLAPI void APIENTRY glFrustum(GLdouble left, GLdouble right, GLdouble bottom, GLdouble top, GLdouble zNear, GLdouble zFar);
GLAPI void APIENTRY glGenBuffers(GLsizei n, GLuint *buffers);
GLAPI void APIENTRY glGenFramebuffers(GLsizei n, GLuint *framebuffers);
GLAPI GLuint APIENTRY glGenLists(GLsizei range);
GLAPI void APIENTRY glGenProgramPipelines(GLsizei n, GLuint *pipelines);
GLAPI void APIENTRY glGenQueries(GLsizei n, GLuint *ids);
GLAPI void APIENTRY glGenRenderbuffers(GLsizei n, GLuint *renderbuffers);
GLAPI void APIENTRY glGenSamplers(GLsizei count, GLuint *samplers);
GLAPI void APIENTRY glGenTextures(GLsizei n, GLuint *textures);
GLAPI void APIENTRY glGenTransformFeedbacks(GLsizei n, GLuint *ids);
GLAPI void APIENTRY glGenVertexArrays(GLsizei n, GLuint *arrays);
GLAPI void APIENTRY glGenerateMipmap(GLenum target);
GLAPI void APIENTRY glGenerateTextureMipmap(GLuint texture);
GLAPI void APIENTRY glGetActiveAtomicCounterBufferiv(GLuint program, GLuint bufferIndex, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetActiveAttrib(GLuint program, GLuint index, GLsizei bufSize, GLsizei *length, GLint *size, GLenum *type, GLchar *name);
GLAPI void APIENTRY glGetActiveSubroutineName(GLuint program, GLenum shadertype, GLuint index, GLsizei bufSize, GLsizei *length, GLchar *name);
GLAPI void APIENTRY glGetActiveSubroutineUniformName(GLuint program, GLenum shadertype, GLuint index, GLsizei bufSize, GLsizei *length, GLchar *name);
GLAPI void APIENTRY glGetActiveSubroutineUniformiv(GLuint program, GLenum shadertype, GLuint index, GLenum pname, GLint *values);
GLAPI void APIENTRY glGetActiveUniform(GLuint program, GLuint index, GLsizei bufSize, GLsizei *length, GLint *size, GLenum *type, GLchar *name);
GLAPI void APIENTRY glGetActiveUniformBlockName(GLuint program, GLuint uniformBlockIndex, GLsizei bufSize, GLsizei *length, GLchar *uniformBlockName);
GLAPI void APIENTRY glGetActiveUniformBlockiv(GLuint program, GLuint uniformBlockIndex, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetActiveUniformName(GLuint program, GLuint uniformIndex, GLsizei bufSize, GLsizei *length, GLchar *uniformName);
GLAPI void APIENTRY glGetActiveUniformsiv(GLuint program, GLsizei uniformCount, const GLuint *uniformIndices, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetAttachedShaders(GLuint program, GLsizei maxCount, GLsizei *count, GLuint *shaders);
GLAPI GLint APIENTRY glGetAttribLocation(GLuint program, const GLchar *name);
GLAPI void APIENTRY glGetBooleani_v(GLenum target, GLuint index, GLboolean *data);
GLAPI void APIENTRY glGetBooleanv(GLenum pname, GLboolean *data);
GLAPI void APIENTRY glGetBufferParameteri64v(GLenum target, GLenum pname, GLint64 *params);
GLAPI void APIENTRY glGetBufferParameteriv(GLenum target, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetBufferPointerv(GLenum target, GLenum pname, void **params);
GLAPI void APIENTRY glGetBufferSubData(GLenum target, GLintptr offset, GLsizeiptr size, void *data);
GLAPI void APIENTRY glGetClipPlane(GLenum plane, GLdouble *equation);
GLAPI void APIENTRY glGetCompressedTexImage(GLenum target, GLint level, void *img);
GLAPI void APIENTRY glGetCompressedTextureImage(GLuint texture, GLint level, GLsizei bufSize, void *pixels);
GLAPI void APIENTRY glGetCompressedTextureSubImage(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLsizei bufSize, void *pixels);
GLAPI GLuint APIENTRY glGetDebugMessageLog(GLuint count, GLsizei bufSize, GLenum *sources, GLenum *types, GLuint *ids, GLenum *severities, GLsizei *lengths, GLchar *messageLog);
GLAPI void APIENTRY glGetDoublei_v(GLenum target, GLuint index, GLdouble *data);
GLAPI void APIENTRY glGetDoublev(GLenum pname, GLdouble *data);
GLAPI GLenum APIENTRY glGetError(void);
GLAPI void APIENTRY glGetFloati_v(GLenum target, GLuint index, GLfloat *data);
GLAPI void APIENTRY glGetFloatv(GLenum pname, GLfloat *data);
GLAPI GLint APIENTRY glGetFragDataIndex(GLuint program, const GLchar *name);
GLAPI GLint APIENTRY glGetFragDataLocation(GLuint program, const GLchar *name);
GLAPI void APIENTRY glGetFramebufferAttachmentParameteriv(GLenum target, GLenum attachment, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetFramebufferParameteriv(GLenum target, GLenum pname, GLint *params);
GLAPI GLenum APIENTRY glGetGraphicsResetStatus(void);
GLAPI void APIENTRY glGetInteger64i_v(GLenum target, GLuint index, GLint64 *data);
GLAPI void APIENTRY glGetInteger64v(GLenum pname, GLint64 *data);
GLAPI void APIENTRY glGetIntegeri_v(GLenum target, GLuint index, GLint *data);
GLAPI void APIENTRY glGetIntegerv(GLenum pname, GLint *data);
GLAPI void APIENTRY glGetInternalformati64v(GLenum target, GLenum internalformat, GLenum pname, GLsizei count, GLint64 *params);
GLAPI void APIENTRY glGetInternalformativ(GLenum target, GLenum internalformat, GLenum pname, GLsizei count, GLint *params);
GLAPI void APIENTRY glGetLightfv(GLenum light, GLenum pname, GLfloat *params);
GLAPI void APIENTRY glGetLightiv(GLenum light, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetMapdv(GLenum target, GLenum query, GLdouble *v);
GLAPI void APIENTRY glGetMapfv(GLenum target, GLenum query, GLfloat *v);
GLAPI void APIENTRY glGetMapiv(GLenum target, GLenum query, GLint *v);
GLAPI void APIENTRY glGetMaterialfv(GLenum face, GLenum pname, GLfloat *params);
GLAPI void APIENTRY glGetMaterialiv(GLenum face, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetMultisamplefv(GLenum pname, GLuint index, GLfloat *val);
GLAPI void APIENTRY glGetNamedBufferParameteri64v(GLuint buffer, GLenum pname, GLint64 *params);
GLAPI void APIENTRY glGetNamedBufferParameteriv(GLuint buffer, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetNamedBufferPointerv(GLuint buffer, GLenum pname, void **params);
GLAPI void APIENTRY glGetNamedBufferSubData(GLuint buffer, GLintptr offset, GLsizeiptr size, void *data);
GLAPI void APIENTRY glGetNamedFramebufferAttachmentParameteriv(GLuint framebuffer, GLenum attachment, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetNamedFramebufferParameteriv(GLuint framebuffer, GLenum pname, GLint *param);
GLAPI void APIENTRY glGetNamedRenderbufferParameteriv(GLuint renderbuffer, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetObjectLabel(GLenum identifier, GLuint name, GLsizei bufSize, GLsizei *length, GLchar *label);
GLAPI void APIENTRY glGetObjectPtrLabel(const void *ptr, GLsizei bufSize, GLsizei *length, GLchar *label);
GLAPI void APIENTRY glGetPixelMapfv(GLenum map, GLfloat *values);
GLAPI void APIENTRY glGetPixelMapuiv(GLenum map, GLuint *values);
GLAPI void APIENTRY glGetPixelMapusv(GLenum map, GLushort *values);
GLAPI void APIENTRY glGetPointerv(GLenum pname, void **params);
GLAPI void APIENTRY glGetPolygonStipple(GLubyte *mask);
GLAPI void APIENTRY glGetProgramBinary(GLuint program, GLsizei bufSize, GLsizei *length, GLenum *binaryFormat, void *binary);
GLAPI void APIENTRY glGetProgramInfoLog(GLuint program, GLsizei bufSize, GLsizei *length, GLchar *infoLog);
GLAPI void APIENTRY glGetProgramInterfaceiv(GLuint program, GLenum programInterface, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetProgramPipelineInfoLog(GLuint pipeline, GLsizei bufSize, GLsizei *length, GLchar *infoLog);
GLAPI void APIENTRY glGetProgramPipelineiv(GLuint pipeline, GLenum pname, GLint *params);
GLAPI GLuint APIENTRY glGetProgramResourceIndex(GLuint program, GLenum programInterface, const GLchar *name);
GLAPI GLint APIENTRY glGetProgramResourceLocation(GLuint program, GLenum programInterface, const GLchar *name);
GLAPI GLint APIENTRY glGetProgramResourceLocationIndex(GLuint program, GLenum programInterface, const GLchar *name);
GLAPI void APIENTRY glGetProgramResourceName(GLuint program, GLenum programInterface, GLuint index, GLsizei bufSize, GLsizei *length, GLchar *name);
GLAPI void APIENTRY glGetProgramResourceiv(GLuint program, GLenum programInterface, GLuint index, GLsizei propCount, const GLenum *props, GLsizei count, GLsizei *length, GLint *params);
GLAPI void APIENTRY glGetProgramStageiv(GLuint program, GLenum shadertype, GLenum pname, GLint *values);
GLAPI void APIENTRY glGetProgramiv(GLuint program, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetQueryBufferObjecti64v(GLuint id, GLuint buffer, GLenum pname, GLintptr offset);
GLAPI void APIENTRY glGetQueryBufferObjectiv(GLuint id, GLuint buffer, GLenum pname, GLintptr offset);
GLAPI void APIENTRY glGetQueryBufferObjectui64v(GLuint id, GLuint buffer, GLenum pname, GLintptr offset);
GLAPI void APIENTRY glGetQueryBufferObjectuiv(GLuint id, GLuint buffer, GLenum pname, GLintptr offset);
GLAPI void APIENTRY glGetQueryIndexediv(GLenum target, GLuint index, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetQueryObjecti64v(GLuint id, GLenum pname, GLint64 *params);
GLAPI void APIENTRY glGetQueryObjectiv(GLuint id, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetQueryObjectui64v(GLuint id, GLenum pname, GLuint64 *params);
GLAPI void APIENTRY glGetQueryObjectuiv(GLuint id, GLenum pname, GLuint *params);
GLAPI void APIENTRY glGetQueryiv(GLenum target, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetRenderbufferParameteriv(GLenum target, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetSamplerParameterIiv(GLuint sampler, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetSamplerParameterIuiv(GLuint sampler, GLenum pname, GLuint *params);
GLAPI void APIENTRY glGetSamplerParameterfv(GLuint sampler, GLenum pname, GLfloat *params);
GLAPI void APIENTRY glGetSamplerParameteriv(GLuint sampler, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetShaderInfoLog(GLuint shader, GLsizei bufSize, GLsizei *length, GLchar *infoLog);
GLAPI void APIENTRY glGetShaderPrecisionFormat(GLenum shadertype, GLenum precisiontype, GLint *range, GLint *precision);
GLAPI void APIENTRY glGetShaderSource(GLuint shader, GLsizei bufSize, GLsizei *length, GLchar *source);
GLAPI void APIENTRY glGetShaderiv(GLuint shader, GLenum pname, GLint *params);
GLAPI const GLubyte * APIENTRY glGetString(GLenum name);
GLAPI const GLubyte * APIENTRY glGetStringi(GLenum name, GLuint index);
GLAPI GLuint APIENTRY glGetSubroutineIndex(GLuint program, GLenum shadertype, const GLchar *name);
GLAPI GLint APIENTRY glGetSubroutineUniformLocation(GLuint program, GLenum shadertype, const GLchar *name);
GLAPI void APIENTRY glGetSynciv(GLsync sync, GLenum pname, GLsizei count, GLsizei *length, GLint *values);
GLAPI void APIENTRY glGetTexEnvfv(GLenum target, GLenum pname, GLfloat *params);
GLAPI void APIENTRY glGetTexEnviv(GLenum target, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetTexGendv(GLenum coord, GLenum pname, GLdouble *params);
GLAPI void APIENTRY glGetTexGenfv(GLenum coord, GLenum pname, GLfloat *params);
GLAPI void APIENTRY glGetTexGeniv(GLenum coord, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetTexImage(GLenum target, GLint level, GLenum format, GLenum type, void *pixels);
GLAPI void APIENTRY glGetTexLevelParameterfv(GLenum target, GLint level, GLenum pname, GLfloat *params);
GLAPI void APIENTRY glGetTexLevelParameteriv(GLenum target, GLint level, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetTexParameterIiv(GLenum target, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetTexParameterIuiv(GLenum target, GLenum pname, GLuint *params);
GLAPI void APIENTRY glGetTexParameterfv(GLenum target, GLenum pname, GLfloat *params);
GLAPI void APIENTRY glGetTexParameteriv(GLenum target, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetTextureImage(GLuint texture, GLint level, GLenum format, GLenum type, GLsizei bufSize, void *pixels);
GLAPI void APIENTRY glGetTextureLevelParameterfv(GLuint texture, GLint level, GLenum pname, GLfloat *params);
GLAPI void APIENTRY glGetTextureLevelParameteriv(GLuint texture, GLint level, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetTextureParameterIiv(GLuint texture, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetTextureParameterIuiv(GLuint texture, GLenum pname, GLuint *params);
GLAPI void APIENTRY glGetTextureParameterfv(GLuint texture, GLenum pname, GLfloat *params);
GLAPI void APIENTRY glGetTextureParameteriv(GLuint texture, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetTextureSubImage(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, GLsizei bufSize, void *pixels);
GLAPI void APIENTRY glGetTransformFeedbackVarying(GLuint program, GLuint index, GLsizei bufSize, GLsizei *length, GLsizei *size, GLenum *type, GLchar *name);
GLAPI void APIENTRY glGetTransformFeedbacki64_v(GLuint xfb, GLenum pname, GLuint index, GLint64 *param);
GLAPI void APIENTRY glGetTransformFeedbacki_v(GLuint xfb, GLenum pname, GLuint index, GLint *param);
GLAPI void APIENTRY glGetTransformFeedbackiv(GLuint xfb, GLenum pname, GLint *param);
GLAPI GLuint APIENTRY glGetUniformBlockIndex(GLuint program, const GLchar *uniformBlockName);
GLAPI void APIENTRY glGetUniformIndices(GLuint program, GLsizei uniformCount, const GLchar *const *uniformNames, GLuint *uniformIndices);
GLAPI GLint APIENTRY glGetUniformLocation(GLuint program, const GLchar *name);
GLAPI void APIENTRY glGetUniformSubroutineuiv(GLenum shadertype, GLint location, GLuint *params);
GLAPI void APIENTRY glGetUniformdv(GLuint program, GLint location, GLdouble *params);
GLAPI void APIENTRY glGetUniformfv(GLuint program, GLint location, GLfloat *params);
GLAPI void APIENTRY glGetUniformiv(GLuint program, GLint location, GLint *params);
GLAPI void APIENTRY glGetUniformuiv(GLuint program, GLint location, GLuint *params);
GLAPI void APIENTRY glGetVertexArrayIndexed64iv(GLuint vaobj, GLuint index, GLenum pname, GLint64 *param);
GLAPI void APIENTRY glGetVertexArrayIndexediv(GLuint vaobj, GLuint index, GLenum pname, GLint *param);
GLAPI void APIENTRY glGetVertexArrayiv(GLuint vaobj, GLenum pname, GLint *param);
GLAPI void APIENTRY glGetVertexAttribIiv(GLuint index, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetVertexAttribIuiv(GLuint index, GLenum pname, GLuint *params);
GLAPI void APIENTRY glGetVertexAttribLdv(GLuint index, GLenum pname, GLdouble *params);
GLAPI void APIENTRY glGetVertexAttribPointerv(GLuint index, GLenum pname, void **pointer);
GLAPI void APIENTRY glGetVertexAttribdv(GLuint index, GLenum pname, GLdouble *params);
GLAPI void APIENTRY glGetVertexAttribfv(GLuint index, GLenum pname, GLfloat *params);
GLAPI void APIENTRY glGetVertexAttribiv(GLuint index, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetnColorTable(GLenum target, GLenum format, GLenum type, GLsizei bufSize, void *table);
GLAPI void APIENTRY glGetnCompressedTexImage(GLenum target, GLint lod, GLsizei bufSize, void *pixels);
GLAPI void APIENTRY glGetnConvolutionFilter(GLenum target, GLenum format, GLenum type, GLsizei bufSize, void *image);
GLAPI void APIENTRY glGetnHistogram(GLenum target, GLboolean reset, GLenum format, GLenum type, GLsizei bufSize, void *values);
GLAPI void APIENTRY glGetnMapdv(GLenum target, GLenum query, GLsizei bufSize, GLdouble *v);
GLAPI void APIENTRY glGetnMapfv(GLenum target, GLenum query, GLsizei bufSize, GLfloat *v);
GLAPI void APIENTRY glGetnMapiv(GLenum target, GLenum query, GLsizei bufSize, GLint *v);
GLAPI void APIENTRY glGetnMinmax(GLenum target, GLboolean reset, GLenum format, GLenum type, GLsizei bufSize, void *values);
GLAPI void APIENTRY glGetnPixelMapfv(GLenum map, GLsizei bufSize, GLfloat *values);
GLAPI void APIENTRY glGetnPixelMapuiv(GLenum map, GLsizei bufSize, GLuint *values);
GLAPI void APIENTRY glGetnPixelMapusv(GLenum map, GLsizei bufSize, GLushort *values);
GLAPI void APIENTRY glGetnPolygonStipple(GLsizei bufSize, GLubyte *pattern);
GLAPI void APIENTRY glGetnSeparableFilter(GLenum target, GLenum format, GLenum type, GLsizei rowBufSize, void *row, GLsizei columnBufSize, void *column, void *span);
GLAPI void APIENTRY glGetnTexImage(GLenum target, GLint level, GLenum format, GLenum type, GLsizei bufSize, void *pixels);
GLAPI void APIENTRY glGetnUniformdv(GLuint program, GLint location, GLsizei bufSize, GLdouble *params);
GLAPI void APIENTRY glGetnUniformfv(GLuint program, GLint location, GLsizei bufSize, GLfloat *params);
GLAPI void APIENTRY glGetnUniformiv(GLuint program, GLint location, GLsizei bufSize, GLint *params);
GLAPI void APIENTRY glGetnUniformuiv(GLuint program, GLint location, GLsizei bufSize, GLuint *params);
GLAPI void APIENTRY glHint(GLenum target, GLenum mode);
GLAPI void APIENTRY glIndexMask(GLuint mask);
GLAPI void APIENTRY glIndexPointer(GLenum type, GLsizei stride, const void *pointer);
GLAPI void APIENTRY glIndexd(GLdouble c);
GLAPI void APIENTRY glIndexdv(const GLdouble *c);
GLAPI void APIENTRY glIndexf(GLfloat c);
GLAPI void APIENTRY glIndexfv(const GLfloat *c);
GLAPI void APIENTRY glIndexi(GLint c);
GLAPI void APIENTRY glIndexiv(const GLint *c);
GLAPI void APIENTRY glIndexs(GLshort c);
GLAPI void APIENTRY glIndexsv(const GLshort *c);
GLAPI void APIENTRY glIndexub(GLubyte c);
GLAPI void APIENTRY glIndexubv(const GLubyte *c);
GLAPI void APIENTRY glInitNames(void);
GLAPI void APIENTRY glInterleavedArrays(GLenum format, GLsizei stride, const void *pointer);
GLAPI void APIENTRY glInvalidateBufferData(GLuint buffer);
GLAPI void APIENTRY glInvalidateBufferSubData(GLuint buffer, GLintptr offset, GLsizeiptr length);
GLAPI void APIENTRY glInvalidateFramebuffer(GLenum target, GLsizei numAttachments, const GLenum *attachments);
GLAPI void APIENTRY glInvalidateNamedFramebufferData(GLuint framebuffer, GLsizei numAttachments, const GLenum *attachments);
GLAPI void APIENTRY glInvalidateNamedFramebufferSubData(GLuint framebuffer, GLsizei numAttachments, const GLenum *attachments, GLint x, GLint y, GLsizei width, GLsizei height);
GLAPI void APIENTRY glInvalidateSubFramebuffer(GLenum target, GLsizei numAttachments, const GLenum *attachments, GLint x, GLint y, GLsizei width, GLsizei height);
GLAPI void APIENTRY glInvalidateTexImage(GLuint texture, GLint level);
GLAPI void APIENTRY glInvalidateTexSubImage(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth);
GLAPI GLboolean APIENTRY glIsBuffer(GLuint buffer);
GLAPI GLboolean APIENTRY glIsEnabled(GLenum cap);
GLAPI GLboolean APIENTRY glIsEnabledi(GLenum target, GLuint index);
GLAPI GLboolean APIENTRY glIsFramebuffer(GLuint framebuffer);
GLAPI GLboolean APIENTRY glIsList(GLuint list);
GLAPI GLboolean APIENTRY glIsProgram(GLuint program);
GLAPI GLboolean APIENTRY glIsProgramPipeline(GLuint pipeline);
GLAPI GLboolean APIENTRY glIsQuery(GLuint id);
GLAPI GLboolean APIENTRY glIsRenderbuffer(GLuint renderbuffer);
GLAPI GLboolean APIENTRY glIsSampler(GLuint sampler);
GLAPI GLboolean APIENTRY glIsShader(GLuint shader);
GLAPI GLboolean APIENTRY glIsSync(GLsync sync);
GLAPI GLboolean APIENTRY glIsTexture(GLuint texture);
GLAPI GLboolean APIENTRY glIsTransformFeedback(GLuint id);
GLAPI GLboolean APIENTRY glIsVertexArray(GLuint array);
GLAPI void APIENTRY glLightModelf(GLenum pname, GLfloat param);
GLAPI void APIENTRY glLightModelfv(GLenum pname, const GLfloat *params);
GLAPI void APIENTRY glLightModeli(GLenum pname, GLint param);
GLAPI void APIENTRY glLightModeliv(GLenum pname, const GLint *params);
GLAPI void APIENTRY glLightf(GLenum light, GLenum pname, GLfloat param);
GLAPI void APIENTRY glLightfv(GLenum light, GLenum pname, const GLfloat *params);
GLAPI void APIENTRY glLighti(GLenum light, GLenum pname, GLint param);
GLAPI void APIENTRY glLightiv(GLenum light, GLenum pname, const GLint *params);
GLAPI void APIENTRY glLineStipple(GLint factor, GLushort pattern);
GLAPI void APIENTRY glLineWidth(GLfloat width);
GLAPI void APIENTRY glLinkProgram(GLuint program);
GLAPI void APIENTRY glListBase(GLuint base);
GLAPI void APIENTRY glLoadIdentity(void);
GLAPI void APIENTRY glLoadMatrixd(const GLdouble *m);
GLAPI void APIENTRY glLoadMatrixf(const GLfloat *m);
GLAPI void APIENTRY glLoadName(GLuint name);
GLAPI void APIENTRY glLoadTransposeMatrixd(const GLdouble *m);
GLAPI void APIENTRY glLoadTransposeMatrixf(const GLfloat *m);
GLAPI void APIENTRY glLogicOp(GLenum opcode);
GLAPI void APIENTRY glMap1d(GLenum target, GLdouble u1, GLdouble u2, GLint stride, GLint order, const GLdouble *points);
GLAPI void APIENTRY glMap1f(GLenum target, GLfloat u1, GLfloat u2, GLint stride, GLint order, const GLfloat *points);
GLAPI void APIENTRY glMap2d(GLenum target, GLdouble u1, GLdouble u2, GLint ustride, GLint uorder, GLdouble v1, GLdouble v2, GLint vstride, GLint vorder, const GLdouble *points);
GLAPI void APIENTRY glMap2f(GLenum target, GLfloat u1, GLfloat u2, GLint ustride, GLint uorder, GLfloat v1, GLfloat v2, GLint vstride, GLint vorder, const GLfloat *points);
GLAPI void * APIENTRY glMapBuffer(GLenum target, GLenum access);
GLAPI void * APIENTRY glMapBufferRange(GLenum target, GLintptr offset, GLsizeiptr length, GLbitfield access);
GLAPI void APIENTRY glMapGrid1d(GLint un, GLdouble u1, GLdouble u2);
GLAPI void APIENTRY glMapGrid1f(GLint un, GLfloat u1, GLfloat u2);
GLAPI void APIENTRY glMapGrid2d(GLint un, GLdouble u1, GLdouble u2, GLint vn, GLdouble v1, GLdouble v2);
GLAPI void APIENTRY glMapGrid2f(GLint un, GLfloat u1, GLfloat u2, GLint vn, GLfloat v1, GLfloat v2);
GLAPI void * APIENTRY glMapNamedBuffer(GLuint buffer, GLenum access);
GLAPI void * APIENTRY glMapNamedBufferRange(GLuint buffer, GLintptr offset, GLsizeiptr length, GLbitfield access);
GLAPI void APIENTRY glMaterialf(GLenum face, GLenum pname, GLfloat param);
GLAPI void APIENTRY glMaterialfv(GLenum face, GLenum pname, const GLfloat *params);
GLAPI void APIENTRY glMateriali(GLenum face, GLenum pname, GLint param);
GLAPI void APIENTRY glMaterialiv(GLenum face, GLenum pname, const GLint *params);
GLAPI void APIENTRY glMatrixMode(GLenum mode);
GLAPI void APIENTRY glMemoryBarrier(GLbitfield barriers);
GLAPI void APIENTRY glMemoryBarrierByRegion(GLbitfield barriers);
GLAPI void APIENTRY glMinSampleShading(GLfloat value);
GLAPI void APIENTRY glMultMatrixd(const GLdouble *m);
GLAPI void APIENTRY glMultMatrixf(const GLfloat *m);
GLAPI void APIENTRY glMultTransposeMatrixd(const GLdouble *m);
GLAPI void APIENTRY glMultTransposeMatrixf(const GLfloat *m);
GLAPI void APIENTRY glMultiDrawArrays(GLenum mode, const GLint *first, const GLsizei *count, GLsizei drawcount);
GLAPI void APIENTRY glMultiDrawArraysIndirect(GLenum mode, const void *indirect, GLsizei drawcount, GLsizei stride);
GLAPI void APIENTRY glMultiDrawElements(GLenum mode, const GLsizei *count, GLenum type, const void *const *indices, GLsizei drawcount);
GLAPI void APIENTRY glMultiDrawElementsBaseVertex(GLenum mode, const GLsizei *count, GLenum type, const void *const *indices, GLsizei drawcount, const GLint *basevertex);
GLAPI void APIENTRY glMultiDrawElementsIndirect(GLenum mode, GLenum type, const void *indirect, GLsizei drawcount, GLsizei stride);
GLAPI void APIENTRY glMultiTexCoord1d(GLenum target, GLdouble s);
GLAPI void APIENTRY glMultiTexCoord1dv(GLenum target, const GLdouble *v);
GLAPI void APIENTRY glMultiTexCoord1f(GLenum target, GLfloat s);
GLAPI void APIENTRY glMultiTexCoord1fv(GLenum target, const GLfloat *v);
GLAPI void APIENTRY glMultiTexCoord1i(GLenum target, GLint s);
GLAPI void APIENTRY glMultiTexCoord1iv(GLenum target, const GLint *v);
GLAPI void APIENTRY glMultiTexCoord1s(GLenum target, GLshort s);
GLAPI void APIENTRY glMultiTexCoord1sv(GLenum target, const GLshort *v);
GLAPI void APIENTRY glMultiTexCoord2d(GLenum target, GLdouble s, GLdouble t);
GLAPI void APIENTRY glMultiTexCoord2dv(GLenum target, const GLdouble *v);
GLAPI void APIENTRY glMultiTexCoord2f(GLenum target, GLfloat s, GLfloat t);
GLAPI void APIENTRY glMultiTexCoord2fv(GLenum target, const GLfloat *v);
GLAPI void APIENTRY glMultiTexCoord2i(GLenum target, GLint s, GLint t);
GLAPI void APIENTRY glMultiTexCoord2iv(GLenum target, const GLint *v);
GLAPI void APIENTRY glMultiTexCoord2s(GLenum target, GLshort s, GLshort t);
GLAPI void APIENTRY glMultiTexCoord2sv(GLenum target, const GLshort *v);
GLAPI void APIENTRY glMultiTexCoord3d(GLenum target, GLdouble s, GLdouble t, GLdouble r);
GLAPI void APIENTRY glMultiTexCoord3dv(GLenum target, const GLdouble *v);
GLAPI void APIENTRY glMultiTexCoord3f(GLenum target, GLfloat s, GLfloat t, GLfloat r);
GLAPI void APIENTRY glMultiTexCoord3fv(GLenum target, const GLfloat *v);
GLAPI void APIENTRY glMultiTexCoord3i(GLenum target, GLint s, GLint t, GLint r);
GLAPI void APIENTRY glMultiTexCoord3iv(GLenum target, const GLint *v);
GLAPI void APIENTRY glMultiTexCoord3s(GLenum target, GLshort s, GLshort t, GLshort r);
GLAPI void APIENTRY glMultiTexCoord3sv(GLenum target, const GLshort *v);
GLAPI void APIENTRY glMultiTexCoord4d(GLenum target, GLdouble s, GLdouble t, GLdouble r, GLdouble q);
GLAPI void APIENTRY glMultiTexCoord4dv(GLenum target, const GLdouble *v);
GLAPI void APIENTRY glMultiTexCoord4f(GLenum target, GLfloat s, GLfloat t, GLfloat r, GLfloat q);
GLAPI void APIENTRY glMultiTexCoord4fv(GLenum target, const GLfloat *v);
GLAPI void APIENTRY glMultiTexCoord4i(GLenum target, GLint s, GLint t, GLint r, GLint q);
GLAPI void APIENTRY glMultiTexCoord4iv(GLenum target, const GLint *v);
GLAPI void APIENTRY glMultiTexCoord4s(GLenum target, GLshort s, GLshort t, GLshort r, GLshort q);
GLAPI void APIENTRY glMultiTexCoord4sv(GLenum target, const GLshort *v);
GLAPI void APIENTRY glMultiTexCoordP1ui(GLenum texture, GLenum type, GLuint coords);
GLAPI void APIENTRY glMultiTexCoordP1uiv(GLenum texture, GLenum type, const GLuint *coords);
GLAPI void APIENTRY glMultiTexCoordP2ui(GLenum texture, GLenum type, GLuint coords);
GLAPI void APIENTRY glMultiTexCoordP2uiv(GLenum texture, GLenum type, const GLuint *coords);
GLAPI void APIENTRY glMultiTexCoordP3ui(GLenum texture, GLenum type, GLuint coords);
GLAPI void APIENTRY glMultiTexCoordP3uiv(GLenum texture, GLenum type, const GLuint *coords);
GLAPI void APIENTRY glMultiTexCoordP4ui(GLenum texture, GLenum type, GLuint coords);
GLAPI void APIENTRY glMultiTexCoordP4uiv(GLenum texture, GLenum type, const GLuint *coords);
GLAPI void APIENTRY glNamedBufferData(GLuint buffer, GLsizeiptr size, const void *data, GLenum usage);
GLAPI void APIENTRY glNamedBufferStorage(GLuint buffer, GLsizeiptr size, const void *data, GLbitfield flags);
GLAPI void APIENTRY glNamedBufferSubData(GLuint buffer, GLintptr offset, GLsizeiptr size, const void *data);
GLAPI void APIENTRY glNamedFramebufferDrawBuffer(GLuint framebuffer, GLenum buf);
GLAPI void APIENTRY glNamedFramebufferDrawBuffers(GLuint framebuffer, GLsizei n, const GLenum *bufs);
GLAPI void APIENTRY glNamedFramebufferParameteri(GLuint framebuffer, GLenum pname, GLint param);
GLAPI void APIENTRY glNamedFramebufferReadBuffer(GLuint framebuffer, GLenum src);
GLAPI void APIENTRY glNamedFramebufferRenderbuffer(GLuint framebuffer, GLenum attachment, GLenum renderbuffertarget, GLuint renderbuffer);
GLAPI void APIENTRY glNamedFramebufferTexture(GLuint framebuffer, GLenum attachment, GLuint texture, GLint level);
GLAPI void APIENTRY glNamedFramebufferTextureLayer(GLuint framebuffer, GLenum attachment, GLuint texture, GLint level, GLint layer);
GLAPI void APIENTRY glNamedRenderbufferStorage(GLuint renderbuffer, GLenum internalformat, GLsizei width, GLsizei height);
GLAPI void APIENTRY glNamedRenderbufferStorageMultisample(GLuint renderbuffer, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height);
GLAPI void APIENTRY glNewList(GLuint list, GLenum mode);
GLAPI void APIENTRY glNormal3b(GLbyte nx, GLbyte ny, GLbyte nz);
GLAPI void APIENTRY glNormal3bv(const GLbyte *v);
GLAPI void APIENTRY glNormal3d(GLdouble nx, GLdouble ny, GLdouble nz);
GLAPI void APIENTRY glNormal3dv(const GLdouble *v);
GLAPI void APIENTRY glNormal3f(GLfloat nx, GLfloat ny, GLfloat nz);
GLAPI void APIENTRY glNormal3fv(const GLfloat *v);
GLAPI void APIENTRY glNormal3i(GLint nx, GLint ny, GLint nz);
GLAPI void APIENTRY glNormal3iv(const GLint *v);
GLAPI void APIENTRY glNormal3s(GLshort nx, GLshort ny, GLshort nz);
GLAPI void APIENTRY glNormal3sv(const GLshort *v);
GLAPI void APIENTRY glNormalP3ui(GLenum type, GLuint coords);
GLAPI void APIENTRY glNormalP3uiv(GLenum type, const GLuint *coords);
GLAPI void APIENTRY glNormalPointer(GLenum type, GLsizei stride, const void *pointer);
GLAPI void APIENTRY glObjectLabel(GLenum identifier, GLuint name, GLsizei length, const GLchar *label);
GLAPI void APIENTRY glObjectPtrLabel(const void *ptr, GLsizei length, const GLchar *label);
GLAPI void APIENTRY glOrtho(GLdouble left, GLdouble right, GLdouble bottom, GLdouble top, GLdouble zNear, GLdouble zFar);
GLAPI void APIENTRY glPassThrough(GLfloat token);
GLAPI void APIENTRY glPatchParameterfv(GLenum pname, const GLfloat *values);
GLAPI void APIENTRY glPatchParameteri(GLenum pname, GLint value);
GLAPI void APIENTRY glPauseTransformFeedback(void);
GLAPI void APIENTRY glPixelMapfv(GLenum map, GLsizei mapsize, const GLfloat *values);
GLAPI void APIENTRY glPixelMapuiv(GLenum map, GLsizei mapsize, const GLuint *values);
GLAPI void APIENTRY glPixelMapusv(GLenum map, GLsizei mapsize, const GLushort *values);
GLAPI void APIENTRY glPixelStoref(GLenum pname, GLfloat param);
GLAPI void APIENTRY glPixelStorei(GLenum pname, GLint param);
GLAPI void APIENTRY glPixelTransferf(GLenum pname, GLfloat param);
GLAPI void APIENTRY glPixelTransferi(GLenum pname, GLint param);
GLAPI void APIENTRY glPixelZoom(GLfloat xfactor, GLfloat yfactor);
GLAPI void APIENTRY glPointParameterf(GLenum pname, GLfloat param);
GLAPI void APIENTRY glPointParameterfv(GLenum pname, const GLfloat *params);
GLAPI void APIENTRY glPointParameteri(GLenum pname, GLint param);
GLAPI void APIENTRY glPointParameteriv(GLenum pname, const GLint *params);
GLAPI void APIENTRY glPointSize(GLfloat size);
GLAPI void APIENTRY glPolygonMode(GLenum face, GLenum mode);
GLAPI void APIENTRY glPolygonOffset(GLfloat factor, GLfloat units);
GLAPI void APIENTRY glPolygonStipple(const GLubyte *mask);
GLAPI void APIENTRY glPopAttrib(void);
GLAPI void APIENTRY glPopClientAttrib(void);
GLAPI void APIENTRY glPopDebugGroup(void);
GLAPI void APIENTRY glPopMatrix(void);
GLAPI void APIENTRY glPopName(void);
GLAPI void APIENTRY glPrimitiveRestartIndex(GLuint index);
GLAPI void APIENTRY glPrioritizeTextures(GLsizei n, const GLuint *textures, const GLfloat *priorities);
GLAPI void APIENTRY glProgramBinary(GLuint program, GLenum binaryFormat, const void *binary, GLsizei length);
GLAPI void APIENTRY glProgramParameteri(GLuint program, GLenum pname, GLint value);
GLAPI void APIENTRY glProgramUniform1d(GLuint program, GLint location, GLdouble v0);
GLAPI void APIENTRY glProgramUniform1dv(GLuint program, GLint location, GLsizei count, const GLdouble *value);
GLAPI void APIENTRY glProgramUniform1f(GLuint program, GLint location, GLfloat v0);
GLAPI void APIENTRY glProgramUniform1fv(GLuint program, GLint location, GLsizei count, const GLfloat *value);
GLAPI void APIENTRY glProgramUniform1i(GLuint program, GLint location, GLint v0);
GLAPI void APIENTRY glProgramUniform1iv(GLuint program, GLint location, GLsizei count, const GLint *value);
GLAPI void APIENTRY glProgramUniform1ui(GLuint program, GLint location, GLuint v0);
GLAPI void APIENTRY glProgramUniform1uiv(GLuint program, GLint location, GLsizei count, const GLuint *value);
GLAPI void APIENTRY glProgramUniform2d(GLuint program, GLint location, GLdouble v0, GLdouble v1);
GLAPI void APIENTRY glProgramUniform2dv(GLuint program, GLint location, GLsizei count, const GLdouble *value);
GLAPI void APIENTRY glProgramUniform2f(GLuint program, GLint location, GLfloat v0, GLfloat v1);
GLAPI void APIENTRY glProgramUniform2fv(GLuint program, GLint location, GLsizei count, const GLfloat *value);
GLAPI void APIENTRY glProgramUniform2i(GLuint program, GLint location, GLint v0, GLint v1);
GLAPI void APIENTRY glProgramUniform2iv(GLuint program, GLint location, GLsizei count, const GLint *value);
GLAPI void APIENTRY glProgramUniform2ui(GLuint program, GLint location, GLuint v0, GLuint v1);
GLAPI void APIENTRY glProgramUniform2uiv(GLuint program, GLint location, GLsizei count, const GLuint *value);
GLAPI void APIENTRY glProgramUniform3d(GLuint program, GLint location, GLdouble v0, GLdouble v1, GLdouble v2);
GLAPI void APIENTRY glProgramUniform3dv(GLuint program, GLint location, GLsizei count, const GLdouble *value);
GLAPI void APIENTRY glProgramUniform3f(GLuint program, GLint location, GLfloat v0, GLfloat v1, GLfloat v2);
GLAPI void APIENTRY glProgramUniform3fv(GLuint program, GLint location, GLsizei count, const GLfloat *value);
GLAPI void APIENTRY glProgramUniform3i(GLuint program, GLint location, GLint v0, GLint v1, GLint v2);
GLAPI void APIENTRY glProgramUniform3iv(GLuint program, GLint location, GLsizei count, const GLint *value);
GLAPI void APIENTRY glProgramUniform3ui(GLuint program, GLint location, GLuint v0, GLuint v1, GLuint v2);
GLAPI void APIENTRY glProgramUniform3uiv(GLuint program, GLint location, GLsizei count, const GLuint *value);
GLAPI void APIENTRY glProgramUniform4d(GLuint program, GLint location, GLdouble v0, GLdouble v1, GLdouble v2, GLdouble v3);
GLAPI void APIENTRY glProgramUniform4dv(GLuint program, GLint location, GLsizei count, const GLdouble *value);
GLAPI void APIENTRY glProgramUniform4f(GLuint program, GLint location, GLfloat v0, GLfloat v1, GLfloat v2, GLfloat v3);
GLAPI void APIENTRY glProgramUniform4fv(GLuint program, GLint location, GLsizei count, const GLfloat *value);
GLAPI void APIENTRY glProgramUniform4i(GLuint program, GLint location, GLint v0, GLint v1, GLint v2, GLint v3);
GLAPI void APIENTRY glProgramUniform4iv(GLuint program, GLint location, GLsizei count, const GLint *value);
GLAPI void APIENTRY glProgramUniform4ui(GLuint program, GLint location, GLuint v0, GLuint v1, GLuint v2, GLuint v3);
GLAPI void APIENTRY glProgramUniform4uiv(GLuint program, GLint location, GLsizei count, const GLuint *value);
GLAPI void APIENTRY glProgramUniformMatrix2dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value);
GLAPI void APIENTRY glProgramUniformMatrix2fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value);
GLAPI void APIENTRY glProgramUniformMatrix2x3dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value);
GLAPI void APIENTRY glProgramUniformMatrix2x3fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value);
GLAPI void APIENTRY glProgramUniformMatrix2x4dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value);
GLAPI void APIENTRY glProgramUniformMatrix2x4fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value);
GLAPI void APIENTRY glProgramUniformMatrix3dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value);
GLAPI void APIENTRY glProgramUniformMatrix3fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value);
GLAPI void APIENTRY glProgramUniformMatrix3x2dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value);
GLAPI void APIENTRY glProgramUniformMatrix3x2fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value);
GLAPI void APIENTRY glProgramUniformMatrix3x4dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value);
GLAPI void APIENTRY glProgramUniformMatrix3x4fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value);
GLAPI void APIENTRY glProgramUniformMatrix4dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value);
GLAPI void APIENTRY glProgramUniformMatrix4fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value);
GLAPI void APIENTRY glProgramUniformMatrix4x2dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value);
GLAPI void APIENTRY glProgramUniformMatrix4x2fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value);
GLAPI void APIENTRY glProgramUniformMatrix4x3dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value);
GLAPI void APIENTRY glProgramUniformMatrix4x3fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value);
GLAPI void APIENTRY glProvokingVertex(GLenum mode);
GLAPI void APIENTRY glPushAttrib(GLbitfield mask);
GLAPI void APIENTRY glPushClientAttrib(GLbitfield mask);
GLAPI void APIENTRY glPushDebugGroup(GLenum source, GLuint id, GLsizei length, const GLchar *message);
GLAPI void APIENTRY glPushMatrix(void);
GLAPI void APIENTRY glPushName(GLuint name);
GLAPI void APIENTRY glQueryCounter(GLuint id, GLenum target);
GLAPI void APIENTRY glRasterPos2d(GLdouble x, GLdouble y);
GLAPI void APIENTRY glRasterPos2dv(const GLdouble *v);
GLAPI void APIENTRY glRasterPos2f(GLfloat x, GLfloat y);
GLAPI void APIENTRY glRasterPos2fv(const GLfloat *v);
GLAPI void APIENTRY glRasterPos2i(GLint x, GLint y);
GLAPI void APIENTRY glRasterPos2iv(const GLint *v);
GLAPI void APIENTRY glRasterPos2s(GLshort x, GLshort y);
GLAPI void APIENTRY glRasterPos2sv(const GLshort *v);
GLAPI void APIENTRY glRasterPos3d(GLdouble x, GLdouble y, GLdouble z);
GLAPI void APIENTRY glRasterPos3dv(const GLdouble *v);
GLAPI void APIENTRY glRasterPos3f(GLfloat x, GLfloat y, GLfloat z);
GLAPI void APIENTRY glRasterPos3fv(const GLfloat *v);
GLAPI void APIENTRY glRasterPos3i(GLint x, GLint y, GLint z);
GLAPI void APIENTRY glRasterPos3iv(const GLint *v);
GLAPI void APIENTRY glRasterPos3s(GLshort x, GLshort y, GLshort z);
GLAPI void APIENTRY glRasterPos3sv(const GLshort *v);
GLAPI void APIENTRY glRasterPos4d(GLdouble x, GLdouble y, GLdouble z, GLdouble w);
GLAPI void APIENTRY glRasterPos4dv(const GLdouble *v);
GLAPI void APIENTRY glRasterPos4f(GLfloat x, GLfloat y, GLfloat z, GLfloat w);
GLAPI void APIENTRY glRasterPos4fv(const GLfloat *v);
GLAPI void APIENTRY glRasterPos4i(GLint x, GLint y, GLint z, GLint w);
GLAPI void APIENTRY glRasterPos4iv(const GLint *v);
GLAPI void APIENTRY glRasterPos4s(GLshort x, GLshort y, GLshort z, GLshort w);
GLAPI void APIENTRY glRasterPos4sv(const GLshort *v);
GLAPI void APIENTRY glReadBuffer(GLenum src);
GLAPI void APIENTRY glReadPixels(GLint x, GLint y, GLsizei width, GLsizei height, GLenum format, GLenum type, void *pixels);
GLAPI void APIENTRY glReadnPixels(GLint x, GLint y, GLsizei width, GLsizei height, GLenum format, GLenum type, GLsizei bufSize, void *data);
GLAPI void APIENTRY glRectd(GLdouble x1, GLdouble y1, GLdouble x2, GLdouble y2);
GLAPI void APIENTRY glRectdv(const GLdouble *v1, const GLdouble *v2);
GLAPI void APIENTRY glRectf(GLfloat x1, GLfloat y1, GLfloat x2, GLfloat y2);
GLAPI void APIENTRY glRectfv(const GLfloat *v1, const GLfloat *v2);
GLAPI void APIENTRY glRecti(GLint x1, GLint y1, GLint x2, GLint y2);
GLAPI void APIENTRY glRectiv(const GLint *v1, const GLint *v2);
GLAPI void APIENTRY glRects(GLshort x1, GLshort y1, GLshort x2, GLshort y2);
GLAPI void APIENTRY glRectsv(const GLshort *v1, const GLshort *v2);
GLAPI void APIENTRY glReleaseShaderCompiler(void);
GLAPI GLint APIENTRY glRenderMode(GLenum mode);
GLAPI void APIENTRY glRenderbufferStorage(GLenum target, GLenum internalformat, GLsizei width, GLsizei height);
GLAPI void APIENTRY glRenderbufferStorageMultisample(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height);
GLAPI void APIENTRY glResumeTransformFeedback(void);
GLAPI void APIENTRY glRotated(GLdouble angle, GLdouble x, GLdouble y, GLdouble z);
GLAPI void APIENTRY glRotatef(GLfloat angle, GLfloat x, GLfloat y, GLfloat z);
GLAPI void APIENTRY glSampleCoverage(GLfloat value, GLboolean invert);
GLAPI void APIENTRY glSampleMaski(GLuint maskNumber, GLbitfield mask);
GLAPI void APIENTRY glSamplerParameterIiv(GLuint sampler, GLenum pname, const GLint *param);
GLAPI void APIENTRY glSamplerParameterIuiv(GLuint sampler, GLenum pname, const GLuint *param);
GLAPI void APIENTRY glSamplerParameterf(GLuint sampler, GLenum pname, GLfloat param);
GLAPI void APIENTRY glSamplerParameterfv(GLuint sampler, GLenum pname, const GLfloat *param);
GLAPI void APIENTRY glSamplerParameteri(GLuint sampler, GLenum pname, GLint param);
GLAPI void APIENTRY glSamplerParameteriv(GLuint sampler, GLenum pname, const GLint *param);
GLAPI void APIENTRY glScaled(GLdouble x, GLdouble y, GLdouble z);
GLAPI void APIENTRY glScalef(GLfloat x, GLfloat y, GLfloat z);
GLAPI void APIENTRY glScissor(GLint x, GLint y, GLsizei width, GLsizei height);
GLAPI void APIENTRY glScissorArrayv(GLuint first, GLsizei count, const GLint *v);
GLAPI void APIENTRY glScissorIndexed(GLuint index, GLint left, GLint bottom, GLsizei width, GLsizei height);
GLAPI void APIENTRY glScissorIndexedv(GLuint index, const GLint *v);
GLAPI void APIENTRY glSecondaryColor3b(GLbyte red, GLbyte green, GLbyte blue);
GLAPI void APIENTRY glSecondaryColor3bv(const GLbyte *v);
GLAPI void APIENTRY glSecondaryColor3d(GLdouble red, GLdouble green, GLdouble blue);
GLAPI void APIENTRY glSecondaryColor3dv(const GLdouble *v);
GLAPI void APIENTRY glSecondaryColor3f(GLfloat red, GLfloat green, GLfloat blue);
GLAPI void APIENTRY glSecondaryColor3fv(const GLfloat *v);
GLAPI void APIENTRY glSecondaryColor3i(GLint red, GLint green, GLint blue);
GLAPI void APIENTRY glSecondaryColor3iv(const GLint *v);
GLAPI void APIENTRY glSecondaryColor3s(GLshort red, GLshort green, GLshort blue);
GLAPI void APIENTRY glSecondaryColor3sv(const GLshort *v);
GLAPI void APIENTRY glSecondaryColor3ub(GLubyte red, GLubyte green, GLubyte blue);
GLAPI void APIENTRY glSecondaryColor3ubv(const GLubyte *v);
GLAPI void APIENTRY glSecondaryColor3ui(GLuint red, GLuint green, GLuint blue);
GLAPI void APIENTRY glSecondaryColor3uiv(const GLuint *v);
GLAPI void APIENTRY glSecondaryColor3us(GLushort red, GLushort green, GLushort blue);
GLAPI void APIENTRY glSecondaryColor3usv(const GLushort *v);
GLAPI void APIENTRY glSecondaryColorP3ui(GLenum type, GLuint color);
GLAPI void APIENTRY glSecondaryColorP3uiv(GLenum type, const GLuint *color);
GLAPI void APIENTRY glSecondaryColorPointer(GLint size, GLenum type, GLsizei stride, const void *pointer);
GLAPI void APIENTRY glSelectBuffer(GLsizei size, GLuint *buffer);
GLAPI void APIENTRY glShadeModel(GLenum mode);
GLAPI void APIENTRY glShaderBinary(GLsizei count, const GLuint *shaders, GLenum binaryFormat, const void *binary, GLsizei length);
GLAPI void APIENTRY glShaderSource(GLuint shader, GLsizei count, const GLchar *const *string, const GLint *length);
GLAPI void APIENTRY glShaderStorageBlockBinding(GLuint program, GLuint storageBlockIndex, GLuint storageBlockBinding);
GLAPI void APIENTRY glStencilFunc(GLenum func, GLint ref, GLuint mask);
GLAPI void APIENTRY glStencilFuncSeparate(GLenum face, GLenum func, GLint ref, GLuint mask);
GLAPI void APIENTRY glStencilMask(GLuint mask);
GLAPI void APIENTRY glStencilMaskSeparate(GLenum face, GLuint mask);
GLAPI void APIENTRY glStencilOp(GLenum fail, GLenum zfail, GLenum zpass);
GLAPI void APIENTRY glStencilOpSeparate(GLenum face, GLenum sfail, GLenum dpfail, GLenum dppass);
GLAPI void APIENTRY glTexBuffer(GLenum target, GLenum internalformat, GLuint buffer);
GLAPI void APIENTRY glTexBufferRange(GLenum target, GLenum internalformat, GLuint buffer, GLintptr offset, GLsizeiptr size);
GLAPI void APIENTRY glTexCoord1d(GLdouble s);
GLAPI void APIENTRY glTexCoord1dv(const GLdouble *v);
GLAPI void APIENTRY glTexCoord1f(GLfloat s);
GLAPI void APIENTRY glTexCoord1fv(const GLfloat *v);
GLAPI void APIENTRY glTexCoord1i(GLint s);
GLAPI void APIENTRY glTexCoord1iv(const GLint *v);
GLAPI void APIENTRY glTexCoord1s(GLshort s);
GLAPI void APIENTRY glTexCoord1sv(const GLshort *v);
GLAPI void APIENTRY glTexCoord2d(GLdouble s, GLdouble t);
GLAPI void APIENTRY glTexCoord2dv(const GLdouble *v);
GLAPI void APIENTRY glTexCoord2f(GLfloat s, GLfloat t);
GLAPI void APIENTRY glTexCoord2fv(const GLfloat *v);
GLAPI void APIENTRY glTexCoord2i(GLint s, GLint t);
GLAPI void APIENTRY glTexCoord2iv(const GLint *v);
GLAPI void APIENTRY glTexCoord2s(GLshort s, GLshort t);
GLAPI void APIENTRY glTexCoord2sv(const GLshort *v);
GLAPI void APIENTRY glTexCoord3d(GLdouble s, GLdouble t, GLdouble r);
GLAPI void APIENTRY glTexCoord3dv(const GLdouble *v);
GLAPI void APIENTRY glTexCoord3f(GLfloat s, GLfloat t, GLfloat r);
GLAPI void APIENTRY glTexCoord3fv(const GLfloat *v);
GLAPI void APIENTRY glTexCoord3i(GLint s, GLint t, GLint r);
GLAPI void APIENTRY glTexCoord3iv(const GLint *v);
GLAPI void APIENTRY glTexCoord3s(GLshort s, GLshort t, GLshort r);
GLAPI void APIENTRY glTexCoord3sv(const GLshort *v);
GLAPI void APIENTRY glTexCoord4d(GLdouble s, GLdouble t, GLdouble r, GLdouble q);
GLAPI void APIENTRY glTexCoord4dv(const GLdouble *v);
GLAPI void APIENTRY glTexCoord4f(GLfloat s, GLfloat t, GLfloat r, GLfloat q);
GLAPI void APIENTRY glTexCoord4fv(const GLfloat *v);
GLAPI void APIENTRY glTexCoord4i(GLint s, GLint t, GLint r, GLint q);
GLAPI void APIENTRY glTexCoord4iv(const GLint *v);
GLAPI void APIENTRY glTexCoord4s(GLshort s, GLshort t, GLshort r, GLshort q);
GLAPI void APIENTRY glTexCoord4sv(const GLshort *v);
GLAPI void APIENTRY glTexCoordP1ui(GLenum type, GLuint coords);
GLAPI void APIENTRY glTexCoordP1uiv(GLenum type, const GLuint *coords);
GLAPI void APIENTRY glTexCoordP2ui(GLenum type, GLuint coords);
GLAPI void APIENTRY glTexCoordP2uiv(GLenum type, const GLuint *coords);
GLAPI void APIENTRY glTexCoordP3ui(GLenum type, GLuint coords);
GLAPI void APIENTRY glTexCoordP3uiv(GLenum type, const GLuint *coords);
GLAPI void APIENTRY glTexCoordP4ui(GLenum type, GLuint coords);
GLAPI void APIENTRY glTexCoordP4uiv(GLenum type, const GLuint *coords);
GLAPI void APIENTRY glTexCoordPointer(GLint size, GLenum type, GLsizei stride, const void *pointer);
GLAPI void APIENTRY glTexEnvf(GLenum target, GLenum pname, GLfloat param);
GLAPI void APIENTRY glTexEnvfv(GLenum target, GLenum pname, const GLfloat *params);
GLAPI void APIENTRY glTexEnvi(GLenum target, GLenum pname, GLint param);
GLAPI void APIENTRY glTexEnviv(GLenum target, GLenum pname, const GLint *params);
GLAPI void APIENTRY glTexGend(GLenum coord, GLenum pname, GLdouble param);
GLAPI void APIENTRY glTexGendv(GLenum coord, GLenum pname, const GLdouble *params);
GLAPI void APIENTRY glTexGenf(GLenum coord, GLenum pname, GLfloat param);
GLAPI void APIENTRY glTexGenfv(GLenum coord, GLenum pname, const GLfloat *params);
GLAPI void APIENTRY glTexGeni(GLenum coord, GLenum pname, GLint param);
GLAPI void APIENTRY glTexGeniv(GLenum coord, GLenum pname, const GLint *params);
GLAPI void APIENTRY glTexImage1D(GLenum target, GLint level, GLint internalformat, GLsizei width, GLint border, GLenum format, GLenum type, const void *pixels);
GLAPI void APIENTRY glTexImage2D(GLenum target, GLint level, GLint internalformat, GLsizei width, GLsizei height, GLint border, GLenum format, GLenum type, const void *pixels);
GLAPI void APIENTRY glTexImage2DMultisample(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLboolean fixedsamplelocations);
GLAPI void APIENTRY glTexImage3D(GLenum target, GLint level, GLint internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLenum format, GLenum type, const void *pixels);
GLAPI void APIENTRY glTexImage3DMultisample(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedsamplelocations);
GLAPI void APIENTRY glTexParameterIiv(GLenum target, GLenum pname, const GLint *params);
GLAPI void APIENTRY glTexParameterIuiv(GLenum target, GLenum pname, const GLuint *params);
GLAPI void APIENTRY glTexParameterf(GLenum target, GLenum pname, GLfloat param);
GLAPI void APIENTRY glTexParameterfv(GLenum target, GLenum pname, const GLfloat *params);
GLAPI void APIENTRY glTexParameteri(GLenum target, GLenum pname, GLint param);
GLAPI void APIENTRY glTexParameteriv(GLenum target, GLenum pname, const GLint *params);
GLAPI void APIENTRY glTexStorage1D(GLenum target, GLsizei levels, GLenum internalformat, GLsizei width);
GLAPI void APIENTRY glTexStorage2D(GLenum target, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height);
GLAPI void APIENTRY glTexStorage2DMultisample(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLboolean fixedsamplelocations);
GLAPI void APIENTRY glTexStorage3D(GLenum target, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth);
GLAPI void APIENTRY glTexStorage3DMultisample(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedsamplelocations);
GLAPI void APIENTRY glTexSubImage1D(GLenum target, GLint level, GLint xoffset, GLsizei width, GLenum format, GLenum type, const void *pixels);
GLAPI void APIENTRY glTexSubImage2D(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLenum type, const void *pixels);
GLAPI void APIENTRY glTexSubImage3D(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void *pixels);
GLAPI void APIENTRY glTextureBarrier(void);
GLAPI void APIENTRY glTextureBuffer(GLuint texture, GLenum internalformat, GLuint buffer);
GLAPI void APIENTRY glTextureBufferRange(GLuint texture, GLenum internalformat, GLuint buffer, GLintptr offset, GLsizeiptr size);
GLAPI void APIENTRY glTextureParameterIiv(GLuint texture, GLenum pname, const GLint *params);
GLAPI void APIENTRY glTextureParameterIuiv(GLuint texture, GLenum pname, const GLuint *params);
GLAPI void APIENTRY glTextureParameterf(GLuint texture, GLenum pname, GLfloat param);
GLAPI void APIENTRY glTextureParameterfv(GLuint texture, GLenum pname, const GLfloat *param);
GLAPI void APIENTRY glTextureParameteri(GLuint texture, GLenum pname, GLint param);
GLAPI void APIENTRY glTextureParameteriv(GLuint texture, GLenum pname, const GLint *param);
GLAPI void APIENTRY glTextureStorage1D(GLuint texture, GLsizei levels, GLenum internalformat, GLsizei width);
GLAPI void APIENTRY glTextureStorage2D(GLuint texture, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height);
GLAPI void APIENTRY glTextureStorage2DMultisample(GLuint texture, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLboolean fixedsamplelocations);
GLAPI void APIENTRY glTextureStorage3D(GLuint texture, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth);
GLAPI void APIENTRY glTextureStorage3DMultisample(GLuint texture, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedsamplelocations);
GLAPI void APIENTRY glTextureSubImage1D(GLuint texture, GLint level, GLint xoffset, GLsizei width, GLenum format, GLenum type, const void *pixels);
GLAPI void APIENTRY glTextureSubImage2D(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLenum type, const void *pixels);
GLAPI void APIENTRY glTextureSubImage3D(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void *pixels);
GLAPI void APIENTRY glTextureView(GLuint texture, GLenum target, GLuint origtexture, GLenum internalformat, GLuint minlevel, GLuint numlevels, GLuint minlayer, GLuint numlayers);
GLAPI void APIENTRY glTransformFeedbackBufferBase(GLuint xfb, GLuint index, GLuint buffer);
GLAPI void APIENTRY glTransformFeedbackBufferRange(GLuint xfb, GLuint index, GLuint buffer, GLintptr offset, GLsizeiptr size);
GLAPI void APIENTRY glTransformFeedbackVaryings(GLuint program, GLsizei count, const GLchar *const *varyings, GLenum bufferMode);
GLAPI void APIENTRY glTranslated(GLdouble x, GLdouble y, GLdouble z);
GLAPI void APIENTRY glTranslatef(GLfloat x, GLfloat y, GLfloat z);
GLAPI void APIENTRY glUniform1d(GLint location, GLdouble x);
GLAPI void APIENTRY glUniform1dv(GLint location, GLsizei count, const GLdouble *value);
GLAPI void APIENTRY glUniform1f(GLint location, GLfloat v0);
GLAPI void APIENTRY glUniform1fv(GLint location, GLsizei count, const GLfloat *value);
GLAPI void APIENTRY glUniform1i(GLint location, GLint v0);
GLAPI void APIENTRY glUniform1iv(GLint location, GLsizei count, const GLint *value);
GLAPI void APIENTRY glUniform1ui(GLint location, GLuint v0);
GLAPI void APIENTRY glUniform1uiv(GLint location, GLsizei count, const GLuint *value);
GLAPI void APIENTRY glUniform2d(GLint location, GLdouble x, GLdouble y);
GLAPI void APIENTRY glUniform2dv(GLint location, GLsizei count, const GLdouble *value);
GLAPI void APIENTRY glUniform2f(GLint location, GLfloat v0, GLfloat v1);
GLAPI void APIENTRY glUniform2fv(GLint location, GLsizei count, const GLfloat *value);
GLAPI void APIENTRY glUniform2i(GLint location, GLint v0, GLint v1);
GLAPI void APIENTRY glUniform2iv(GLint location, GLsizei count, const GLint *value);
GLAPI void APIENTRY glUniform2ui(GLint location, GLuint v0, GLuint v1);
GLAPI void APIENTRY glUniform2uiv(GLint location, GLsizei count, const GLuint *value);
GLAPI void APIENTRY glUniform3d(GLint location, GLdouble x, GLdouble y, GLdouble z);
GLAPI void APIENTRY glUniform3dv(GLint location, GLsizei count, const GLdouble *value);
GLAPI void APIENTRY glUniform3f(GLint location, GLfloat v0, GLfloat v1, GLfloat v2);
GLAPI void APIENTRY glUniform3fv(GLint location, GLsizei count, const GLfloat *value);
GLAPI void APIENTRY glUniform3i(GLint location, GLint v0, GLint v1, GLint v2);
GLAPI void APIENTRY glUniform3iv(GLint location, GLsizei count, const GLint *value);
GLAPI void APIENTRY glUniform3ui(GLint location, GLuint v0, GLuint v1, GLuint v2);
GLAPI void APIENTRY glUniform3uiv(GLint location, GLsizei count, const GLuint *value);
GLAPI void APIENTRY glUniform4d(GLint location, GLdouble x, GLdouble y, GLdouble z, GLdouble w);
GLAPI void APIENTRY glUniform4dv(GLint location, GLsizei count, const GLdouble *value);
GLAPI void APIENTRY glUniform4f(GLint location, GLfloat v0, GLfloat v1, GLfloat v2, GLfloat v3);
GLAPI void APIENTRY glUniform4fv(GLint location, GLsizei count, const GLfloat *value);
GLAPI void APIENTRY glUniform4i(GLint location, GLint v0, GLint v1, GLint v2, GLint v3);
GLAPI void APIENTRY glUniform4iv(GLint location, GLsizei count, const GLint *value);
GLAPI void APIENTRY glUniform4ui(GLint location, GLuint v0, GLuint v1, GLuint v2, GLuint v3);
GLAPI void APIENTRY glUniform4uiv(GLint location, GLsizei count, const GLuint *value);
GLAPI void APIENTRY glUniformBlockBinding(GLuint program, GLuint uniformBlockIndex, GLuint uniformBlockBinding);
GLAPI void APIENTRY glUniformMatrix2dv(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value);
GLAPI void APIENTRY glUniformMatrix2fv(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value);
GLAPI void APIENTRY glUniformMatrix2x3dv(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value);
GLAPI void APIENTRY glUniformMatrix2x3fv(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value);
GLAPI void APIENTRY glUniformMatrix2x4dv(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value);
GLAPI void APIENTRY glUniformMatrix2x4fv(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value);
GLAPI void APIENTRY glUniformMatrix3dv(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value);
GLAPI void APIENTRY glUniformMatrix3fv(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value);
GLAPI void APIENTRY glUniformMatrix3x2dv(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value);
GLAPI void APIENTRY glUniformMatrix3x2fv(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value);
GLAPI void APIENTRY glUniformMatrix3x4dv(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value);
GLAPI void APIENTRY glUniformMatrix3x4fv(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value);
GLAPI void APIENTRY glUniformMatrix4dv(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value);
GLAPI void APIENTRY glUniformMatrix4fv(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value);
GLAPI void APIENTRY glUniformMatrix4x2dv(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value);
GLAPI void APIENTRY glUniformMatrix4x2fv(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value);
GLAPI void APIENTRY glUniformMatrix4x3dv(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value);
GLAPI void APIENTRY glUniformMatrix4x3fv(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value);
GLAPI void APIENTRY glUniformSubroutinesuiv(GLenum shadertype, GLsizei count, const GLuint *indices);
GLAPI GLboolean APIENTRY glUnmapBuffer(GLenum target);
GLAPI GLboolean APIENTRY glUnmapNamedBuffer(GLuint buffer);
GLAPI void APIENTRY glUseProgram(GLuint program);
GLAPI void APIENTRY glUseProgramStages(GLuint pipeline, GLbitfield stages, GLuint program);
GLAPI void APIENTRY glValidateProgram(GLuint program);
GLAPI void APIENTRY glValidateProgramPipeline(GLuint pipeline);
GLAPI void APIENTRY glVertex2d(GLdouble x, GLdouble y);
GLAPI void APIENTRY glVertex2dv(const GLdouble *v);
GLAPI void APIENTRY glVertex2f(GLfloat x, GLfloat y);
GLAPI void APIENTRY glVertex2fv(const GLfloat *v);
GLAPI void APIENTRY glVertex2i(GLint x, GLint y);
GLAPI void APIENTRY glVertex2iv(const GLint *v);
GLAPI void APIENTRY glVertex2s(GLshort x, GLshort y);
GLAPI void APIENTRY glVertex2sv(const GLshort *v);
GLAPI void APIENTRY glVertex3d(GLdouble x, GLdouble y, GLdouble z);
GLAPI void APIENTRY glVertex3dv(const GLdouble *v);
GLAPI void APIENTRY glVertex3f(GLfloat x, GLfloat y, GLfloat z);
GLAPI void APIENTRY glVertex3fv(const GLfloat *v);
GLAPI void APIENTRY glVertex3i(GLint x, GLint y, GLint z);
GLAPI void APIENTRY glVertex3iv(const GLint *v);
GLAPI void APIENTRY glVertex3s(GLshort x, GLshort y, GLshort z);
GLAPI void APIENTRY glVertex3sv(const GLshort *v);
GLAPI void APIENTRY glVertex4d(GLdouble x, GLdouble y, GLdouble z, GLdouble w);
GLAPI void APIENTRY glVertex4dv(const GLdouble *v);
GLAPI void APIENTRY glVertex4f(GLfloat x, GLfloat y, GLfloat z, GLfloat w);
GLAPI void APIENTRY glVertex4fv(const GLfloat *v);
GLAPI void APIENTRY glVertex4i(GLint x, GLint y, GLint z, GLint w);
GLAPI void APIENTRY glVertex4iv(const GLint *v);
GLAPI void APIENTRY glVertex4s(GLshort x, GLshort y, GLshort z, GLshort w);
GLAPI void APIENTRY glVertex4sv(const GLshort *v);
GLAPI void APIENTRY glVertexArrayAttribBinding(GLuint vaobj, GLuint attribindex, GLuint bindingindex);
GLAPI void APIENTRY glVertexArrayAttribFormat(GLuint vaobj, GLuint attribindex, GLint size, GLenum type, GLboolean normalized, GLuint relativeoffset);
GLAPI void APIENTRY glVertexArrayAttribIFormat(GLuint vaobj, GLuint attribindex, GLint size, GLenum type, GLuint relativeoffset);
GLAPI void APIENTRY glVertexArrayAttribLFormat(GLuint vaobj, GLuint attribindex, GLint size, GLenum type, GLuint relativeoffset);
GLAPI void APIENTRY glVertexArrayBindingDivisor(GLuint vaobj, GLuint bindingindex, GLuint divisor);
GLAPI void APIENTRY glVertexArrayElementBuffer(GLuint vaobj, GLuint buffer);
GLAPI void APIENTRY glVertexArrayVertexBuffer(GLuint vaobj, GLuint bindingindex, GLuint buffer, GLintptr offset, GLsizei stride);
GLAPI void APIENTRY glVertexArrayVertexBuffers(GLuint vaobj, GLuint first, GLsizei count, const GLuint *buffers, const GLintptr *offsets, const GLsizei *strides);
GLAPI void APIENTRY glVertexAttrib1d(GLuint index, GLdouble x);
GLAPI void APIENTRY glVertexAttrib1dv(GLuint index, const GLdouble *v);
GLAPI void APIENTRY glVertexAttrib1f(GLuint index, GLfloat x);
GLAPI void APIENTRY glVertexAttrib1fv(GLuint index, const GLfloat *v);
GLAPI void APIENTRY glVertexAttrib1s(GLuint index, GLshort x);
GLAPI void APIENTRY glVertexAttrib1sv(GLuint index, const GLshort *v);
GLAPI void APIENTRY glVertexAttrib2d(GLuint index, GLdouble x, GLdouble y);
GLAPI void APIENTRY glVertexAttrib2dv(GLuint index, const GLdouble *v);
GLAPI void APIENTRY glVertexAttrib2f(GLuint index, GLfloat x, GLfloat y);
GLAPI void APIENTRY glVertexAttrib2fv(GLuint index, const GLfloat *v);
GLAPI void APIENTRY glVertexAttrib2s(GLuint index, GLshort x, GLshort y);
GLAPI void APIENTRY glVertexAttrib2sv(GLuint index, const GLshort *v);
GLAPI void APIENTRY glVertexAttrib3d(GLuint index, GLdouble x, GLdouble y, GLdouble z);
GLAPI void APIENTRY glVertexAttrib3dv(GLuint index, const GLdouble *v);
GLAPI void APIENTRY glVertexAttrib3f(GLuint index, GLfloat x, GLfloat y, GLfloat z);
GLAPI void APIENTRY glVertexAttrib3fv(GLuint index, const GLfloat *v);
GLAPI void APIENTRY glVertexAttrib3s(GLuint index, GLshort x, GLshort y, GLshort z);
GLAPI void APIENTRY glVertexAttrib3sv(GLuint index, const GLshort *v);
GLAPI void APIENTRY glVertexAttrib4Nbv(GLuint index, const GLbyte *v);
GLAPI void APIENTRY glVertexAttrib4Niv(GLuint index, const GLint *v);
GLAPI void APIENTRY glVertexAttrib4Nsv(GLuint index, const GLshort *v);
GLAPI void APIENTRY glVertexAttrib4Nub(GLuint index, GLubyte x, GLubyte y, GLubyte z, GLubyte w);
GLAPI void APIENTRY glVertexAttrib4Nubv(GLuint index, const GLubyte *v);
GLAPI void APIENTRY glVertexAttrib4Nuiv(GLuint index, const GLuint *v);
GLAPI void APIENTRY glVertexAttrib4Nusv(GLuint index, const GLushort *v);
GLAPI void APIENTRY glVertexAttrib4bv(GLuint index, const GLbyte *v);
GLAPI void APIENTRY glVertexAttrib4d(GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w);
GLAPI void APIENTRY glVertexAttrib4dv(GLuint index, const GLdouble *v);
GLAPI void APIENTRY glVertexAttrib4f(GLuint index, GLfloat x, GLfloat y, GLfloat z, GLfloat w);
GLAPI void APIENTRY glVertexAttrib4fv(GLuint index, const GLfloat *v);
GLAPI void APIENTRY glVertexAttrib4iv(GLuint index, const GLint *v);
GLAPI void APIENTRY glVertexAttrib4s(GLuint index, GLshort x, GLshort y, GLshort z, GLshort w);
GLAPI void APIENTRY glVertexAttrib4sv(GLuint index, const GLshort *v);
GLAPI void APIENTRY glVertexAttrib4ubv(GLuint index, const GLubyte *v);
GLAPI void APIENTRY glVertexAttrib4uiv(GLuint index, const GLuint *v);
GLAPI void APIENTRY glVertexAttrib4usv(GLuint index, const GLushort *v);
GLAPI void APIENTRY glVertexAttribBinding(GLuint attribindex, GLuint bindingindex);
GLAPI void APIENTRY glVertexAttribDivisor(GLuint index, GLuint divisor);
GLAPI void APIENTRY glVertexAttribFormat(GLuint attribindex, GLint size, GLenum type, GLboolean normalized, GLuint relativeoffset);
GLAPI void APIENTRY glVertexAttribI1i(GLuint index, GLint x);
GLAPI void APIENTRY glVertexAttribI1iv(GLuint index, const GLint *v);
GLAPI void APIENTRY glVertexAttribI1ui(GLuint index, GLuint x);
GLAPI void APIENTRY glVertexAttribI1uiv(GLuint index, const GLuint *v);
GLAPI void APIENTRY glVertexAttribI2i(GLuint index, GLint x, GLint y);
GLAPI void APIENTRY glVertexAttribI2iv(GLuint index, const GLint *v);
GLAPI void APIENTRY glVertexAttribI2ui(GLuint index, GLuint x, GLuint y);
GLAPI void APIENTRY glVertexAttribI2uiv(GLuint index, const GLuint *v);
GLAPI void APIENTRY glVertexAttribI3i(GLuint index, GLint x, GLint y, GLint z);
GLAPI void APIENTRY glVertexAttribI3iv(GLuint index, const GLint *v);
GLAPI void APIENTRY glVertexAttribI3ui(GLuint index, GLuint x, GLuint y, GLuint z);
GLAPI void APIENTRY glVertexAttribI3uiv(GLuint index, const GLuint *v);
GLAPI void APIENTRY glVertexAttribI4bv(GLuint index, const GLbyte *v);
GLAPI void APIENTRY glVertexAttribI4i(GLuint index, GLint x, GLint y, GLint z, GLint w);
GLAPI void APIENTRY glVertexAttribI4iv(GLuint index, const GLint *v);
GLAPI void APIENTRY glVertexAttribI4sv(GLuint index, const GLshort *v);
GLAPI void APIENTRY glVertexAttribI4ubv(GLuint index, const GLubyte *v);
GLAPI void APIENTRY glVertexAttribI4ui(GLuint index, GLuint x, GLuint y, GLuint z, GLuint w);
GLAPI void APIENTRY glVertexAttribI4uiv(GLuint index, const GLuint *v);
GLAPI void APIENTRY glVertexAttribI4usv(GLuint index, const GLushort *v);
GLAPI void APIENTRY glVertexAttribIFormat(GLuint attribindex, GLint size, GLenum type, GLuint relativeoffset);
GLAPI void APIENTRY glVertexAttribIPointer(GLuint index, GLint size, GLenum type, GLsizei stride, const void *pointer);
GLAPI void APIENTRY glVertexAttribL1d(GLuint index, GLdouble x);
GLAPI void APIENTRY glVertexAttribL1dv(GLuint index, const GLdouble *v);
GLAPI void APIENTRY glVertexAttribL2d(GLuint index, GLdouble x, GLdouble y);
GLAPI void APIENTRY glVertexAttribL2dv(GLuint index, const GLdouble *v);
GLAPI void APIENTRY glVertexAttribL3d(GLuint index, GLdouble x, GLdouble y, GLdouble z);
GLAPI void APIENTRY glVertexAttribL3dv(GLuint index, const GLdouble *v);
GLAPI void APIENTRY glVertexAttribL4d(GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w);
GLAPI void APIENTRY glVertexAttribL4dv(GLuint index, const GLdouble *v);
GLAPI void APIENTRY glVertexAttribLFormat(GLuint attribindex, GLint size, GLenum type, GLuint relativeoffset);
GLAPI void APIENTRY glVertexAttribLPointer(GLuint index, GLint size, GLenum type, GLsizei stride, const void *pointer);
GLAPI void APIENTRY glVertexAttribP1ui(GLuint index, GLenum type, GLboolean normalized, GLuint value);
GLAPI void APIENTRY glVertexAttribP1uiv(GLuint index, GLenum type, GLboolean normalized, const GLuint *value);
GLAPI void APIENTRY glVertexAttribP2ui(GLuint index, GLenum type, GLboolean normalized, GLuint value);
GLAPI void APIENTRY glVertexAttribP2uiv(GLuint index, GLenum type, GLboolean normalized, const GLuint *value);
GLAPI void APIENTRY glVertexAttribP3ui(GLuint index, GLenum type, GLboolean normalized, GLuint value);
GLAPI void APIENTRY glVertexAttribP3uiv(GLuint index, GLenum type, GLboolean normalized, const GLuint *value);
GLAPI void APIENTRY glVertexAttribP4ui(GLuint index, GLenum type, GLboolean normalized, GLuint value);
GLAPI void APIENTRY glVertexAttribP4uiv(GLuint index, GLenum type, GLboolean normalized, const GLuint *value);
GLAPI void APIENTRY glVertexAttribPointer(GLuint index, GLint size, GLenum type, GLboolean normalized, GLsizei stride, const void *pointer);
GLAPI void APIENTRY glVertexBindingDivisor(GLuint bindingindex, GLuint divisor);
GLAPI void APIENTRY glVertexP2ui(GLenum type, GLuint value);
GLAPI void APIENTRY glVertexP2uiv(GLenum type, const GLuint *value);
GLAPI void APIENTRY glVertexP3ui(GLenum type, GLuint value);
GLAPI void APIENTRY glVertexP3uiv(GLenum type, const GLuint *value);
GLAPI void APIENTRY glVertexP4ui(GLenum type, GLuint value);
GLAPI void APIENTRY glVertexP4uiv(GLenum type, const GLuint *value);
GLAPI void APIENTRY glVertexPointer(GLint size, GLenum type, GLsizei stride, const void *pointer);
GLAPI void APIENTRY glViewport(GLint x, GLint y, GLsizei width, GLsizei height);
GLAPI void APIENTRY glViewportArrayv(GLuint first, GLsizei count, const GLfloat *v);
GLAPI void APIENTRY glViewportIndexedf(GLuint index, GLfloat x, GLfloat y, GLfloat w, GLfloat h);
GLAPI void APIENTRY glViewportIndexedfv(GLuint index, const GLfloat *v);
GLAPI void APIENTRY glWaitSync(GLsync sync, GLbitfield flags, GLuint64 timeout);
GLAPI void APIENTRY glWindowPos2d(GLdouble x, GLdouble y);
GLAPI void APIENTRY glWindowPos2dv(const GLdouble *v);
GLAPI void APIENTRY glWindowPos2f(GLfloat x, GLfloat y);
GLAPI void APIENTRY glWindowPos2fv(const GLfloat *v);
GLAPI void APIENTRY glWindowPos2i(GLint x, GLint y);
GLAPI void APIENTRY glWindowPos2iv(const GLint *v);
GLAPI void APIENTRY glWindowPos2s(GLshort x, GLshort y);
GLAPI void APIENTRY glWindowPos2sv(const GLshort *v);
GLAPI void APIENTRY glWindowPos3d(GLdouble x, GLdouble y, GLdouble z);
GLAPI void APIENTRY glWindowPos3dv(const GLdouble *v);
GLAPI void APIENTRY glWindowPos3f(GLfloat x, GLfloat y, GLfloat z);
GLAPI void APIENTRY glWindowPos3fv(const GLfloat *v);
GLAPI void APIENTRY glWindowPos3i(GLint x, GLint y, GLint z);
GLAPI void APIENTRY glWindowPos3iv(const GLint *v);
GLAPI void APIENTRY glWindowPos3s(GLshort x, GLshort y, GLshort z);
GLAPI void APIENTRY glWindowPos3sv(const GLshort *v);
#undef MAPI_TMP_DEFINES
#endif /* MAPI_TMP_DEFINES */

#ifdef MAPI_TMP_TABLE
#define MAPI_TABLE_NUM_STATIC 3352
#define MAPI_TABLE_NUM_DYNAMIC 4096
#undef MAPI_TMP_TABLE
#endif /* MAPI_TMP_TABLE */

#ifdef MAPI_TMP_NOOP_ARRAY
#ifdef DEBUG

static void APIENTRY noopAccum(GLenum op, GLfloat value)
{
   (void) op; (void) value;
   noop_warn("glAccum");
}

static void APIENTRY noopActiveShaderProgram(GLuint pipeline, GLuint program)
{
   (void) pipeline; (void) program;
   noop_warn("glActiveShaderProgram");
}

static void APIENTRY noopActiveTexture(GLenum texture)
{
   (void) texture;
   noop_warn("glActiveTexture");
}

static void APIENTRY noopAlphaFunc(GLenum func, GLfloat ref)
{
   (void) func; (void) ref;
   noop_warn("glAlphaFunc");
}

static GLboolean APIENTRY noopAreTexturesResident(GLsizei n, const GLuint *textures, GLboolean *residences)
{
   (void) n; (void) textures; (void) residences;
   noop_warn("glAreTexturesResident");
   return (GLboolean) 0;
}

static void APIENTRY noopArrayElement(GLint i)
{
   (void) i;
   noop_warn("glArrayElement");
}

static void APIENTRY noopAttachShader(GLuint program, GLuint shader)
{
   (void) program; (void) shader;
   noop_warn("glAttachShader");
}

static void APIENTRY noopBegin(GLenum mode)
{
   (void) mode;
   noop_warn("glBegin");
}

static void APIENTRY noopBeginConditionalRender(GLuint id, GLenum mode)
{
   (void) id; (void) mode;
   noop_warn("glBeginConditionalRender");
}

static void APIENTRY noopBeginQuery(GLenum target, GLuint id)
{
   (void) target; (void) id;
   noop_warn("glBeginQuery");
}

static void APIENTRY noopBeginQueryIndexed(GLenum target, GLuint index, GLuint id)
{
   (void) target; (void) index; (void) id;
   noop_warn("glBeginQueryIndexed");
}

static void APIENTRY noopBeginTransformFeedback(GLenum primitiveMode)
{
   (void) primitiveMode;
   noop_warn("glBeginTransformFeedback");
}

static void APIENTRY noopBindAttribLocation(GLuint program, GLuint index, const GLchar *name)
{
   (void) program; (void) index; (void) name;
   noop_warn("glBindAttribLocation");
}

static void APIENTRY noopBindBuffer(GLenum target, GLuint buffer)
{
   (void) target; (void) buffer;
   noop_warn("glBindBuffer");
}

static void APIENTRY noopBindBufferBase(GLenum target, GLuint index, GLuint buffer)
{
   (void) target; (void) index; (void) buffer;
   noop_warn("glBindBufferBase");
}

static void APIENTRY noopBindBufferRange(GLenum target, GLuint index, GLuint buffer, GLintptr offset, GLsizeiptr size)
{
   (void) target; (void) index; (void) buffer; (void) offset; (void) size;
   noop_warn("glBindBufferRange");
}

static void APIENTRY noopBindBuffersBase(GLenum target, GLuint first, GLsizei count, const GLuint *buffers)
{
   (void) target; (void) first; (void) count; (void) buffers;
   noop_warn("glBindBuffersBase");
}

static void APIENTRY noopBindBuffersRange(GLenum target, GLuint first, GLsizei count, const GLuint *buffers, const GLintptr *offsets, const GLsizeiptr *sizes)
{
   (void) target; (void) first; (void) count; (void) buffers; (void) offsets; (void) sizes;
   noop_warn("glBindBuffersRange");
}

static void APIENTRY noopBindFragDataLocation(GLuint program, GLuint color, const GLchar *name)
{
   (void) program; (void) color; (void) name;
   noop_warn("glBindFragDataLocation");
}

static void APIENTRY noopBindFragDataLocationIndexed(GLuint program, GLuint colorNumber, GLuint index, const GLchar *name)
{
   (void) program; (void) colorNumber; (void) index; (void) name;
   noop_warn("glBindFragDataLocationIndexed");
}

static void APIENTRY noopBindFramebuffer(GLenum target, GLuint framebuffer)
{
   (void) target; (void) framebuffer;
   noop_warn("glBindFramebuffer");
}

static void APIENTRY noopBindImageTexture(GLuint unit, GLuint texture, GLint level, GLboolean layered, GLint layer, GLenum access, GLenum format)
{
   (void) unit; (void) texture; (void) level; (void) layered; (void) layer; (void) access; (void) format;
   noop_warn("glBindImageTexture");
}

static void APIENTRY noopBindImageTextures(GLuint first, GLsizei count, const GLuint *textures)
{
   (void) first; (void) count; (void) textures;
   noop_warn("glBindImageTextures");
}

static void APIENTRY noopBindProgramPipeline(GLuint pipeline)
{
   (void) pipeline;
   noop_warn("glBindProgramPipeline");
}

static void APIENTRY noopBindRenderbuffer(GLenum target, GLuint renderbuffer)
{
   (void) target; (void) renderbuffer;
   noop_warn("glBindRenderbuffer");
}

static void APIENTRY noopBindSampler(GLuint unit, GLuint sampler)
{
   (void) unit; (void) sampler;
   noop_warn("glBindSampler");
}

static void APIENTRY noopBindSamplers(GLuint first, GLsizei count, const GLuint *samplers)
{
   (void) first; (void) count; (void) samplers;
   noop_warn("glBindSamplers");
}

static void APIENTRY noopBindTexture(GLenum target, GLuint texture)
{
   (void) target; (void) texture;
   noop_warn("glBindTexture");
}

static void APIENTRY noopBindTextureUnit(GLuint unit, GLuint texture)
{
   (void) unit; (void) texture;
   noop_warn("glBindTextureUnit");
}

static void APIENTRY noopBindTextures(GLuint first, GLsizei count, const GLuint *textures)
{
   (void) first; (void) count; (void) textures;
   noop_warn("glBindTextures");
}

static void APIENTRY noopBindTransformFeedback(GLenum target, GLuint id)
{
   (void) target; (void) id;
   noop_warn("glBindTransformFeedback");
}

static void APIENTRY noopBindVertexArray(GLuint array)
{
   (void) array;
   noop_warn("glBindVertexArray");
}

static void APIENTRY noopBindVertexBuffer(GLuint bindingindex, GLuint buffer, GLintptr offset, GLsizei stride)
{
   (void) bindingindex; (void) buffer; (void) offset; (void) stride;
   noop_warn("glBindVertexBuffer");
}

static void APIENTRY noopBindVertexBuffers(GLuint first, GLsizei count, const GLuint *buffers, const GLintptr *offsets, const GLsizei *strides)
{
   (void) first; (void) count; (void) buffers; (void) offsets; (void) strides;
   noop_warn("glBindVertexBuffers");
}

static void APIENTRY noopBitmap(GLsizei width, GLsizei height, GLfloat xorig, GLfloat yorig, GLfloat xmove, GLfloat ymove, const GLubyte *bitmap)
{
   (void) width; (void) height; (void) xorig; (void) yorig; (void) xmove; (void) ymove; (void) bitmap;
   noop_warn("glBitmap");
}

static void APIENTRY noopBlendColor(GLfloat red, GLfloat green, GLfloat blue, GLfloat alpha)
{
   (void) red; (void) green; (void) blue; (void) alpha;
   noop_warn("glBlendColor");
}

static void APIENTRY noopBlendEquation(GLenum mode)
{
   (void) mode;
   noop_warn("glBlendEquation");
}

static void APIENTRY noopBlendEquationSeparate(GLenum modeRGB, GLenum modeAlpha)
{
   (void) modeRGB; (void) modeAlpha;
   noop_warn("glBlendEquationSeparate");
}

static void APIENTRY noopBlendEquationSeparatei(GLuint buf, GLenum modeRGB, GLenum modeAlpha)
{
   (void) buf; (void) modeRGB; (void) modeAlpha;
   noop_warn("glBlendEquationSeparatei");
}

static void APIENTRY noopBlendEquationi(GLuint buf, GLenum mode)
{
   (void) buf; (void) mode;
   noop_warn("glBlendEquationi");
}

static void APIENTRY noopBlendFunc(GLenum sfactor, GLenum dfactor)
{
   (void) sfactor; (void) dfactor;
   noop_warn("glBlendFunc");
}

static void APIENTRY noopBlendFuncSeparate(GLenum sfactorRGB, GLenum dfactorRGB, GLenum sfactorAlpha, GLenum dfactorAlpha)
{
   (void) sfactorRGB; (void) dfactorRGB; (void) sfactorAlpha; (void) dfactorAlpha;
   noop_warn("glBlendFuncSeparate");
}

static void APIENTRY noopBlendFuncSeparatei(GLuint buf, GLenum srcRGB, GLenum dstRGB, GLenum srcAlpha, GLenum dstAlpha)
{
   (void) buf; (void) srcRGB; (void) dstRGB; (void) srcAlpha; (void) dstAlpha;
   noop_warn("glBlendFuncSeparatei");
}

static void APIENTRY noopBlendFunci(GLuint buf, GLenum src, GLenum dst)
{
   (void) buf; (void) src; (void) dst;
   noop_warn("glBlendFunci");
}

static void APIENTRY noopBlitFramebuffer(GLint srcX0, GLint srcY0, GLint srcX1, GLint srcY1, GLint dstX0, GLint dstY0, GLint dstX1, GLint dstY1, GLbitfield mask, GLenum filter)
{
   (void) srcX0; (void) srcY0; (void) srcX1; (void) srcY1; (void) dstX0; (void) dstY0; (void) dstX1; (void) dstY1; (void) mask; (void) filter;
   noop_warn("glBlitFramebuffer");
}

static void APIENTRY noopBlitNamedFramebuffer(GLuint readFramebuffer, GLuint drawFramebuffer, GLint srcX0, GLint srcY0, GLint srcX1, GLint srcY1, GLint dstX0, GLint dstY0, GLint dstX1, GLint dstY1, GLbitfield mask, GLenum filter)
{
   (void) readFramebuffer; (void) drawFramebuffer; (void) srcX0; (void) srcY0; (void) srcX1; (void) srcY1; (void) dstX0; (void) dstY0; (void) dstX1; (void) dstY1; (void) mask; (void) filter;
   noop_warn("glBlitNamedFramebuffer");
}

static void APIENTRY noopBufferData(GLenum target, GLsizeiptr size, const void *data, GLenum usage)
{
   (void) target; (void) size; (void) data; (void) usage;
   noop_warn("glBufferData");
}

static void APIENTRY noopBufferStorage(GLenum target, GLsizeiptr size, const void *data, GLbitfield flags)
{
   (void) target; (void) size; (void) data; (void) flags;
   noop_warn("glBufferStorage");
}

static void APIENTRY noopBufferSubData(GLenum target, GLintptr offset, GLsizeiptr size, const void *data)
{
   (void) target; (void) offset; (void) size; (void) data;
   noop_warn("glBufferSubData");
}

static void APIENTRY noopCallList(GLuint list)
{
   (void) list;
   noop_warn("glCallList");
}

static void APIENTRY noopCallLists(GLsizei n, GLenum type, const void *lists)
{
   (void) n; (void) type; (void) lists;
   noop_warn("glCallLists");
}

static GLenum APIENTRY noopCheckFramebufferStatus(GLenum target)
{
   (void) target;
   noop_warn("glCheckFramebufferStatus");
   return (GLenum) 0;
}

static GLenum APIENTRY noopCheckNamedFramebufferStatus(GLuint framebuffer, GLenum target)
{
   (void) framebuffer; (void) target;
   noop_warn("glCheckNamedFramebufferStatus");
   return (GLenum) 0;
}

static void APIENTRY noopClampColor(GLenum target, GLenum clamp)
{
   (void) target; (void) clamp;
   noop_warn("glClampColor");
}

static void APIENTRY noopClear(GLbitfield mask)
{
   (void) mask;
   noop_warn("glClear");
}

static void APIENTRY noopClearAccum(GLfloat red, GLfloat green, GLfloat blue, GLfloat alpha)
{
   (void) red; (void) green; (void) blue; (void) alpha;
   noop_warn("glClearAccum");
}

static void APIENTRY noopClearBufferData(GLenum target, GLenum internalformat, GLenum format, GLenum type, const void *data)
{
   (void) target; (void) internalformat; (void) format; (void) type; (void) data;
   noop_warn("glClearBufferData");
}

static void APIENTRY noopClearBufferSubData(GLenum target, GLenum internalformat, GLintptr offset, GLsizeiptr size, GLenum format, GLenum type, const void *data)
{
   (void) target; (void) internalformat; (void) offset; (void) size; (void) format; (void) type; (void) data;
   noop_warn("glClearBufferSubData");
}

static void APIENTRY noopClearBufferfi(GLenum buffer, GLint drawbuffer, GLfloat depth, GLint stencil)
{
   (void) buffer; (void) drawbuffer; (void) depth; (void) stencil;
   noop_warn("glClearBufferfi");
}

static void APIENTRY noopClearBufferfv(GLenum buffer, GLint drawbuffer, const GLfloat *value)
{
   (void) buffer; (void) drawbuffer; (void) value;
   noop_warn("glClearBufferfv");
}

static void APIENTRY noopClearBufferiv(GLenum buffer, GLint drawbuffer, const GLint *value)
{
   (void) buffer; (void) drawbuffer; (void) value;
   noop_warn("glClearBufferiv");
}

static void APIENTRY noopClearBufferuiv(GLenum buffer, GLint drawbuffer, const GLuint *value)
{
   (void) buffer; (void) drawbuffer; (void) value;
   noop_warn("glClearBufferuiv");
}

static void APIENTRY noopClearColor(GLfloat red, GLfloat green, GLfloat blue, GLfloat alpha)
{
   (void) red; (void) green; (void) blue; (void) alpha;
   noop_warn("glClearColor");
}

static void APIENTRY noopClearDepth(GLdouble depth)
{
   (void) depth;
   noop_warn("glClearDepth");
}

static void APIENTRY noopClearDepthf(GLfloat d)
{
   (void) d;
   noop_warn("glClearDepthf");
}

static void APIENTRY noopClearIndex(GLfloat c)
{
   (void) c;
   noop_warn("glClearIndex");
}

static void APIENTRY noopClearNamedBufferData(GLuint buffer, GLenum internalformat, GLenum format, GLenum type, const void *data)
{
   (void) buffer; (void) internalformat; (void) format; (void) type; (void) data;
   noop_warn("glClearNamedBufferData");
}

static void APIENTRY noopClearNamedBufferSubData(GLuint buffer, GLenum internalformat, GLintptr offset, GLsizeiptr size, GLenum format, GLenum type, const void *data)
{
   (void) buffer; (void) internalformat; (void) offset; (void) size; (void) format; (void) type; (void) data;
   noop_warn("glClearNamedBufferSubData");
}

static void APIENTRY noopClearNamedFramebufferfi(GLuint framebuffer, GLenum buffer, GLint drawbuffer, GLfloat depth, GLint stencil)
{
   (void) framebuffer; (void) buffer; (void) drawbuffer; (void) depth; (void) stencil;
   noop_warn("glClearNamedFramebufferfi");
}

static void APIENTRY noopClearNamedFramebufferfv(GLuint framebuffer, GLenum buffer, GLint drawbuffer, const GLfloat *value)
{
   (void) framebuffer; (void) buffer; (void) drawbuffer; (void) value;
   noop_warn("glClearNamedFramebufferfv");
}

static void APIENTRY noopClearNamedFramebufferiv(GLuint framebuffer, GLenum buffer, GLint drawbuffer, const GLint *value)
{
   (void) framebuffer; (void) buffer; (void) drawbuffer; (void) value;
   noop_warn("glClearNamedFramebufferiv");
}

static void APIENTRY noopClearNamedFramebufferuiv(GLuint framebuffer, GLenum buffer, GLint drawbuffer, const GLuint *value)
{
   (void) framebuffer; (void) buffer; (void) drawbuffer; (void) value;
   noop_warn("glClearNamedFramebufferuiv");
}

static void APIENTRY noopClearStencil(GLint s)
{
   (void) s;
   noop_warn("glClearStencil");
}

static void APIENTRY noopClearTexImage(GLuint texture, GLint level, GLenum format, GLenum type, const void *data)
{
   (void) texture; (void) level; (void) format; (void) type; (void) data;
   noop_warn("glClearTexImage");
}

static void APIENTRY noopClearTexSubImage(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void *data)
{
   (void) texture; (void) level; (void) xoffset; (void) yoffset; (void) zoffset; (void) width; (void) height; (void) depth; (void) format; (void) type; (void) data;
   noop_warn("glClearTexSubImage");
}

static void APIENTRY noopClientActiveTexture(GLenum texture)
{
   (void) texture;
   noop_warn("glClientActiveTexture");
}

static GLenum APIENTRY noopClientWaitSync(GLsync sync, GLbitfield flags, GLuint64 timeout)
{
   (void) sync; (void) flags; (void) timeout;
   noop_warn("glClientWaitSync");
   return (GLenum) 0;
}

static void APIENTRY noopClipControl(GLenum origin, GLenum depth)
{
   (void) origin; (void) depth;
   noop_warn("glClipControl");
}

static void APIENTRY noopClipPlane(GLenum plane, const GLdouble *equation)
{
   (void) plane; (void) equation;
   noop_warn("glClipPlane");
}

static void APIENTRY noopColor3b(GLbyte red, GLbyte green, GLbyte blue)
{
   (void) red; (void) green; (void) blue;
   noop_warn("glColor3b");
}

static void APIENTRY noopColor3bv(const GLbyte *v)
{
   (void) v;
   noop_warn("glColor3bv");
}

static void APIENTRY noopColor3d(GLdouble red, GLdouble green, GLdouble blue)
{
   (void) red; (void) green; (void) blue;
   noop_warn("glColor3d");
}

static void APIENTRY noopColor3dv(const GLdouble *v)
{
   (void) v;
   noop_warn("glColor3dv");
}

static void APIENTRY noopColor3f(GLfloat red, GLfloat green, GLfloat blue)
{
   (void) red; (void) green; (void) blue;
   noop_warn("glColor3f");
}

static void APIENTRY noopColor3fv(const GLfloat *v)
{
   (void) v;
   noop_warn("glColor3fv");
}

static void APIENTRY noopColor3i(GLint red, GLint green, GLint blue)
{
   (void) red; (void) green; (void) blue;
   noop_warn("glColor3i");
}

static void APIENTRY noopColor3iv(const GLint *v)
{
   (void) v;
   noop_warn("glColor3iv");
}

static void APIENTRY noopColor3s(GLshort red, GLshort green, GLshort blue)
{
   (void) red; (void) green; (void) blue;
   noop_warn("glColor3s");
}

static void APIENTRY noopColor3sv(const GLshort *v)
{
   (void) v;
   noop_warn("glColor3sv");
}

static void APIENTRY noopColor3ub(GLubyte red, GLubyte green, GLubyte blue)
{
   (void) red; (void) green; (void) blue;
   noop_warn("glColor3ub");
}

static void APIENTRY noopColor3ubv(const GLubyte *v)
{
   (void) v;
   noop_warn("glColor3ubv");
}

static void APIENTRY noopColor3ui(GLuint red, GLuint green, GLuint blue)
{
   (void) red; (void) green; (void) blue;
   noop_warn("glColor3ui");
}

static void APIENTRY noopColor3uiv(const GLuint *v)
{
   (void) v;
   noop_warn("glColor3uiv");
}

static void APIENTRY noopColor3us(GLushort red, GLushort green, GLushort blue)
{
   (void) red; (void) green; (void) blue;
   noop_warn("glColor3us");
}

static void APIENTRY noopColor3usv(const GLushort *v)
{
   (void) v;
   noop_warn("glColor3usv");
}

static void APIENTRY noopColor4b(GLbyte red, GLbyte green, GLbyte blue, GLbyte alpha)
{
   (void) red; (void) green; (void) blue; (void) alpha;
   noop_warn("glColor4b");
}

static void APIENTRY noopColor4bv(const GLbyte *v)
{
   (void) v;
   noop_warn("glColor4bv");
}

static void APIENTRY noopColor4d(GLdouble red, GLdouble green, GLdouble blue, GLdouble alpha)
{
   (void) red; (void) green; (void) blue; (void) alpha;
   noop_warn("glColor4d");
}

static void APIENTRY noopColor4dv(const GLdouble *v)
{
   (void) v;
   noop_warn("glColor4dv");
}

static void APIENTRY noopColor4f(GLfloat red, GLfloat green, GLfloat blue, GLfloat alpha)
{
   (void) red; (void) green; (void) blue; (void) alpha;
   noop_warn("glColor4f");
}

static void APIENTRY noopColor4fv(const GLfloat *v)
{
   (void) v;
   noop_warn("glColor4fv");
}

static void APIENTRY noopColor4i(GLint red, GLint green, GLint blue, GLint alpha)
{
   (void) red; (void) green; (void) blue; (void) alpha;
   noop_warn("glColor4i");
}

static void APIENTRY noopColor4iv(const GLint *v)
{
   (void) v;
   noop_warn("glColor4iv");
}

static void APIENTRY noopColor4s(GLshort red, GLshort green, GLshort blue, GLshort alpha)
{
   (void) red; (void) green; (void) blue; (void) alpha;
   noop_warn("glColor4s");
}

static void APIENTRY noopColor4sv(const GLshort *v)
{
   (void) v;
   noop_warn("glColor4sv");
}

static void APIENTRY noopColor4ub(GLubyte red, GLubyte green, GLubyte blue, GLubyte alpha)
{
   (void) red; (void) green; (void) blue; (void) alpha;
   noop_warn("glColor4ub");
}

static void APIENTRY noopColor4ubv(const GLubyte *v)
{
   (void) v;
   noop_warn("glColor4ubv");
}

static void APIENTRY noopColor4ui(GLuint red, GLuint green, GLuint blue, GLuint alpha)
{
   (void) red; (void) green; (void) blue; (void) alpha;
   noop_warn("glColor4ui");
}

static void APIENTRY noopColor4uiv(const GLuint *v)
{
   (void) v;
   noop_warn("glColor4uiv");
}

static void APIENTRY noopColor4us(GLushort red, GLushort green, GLushort blue, GLushort alpha)
{
   (void) red; (void) green; (void) blue; (void) alpha;
   noop_warn("glColor4us");
}

static void APIENTRY noopColor4usv(const GLushort *v)
{
   (void) v;
   noop_warn("glColor4usv");
}

static void APIENTRY noopColorMask(GLboolean red, GLboolean green, GLboolean blue, GLboolean alpha)
{
   (void) red; (void) green; (void) blue; (void) alpha;
   noop_warn("glColorMask");
}

static void APIENTRY noopColorMaski(GLuint index, GLboolean r, GLboolean g, GLboolean b, GLboolean a)
{
   (void) index; (void) r; (void) g; (void) b; (void) a;
   noop_warn("glColorMaski");
}

static void APIENTRY noopColorMaterial(GLenum face, GLenum mode)
{
   (void) face; (void) mode;
   noop_warn("glColorMaterial");
}

static void APIENTRY noopColorP3ui(GLenum type, GLuint color)
{
   (void) type; (void) color;
   noop_warn("glColorP3ui");
}

static void APIENTRY noopColorP3uiv(GLenum type, const GLuint *color)
{
   (void) type; (void) color;
   noop_warn("glColorP3uiv");
}

static void APIENTRY noopColorP4ui(GLenum type, GLuint color)
{
   (void) type; (void) color;
   noop_warn("glColorP4ui");
}

static void APIENTRY noopColorP4uiv(GLenum type, const GLuint *color)
{
   (void) type; (void) color;
   noop_warn("glColorP4uiv");
}

static void APIENTRY noopColorPointer(GLint size, GLenum type, GLsizei stride, const void *pointer)
{
   (void) size; (void) type; (void) stride; (void) pointer;
   noop_warn("glColorPointer");
}

static void APIENTRY noopCompileShader(GLuint shader)
{
   (void) shader;
   noop_warn("glCompileShader");
}

static void APIENTRY noopCompressedTexImage1D(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLint border, GLsizei imageSize, const void *data)
{
   (void) target; (void) level; (void) internalformat; (void) width; (void) border; (void) imageSize; (void) data;
   noop_warn("glCompressedTexImage1D");
}

static void APIENTRY noopCompressedTexImage2D(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLint border, GLsizei imageSize, const void *data)
{
   (void) target; (void) level; (void) internalformat; (void) width; (void) height; (void) border; (void) imageSize; (void) data;
   noop_warn("glCompressedTexImage2D");
}

static void APIENTRY noopCompressedTexImage3D(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLsizei imageSize, const void *data)
{
   (void) target; (void) level; (void) internalformat; (void) width; (void) height; (void) depth; (void) border; (void) imageSize; (void) data;
   noop_warn("glCompressedTexImage3D");
}

static void APIENTRY noopCompressedTexSubImage1D(GLenum target, GLint level, GLint xoffset, GLsizei width, GLenum format, GLsizei imageSize, const void *data)
{
   (void) target; (void) level; (void) xoffset; (void) width; (void) format; (void) imageSize; (void) data;
   noop_warn("glCompressedTexSubImage1D");
}

static void APIENTRY noopCompressedTexSubImage2D(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLsizei imageSize, const void *data)
{
   (void) target; (void) level; (void) xoffset; (void) yoffset; (void) width; (void) height; (void) format; (void) imageSize; (void) data;
   noop_warn("glCompressedTexSubImage2D");
}

static void APIENTRY noopCompressedTexSubImage3D(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLsizei imageSize, const void *data)
{
   (void) target; (void) level; (void) xoffset; (void) yoffset; (void) zoffset; (void) width; (void) height; (void) depth; (void) format; (void) imageSize; (void) data;
   noop_warn("glCompressedTexSubImage3D");
}

static void APIENTRY noopCompressedTextureSubImage1D(GLuint texture, GLint level, GLint xoffset, GLsizei width, GLenum format, GLsizei imageSize, const void *data)
{
   (void) texture; (void) level; (void) xoffset; (void) width; (void) format; (void) imageSize; (void) data;
   noop_warn("glCompressedTextureSubImage1D");
}

static void APIENTRY noopCompressedTextureSubImage2D(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLsizei imageSize, const void *data)
{
   (void) texture; (void) level; (void) xoffset; (void) yoffset; (void) width; (void) height; (void) format; (void) imageSize; (void) data;
   noop_warn("glCompressedTextureSubImage2D");
}

static void APIENTRY noopCompressedTextureSubImage3D(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLsizei imageSize, const void *data)
{
   (void) texture; (void) level; (void) xoffset; (void) yoffset; (void) zoffset; (void) width; (void) height; (void) depth; (void) format; (void) imageSize; (void) data;
   noop_warn("glCompressedTextureSubImage3D");
}

static void APIENTRY noopCopyBufferSubData(GLenum readTarget, GLenum writeTarget, GLintptr readOffset, GLintptr writeOffset, GLsizeiptr size)
{
   (void) readTarget; (void) writeTarget; (void) readOffset; (void) writeOffset; (void) size;
   noop_warn("glCopyBufferSubData");
}

static void APIENTRY noopCopyImageSubData(GLuint srcName, GLenum srcTarget, GLint srcLevel, GLint srcX, GLint srcY, GLint srcZ, GLuint dstName, GLenum dstTarget, GLint dstLevel, GLint dstX, GLint dstY, GLint dstZ, GLsizei srcWidth, GLsizei srcHeight, GLsizei srcDepth)
{
   (void) srcName; (void) srcTarget; (void) srcLevel; (void) srcX; (void) srcY; (void) srcZ; (void) dstName; (void) dstTarget; (void) dstLevel; (void) dstX; (void) dstY; (void) dstZ; (void) srcWidth; (void) srcHeight; (void) srcDepth;
   noop_warn("glCopyImageSubData");
}

static void APIENTRY noopCopyNamedBufferSubData(GLuint readBuffer, GLuint writeBuffer, GLintptr readOffset, GLintptr writeOffset, GLsizeiptr size)
{
   (void) readBuffer; (void) writeBuffer; (void) readOffset; (void) writeOffset; (void) size;
   noop_warn("glCopyNamedBufferSubData");
}

static void APIENTRY noopCopyPixels(GLint x, GLint y, GLsizei width, GLsizei height, GLenum type)
{
   (void) x; (void) y; (void) width; (void) height; (void) type;
   noop_warn("glCopyPixels");
}

static void APIENTRY noopCopyTexImage1D(GLenum target, GLint level, GLenum internalformat, GLint x, GLint y, GLsizei width, GLint border)
{
   (void) target; (void) level; (void) internalformat; (void) x; (void) y; (void) width; (void) border;
   noop_warn("glCopyTexImage1D");
}

static void APIENTRY noopCopyTexImage2D(GLenum target, GLint level, GLenum internalformat, GLint x, GLint y, GLsizei width, GLsizei height, GLint border)
{
   (void) target; (void) level; (void) internalformat; (void) x; (void) y; (void) width; (void) height; (void) border;
   noop_warn("glCopyTexImage2D");
}

static void APIENTRY noopCopyTexSubImage1D(GLenum target, GLint level, GLint xoffset, GLint x, GLint y, GLsizei width)
{
   (void) target; (void) level; (void) xoffset; (void) x; (void) y; (void) width;
   noop_warn("glCopyTexSubImage1D");
}

static void APIENTRY noopCopyTexSubImage2D(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint x, GLint y, GLsizei width, GLsizei height)
{
   (void) target; (void) level; (void) xoffset; (void) yoffset; (void) x; (void) y; (void) width; (void) height;
   noop_warn("glCopyTexSubImage2D");
}

static void APIENTRY noopCopyTexSubImage3D(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLint x, GLint y, GLsizei width, GLsizei height)
{
   (void) target; (void) level; (void) xoffset; (void) yoffset; (void) zoffset; (void) x; (void) y; (void) width; (void) height;
   noop_warn("glCopyTexSubImage3D");
}

static void APIENTRY noopCopyTextureSubImage1D(GLuint texture, GLint level, GLint xoffset, GLint x, GLint y, GLsizei width)
{
   (void) texture; (void) level; (void) xoffset; (void) x; (void) y; (void) width;
   noop_warn("glCopyTextureSubImage1D");
}

static void APIENTRY noopCopyTextureSubImage2D(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint x, GLint y, GLsizei width, GLsizei height)
{
   (void) texture; (void) level; (void) xoffset; (void) yoffset; (void) x; (void) y; (void) width; (void) height;
   noop_warn("glCopyTextureSubImage2D");
}

static void APIENTRY noopCopyTextureSubImage3D(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLint x, GLint y, GLsizei width, GLsizei height)
{
   (void) texture; (void) level; (void) xoffset; (void) yoffset; (void) zoffset; (void) x; (void) y; (void) width; (void) height;
   noop_warn("glCopyTextureSubImage3D");
}

static void APIENTRY noopCreateBuffers(GLsizei n, GLuint *buffers)
{
   (void) n; (void) buffers;
   noop_warn("glCreateBuffers");
}

static void APIENTRY noopCreateFramebuffers(GLsizei n, GLuint *framebuffers)
{
   (void) n; (void) framebuffers;
   noop_warn("glCreateFramebuffers");
}

static GLuint APIENTRY noopCreateProgram(void)
{
   noop_warn("glCreateProgram");
   return (GLuint) 0;
}

static void APIENTRY noopCreateProgramPipelines(GLsizei n, GLuint *pipelines)
{
   (void) n; (void) pipelines;
   noop_warn("glCreateProgramPipelines");
}

static void APIENTRY noopCreateQueries(GLenum target, GLsizei n, GLuint *ids)
{
   (void) target; (void) n; (void) ids;
   noop_warn("glCreateQueries");
}

static void APIENTRY noopCreateRenderbuffers(GLsizei n, GLuint *renderbuffers)
{
   (void) n; (void) renderbuffers;
   noop_warn("glCreateRenderbuffers");
}

static void APIENTRY noopCreateSamplers(GLsizei n, GLuint *samplers)
{
   (void) n; (void) samplers;
   noop_warn("glCreateSamplers");
}

static GLuint APIENTRY noopCreateShader(GLenum type)
{
   (void) type;
   noop_warn("glCreateShader");
   return (GLuint) 0;
}

static GLuint APIENTRY noopCreateShaderProgramv(GLenum type, GLsizei count, const GLchar *const *strings)
{
   (void) type; (void) count; (void) strings;
   noop_warn("glCreateShaderProgramv");
   return (GLuint) 0;
}

static void APIENTRY noopCreateTextures(GLenum target, GLsizei n, GLuint *textures)
{
   (void) target; (void) n; (void) textures;
   noop_warn("glCreateTextures");
}

static void APIENTRY noopCreateTransformFeedbacks(GLsizei n, GLuint *ids)
{
   (void) n; (void) ids;
   noop_warn("glCreateTransformFeedbacks");
}

static void APIENTRY noopCreateVertexArrays(GLsizei n, GLuint *arrays)
{
   (void) n; (void) arrays;
   noop_warn("glCreateVertexArrays");
}

static void APIENTRY noopCullFace(GLenum mode)
{
   (void) mode;
   noop_warn("glCullFace");
}

static void APIENTRY noopDebugMessageCallback(GLDEBUGPROC callback, const void *userParam)
{
   (void) callback; (void) userParam;
   noop_warn("glDebugMessageCallback");
}

static void APIENTRY noopDebugMessageControl(GLenum source, GLenum type, GLenum severity, GLsizei count, const GLuint *ids, GLboolean enabled)
{
   (void) source; (void) type; (void) severity; (void) count; (void) ids; (void) enabled;
   noop_warn("glDebugMessageControl");
}

static void APIENTRY noopDebugMessageInsert(GLenum source, GLenum type, GLuint id, GLenum severity, GLsizei length, const GLchar *buf)
{
   (void) source; (void) type; (void) id; (void) severity; (void) length; (void) buf;
   noop_warn("glDebugMessageInsert");
}

static void APIENTRY noopDeleteBuffers(GLsizei n, const GLuint *buffers)
{
   (void) n; (void) buffers;
   noop_warn("glDeleteBuffers");
}

static void APIENTRY noopDeleteFramebuffers(GLsizei n, const GLuint *framebuffers)
{
   (void) n; (void) framebuffers;
   noop_warn("glDeleteFramebuffers");
}

static void APIENTRY noopDeleteLists(GLuint list, GLsizei range)
{
   (void) list; (void) range;
   noop_warn("glDeleteLists");
}

static void APIENTRY noopDeleteProgram(GLuint program)
{
   (void) program;
   noop_warn("glDeleteProgram");
}

static void APIENTRY noopDeleteProgramPipelines(GLsizei n, const GLuint *pipelines)
{
   (void) n; (void) pipelines;
   noop_warn("glDeleteProgramPipelines");
}

static void APIENTRY noopDeleteQueries(GLsizei n, const GLuint *ids)
{
   (void) n; (void) ids;
   noop_warn("glDeleteQueries");
}

static void APIENTRY noopDeleteRenderbuffers(GLsizei n, const GLuint *renderbuffers)
{
   (void) n; (void) renderbuffers;
   noop_warn("glDeleteRenderbuffers");
}

static void APIENTRY noopDeleteSamplers(GLsizei count, const GLuint *samplers)
{
   (void) count; (void) samplers;
   noop_warn("glDeleteSamplers");
}

static void APIENTRY noopDeleteShader(GLuint shader)
{
   (void) shader;
   noop_warn("glDeleteShader");
}

static void APIENTRY noopDeleteSync(GLsync sync)
{
   (void) sync;
   noop_warn("glDeleteSync");
}

static void APIENTRY noopDeleteTextures(GLsizei n, const GLuint *textures)
{
   (void) n; (void) textures;
   noop_warn("glDeleteTextures");
}

static void APIENTRY noopDeleteTransformFeedbacks(GLsizei n, const GLuint *ids)
{
   (void) n; (void) ids;
   noop_warn("glDeleteTransformFeedbacks");
}

static void APIENTRY noopDeleteVertexArrays(GLsizei n, const GLuint *arrays)
{
   (void) n; (void) arrays;
   noop_warn("glDeleteVertexArrays");
}

static void APIENTRY noopDepthFunc(GLenum func)
{
   (void) func;
   noop_warn("glDepthFunc");
}

static void APIENTRY noopDepthMask(GLboolean flag)
{
   (void) flag;
   noop_warn("glDepthMask");
}

static void APIENTRY noopDepthRange(GLdouble n, GLdouble f)
{
   (void) n; (void) f;
   noop_warn("glDepthRange");
}

static void APIENTRY noopDepthRangeArrayv(GLuint first, GLsizei count, const GLdouble *v)
{
   (void) first; (void) count; (void) v;
   noop_warn("glDepthRangeArrayv");
}

static void APIENTRY noopDepthRangeIndexed(GLuint index, GLdouble n, GLdouble f)
{
   (void) index; (void) n; (void) f;
   noop_warn("glDepthRangeIndexed");
}

static void APIENTRY noopDepthRangef(GLfloat n, GLfloat f)
{
   (void) n; (void) f;
   noop_warn("glDepthRangef");
}

static void APIENTRY noopDetachShader(GLuint program, GLuint shader)
{
   (void) program; (void) shader;
   noop_warn("glDetachShader");
}

static void APIENTRY noopDisable(GLenum cap)
{
   (void) cap;
   noop_warn("glDisable");
}

static void APIENTRY noopDisableClientState(GLenum array)
{
   (void) array;
   noop_warn("glDisableClientState");
}

static void APIENTRY noopDisableVertexArrayAttrib(GLuint vaobj, GLuint index)
{
   (void) vaobj; (void) index;
   noop_warn("glDisableVertexArrayAttrib");
}

static void APIENTRY noopDisableVertexAttribArray(GLuint index)
{
   (void) index;
   noop_warn("glDisableVertexAttribArray");
}

static void APIENTRY noopDisablei(GLenum target, GLuint index)
{
   (void) target; (void) index;
   noop_warn("glDisablei");
}

static void APIENTRY noopDispatchCompute(GLuint num_groups_x, GLuint num_groups_y, GLuint num_groups_z)
{
   (void) num_groups_x; (void) num_groups_y; (void) num_groups_z;
   noop_warn("glDispatchCompute");
}

static void APIENTRY noopDispatchComputeIndirect(GLintptr indirect)
{
   (void) indirect;
   noop_warn("glDispatchComputeIndirect");
}

static void APIENTRY noopDrawArrays(GLenum mode, GLint first, GLsizei count)
{
   (void) mode; (void) first; (void) count;
   noop_warn("glDrawArrays");
}

static void APIENTRY noopDrawArraysIndirect(GLenum mode, const void *indirect)
{
   (void) mode; (void) indirect;
   noop_warn("glDrawArraysIndirect");
}

static void APIENTRY noopDrawArraysInstanced(GLenum mode, GLint first, GLsizei count, GLsizei instancecount)
{
   (void) mode; (void) first; (void) count; (void) instancecount;
   noop_warn("glDrawArraysInstanced");
}

static void APIENTRY noopDrawArraysInstancedBaseInstance(GLenum mode, GLint first, GLsizei count, GLsizei instancecount, GLuint baseinstance)
{
   (void) mode; (void) first; (void) count; (void) instancecount; (void) baseinstance;
   noop_warn("glDrawArraysInstancedBaseInstance");
}

static void APIENTRY noopDrawBuffer(GLenum buf)
{
   (void) buf;
   noop_warn("glDrawBuffer");
}

static void APIENTRY noopDrawBuffers(GLsizei n, const GLenum *bufs)
{
   (void) n; (void) bufs;
   noop_warn("glDrawBuffers");
}

static void APIENTRY noopDrawElements(GLenum mode, GLsizei count, GLenum type, const void *indices)
{
   (void) mode; (void) count; (void) type; (void) indices;
   noop_warn("glDrawElements");
}

static void APIENTRY noopDrawElementsBaseVertex(GLenum mode, GLsizei count, GLenum type, const void *indices, GLint basevertex)
{
   (void) mode; (void) count; (void) type; (void) indices; (void) basevertex;
   noop_warn("glDrawElementsBaseVertex");
}

static void APIENTRY noopDrawElementsIndirect(GLenum mode, GLenum type, const void *indirect)
{
   (void) mode; (void) type; (void) indirect;
   noop_warn("glDrawElementsIndirect");
}

static void APIENTRY noopDrawElementsInstanced(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei instancecount)
{
   (void) mode; (void) count; (void) type; (void) indices; (void) instancecount;
   noop_warn("glDrawElementsInstanced");
}

static void APIENTRY noopDrawElementsInstancedBaseInstance(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei instancecount, GLuint baseinstance)
{
   (void) mode; (void) count; (void) type; (void) indices; (void) instancecount; (void) baseinstance;
   noop_warn("glDrawElementsInstancedBaseInstance");
}

static void APIENTRY noopDrawElementsInstancedBaseVertex(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei instancecount, GLint basevertex)
{
   (void) mode; (void) count; (void) type; (void) indices; (void) instancecount; (void) basevertex;
   noop_warn("glDrawElementsInstancedBaseVertex");
}

static void APIENTRY noopDrawElementsInstancedBaseVertexBaseInstance(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei instancecount, GLint basevertex, GLuint baseinstance)
{
   (void) mode; (void) count; (void) type; (void) indices; (void) instancecount; (void) basevertex; (void) baseinstance;
   noop_warn("glDrawElementsInstancedBaseVertexBaseInstance");
}

static void APIENTRY noopDrawPixels(GLsizei width, GLsizei height, GLenum format, GLenum type, const void *pixels)
{
   (void) width; (void) height; (void) format; (void) type; (void) pixels;
   noop_warn("glDrawPixels");
}

static void APIENTRY noopDrawRangeElements(GLenum mode, GLuint start, GLuint end, GLsizei count, GLenum type, const void *indices)
{
   (void) mode; (void) start; (void) end; (void) count; (void) type; (void) indices;
   noop_warn("glDrawRangeElements");
}

static void APIENTRY noopDrawRangeElementsBaseVertex(GLenum mode, GLuint start, GLuint end, GLsizei count, GLenum type, const void *indices, GLint basevertex)
{
   (void) mode; (void) start; (void) end; (void) count; (void) type; (void) indices; (void) basevertex;
   noop_warn("glDrawRangeElementsBaseVertex");
}

static void APIENTRY noopDrawTransformFeedback(GLenum mode, GLuint id)
{
   (void) mode; (void) id;
   noop_warn("glDrawTransformFeedback");
}

static void APIENTRY noopDrawTransformFeedbackInstanced(GLenum mode, GLuint id, GLsizei instancecount)
{
   (void) mode; (void) id; (void) instancecount;
   noop_warn("glDrawTransformFeedbackInstanced");
}

static void APIENTRY noopDrawTransformFeedbackStream(GLenum mode, GLuint id, GLuint stream)
{
   (void) mode; (void) id; (void) stream;
   noop_warn("glDrawTransformFeedbackStream");
}

static void APIENTRY noopDrawTransformFeedbackStreamInstanced(GLenum mode, GLuint id, GLuint stream, GLsizei instancecount)
{
   (void) mode; (void) id; (void) stream; (void) instancecount;
   noop_warn("glDrawTransformFeedbackStreamInstanced");
}

static void APIENTRY noopEdgeFlag(GLboolean flag)
{
   (void) flag;
   noop_warn("glEdgeFlag");
}

static void APIENTRY noopEdgeFlagPointer(GLsizei stride, const void *pointer)
{
   (void) stride; (void) pointer;
   noop_warn("glEdgeFlagPointer");
}

static void APIENTRY noopEdgeFlagv(const GLboolean *flag)
{
   (void) flag;
   noop_warn("glEdgeFlagv");
}

static void APIENTRY noopEnable(GLenum cap)
{
   (void) cap;
   noop_warn("glEnable");
}

static void APIENTRY noopEnableClientState(GLenum array)
{
   (void) array;
   noop_warn("glEnableClientState");
}

static void APIENTRY noopEnableVertexArrayAttrib(GLuint vaobj, GLuint index)
{
   (void) vaobj; (void) index;
   noop_warn("glEnableVertexArrayAttrib");
}

static void APIENTRY noopEnableVertexAttribArray(GLuint index)
{
   (void) index;
   noop_warn("glEnableVertexAttribArray");
}

static void APIENTRY noopEnablei(GLenum target, GLuint index)
{
   (void) target; (void) index;
   noop_warn("glEnablei");
}

static void APIENTRY noopEnd(void)
{
   noop_warn("glEnd");
}

static void APIENTRY noopEndConditionalRender(void)
{
   noop_warn("glEndConditionalRender");
}

static void APIENTRY noopEndList(void)
{
   noop_warn("glEndList");
}

static void APIENTRY noopEndQuery(GLenum target)
{
   (void) target;
   noop_warn("glEndQuery");
}

static void APIENTRY noopEndQueryIndexed(GLenum target, GLuint index)
{
   (void) target; (void) index;
   noop_warn("glEndQueryIndexed");
}

static void APIENTRY noopEndTransformFeedback(void)
{
   noop_warn("glEndTransformFeedback");
}

static void APIENTRY noopEvalCoord1d(GLdouble u)
{
   (void) u;
   noop_warn("glEvalCoord1d");
}

static void APIENTRY noopEvalCoord1dv(const GLdouble *u)
{
   (void) u;
   noop_warn("glEvalCoord1dv");
}

static void APIENTRY noopEvalCoord1f(GLfloat u)
{
   (void) u;
   noop_warn("glEvalCoord1f");
}

static void APIENTRY noopEvalCoord1fv(const GLfloat *u)
{
   (void) u;
   noop_warn("glEvalCoord1fv");
}

static void APIENTRY noopEvalCoord2d(GLdouble u, GLdouble v)
{
   (void) u; (void) v;
   noop_warn("glEvalCoord2d");
}

static void APIENTRY noopEvalCoord2dv(const GLdouble *u)
{
   (void) u;
   noop_warn("glEvalCoord2dv");
}

static void APIENTRY noopEvalCoord2f(GLfloat u, GLfloat v)
{
   (void) u; (void) v;
   noop_warn("glEvalCoord2f");
}

static void APIENTRY noopEvalCoord2fv(const GLfloat *u)
{
   (void) u;
   noop_warn("glEvalCoord2fv");
}

static void APIENTRY noopEvalMesh1(GLenum mode, GLint i1, GLint i2)
{
   (void) mode; (void) i1; (void) i2;
   noop_warn("glEvalMesh1");
}

static void APIENTRY noopEvalMesh2(GLenum mode, GLint i1, GLint i2, GLint j1, GLint j2)
{
   (void) mode; (void) i1; (void) i2; (void) j1; (void) j2;
   noop_warn("glEvalMesh2");
}

static void APIENTRY noopEvalPoint1(GLint i)
{
   (void) i;
   noop_warn("glEvalPoint1");
}

static void APIENTRY noopEvalPoint2(GLint i, GLint j)
{
   (void) i; (void) j;
   noop_warn("glEvalPoint2");
}

static void APIENTRY noopFeedbackBuffer(GLsizei size, GLenum type, GLfloat *buffer)
{
   (void) size; (void) type; (void) buffer;
   noop_warn("glFeedbackBuffer");
}

static GLsync APIENTRY noopFenceSync(GLenum condition, GLbitfield flags)
{
   (void) condition; (void) flags;
   noop_warn("glFenceSync");
   return (GLsync) 0;
}

static void APIENTRY noopFinish(void)
{
   noop_warn("glFinish");
}

static void APIENTRY noopFlush(void)
{
   noop_warn("glFlush");
}

static void APIENTRY noopFlushMappedBufferRange(GLenum target, GLintptr offset, GLsizeiptr length)
{
   (void) target; (void) offset; (void) length;
   noop_warn("glFlushMappedBufferRange");
}

static void APIENTRY noopFlushMappedNamedBufferRange(GLuint buffer, GLintptr offset, GLsizeiptr length)
{
   (void) buffer; (void) offset; (void) length;
   noop_warn("glFlushMappedNamedBufferRange");
}

static void APIENTRY noopFogCoordPointer(GLenum type, GLsizei stride, const void *pointer)
{
   (void) type; (void) stride; (void) pointer;
   noop_warn("glFogCoordPointer");
}

static void APIENTRY noopFogCoordd(GLdouble coord)
{
   (void) coord;
   noop_warn("glFogCoordd");
}

static void APIENTRY noopFogCoorddv(const GLdouble *coord)
{
   (void) coord;
   noop_warn("glFogCoorddv");
}

static void APIENTRY noopFogCoordf(GLfloat coord)
{
   (void) coord;
   noop_warn("glFogCoordf");
}

static void APIENTRY noopFogCoordfv(const GLfloat *coord)
{
   (void) coord;
   noop_warn("glFogCoordfv");
}

static void APIENTRY noopFogf(GLenum pname, GLfloat param)
{
   (void) pname; (void) param;
   noop_warn("glFogf");
}

static void APIENTRY noopFogfv(GLenum pname, const GLfloat *params)
{
   (void) pname; (void) params;
   noop_warn("glFogfv");
}

static void APIENTRY noopFogi(GLenum pname, GLint param)
{
   (void) pname; (void) param;
   noop_warn("glFogi");
}

static void APIENTRY noopFogiv(GLenum pname, const GLint *params)
{
   (void) pname; (void) params;
   noop_warn("glFogiv");
}

static void APIENTRY noopFramebufferParameteri(GLenum target, GLenum pname, GLint param)
{
   (void) target; (void) pname; (void) param;
   noop_warn("glFramebufferParameteri");
}

static void APIENTRY noopFramebufferRenderbuffer(GLenum target, GLenum attachment, GLenum renderbuffertarget, GLuint renderbuffer)
{
   (void) target; (void) attachment; (void) renderbuffertarget; (void) renderbuffer;
   noop_warn("glFramebufferRenderbuffer");
}

static void APIENTRY noopFramebufferTexture(GLenum target, GLenum attachment, GLuint texture, GLint level)
{
   (void) target; (void) attachment; (void) texture; (void) level;
   noop_warn("glFramebufferTexture");
}

static void APIENTRY noopFramebufferTexture1D(GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level)
{
   (void) target; (void) attachment; (void) textarget; (void) texture; (void) level;
   noop_warn("glFramebufferTexture1D");
}

static void APIENTRY noopFramebufferTexture2D(GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level)
{
   (void) target; (void) attachment; (void) textarget; (void) texture; (void) level;
   noop_warn("glFramebufferTexture2D");
}

static void APIENTRY noopFramebufferTexture3D(GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level, GLint zoffset)
{
   (void) target; (void) attachment; (void) textarget; (void) texture; (void) level; (void) zoffset;
   noop_warn("glFramebufferTexture3D");
}

static void APIENTRY noopFramebufferTextureLayer(GLenum target, GLenum attachment, GLuint texture, GLint level, GLint layer)
{
   (void) target; (void) attachment; (void) texture; (void) level; (void) layer;
   noop_warn("glFramebufferTextureLayer");
}

static void APIENTRY noopFrontFace(GLenum mode)
{
   (void) mode;
   noop_warn("glFrontFace");
}

static void APIENTRY noopFrustum(GLdouble left, GLdouble right, GLdouble bottom, GLdouble top, GLdouble zNear, GLdouble zFar)
{
   (void) left; (void) right; (void) bottom; (void) top; (void) zNear; (void) zFar;
   noop_warn("glFrustum");
}

static void APIENTRY noopGenBuffers(GLsizei n, GLuint *buffers)
{
   (void) n; (void) buffers;
   noop_warn("glGenBuffers");
}

static void APIENTRY noopGenFramebuffers(GLsizei n, GLuint *framebuffers)
{
   (void) n; (void) framebuffers;
   noop_warn("glGenFramebuffers");
}

static GLuint APIENTRY noopGenLists(GLsizei range)
{
   (void) range;
   noop_warn("glGenLists");
   return (GLuint) 0;
}

static void APIENTRY noopGenProgramPipelines(GLsizei n, GLuint *pipelines)
{
   (void) n; (void) pipelines;
   noop_warn("glGenProgramPipelines");
}

static void APIENTRY noopGenQueries(GLsizei n, GLuint *ids)
{
   (void) n; (void) ids;
   noop_warn("glGenQueries");
}

static void APIENTRY noopGenRenderbuffers(GLsizei n, GLuint *renderbuffers)
{
   (void) n; (void) renderbuffers;
   noop_warn("glGenRenderbuffers");
}

static void APIENTRY noopGenSamplers(GLsizei count, GLuint *samplers)
{
   (void) count; (void) samplers;
   noop_warn("glGenSamplers");
}

static void APIENTRY noopGenTextures(GLsizei n, GLuint *textures)
{
   (void) n; (void) textures;
   noop_warn("glGenTextures");
}

static void APIENTRY noopGenTransformFeedbacks(GLsizei n, GLuint *ids)
{
   (void) n; (void) ids;
   noop_warn("glGenTransformFeedbacks");
}

static void APIENTRY noopGenVertexArrays(GLsizei n, GLuint *arrays)
{
   (void) n; (void) arrays;
   noop_warn("glGenVertexArrays");
}

static void APIENTRY noopGenerateMipmap(GLenum target)
{
   (void) target;
   noop_warn("glGenerateMipmap");
}

static void APIENTRY noopGenerateTextureMipmap(GLuint texture)
{
   (void) texture;
   noop_warn("glGenerateTextureMipmap");
}

static void APIENTRY noopGetActiveAtomicCounterBufferiv(GLuint program, GLuint bufferIndex, GLenum pname, GLint *params)
{
   (void) program; (void) bufferIndex; (void) pname; (void) params;
   noop_warn("glGetActiveAtomicCounterBufferiv");
}

static void APIENTRY noopGetActiveAttrib(GLuint program, GLuint index, GLsizei bufSize, GLsizei *length, GLint *size, GLenum *type, GLchar *name)
{
   (void) program; (void) index; (void) bufSize; (void) length; (void) size; (void) type; (void) name;
   noop_warn("glGetActiveAttrib");
}

static void APIENTRY noopGetActiveSubroutineName(GLuint program, GLenum shadertype, GLuint index, GLsizei bufSize, GLsizei *length, GLchar *name)
{
   (void) program; (void) shadertype; (void) index; (void) bufSize; (void) length; (void) name;
   noop_warn("glGetActiveSubroutineName");
}

static void APIENTRY noopGetActiveSubroutineUniformName(GLuint program, GLenum shadertype, GLuint index, GLsizei bufSize, GLsizei *length, GLchar *name)
{
   (void) program; (void) shadertype; (void) index; (void) bufSize; (void) length; (void) name;
   noop_warn("glGetActiveSubroutineUniformName");
}

static void APIENTRY noopGetActiveSubroutineUniformiv(GLuint program, GLenum shadertype, GLuint index, GLenum pname, GLint *values)
{
   (void) program; (void) shadertype; (void) index; (void) pname; (void) values;
   noop_warn("glGetActiveSubroutineUniformiv");
}

static void APIENTRY noopGetActiveUniform(GLuint program, GLuint index, GLsizei bufSize, GLsizei *length, GLint *size, GLenum *type, GLchar *name)
{
   (void) program; (void) index; (void) bufSize; (void) length; (void) size; (void) type; (void) name;
   noop_warn("glGetActiveUniform");
}

static void APIENTRY noopGetActiveUniformBlockName(GLuint program, GLuint uniformBlockIndex, GLsizei bufSize, GLsizei *length, GLchar *uniformBlockName)
{
   (void) program; (void) uniformBlockIndex; (void) bufSize; (void) length; (void) uniformBlockName;
   noop_warn("glGetActiveUniformBlockName");
}

static void APIENTRY noopGetActiveUniformBlockiv(GLuint program, GLuint uniformBlockIndex, GLenum pname, GLint *params)
{
   (void) program; (void) uniformBlockIndex; (void) pname; (void) params;
   noop_warn("glGetActiveUniformBlockiv");
}

static void APIENTRY noopGetActiveUniformName(GLuint program, GLuint uniformIndex, GLsizei bufSize, GLsizei *length, GLchar *uniformName)
{
   (void) program; (void) uniformIndex; (void) bufSize; (void) length; (void) uniformName;
   noop_warn("glGetActiveUniformName");
}

static void APIENTRY noopGetActiveUniformsiv(GLuint program, GLsizei uniformCount, const GLuint *uniformIndices, GLenum pname, GLint *params)
{
   (void) program; (void) uniformCount; (void) uniformIndices; (void) pname; (void) params;
   noop_warn("glGetActiveUniformsiv");
}

static void APIENTRY noopGetAttachedShaders(GLuint program, GLsizei maxCount, GLsizei *count, GLuint *shaders)
{
   (void) program; (void) maxCount; (void) count; (void) shaders;
   noop_warn("glGetAttachedShaders");
}

static GLint APIENTRY noopGetAttribLocation(GLuint program, const GLchar *name)
{
   (void) program; (void) name;
   noop_warn("glGetAttribLocation");
   return (GLint) 0;
}

static void APIENTRY noopGetBooleani_v(GLenum target, GLuint index, GLboolean *data)
{
   (void) target; (void) index; (void) data;
   noop_warn("glGetBooleani_v");
}

static void APIENTRY noopGetBooleanv(GLenum pname, GLboolean *data)
{
   (void) pname; (void) data;
   noop_warn("glGetBooleanv");
}

static void APIENTRY noopGetBufferParameteri64v(GLenum target, GLenum pname, GLint64 *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetBufferParameteri64v");
}

static void APIENTRY noopGetBufferParameteriv(GLenum target, GLenum pname, GLint *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetBufferParameteriv");
}

static void APIENTRY noopGetBufferPointerv(GLenum target, GLenum pname, void **params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetBufferPointerv");
}

static void APIENTRY noopGetBufferSubData(GLenum target, GLintptr offset, GLsizeiptr size, void *data)
{
   (void) target; (void) offset; (void) size; (void) data;
   noop_warn("glGetBufferSubData");
}

static void APIENTRY noopGetClipPlane(GLenum plane, GLdouble *equation)
{
   (void) plane; (void) equation;
   noop_warn("glGetClipPlane");
}

static void APIENTRY noopGetCompressedTexImage(GLenum target, GLint level, void *img)
{
   (void) target; (void) level; (void) img;
   noop_warn("glGetCompressedTexImage");
}

static void APIENTRY noopGetCompressedTextureImage(GLuint texture, GLint level, GLsizei bufSize, void *pixels)
{
   (void) texture; (void) level; (void) bufSize; (void) pixels;
   noop_warn("glGetCompressedTextureImage");
}

static void APIENTRY noopGetCompressedTextureSubImage(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLsizei bufSize, void *pixels)
{
   (void) texture; (void) level; (void) xoffset; (void) yoffset; (void) zoffset; (void) width; (void) height; (void) depth; (void) bufSize; (void) pixels;
   noop_warn("glGetCompressedTextureSubImage");
}

static GLuint APIENTRY noopGetDebugMessageLog(GLuint count, GLsizei bufSize, GLenum *sources, GLenum *types, GLuint *ids, GLenum *severities, GLsizei *lengths, GLchar *messageLog)
{
   (void) count; (void) bufSize; (void) sources; (void) types; (void) ids; (void) severities; (void) lengths; (void) messageLog;
   noop_warn("glGetDebugMessageLog");
   return (GLuint) 0;
}

static void APIENTRY noopGetDoublei_v(GLenum target, GLuint index, GLdouble *data)
{
   (void) target; (void) index; (void) data;
   noop_warn("glGetDoublei_v");
}

static void APIENTRY noopGetDoublev(GLenum pname, GLdouble *data)
{
   (void) pname; (void) data;
   noop_warn("glGetDoublev");
}

static GLenum APIENTRY noopGetError(void)
{
   noop_warn("glGetError");
   return (GLenum) 0;
}

static void APIENTRY noopGetFloati_v(GLenum target, GLuint index, GLfloat *data)
{
   (void) target; (void) index; (void) data;
   noop_warn("glGetFloati_v");
}

static void APIENTRY noopGetFloatv(GLenum pname, GLfloat *data)
{
   (void) pname; (void) data;
   noop_warn("glGetFloatv");
}

static GLint APIENTRY noopGetFragDataIndex(GLuint program, const GLchar *name)
{
   (void) program; (void) name;
   noop_warn("glGetFragDataIndex");
   return (GLint) 0;
}

static GLint APIENTRY noopGetFragDataLocation(GLuint program, const GLchar *name)
{
   (void) program; (void) name;
   noop_warn("glGetFragDataLocation");
   return (GLint) 0;
}

static void APIENTRY noopGetFramebufferAttachmentParameteriv(GLenum target, GLenum attachment, GLenum pname, GLint *params)
{
   (void) target; (void) attachment; (void) pname; (void) params;
   noop_warn("glGetFramebufferAttachmentParameteriv");
}

static void APIENTRY noopGetFramebufferParameteriv(GLenum target, GLenum pname, GLint *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetFramebufferParameteriv");
}

static GLenum APIENTRY noopGetGraphicsResetStatus(void)
{
   noop_warn("glGetGraphicsResetStatus");
   return (GLenum) 0;
}

static void APIENTRY noopGetInteger64i_v(GLenum target, GLuint index, GLint64 *data)
{
   (void) target; (void) index; (void) data;
   noop_warn("glGetInteger64i_v");
}

static void APIENTRY noopGetInteger64v(GLenum pname, GLint64 *data)
{
   (void) pname; (void) data;
   noop_warn("glGetInteger64v");
}

static void APIENTRY noopGetIntegeri_v(GLenum target, GLuint index, GLint *data)
{
   (void) target; (void) index; (void) data;
   noop_warn("glGetIntegeri_v");
}

static void APIENTRY noopGetIntegerv(GLenum pname, GLint *data)
{
   (void) pname; (void) data;
   noop_warn("glGetIntegerv");
}

static void APIENTRY noopGetInternalformati64v(GLenum target, GLenum internalformat, GLenum pname, GLsizei count, GLint64 *params)
{
   (void) target; (void) internalformat; (void) pname; (void) count; (void) params;
   noop_warn("glGetInternalformati64v");
}

static void APIENTRY noopGetInternalformativ(GLenum target, GLenum internalformat, GLenum pname, GLsizei count, GLint *params)
{
   (void) target; (void) internalformat; (void) pname; (void) count; (void) params;
   noop_warn("glGetInternalformativ");
}

static void APIENTRY noopGetLightfv(GLenum light, GLenum pname, GLfloat *params)
{
   (void) light; (void) pname; (void) params;
   noop_warn("glGetLightfv");
}

static void APIENTRY noopGetLightiv(GLenum light, GLenum pname, GLint *params)
{
   (void) light; (void) pname; (void) params;
   noop_warn("glGetLightiv");
}

static void APIENTRY noopGetMapdv(GLenum target, GLenum query, GLdouble *v)
{
   (void) target; (void) query; (void) v;
   noop_warn("glGetMapdv");
}

static void APIENTRY noopGetMapfv(GLenum target, GLenum query, GLfloat *v)
{
   (void) target; (void) query; (void) v;
   noop_warn("glGetMapfv");
}

static void APIENTRY noopGetMapiv(GLenum target, GLenum query, GLint *v)
{
   (void) target; (void) query; (void) v;
   noop_warn("glGetMapiv");
}

static void APIENTRY noopGetMaterialfv(GLenum face, GLenum pname, GLfloat *params)
{
   (void) face; (void) pname; (void) params;
   noop_warn("glGetMaterialfv");
}

static void APIENTRY noopGetMaterialiv(GLenum face, GLenum pname, GLint *params)
{
   (void) face; (void) pname; (void) params;
   noop_warn("glGetMaterialiv");
}

static void APIENTRY noopGetMultisamplefv(GLenum pname, GLuint index, GLfloat *val)
{
   (void) pname; (void) index; (void) val;
   noop_warn("glGetMultisamplefv");
}

static void APIENTRY noopGetNamedBufferParameteri64v(GLuint buffer, GLenum pname, GLint64 *params)
{
   (void) buffer; (void) pname; (void) params;
   noop_warn("glGetNamedBufferParameteri64v");
}

static void APIENTRY noopGetNamedBufferParameteriv(GLuint buffer, GLenum pname, GLint *params)
{
   (void) buffer; (void) pname; (void) params;
   noop_warn("glGetNamedBufferParameteriv");
}

static void APIENTRY noopGetNamedBufferPointerv(GLuint buffer, GLenum pname, void **params)
{
   (void) buffer; (void) pname; (void) params;
   noop_warn("glGetNamedBufferPointerv");
}

static void APIENTRY noopGetNamedBufferSubData(GLuint buffer, GLintptr offset, GLsizeiptr size, void *data)
{
   (void) buffer; (void) offset; (void) size; (void) data;
   noop_warn("glGetNamedBufferSubData");
}

static void APIENTRY noopGetNamedFramebufferAttachmentParameteriv(GLuint framebuffer, GLenum attachment, GLenum pname, GLint *params)
{
   (void) framebuffer; (void) attachment; (void) pname; (void) params;
   noop_warn("glGetNamedFramebufferAttachmentParameteriv");
}

static void APIENTRY noopGetNamedFramebufferParameteriv(GLuint framebuffer, GLenum pname, GLint *param)
{
   (void) framebuffer; (void) pname; (void) param;
   noop_warn("glGetNamedFramebufferParameteriv");
}

static void APIENTRY noopGetNamedRenderbufferParameteriv(GLuint renderbuffer, GLenum pname, GLint *params)
{
   (void) renderbuffer; (void) pname; (void) params;
   noop_warn("glGetNamedRenderbufferParameteriv");
}

static void APIENTRY noopGetObjectLabel(GLenum identifier, GLuint name, GLsizei bufSize, GLsizei *length, GLchar *label)
{
   (void) identifier; (void) name; (void) bufSize; (void) length; (void) label;
   noop_warn("glGetObjectLabel");
}

static void APIENTRY noopGetObjectPtrLabel(const void *ptr, GLsizei bufSize, GLsizei *length, GLchar *label)
{
   (void) ptr; (void) bufSize; (void) length; (void) label;
   noop_warn("glGetObjectPtrLabel");
}

static void APIENTRY noopGetPixelMapfv(GLenum map, GLfloat *values)
{
   (void) map; (void) values;
   noop_warn("glGetPixelMapfv");
}

static void APIENTRY noopGetPixelMapuiv(GLenum map, GLuint *values)
{
   (void) map; (void) values;
   noop_warn("glGetPixelMapuiv");
}

static void APIENTRY noopGetPixelMapusv(GLenum map, GLushort *values)
{
   (void) map; (void) values;
   noop_warn("glGetPixelMapusv");
}

static void APIENTRY noopGetPointerv(GLenum pname, void **params)
{
   (void) pname; (void) params;
   noop_warn("glGetPointerv");
}

static void APIENTRY noopGetPolygonStipple(GLubyte *mask)
{
   (void) mask;
   noop_warn("glGetPolygonStipple");
}

static void APIENTRY noopGetProgramBinary(GLuint program, GLsizei bufSize, GLsizei *length, GLenum *binaryFormat, void *binary)
{
   (void) program; (void) bufSize; (void) length; (void) binaryFormat; (void) binary;
   noop_warn("glGetProgramBinary");
}

static void APIENTRY noopGetProgramInfoLog(GLuint program, GLsizei bufSize, GLsizei *length, GLchar *infoLog)
{
   (void) program; (void) bufSize; (void) length; (void) infoLog;
   noop_warn("glGetProgramInfoLog");
}

static void APIENTRY noopGetProgramInterfaceiv(GLuint program, GLenum programInterface, GLenum pname, GLint *params)
{
   (void) program; (void) programInterface; (void) pname; (void) params;
   noop_warn("glGetProgramInterfaceiv");
}

static void APIENTRY noopGetProgramPipelineInfoLog(GLuint pipeline, GLsizei bufSize, GLsizei *length, GLchar *infoLog)
{
   (void) pipeline; (void) bufSize; (void) length; (void) infoLog;
   noop_warn("glGetProgramPipelineInfoLog");
}

static void APIENTRY noopGetProgramPipelineiv(GLuint pipeline, GLenum pname, GLint *params)
{
   (void) pipeline; (void) pname; (void) params;
   noop_warn("glGetProgramPipelineiv");
}

static GLuint APIENTRY noopGetProgramResourceIndex(GLuint program, GLenum programInterface, const GLchar *name)
{
   (void) program; (void) programInterface; (void) name;
   noop_warn("glGetProgramResourceIndex");
   return (GLuint) 0;
}

static GLint APIENTRY noopGetProgramResourceLocation(GLuint program, GLenum programInterface, const GLchar *name)
{
   (void) program; (void) programInterface; (void) name;
   noop_warn("glGetProgramResourceLocation");
   return (GLint) 0;
}

static GLint APIENTRY noopGetProgramResourceLocationIndex(GLuint program, GLenum programInterface, const GLchar *name)
{
   (void) program; (void) programInterface; (void) name;
   noop_warn("glGetProgramResourceLocationIndex");
   return (GLint) 0;
}

static void APIENTRY noopGetProgramResourceName(GLuint program, GLenum programInterface, GLuint index, GLsizei bufSize, GLsizei *length, GLchar *name)
{
   (void) program; (void) programInterface; (void) index; (void) bufSize; (void) length; (void) name;
   noop_warn("glGetProgramResourceName");
}

static void APIENTRY noopGetProgramResourceiv(GLuint program, GLenum programInterface, GLuint index, GLsizei propCount, const GLenum *props, GLsizei count, GLsizei *length, GLint *params)
{
   (void) program; (void) programInterface; (void) index; (void) propCount; (void) props; (void) count; (void) length; (void) params;
   noop_warn("glGetProgramResourceiv");
}

static void APIENTRY noopGetProgramStageiv(GLuint program, GLenum shadertype, GLenum pname, GLint *values)
{
   (void) program; (void) shadertype; (void) pname; (void) values;
   noop_warn("glGetProgramStageiv");
}

static void APIENTRY noopGetProgramiv(GLuint program, GLenum pname, GLint *params)
{
   (void) program; (void) pname; (void) params;
   noop_warn("glGetProgramiv");
}

static void APIENTRY noopGetQueryBufferObjecti64v(GLuint id, GLuint buffer, GLenum pname, GLintptr offset)
{
   (void) id; (void) buffer; (void) pname; (void) offset;
   noop_warn("glGetQueryBufferObjecti64v");
}

static void APIENTRY noopGetQueryBufferObjectiv(GLuint id, GLuint buffer, GLenum pname, GLintptr offset)
{
   (void) id; (void) buffer; (void) pname; (void) offset;
   noop_warn("glGetQueryBufferObjectiv");
}

static void APIENTRY noopGetQueryBufferObjectui64v(GLuint id, GLuint buffer, GLenum pname, GLintptr offset)
{
   (void) id; (void) buffer; (void) pname; (void) offset;
   noop_warn("glGetQueryBufferObjectui64v");
}

static void APIENTRY noopGetQueryBufferObjectuiv(GLuint id, GLuint buffer, GLenum pname, GLintptr offset)
{
   (void) id; (void) buffer; (void) pname; (void) offset;
   noop_warn("glGetQueryBufferObjectuiv");
}

static void APIENTRY noopGetQueryIndexediv(GLenum target, GLuint index, GLenum pname, GLint *params)
{
   (void) target; (void) index; (void) pname; (void) params;
   noop_warn("glGetQueryIndexediv");
}

static void APIENTRY noopGetQueryObjecti64v(GLuint id, GLenum pname, GLint64 *params)
{
   (void) id; (void) pname; (void) params;
   noop_warn("glGetQueryObjecti64v");
}

static void APIENTRY noopGetQueryObjectiv(GLuint id, GLenum pname, GLint *params)
{
   (void) id; (void) pname; (void) params;
   noop_warn("glGetQueryObjectiv");
}

static void APIENTRY noopGetQueryObjectui64v(GLuint id, GLenum pname, GLuint64 *params)
{
   (void) id; (void) pname; (void) params;
   noop_warn("glGetQueryObjectui64v");
}

static void APIENTRY noopGetQueryObjectuiv(GLuint id, GLenum pname, GLuint *params)
{
   (void) id; (void) pname; (void) params;
   noop_warn("glGetQueryObjectuiv");
}

static void APIENTRY noopGetQueryiv(GLenum target, GLenum pname, GLint *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetQueryiv");
}

static void APIENTRY noopGetRenderbufferParameteriv(GLenum target, GLenum pname, GLint *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetRenderbufferParameteriv");
}

static void APIENTRY noopGetSamplerParameterIiv(GLuint sampler, GLenum pname, GLint *params)
{
   (void) sampler; (void) pname; (void) params;
   noop_warn("glGetSamplerParameterIiv");
}

static void APIENTRY noopGetSamplerParameterIuiv(GLuint sampler, GLenum pname, GLuint *params)
{
   (void) sampler; (void) pname; (void) params;
   noop_warn("glGetSamplerParameterIuiv");
}

static void APIENTRY noopGetSamplerParameterfv(GLuint sampler, GLenum pname, GLfloat *params)
{
   (void) sampler; (void) pname; (void) params;
   noop_warn("glGetSamplerParameterfv");
}

static void APIENTRY noopGetSamplerParameteriv(GLuint sampler, GLenum pname, GLint *params)
{
   (void) sampler; (void) pname; (void) params;
   noop_warn("glGetSamplerParameteriv");
}

static void APIENTRY noopGetShaderInfoLog(GLuint shader, GLsizei bufSize, GLsizei *length, GLchar *infoLog)
{
   (void) shader; (void) bufSize; (void) length; (void) infoLog;
   noop_warn("glGetShaderInfoLog");
}

static void APIENTRY noopGetShaderPrecisionFormat(GLenum shadertype, GLenum precisiontype, GLint *range, GLint *precision)
{
   (void) shadertype; (void) precisiontype; (void) range; (void) precision;
   noop_warn("glGetShaderPrecisionFormat");
}

static void APIENTRY noopGetShaderSource(GLuint shader, GLsizei bufSize, GLsizei *length, GLchar *source)
{
   (void) shader; (void) bufSize; (void) length; (void) source;
   noop_warn("glGetShaderSource");
}

static void APIENTRY noopGetShaderiv(GLuint shader, GLenum pname, GLint *params)
{
   (void) shader; (void) pname; (void) params;
   noop_warn("glGetShaderiv");
}

static const GLubyte * APIENTRY noopGetString(GLenum name)
{
   (void) name;
   noop_warn("glGetString");
   return (const GLubyte *) 0;
}

static const GLubyte * APIENTRY noopGetStringi(GLenum name, GLuint index)
{
   (void) name; (void) index;
   noop_warn("glGetStringi");
   return (const GLubyte *) 0;
}

static GLuint APIENTRY noopGetSubroutineIndex(GLuint program, GLenum shadertype, const GLchar *name)
{
   (void) program; (void) shadertype; (void) name;
   noop_warn("glGetSubroutineIndex");
   return (GLuint) 0;
}

static GLint APIENTRY noopGetSubroutineUniformLocation(GLuint program, GLenum shadertype, const GLchar *name)
{
   (void) program; (void) shadertype; (void) name;
   noop_warn("glGetSubroutineUniformLocation");
   return (GLint) 0;
}

static void APIENTRY noopGetSynciv(GLsync sync, GLenum pname, GLsizei count, GLsizei *length, GLint *values)
{
   (void) sync; (void) pname; (void) count; (void) length; (void) values;
   noop_warn("glGetSynciv");
}

static void APIENTRY noopGetTexEnvfv(GLenum target, GLenum pname, GLfloat *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetTexEnvfv");
}

static void APIENTRY noopGetTexEnviv(GLenum target, GLenum pname, GLint *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetTexEnviv");
}

static void APIENTRY noopGetTexGendv(GLenum coord, GLenum pname, GLdouble *params)
{
   (void) coord; (void) pname; (void) params;
   noop_warn("glGetTexGendv");
}

static void APIENTRY noopGetTexGenfv(GLenum coord, GLenum pname, GLfloat *params)
{
   (void) coord; (void) pname; (void) params;
   noop_warn("glGetTexGenfv");
}

static void APIENTRY noopGetTexGeniv(GLenum coord, GLenum pname, GLint *params)
{
   (void) coord; (void) pname; (void) params;
   noop_warn("glGetTexGeniv");
}

static void APIENTRY noopGetTexImage(GLenum target, GLint level, GLenum format, GLenum type, void *pixels)
{
   (void) target; (void) level; (void) format; (void) type; (void) pixels;
   noop_warn("glGetTexImage");
}

static void APIENTRY noopGetTexLevelParameterfv(GLenum target, GLint level, GLenum pname, GLfloat *params)
{
   (void) target; (void) level; (void) pname; (void) params;
   noop_warn("glGetTexLevelParameterfv");
}

static void APIENTRY noopGetTexLevelParameteriv(GLenum target, GLint level, GLenum pname, GLint *params)
{
   (void) target; (void) level; (void) pname; (void) params;
   noop_warn("glGetTexLevelParameteriv");
}

static void APIENTRY noopGetTexParameterIiv(GLenum target, GLenum pname, GLint *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetTexParameterIiv");
}

static void APIENTRY noopGetTexParameterIuiv(GLenum target, GLenum pname, GLuint *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetTexParameterIuiv");
}

static void APIENTRY noopGetTexParameterfv(GLenum target, GLenum pname, GLfloat *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetTexParameterfv");
}

static void APIENTRY noopGetTexParameteriv(GLenum target, GLenum pname, GLint *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetTexParameteriv");
}

static void APIENTRY noopGetTextureImage(GLuint texture, GLint level, GLenum format, GLenum type, GLsizei bufSize, void *pixels)
{
   (void) texture; (void) level; (void) format; (void) type; (void) bufSize; (void) pixels;
   noop_warn("glGetTextureImage");
}

static void APIENTRY noopGetTextureLevelParameterfv(GLuint texture, GLint level, GLenum pname, GLfloat *params)
{
   (void) texture; (void) level; (void) pname; (void) params;
   noop_warn("glGetTextureLevelParameterfv");
}

static void APIENTRY noopGetTextureLevelParameteriv(GLuint texture, GLint level, GLenum pname, GLint *params)
{
   (void) texture; (void) level; (void) pname; (void) params;
   noop_warn("glGetTextureLevelParameteriv");
}

static void APIENTRY noopGetTextureParameterIiv(GLuint texture, GLenum pname, GLint *params)
{
   (void) texture; (void) pname; (void) params;
   noop_warn("glGetTextureParameterIiv");
}

static void APIENTRY noopGetTextureParameterIuiv(GLuint texture, GLenum pname, GLuint *params)
{
   (void) texture; (void) pname; (void) params;
   noop_warn("glGetTextureParameterIuiv");
}

static void APIENTRY noopGetTextureParameterfv(GLuint texture, GLenum pname, GLfloat *params)
{
   (void) texture; (void) pname; (void) params;
   noop_warn("glGetTextureParameterfv");
}

static void APIENTRY noopGetTextureParameteriv(GLuint texture, GLenum pname, GLint *params)
{
   (void) texture; (void) pname; (void) params;
   noop_warn("glGetTextureParameteriv");
}

static void APIENTRY noopGetTextureSubImage(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, GLsizei bufSize, void *pixels)
{
   (void) texture; (void) level; (void) xoffset; (void) yoffset; (void) zoffset; (void) width; (void) height; (void) depth; (void) format; (void) type; (void) bufSize; (void) pixels;
   noop_warn("glGetTextureSubImage");
}

static void APIENTRY noopGetTransformFeedbackVarying(GLuint program, GLuint index, GLsizei bufSize, GLsizei *length, GLsizei *size, GLenum *type, GLchar *name)
{
   (void) program; (void) index; (void) bufSize; (void) length; (void) size; (void) type; (void) name;
   noop_warn("glGetTransformFeedbackVarying");
}

static void APIENTRY noopGetTransformFeedbacki64_v(GLuint xfb, GLenum pname, GLuint index, GLint64 *param)
{
   (void) xfb; (void) pname; (void) index; (void) param;
   noop_warn("glGetTransformFeedbacki64_v");
}

static void APIENTRY noopGetTransformFeedbacki_v(GLuint xfb, GLenum pname, GLuint index, GLint *param)
{
   (void) xfb; (void) pname; (void) index; (void) param;
   noop_warn("glGetTransformFeedbacki_v");
}

static void APIENTRY noopGetTransformFeedbackiv(GLuint xfb, GLenum pname, GLint *param)
{
   (void) xfb; (void) pname; (void) param;
   noop_warn("glGetTransformFeedbackiv");
}

static GLuint APIENTRY noopGetUniformBlockIndex(GLuint program, const GLchar *uniformBlockName)
{
   (void) program; (void) uniformBlockName;
   noop_warn("glGetUniformBlockIndex");
   return (GLuint) 0;
}

static void APIENTRY noopGetUniformIndices(GLuint program, GLsizei uniformCount, const GLchar *const *uniformNames, GLuint *uniformIndices)
{
   (void) program; (void) uniformCount; (void) uniformNames; (void) uniformIndices;
   noop_warn("glGetUniformIndices");
}

static GLint APIENTRY noopGetUniformLocation(GLuint program, const GLchar *name)
{
   (void) program; (void) name;
   noop_warn("glGetUniformLocation");
   return (GLint) 0;
}

static void APIENTRY noopGetUniformSubroutineuiv(GLenum shadertype, GLint location, GLuint *params)
{
   (void) shadertype; (void) location; (void) params;
   noop_warn("glGetUniformSubroutineuiv");
}

static void APIENTRY noopGetUniformdv(GLuint program, GLint location, GLdouble *params)
{
   (void) program; (void) location; (void) params;
   noop_warn("glGetUniformdv");
}

static void APIENTRY noopGetUniformfv(GLuint program, GLint location, GLfloat *params)
{
   (void) program; (void) location; (void) params;
   noop_warn("glGetUniformfv");
}

static void APIENTRY noopGetUniformiv(GLuint program, GLint location, GLint *params)
{
   (void) program; (void) location; (void) params;
   noop_warn("glGetUniformiv");
}

static void APIENTRY noopGetUniformuiv(GLuint program, GLint location, GLuint *params)
{
   (void) program; (void) location; (void) params;
   noop_warn("glGetUniformuiv");
}

static void APIENTRY noopGetVertexArrayIndexed64iv(GLuint vaobj, GLuint index, GLenum pname, GLint64 *param)
{
   (void) vaobj; (void) index; (void) pname; (void) param;
   noop_warn("glGetVertexArrayIndexed64iv");
}

static void APIENTRY noopGetVertexArrayIndexediv(GLuint vaobj, GLuint index, GLenum pname, GLint *param)
{
   (void) vaobj; (void) index; (void) pname; (void) param;
   noop_warn("glGetVertexArrayIndexediv");
}

static void APIENTRY noopGetVertexArrayiv(GLuint vaobj, GLenum pname, GLint *param)
{
   (void) vaobj; (void) pname; (void) param;
   noop_warn("glGetVertexArrayiv");
}

static void APIENTRY noopGetVertexAttribIiv(GLuint index, GLenum pname, GLint *params)
{
   (void) index; (void) pname; (void) params;
   noop_warn("glGetVertexAttribIiv");
}

static void APIENTRY noopGetVertexAttribIuiv(GLuint index, GLenum pname, GLuint *params)
{
   (void) index; (void) pname; (void) params;
   noop_warn("glGetVertexAttribIuiv");
}

static void APIENTRY noopGetVertexAttribLdv(GLuint index, GLenum pname, GLdouble *params)
{
   (void) index; (void) pname; (void) params;
   noop_warn("glGetVertexAttribLdv");
}

static void APIENTRY noopGetVertexAttribPointerv(GLuint index, GLenum pname, void **pointer)
{
   (void) index; (void) pname; (void) pointer;
   noop_warn("glGetVertexAttribPointerv");
}

static void APIENTRY noopGetVertexAttribdv(GLuint index, GLenum pname, GLdouble *params)
{
   (void) index; (void) pname; (void) params;
   noop_warn("glGetVertexAttribdv");
}

static void APIENTRY noopGetVertexAttribfv(GLuint index, GLenum pname, GLfloat *params)
{
   (void) index; (void) pname; (void) params;
   noop_warn("glGetVertexAttribfv");
}

static void APIENTRY noopGetVertexAttribiv(GLuint index, GLenum pname, GLint *params)
{
   (void) index; (void) pname; (void) params;
   noop_warn("glGetVertexAttribiv");
}

static void APIENTRY noopGetnColorTable(GLenum target, GLenum format, GLenum type, GLsizei bufSize, void *table)
{
   (void) target; (void) format; (void) type; (void) bufSize; (void) table;
   noop_warn("glGetnColorTable");
}

static void APIENTRY noopGetnCompressedTexImage(GLenum target, GLint lod, GLsizei bufSize, void *pixels)
{
   (void) target; (void) lod; (void) bufSize; (void) pixels;
   noop_warn("glGetnCompressedTexImage");
}

static void APIENTRY noopGetnConvolutionFilter(GLenum target, GLenum format, GLenum type, GLsizei bufSize, void *image)
{
   (void) target; (void) format; (void) type; (void) bufSize; (void) image;
   noop_warn("glGetnConvolutionFilter");
}

static void APIENTRY noopGetnHistogram(GLenum target, GLboolean reset, GLenum format, GLenum type, GLsizei bufSize, void *values)
{
   (void) target; (void) reset; (void) format; (void) type; (void) bufSize; (void) values;
   noop_warn("glGetnHistogram");
}

static void APIENTRY noopGetnMapdv(GLenum target, GLenum query, GLsizei bufSize, GLdouble *v)
{
   (void) target; (void) query; (void) bufSize; (void) v;
   noop_warn("glGetnMapdv");
}

static void APIENTRY noopGetnMapfv(GLenum target, GLenum query, GLsizei bufSize, GLfloat *v)
{
   (void) target; (void) query; (void) bufSize; (void) v;
   noop_warn("glGetnMapfv");
}

static void APIENTRY noopGetnMapiv(GLenum target, GLenum query, GLsizei bufSize, GLint *v)
{
   (void) target; (void) query; (void) bufSize; (void) v;
   noop_warn("glGetnMapiv");
}

static void APIENTRY noopGetnMinmax(GLenum target, GLboolean reset, GLenum format, GLenum type, GLsizei bufSize, void *values)
{
   (void) target; (void) reset; (void) format; (void) type; (void) bufSize; (void) values;
   noop_warn("glGetnMinmax");
}

static void APIENTRY noopGetnPixelMapfv(GLenum map, GLsizei bufSize, GLfloat *values)
{
   (void) map; (void) bufSize; (void) values;
   noop_warn("glGetnPixelMapfv");
}

static void APIENTRY noopGetnPixelMapuiv(GLenum map, GLsizei bufSize, GLuint *values)
{
   (void) map; (void) bufSize; (void) values;
   noop_warn("glGetnPixelMapuiv");
}

static void APIENTRY noopGetnPixelMapusv(GLenum map, GLsizei bufSize, GLushort *values)
{
   (void) map; (void) bufSize; (void) values;
   noop_warn("glGetnPixelMapusv");
}

static void APIENTRY noopGetnPolygonStipple(GLsizei bufSize, GLubyte *pattern)
{
   (void) bufSize; (void) pattern;
   noop_warn("glGetnPolygonStipple");
}

static void APIENTRY noopGetnSeparableFilter(GLenum target, GLenum format, GLenum type, GLsizei rowBufSize, void *row, GLsizei columnBufSize, void *column, void *span)
{
   (void) target; (void) format; (void) type; (void) rowBufSize; (void) row; (void) columnBufSize; (void) column; (void) span;
   noop_warn("glGetnSeparableFilter");
}

static void APIENTRY noopGetnTexImage(GLenum target, GLint level, GLenum format, GLenum type, GLsizei bufSize, void *pixels)
{
   (void) target; (void) level; (void) format; (void) type; (void) bufSize; (void) pixels;
   noop_warn("glGetnTexImage");
}

static void APIENTRY noopGetnUniformdv(GLuint program, GLint location, GLsizei bufSize, GLdouble *params)
{
   (void) program; (void) location; (void) bufSize; (void) params;
   noop_warn("glGetnUniformdv");
}

static void APIENTRY noopGetnUniformfv(GLuint program, GLint location, GLsizei bufSize, GLfloat *params)
{
   (void) program; (void) location; (void) bufSize; (void) params;
   noop_warn("glGetnUniformfv");
}

static void APIENTRY noopGetnUniformiv(GLuint program, GLint location, GLsizei bufSize, GLint *params)
{
   (void) program; (void) location; (void) bufSize; (void) params;
   noop_warn("glGetnUniformiv");
}

static void APIENTRY noopGetnUniformuiv(GLuint program, GLint location, GLsizei bufSize, GLuint *params)
{
   (void) program; (void) location; (void) bufSize; (void) params;
   noop_warn("glGetnUniformuiv");
}

static void APIENTRY noopHint(GLenum target, GLenum mode)
{
   (void) target; (void) mode;
   noop_warn("glHint");
}

static void APIENTRY noopIndexMask(GLuint mask)
{
   (void) mask;
   noop_warn("glIndexMask");
}

static void APIENTRY noopIndexPointer(GLenum type, GLsizei stride, const void *pointer)
{
   (void) type; (void) stride; (void) pointer;
   noop_warn("glIndexPointer");
}

static void APIENTRY noopIndexd(GLdouble c)
{
   (void) c;
   noop_warn("glIndexd");
}

static void APIENTRY noopIndexdv(const GLdouble *c)
{
   (void) c;
   noop_warn("glIndexdv");
}

static void APIENTRY noopIndexf(GLfloat c)
{
   (void) c;
   noop_warn("glIndexf");
}

static void APIENTRY noopIndexfv(const GLfloat *c)
{
   (void) c;
   noop_warn("glIndexfv");
}

static void APIENTRY noopIndexi(GLint c)
{
   (void) c;
   noop_warn("glIndexi");
}

static void APIENTRY noopIndexiv(const GLint *c)
{
   (void) c;
   noop_warn("glIndexiv");
}

static void APIENTRY noopIndexs(GLshort c)
{
   (void) c;
   noop_warn("glIndexs");
}

static void APIENTRY noopIndexsv(const GLshort *c)
{
   (void) c;
   noop_warn("glIndexsv");
}

static void APIENTRY noopIndexub(GLubyte c)
{
   (void) c;
   noop_warn("glIndexub");
}

static void APIENTRY noopIndexubv(const GLubyte *c)
{
   (void) c;
   noop_warn("glIndexubv");
}

static void APIENTRY noopInitNames(void)
{
   noop_warn("glInitNames");
}

static void APIENTRY noopInterleavedArrays(GLenum format, GLsizei stride, const void *pointer)
{
   (void) format; (void) stride; (void) pointer;
   noop_warn("glInterleavedArrays");
}

static void APIENTRY noopInvalidateBufferData(GLuint buffer)
{
   (void) buffer;
   noop_warn("glInvalidateBufferData");
}

static void APIENTRY noopInvalidateBufferSubData(GLuint buffer, GLintptr offset, GLsizeiptr length)
{
   (void) buffer; (void) offset; (void) length;
   noop_warn("glInvalidateBufferSubData");
}

static void APIENTRY noopInvalidateFramebuffer(GLenum target, GLsizei numAttachments, const GLenum *attachments)
{
   (void) target; (void) numAttachments; (void) attachments;
   noop_warn("glInvalidateFramebuffer");
}

static void APIENTRY noopInvalidateNamedFramebufferData(GLuint framebuffer, GLsizei numAttachments, const GLenum *attachments)
{
   (void) framebuffer; (void) numAttachments; (void) attachments;
   noop_warn("glInvalidateNamedFramebufferData");
}

static void APIENTRY noopInvalidateNamedFramebufferSubData(GLuint framebuffer, GLsizei numAttachments, const GLenum *attachments, GLint x, GLint y, GLsizei width, GLsizei height)
{
   (void) framebuffer; (void) numAttachments; (void) attachments; (void) x; (void) y; (void) width; (void) height;
   noop_warn("glInvalidateNamedFramebufferSubData");
}

static void APIENTRY noopInvalidateSubFramebuffer(GLenum target, GLsizei numAttachments, const GLenum *attachments, GLint x, GLint y, GLsizei width, GLsizei height)
{
   (void) target; (void) numAttachments; (void) attachments; (void) x; (void) y; (void) width; (void) height;
   noop_warn("glInvalidateSubFramebuffer");
}

static void APIENTRY noopInvalidateTexImage(GLuint texture, GLint level)
{
   (void) texture; (void) level;
   noop_warn("glInvalidateTexImage");
}

static void APIENTRY noopInvalidateTexSubImage(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth)
{
   (void) texture; (void) level; (void) xoffset; (void) yoffset; (void) zoffset; (void) width; (void) height; (void) depth;
   noop_warn("glInvalidateTexSubImage");
}

static GLboolean APIENTRY noopIsBuffer(GLuint buffer)
{
   (void) buffer;
   noop_warn("glIsBuffer");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsEnabled(GLenum cap)
{
   (void) cap;
   noop_warn("glIsEnabled");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsEnabledi(GLenum target, GLuint index)
{
   (void) target; (void) index;
   noop_warn("glIsEnabledi");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsFramebuffer(GLuint framebuffer)
{
   (void) framebuffer;
   noop_warn("glIsFramebuffer");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsList(GLuint list)
{
   (void) list;
   noop_warn("glIsList");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsProgram(GLuint program)
{
   (void) program;
   noop_warn("glIsProgram");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsProgramPipeline(GLuint pipeline)
{
   (void) pipeline;
   noop_warn("glIsProgramPipeline");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsQuery(GLuint id)
{
   (void) id;
   noop_warn("glIsQuery");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsRenderbuffer(GLuint renderbuffer)
{
   (void) renderbuffer;
   noop_warn("glIsRenderbuffer");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsSampler(GLuint sampler)
{
   (void) sampler;
   noop_warn("glIsSampler");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsShader(GLuint shader)
{
   (void) shader;
   noop_warn("glIsShader");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsSync(GLsync sync)
{
   (void) sync;
   noop_warn("glIsSync");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsTexture(GLuint texture)
{
   (void) texture;
   noop_warn("glIsTexture");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsTransformFeedback(GLuint id)
{
   (void) id;
   noop_warn("glIsTransformFeedback");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsVertexArray(GLuint array)
{
   (void) array;
   noop_warn("glIsVertexArray");
   return (GLboolean) 0;
}

static void APIENTRY noopLightModelf(GLenum pname, GLfloat param)
{
   (void) pname; (void) param;
   noop_warn("glLightModelf");
}

static void APIENTRY noopLightModelfv(GLenum pname, const GLfloat *params)
{
   (void) pname; (void) params;
   noop_warn("glLightModelfv");
}

static void APIENTRY noopLightModeli(GLenum pname, GLint param)
{
   (void) pname; (void) param;
   noop_warn("glLightModeli");
}

static void APIENTRY noopLightModeliv(GLenum pname, const GLint *params)
{
   (void) pname; (void) params;
   noop_warn("glLightModeliv");
}

static void APIENTRY noopLightf(GLenum light, GLenum pname, GLfloat param)
{
   (void) light; (void) pname; (void) param;
   noop_warn("glLightf");
}

static void APIENTRY noopLightfv(GLenum light, GLenum pname, const GLfloat *params)
{
   (void) light; (void) pname; (void) params;
   noop_warn("glLightfv");
}

static void APIENTRY noopLighti(GLenum light, GLenum pname, GLint param)
{
   (void) light; (void) pname; (void) param;
   noop_warn("glLighti");
}

static void APIENTRY noopLightiv(GLenum light, GLenum pname, const GLint *params)
{
   (void) light; (void) pname; (void) params;
   noop_warn("glLightiv");
}

static void APIENTRY noopLineStipple(GLint factor, GLushort pattern)
{
   (void) factor; (void) pattern;
   noop_warn("glLineStipple");
}

static void APIENTRY noopLineWidth(GLfloat width)
{
   (void) width;
   noop_warn("glLineWidth");
}

static void APIENTRY noopLinkProgram(GLuint program)
{
   (void) program;
   noop_warn("glLinkProgram");
}

static void APIENTRY noopListBase(GLuint base)
{
   (void) base;
   noop_warn("glListBase");
}

static void APIENTRY noopLoadIdentity(void)
{
   noop_warn("glLoadIdentity");
}

static void APIENTRY noopLoadMatrixd(const GLdouble *m)
{
   (void) m;
   noop_warn("glLoadMatrixd");
}

static void APIENTRY noopLoadMatrixf(const GLfloat *m)
{
   (void) m;
   noop_warn("glLoadMatrixf");
}

static void APIENTRY noopLoadName(GLuint name)
{
   (void) name;
   noop_warn("glLoadName");
}

static void APIENTRY noopLoadTransposeMatrixd(const GLdouble *m)
{
   (void) m;
   noop_warn("glLoadTransposeMatrixd");
}

static void APIENTRY noopLoadTransposeMatrixf(const GLfloat *m)
{
   (void) m;
   noop_warn("glLoadTransposeMatrixf");
}

static void APIENTRY noopLogicOp(GLenum opcode)
{
   (void) opcode;
   noop_warn("glLogicOp");
}

static void APIENTRY noopMap1d(GLenum target, GLdouble u1, GLdouble u2, GLint stride, GLint order, const GLdouble *points)
{
   (void) target; (void) u1; (void) u2; (void) stride; (void) order; (void) points;
   noop_warn("glMap1d");
}

static void APIENTRY noopMap1f(GLenum target, GLfloat u1, GLfloat u2, GLint stride, GLint order, const GLfloat *points)
{
   (void) target; (void) u1; (void) u2; (void) stride; (void) order; (void) points;
   noop_warn("glMap1f");
}

static void APIENTRY noopMap2d(GLenum target, GLdouble u1, GLdouble u2, GLint ustride, GLint uorder, GLdouble v1, GLdouble v2, GLint vstride, GLint vorder, const GLdouble *points)
{
   (void) target; (void) u1; (void) u2; (void) ustride; (void) uorder; (void) v1; (void) v2; (void) vstride; (void) vorder; (void) points;
   noop_warn("glMap2d");
}

static void APIENTRY noopMap2f(GLenum target, GLfloat u1, GLfloat u2, GLint ustride, GLint uorder, GLfloat v1, GLfloat v2, GLint vstride, GLint vorder, const GLfloat *points)
{
   (void) target; (void) u1; (void) u2; (void) ustride; (void) uorder; (void) v1; (void) v2; (void) vstride; (void) vorder; (void) points;
   noop_warn("glMap2f");
}

static void * APIENTRY noopMapBuffer(GLenum target, GLenum access)
{
   (void) target; (void) access;
   noop_warn("glMapBuffer");
   return (void *) 0;
}

static void * APIENTRY noopMapBufferRange(GLenum target, GLintptr offset, GLsizeiptr length, GLbitfield access)
{
   (void) target; (void) offset; (void) length; (void) access;
   noop_warn("glMapBufferRange");
   return (void *) 0;
}

static void APIENTRY noopMapGrid1d(GLint un, GLdouble u1, GLdouble u2)
{
   (void) un; (void) u1; (void) u2;
   noop_warn("glMapGrid1d");
}

static void APIENTRY noopMapGrid1f(GLint un, GLfloat u1, GLfloat u2)
{
   (void) un; (void) u1; (void) u2;
   noop_warn("glMapGrid1f");
}

static void APIENTRY noopMapGrid2d(GLint un, GLdouble u1, GLdouble u2, GLint vn, GLdouble v1, GLdouble v2)
{
   (void) un; (void) u1; (void) u2; (void) vn; (void) v1; (void) v2;
   noop_warn("glMapGrid2d");
}

static void APIENTRY noopMapGrid2f(GLint un, GLfloat u1, GLfloat u2, GLint vn, GLfloat v1, GLfloat v2)
{
   (void) un; (void) u1; (void) u2; (void) vn; (void) v1; (void) v2;
   noop_warn("glMapGrid2f");
}

static void * APIENTRY noopMapNamedBuffer(GLuint buffer, GLenum access)
{
   (void) buffer; (void) access;
   noop_warn("glMapNamedBuffer");
   return (void *) 0;
}

static void * APIENTRY noopMapNamedBufferRange(GLuint buffer, GLintptr offset, GLsizeiptr length, GLbitfield access)
{
   (void) buffer; (void) offset; (void) length; (void) access;
   noop_warn("glMapNamedBufferRange");
   return (void *) 0;
}

static void APIENTRY noopMaterialf(GLenum face, GLenum pname, GLfloat param)
{
   (void) face; (void) pname; (void) param;
   noop_warn("glMaterialf");
}

static void APIENTRY noopMaterialfv(GLenum face, GLenum pname, const GLfloat *params)
{
   (void) face; (void) pname; (void) params;
   noop_warn("glMaterialfv");
}

static void APIENTRY noopMateriali(GLenum face, GLenum pname, GLint param)
{
   (void) face; (void) pname; (void) param;
   noop_warn("glMateriali");
}

static void APIENTRY noopMaterialiv(GLenum face, GLenum pname, const GLint *params)
{
   (void) face; (void) pname; (void) params;
   noop_warn("glMaterialiv");
}

static void APIENTRY noopMatrixMode(GLenum mode)
{
   (void) mode;
   noop_warn("glMatrixMode");
}

static void APIENTRY noopMemoryBarrier(GLbitfield barriers)
{
   (void) barriers;
   noop_warn("glMemoryBarrier");
}

static void APIENTRY noopMemoryBarrierByRegion(GLbitfield barriers)
{
   (void) barriers;
   noop_warn("glMemoryBarrierByRegion");
}

static void APIENTRY noopMinSampleShading(GLfloat value)
{
   (void) value;
   noop_warn("glMinSampleShading");
}

static void APIENTRY noopMultMatrixd(const GLdouble *m)
{
   (void) m;
   noop_warn("glMultMatrixd");
}

static void APIENTRY noopMultMatrixf(const GLfloat *m)
{
   (void) m;
   noop_warn("glMultMatrixf");
}

static void APIENTRY noopMultTransposeMatrixd(const GLdouble *m)
{
   (void) m;
   noop_warn("glMultTransposeMatrixd");
}

static void APIENTRY noopMultTransposeMatrixf(const GLfloat *m)
{
   (void) m;
   noop_warn("glMultTransposeMatrixf");
}

static void APIENTRY noopMultiDrawArrays(GLenum mode, const GLint *first, const GLsizei *count, GLsizei drawcount)
{
   (void) mode; (void) first; (void) count; (void) drawcount;
   noop_warn("glMultiDrawArrays");
}

static void APIENTRY noopMultiDrawArraysIndirect(GLenum mode, const void *indirect, GLsizei drawcount, GLsizei stride)
{
   (void) mode; (void) indirect; (void) drawcount; (void) stride;
   noop_warn("glMultiDrawArraysIndirect");
}

static void APIENTRY noopMultiDrawElements(GLenum mode, const GLsizei *count, GLenum type, const void *const *indices, GLsizei drawcount)
{
   (void) mode; (void) count; (void) type; (void) indices; (void) drawcount;
   noop_warn("glMultiDrawElements");
}

static void APIENTRY noopMultiDrawElementsBaseVertex(GLenum mode, const GLsizei *count, GLenum type, const void *const *indices, GLsizei drawcount, const GLint *basevertex)
{
   (void) mode; (void) count; (void) type; (void) indices; (void) drawcount; (void) basevertex;
   noop_warn("glMultiDrawElementsBaseVertex");
}

static void APIENTRY noopMultiDrawElementsIndirect(GLenum mode, GLenum type, const void *indirect, GLsizei drawcount, GLsizei stride)
{
   (void) mode; (void) type; (void) indirect; (void) drawcount; (void) stride;
   noop_warn("glMultiDrawElementsIndirect");
}

static void APIENTRY noopMultiTexCoord1d(GLenum target, GLdouble s)
{
   (void) target; (void) s;
   noop_warn("glMultiTexCoord1d");
}

static void APIENTRY noopMultiTexCoord1dv(GLenum target, const GLdouble *v)
{
   (void) target; (void) v;
   noop_warn("glMultiTexCoord1dv");
}

static void APIENTRY noopMultiTexCoord1f(GLenum target, GLfloat s)
{
   (void) target; (void) s;
   noop_warn("glMultiTexCoord1f");
}

static void APIENTRY noopMultiTexCoord1fv(GLenum target, const GLfloat *v)
{
   (void) target; (void) v;
   noop_warn("glMultiTexCoord1fv");
}

static void APIENTRY noopMultiTexCoord1i(GLenum target, GLint s)
{
   (void) target; (void) s;
   noop_warn("glMultiTexCoord1i");
}

static void APIENTRY noopMultiTexCoord1iv(GLenum target, const GLint *v)
{
   (void) target; (void) v;
   noop_warn("glMultiTexCoord1iv");
}

static void APIENTRY noopMultiTexCoord1s(GLenum target, GLshort s)
{
   (void) target; (void) s;
   noop_warn("glMultiTexCoord1s");
}

static void APIENTRY noopMultiTexCoord1sv(GLenum target, const GLshort *v)
{
   (void) target; (void) v;
   noop_warn("glMultiTexCoord1sv");
}

static void APIENTRY noopMultiTexCoord2d(GLenum target, GLdouble s, GLdouble t)
{
   (void) target; (void) s; (void) t;
   noop_warn("glMultiTexCoord2d");
}

static void APIENTRY noopMultiTexCoord2dv(GLenum target, const GLdouble *v)
{
   (void) target; (void) v;
   noop_warn("glMultiTexCoord2dv");
}

static void APIENTRY noopMultiTexCoord2f(GLenum target, GLfloat s, GLfloat t)
{
   (void) target; (void) s; (void) t;
   noop_warn("glMultiTexCoord2f");
}

static void APIENTRY noopMultiTexCoord2fv(GLenum target, const GLfloat *v)
{
   (void) target; (void) v;
   noop_warn("glMultiTexCoord2fv");
}

static void APIENTRY noopMultiTexCoord2i(GLenum target, GLint s, GLint t)
{
   (void) target; (void) s; (void) t;
   noop_warn("glMultiTexCoord2i");
}

static void APIENTRY noopMultiTexCoord2iv(GLenum target, const GLint *v)
{
   (void) target; (void) v;
   noop_warn("glMultiTexCoord2iv");
}

static void APIENTRY noopMultiTexCoord2s(GLenum target, GLshort s, GLshort t)
{
   (void) target; (void) s; (void) t;
   noop_warn("glMultiTexCoord2s");
}

static void APIENTRY noopMultiTexCoord2sv(GLenum target, const GLshort *v)
{
   (void) target; (void) v;
   noop_warn("glMultiTexCoord2sv");
}

static void APIENTRY noopMultiTexCoord3d(GLenum target, GLdouble s, GLdouble t, GLdouble r)
{
   (void) target; (void) s; (void) t; (void) r;
   noop_warn("glMultiTexCoord3d");
}

static void APIENTRY noopMultiTexCoord3dv(GLenum target, const GLdouble *v)
{
   (void) target; (void) v;
   noop_warn("glMultiTexCoord3dv");
}

static void APIENTRY noopMultiTexCoord3f(GLenum target, GLfloat s, GLfloat t, GLfloat r)
{
   (void) target; (void) s; (void) t; (void) r;
   noop_warn("glMultiTexCoord3f");
}

static void APIENTRY noopMultiTexCoord3fv(GLenum target, const GLfloat *v)
{
   (void) target; (void) v;
   noop_warn("glMultiTexCoord3fv");
}

static void APIENTRY noopMultiTexCoord3i(GLenum target, GLint s, GLint t, GLint r)
{
   (void) target; (void) s; (void) t; (void) r;
   noop_warn("glMultiTexCoord3i");
}

static void APIENTRY noopMultiTexCoord3iv(GLenum target, const GLint *v)
{
   (void) target; (void) v;
   noop_warn("glMultiTexCoord3iv");
}

static void APIENTRY noopMultiTexCoord3s(GLenum target, GLshort s, GLshort t, GLshort r)
{
   (void) target; (void) s; (void) t; (void) r;
   noop_warn("glMultiTexCoord3s");
}

static void APIENTRY noopMultiTexCoord3sv(GLenum target, const GLshort *v)
{
   (void) target; (void) v;
   noop_warn("glMultiTexCoord3sv");
}

static void APIENTRY noopMultiTexCoord4d(GLenum target, GLdouble s, GLdouble t, GLdouble r, GLdouble q)
{
   (void) target; (void) s; (void) t; (void) r; (void) q;
   noop_warn("glMultiTexCoord4d");
}

static void APIENTRY noopMultiTexCoord4dv(GLenum target, const GLdouble *v)
{
   (void) target; (void) v;
   noop_warn("glMultiTexCoord4dv");
}

static void APIENTRY noopMultiTexCoord4f(GLenum target, GLfloat s, GLfloat t, GLfloat r, GLfloat q)
{
   (void) target; (void) s; (void) t; (void) r; (void) q;
   noop_warn("glMultiTexCoord4f");
}

static void APIENTRY noopMultiTexCoord4fv(GLenum target, const GLfloat *v)
{
   (void) target; (void) v;
   noop_warn("glMultiTexCoord4fv");
}

static void APIENTRY noopMultiTexCoord4i(GLenum target, GLint s, GLint t, GLint r, GLint q)
{
   (void) target; (void) s; (void) t; (void) r; (void) q;
   noop_warn("glMultiTexCoord4i");
}

static void APIENTRY noopMultiTexCoord4iv(GLenum target, const GLint *v)
{
   (void) target; (void) v;
   noop_warn("glMultiTexCoord4iv");
}

static void APIENTRY noopMultiTexCoord4s(GLenum target, GLshort s, GLshort t, GLshort r, GLshort q)
{
   (void) target; (void) s; (void) t; (void) r; (void) q;
   noop_warn("glMultiTexCoord4s");
}

static void APIENTRY noopMultiTexCoord4sv(GLenum target, const GLshort *v)
{
   (void) target; (void) v;
   noop_warn("glMultiTexCoord4sv");
}

static void APIENTRY noopMultiTexCoordP1ui(GLenum texture, GLenum type, GLuint coords)
{
   (void) texture; (void) type; (void) coords;
   noop_warn("glMultiTexCoordP1ui");
}

static void APIENTRY noopMultiTexCoordP1uiv(GLenum texture, GLenum type, const GLuint *coords)
{
   (void) texture; (void) type; (void) coords;
   noop_warn("glMultiTexCoordP1uiv");
}

static void APIENTRY noopMultiTexCoordP2ui(GLenum texture, GLenum type, GLuint coords)
{
   (void) texture; (void) type; (void) coords;
   noop_warn("glMultiTexCoordP2ui");
}

static void APIENTRY noopMultiTexCoordP2uiv(GLenum texture, GLenum type, const GLuint *coords)
{
   (void) texture; (void) type; (void) coords;
   noop_warn("glMultiTexCoordP2uiv");
}

static void APIENTRY noopMultiTexCoordP3ui(GLenum texture, GLenum type, GLuint coords)
{
   (void) texture; (void) type; (void) coords;
   noop_warn("glMultiTexCoordP3ui");
}

static void APIENTRY noopMultiTexCoordP3uiv(GLenum texture, GLenum type, const GLuint *coords)
{
   (void) texture; (void) type; (void) coords;
   noop_warn("glMultiTexCoordP3uiv");
}

static void APIENTRY noopMultiTexCoordP4ui(GLenum texture, GLenum type, GLuint coords)
{
   (void) texture; (void) type; (void) coords;
   noop_warn("glMultiTexCoordP4ui");
}

static void APIENTRY noopMultiTexCoordP4uiv(GLenum texture, GLenum type, const GLuint *coords)
{
   (void) texture; (void) type; (void) coords;
   noop_warn("glMultiTexCoordP4uiv");
}

static void APIENTRY noopNamedBufferData(GLuint buffer, GLsizeiptr size, const void *data, GLenum usage)
{
   (void) buffer; (void) size; (void) data; (void) usage;
   noop_warn("glNamedBufferData");
}

static void APIENTRY noopNamedBufferStorage(GLuint buffer, GLsizeiptr size, const void *data, GLbitfield flags)
{
   (void) buffer; (void) size; (void) data; (void) flags;
   noop_warn("glNamedBufferStorage");
}

static void APIENTRY noopNamedBufferSubData(GLuint buffer, GLintptr offset, GLsizeiptr size, const void *data)
{
   (void) buffer; (void) offset; (void) size; (void) data;
   noop_warn("glNamedBufferSubData");
}

static void APIENTRY noopNamedFramebufferDrawBuffer(GLuint framebuffer, GLenum buf)
{
   (void) framebuffer; (void) buf;
   noop_warn("glNamedFramebufferDrawBuffer");
}

static void APIENTRY noopNamedFramebufferDrawBuffers(GLuint framebuffer, GLsizei n, const GLenum *bufs)
{
   (void) framebuffer; (void) n; (void) bufs;
   noop_warn("glNamedFramebufferDrawBuffers");
}

static void APIENTRY noopNamedFramebufferParameteri(GLuint framebuffer, GLenum pname, GLint param)
{
   (void) framebuffer; (void) pname; (void) param;
   noop_warn("glNamedFramebufferParameteri");
}

static void APIENTRY noopNamedFramebufferReadBuffer(GLuint framebuffer, GLenum src)
{
   (void) framebuffer; (void) src;
   noop_warn("glNamedFramebufferReadBuffer");
}

static void APIENTRY noopNamedFramebufferRenderbuffer(GLuint framebuffer, GLenum attachment, GLenum renderbuffertarget, GLuint renderbuffer)
{
   (void) framebuffer; (void) attachment; (void) renderbuffertarget; (void) renderbuffer;
   noop_warn("glNamedFramebufferRenderbuffer");
}

static void APIENTRY noopNamedFramebufferTexture(GLuint framebuffer, GLenum attachment, GLuint texture, GLint level)
{
   (void) framebuffer; (void) attachment; (void) texture; (void) level;
   noop_warn("glNamedFramebufferTexture");
}

static void APIENTRY noopNamedFramebufferTextureLayer(GLuint framebuffer, GLenum attachment, GLuint texture, GLint level, GLint layer)
{
   (void) framebuffer; (void) attachment; (void) texture; (void) level; (void) layer;
   noop_warn("glNamedFramebufferTextureLayer");
}

static void APIENTRY noopNamedRenderbufferStorage(GLuint renderbuffer, GLenum internalformat, GLsizei width, GLsizei height)
{
   (void) renderbuffer; (void) internalformat; (void) width; (void) height;
   noop_warn("glNamedRenderbufferStorage");
}

static void APIENTRY noopNamedRenderbufferStorageMultisample(GLuint renderbuffer, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height)
{
   (void) renderbuffer; (void) samples; (void) internalformat; (void) width; (void) height;
   noop_warn("glNamedRenderbufferStorageMultisample");
}

static void APIENTRY noopNewList(GLuint list, GLenum mode)
{
   (void) list; (void) mode;
   noop_warn("glNewList");
}

static void APIENTRY noopNormal3b(GLbyte nx, GLbyte ny, GLbyte nz)
{
   (void) nx; (void) ny; (void) nz;
   noop_warn("glNormal3b");
}

static void APIENTRY noopNormal3bv(const GLbyte *v)
{
   (void) v;
   noop_warn("glNormal3bv");
}

static void APIENTRY noopNormal3d(GLdouble nx, GLdouble ny, GLdouble nz)
{
   (void) nx; (void) ny; (void) nz;
   noop_warn("glNormal3d");
}

static void APIENTRY noopNormal3dv(const GLdouble *v)
{
   (void) v;
   noop_warn("glNormal3dv");
}

static void APIENTRY noopNormal3f(GLfloat nx, GLfloat ny, GLfloat nz)
{
   (void) nx; (void) ny; (void) nz;
   noop_warn("glNormal3f");
}

static void APIENTRY noopNormal3fv(const GLfloat *v)
{
   (void) v;
   noop_warn("glNormal3fv");
}

static void APIENTRY noopNormal3i(GLint nx, GLint ny, GLint nz)
{
   (void) nx; (void) ny; (void) nz;
   noop_warn("glNormal3i");
}

static void APIENTRY noopNormal3iv(const GLint *v)
{
   (void) v;
   noop_warn("glNormal3iv");
}

static void APIENTRY noopNormal3s(GLshort nx, GLshort ny, GLshort nz)
{
   (void) nx; (void) ny; (void) nz;
   noop_warn("glNormal3s");
}

static void APIENTRY noopNormal3sv(const GLshort *v)
{
   (void) v;
   noop_warn("glNormal3sv");
}

static void APIENTRY noopNormalP3ui(GLenum type, GLuint coords)
{
   (void) type; (void) coords;
   noop_warn("glNormalP3ui");
}

static void APIENTRY noopNormalP3uiv(GLenum type, const GLuint *coords)
{
   (void) type; (void) coords;
   noop_warn("glNormalP3uiv");
}

static void APIENTRY noopNormalPointer(GLenum type, GLsizei stride, const void *pointer)
{
   (void) type; (void) stride; (void) pointer;
   noop_warn("glNormalPointer");
}

static void APIENTRY noopObjectLabel(GLenum identifier, GLuint name, GLsizei length, const GLchar *label)
{
   (void) identifier; (void) name; (void) length; (void) label;
   noop_warn("glObjectLabel");
}

static void APIENTRY noopObjectPtrLabel(const void *ptr, GLsizei length, const GLchar *label)
{
   (void) ptr; (void) length; (void) label;
   noop_warn("glObjectPtrLabel");
}

static void APIENTRY noopOrtho(GLdouble left, GLdouble right, GLdouble bottom, GLdouble top, GLdouble zNear, GLdouble zFar)
{
   (void) left; (void) right; (void) bottom; (void) top; (void) zNear; (void) zFar;
   noop_warn("glOrtho");
}

static void APIENTRY noopPassThrough(GLfloat token)
{
   (void) token;
   noop_warn("glPassThrough");
}

static void APIENTRY noopPatchParameterfv(GLenum pname, const GLfloat *values)
{
   (void) pname; (void) values;
   noop_warn("glPatchParameterfv");
}

static void APIENTRY noopPatchParameteri(GLenum pname, GLint value)
{
   (void) pname; (void) value;
   noop_warn("glPatchParameteri");
}

static void APIENTRY noopPauseTransformFeedback(void)
{
   noop_warn("glPauseTransformFeedback");
}

static void APIENTRY noopPixelMapfv(GLenum map, GLsizei mapsize, const GLfloat *values)
{
   (void) map; (void) mapsize; (void) values;
   noop_warn("glPixelMapfv");
}

static void APIENTRY noopPixelMapuiv(GLenum map, GLsizei mapsize, const GLuint *values)
{
   (void) map; (void) mapsize; (void) values;
   noop_warn("glPixelMapuiv");
}

static void APIENTRY noopPixelMapusv(GLenum map, GLsizei mapsize, const GLushort *values)
{
   (void) map; (void) mapsize; (void) values;
   noop_warn("glPixelMapusv");
}

static void APIENTRY noopPixelStoref(GLenum pname, GLfloat param)
{
   (void) pname; (void) param;
   noop_warn("glPixelStoref");
}

static void APIENTRY noopPixelStorei(GLenum pname, GLint param)
{
   (void) pname; (void) param;
   noop_warn("glPixelStorei");
}

static void APIENTRY noopPixelTransferf(GLenum pname, GLfloat param)
{
   (void) pname; (void) param;
   noop_warn("glPixelTransferf");
}

static void APIENTRY noopPixelTransferi(GLenum pname, GLint param)
{
   (void) pname; (void) param;
   noop_warn("glPixelTransferi");
}

static void APIENTRY noopPixelZoom(GLfloat xfactor, GLfloat yfactor)
{
   (void) xfactor; (void) yfactor;
   noop_warn("glPixelZoom");
}

static void APIENTRY noopPointParameterf(GLenum pname, GLfloat param)
{
   (void) pname; (void) param;
   noop_warn("glPointParameterf");
}

static void APIENTRY noopPointParameterfv(GLenum pname, const GLfloat *params)
{
   (void) pname; (void) params;
   noop_warn("glPointParameterfv");
}

static void APIENTRY noopPointParameteri(GLenum pname, GLint param)
{
   (void) pname; (void) param;
   noop_warn("glPointParameteri");
}

static void APIENTRY noopPointParameteriv(GLenum pname, const GLint *params)
{
   (void) pname; (void) params;
   noop_warn("glPointParameteriv");
}

static void APIENTRY noopPointSize(GLfloat size)
{
   (void) size;
   noop_warn("glPointSize");
}

static void APIENTRY noopPolygonMode(GLenum face, GLenum mode)
{
   (void) face; (void) mode;
   noop_warn("glPolygonMode");
}

static void APIENTRY noopPolygonOffset(GLfloat factor, GLfloat units)
{
   (void) factor; (void) units;
   noop_warn("glPolygonOffset");
}

static void APIENTRY noopPolygonStipple(const GLubyte *mask)
{
   (void) mask;
   noop_warn("glPolygonStipple");
}

static void APIENTRY noopPopAttrib(void)
{
   noop_warn("glPopAttrib");
}

static void APIENTRY noopPopClientAttrib(void)
{
   noop_warn("glPopClientAttrib");
}

static void APIENTRY noopPopDebugGroup(void)
{
   noop_warn("glPopDebugGroup");
}

static void APIENTRY noopPopMatrix(void)
{
   noop_warn("glPopMatrix");
}

static void APIENTRY noopPopName(void)
{
   noop_warn("glPopName");
}

static void APIENTRY noopPrimitiveRestartIndex(GLuint index)
{
   (void) index;
   noop_warn("glPrimitiveRestartIndex");
}

static void APIENTRY noopPrioritizeTextures(GLsizei n, const GLuint *textures, const GLfloat *priorities)
{
   (void) n; (void) textures; (void) priorities;
   noop_warn("glPrioritizeTextures");
}

static void APIENTRY noopProgramBinary(GLuint program, GLenum binaryFormat, const void *binary, GLsizei length)
{
   (void) program; (void) binaryFormat; (void) binary; (void) length;
   noop_warn("glProgramBinary");
}

static void APIENTRY noopProgramParameteri(GLuint program, GLenum pname, GLint value)
{
   (void) program; (void) pname; (void) value;
   noop_warn("glProgramParameteri");
}

static void APIENTRY noopProgramUniform1d(GLuint program, GLint location, GLdouble v0)
{
   (void) program; (void) location; (void) v0;
   noop_warn("glProgramUniform1d");
}

static void APIENTRY noopProgramUniform1dv(GLuint program, GLint location, GLsizei count, const GLdouble *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform1dv");
}

static void APIENTRY noopProgramUniform1f(GLuint program, GLint location, GLfloat v0)
{
   (void) program; (void) location; (void) v0;
   noop_warn("glProgramUniform1f");
}

static void APIENTRY noopProgramUniform1fv(GLuint program, GLint location, GLsizei count, const GLfloat *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform1fv");
}

static void APIENTRY noopProgramUniform1i(GLuint program, GLint location, GLint v0)
{
   (void) program; (void) location; (void) v0;
   noop_warn("glProgramUniform1i");
}

static void APIENTRY noopProgramUniform1iv(GLuint program, GLint location, GLsizei count, const GLint *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform1iv");
}

static void APIENTRY noopProgramUniform1ui(GLuint program, GLint location, GLuint v0)
{
   (void) program; (void) location; (void) v0;
   noop_warn("glProgramUniform1ui");
}

static void APIENTRY noopProgramUniform1uiv(GLuint program, GLint location, GLsizei count, const GLuint *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform1uiv");
}

static void APIENTRY noopProgramUniform2d(GLuint program, GLint location, GLdouble v0, GLdouble v1)
{
   (void) program; (void) location; (void) v0; (void) v1;
   noop_warn("glProgramUniform2d");
}

static void APIENTRY noopProgramUniform2dv(GLuint program, GLint location, GLsizei count, const GLdouble *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform2dv");
}

static void APIENTRY noopProgramUniform2f(GLuint program, GLint location, GLfloat v0, GLfloat v1)
{
   (void) program; (void) location; (void) v0; (void) v1;
   noop_warn("glProgramUniform2f");
}

static void APIENTRY noopProgramUniform2fv(GLuint program, GLint location, GLsizei count, const GLfloat *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform2fv");
}

static void APIENTRY noopProgramUniform2i(GLuint program, GLint location, GLint v0, GLint v1)
{
   (void) program; (void) location; (void) v0; (void) v1;
   noop_warn("glProgramUniform2i");
}

static void APIENTRY noopProgramUniform2iv(GLuint program, GLint location, GLsizei count, const GLint *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform2iv");
}

static void APIENTRY noopProgramUniform2ui(GLuint program, GLint location, GLuint v0, GLuint v1)
{
   (void) program; (void) location; (void) v0; (void) v1;
   noop_warn("glProgramUniform2ui");
}

static void APIENTRY noopProgramUniform2uiv(GLuint program, GLint location, GLsizei count, const GLuint *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform2uiv");
}

static void APIENTRY noopProgramUniform3d(GLuint program, GLint location, GLdouble v0, GLdouble v1, GLdouble v2)
{
   (void) program; (void) location; (void) v0; (void) v1; (void) v2;
   noop_warn("glProgramUniform3d");
}

static void APIENTRY noopProgramUniform3dv(GLuint program, GLint location, GLsizei count, const GLdouble *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform3dv");
}

static void APIENTRY noopProgramUniform3f(GLuint program, GLint location, GLfloat v0, GLfloat v1, GLfloat v2)
{
   (void) program; (void) location; (void) v0; (void) v1; (void) v2;
   noop_warn("glProgramUniform3f");
}

static void APIENTRY noopProgramUniform3fv(GLuint program, GLint location, GLsizei count, const GLfloat *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform3fv");
}

static void APIENTRY noopProgramUniform3i(GLuint program, GLint location, GLint v0, GLint v1, GLint v2)
{
   (void) program; (void) location; (void) v0; (void) v1; (void) v2;
   noop_warn("glProgramUniform3i");
}

static void APIENTRY noopProgramUniform3iv(GLuint program, GLint location, GLsizei count, const GLint *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform3iv");
}

static void APIENTRY noopProgramUniform3ui(GLuint program, GLint location, GLuint v0, GLuint v1, GLuint v2)
{
   (void) program; (void) location; (void) v0; (void) v1; (void) v2;
   noop_warn("glProgramUniform3ui");
}

static void APIENTRY noopProgramUniform3uiv(GLuint program, GLint location, GLsizei count, const GLuint *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform3uiv");
}

static void APIENTRY noopProgramUniform4d(GLuint program, GLint location, GLdouble v0, GLdouble v1, GLdouble v2, GLdouble v3)
{
   (void) program; (void) location; (void) v0; (void) v1; (void) v2; (void) v3;
   noop_warn("glProgramUniform4d");
}

static void APIENTRY noopProgramUniform4dv(GLuint program, GLint location, GLsizei count, const GLdouble *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform4dv");
}

static void APIENTRY noopProgramUniform4f(GLuint program, GLint location, GLfloat v0, GLfloat v1, GLfloat v2, GLfloat v3)
{
   (void) program; (void) location; (void) v0; (void) v1; (void) v2; (void) v3;
   noop_warn("glProgramUniform4f");
}

static void APIENTRY noopProgramUniform4fv(GLuint program, GLint location, GLsizei count, const GLfloat *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform4fv");
}

static void APIENTRY noopProgramUniform4i(GLuint program, GLint location, GLint v0, GLint v1, GLint v2, GLint v3)
{
   (void) program; (void) location; (void) v0; (void) v1; (void) v2; (void) v3;
   noop_warn("glProgramUniform4i");
}

static void APIENTRY noopProgramUniform4iv(GLuint program, GLint location, GLsizei count, const GLint *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform4iv");
}

static void APIENTRY noopProgramUniform4ui(GLuint program, GLint location, GLuint v0, GLuint v1, GLuint v2, GLuint v3)
{
   (void) program; (void) location; (void) v0; (void) v1; (void) v2; (void) v3;
   noop_warn("glProgramUniform4ui");
}

static void APIENTRY noopProgramUniform4uiv(GLuint program, GLint location, GLsizei count, const GLuint *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform4uiv");
}

static void APIENTRY noopProgramUniformMatrix2dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   (void) program; (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glProgramUniformMatrix2dv");
}

static void APIENTRY noopProgramUniformMatrix2fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   (void) program; (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glProgramUniformMatrix2fv");
}

static void APIENTRY noopProgramUniformMatrix2x3dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   (void) program; (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glProgramUniformMatrix2x3dv");
}

static void APIENTRY noopProgramUniformMatrix2x3fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   (void) program; (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glProgramUniformMatrix2x3fv");
}

static void APIENTRY noopProgramUniformMatrix2x4dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   (void) program; (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glProgramUniformMatrix2x4dv");
}

static void APIENTRY noopProgramUniformMatrix2x4fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   (void) program; (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glProgramUniformMatrix2x4fv");
}

static void APIENTRY noopProgramUniformMatrix3dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   (void) program; (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glProgramUniformMatrix3dv");
}

static void APIENTRY noopProgramUniformMatrix3fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   (void) program; (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glProgramUniformMatrix3fv");
}

static void APIENTRY noopProgramUniformMatrix3x2dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   (void) program; (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glProgramUniformMatrix3x2dv");
}

static void APIENTRY noopProgramUniformMatrix3x2fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   (void) program; (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glProgramUniformMatrix3x2fv");
}

static void APIENTRY noopProgramUniformMatrix3x4dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   (void) program; (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glProgramUniformMatrix3x4dv");
}

static void APIENTRY noopProgramUniformMatrix3x4fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   (void) program; (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glProgramUniformMatrix3x4fv");
}

static void APIENTRY noopProgramUniformMatrix4dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   (void) program; (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glProgramUniformMatrix4dv");
}

static void APIENTRY noopProgramUniformMatrix4fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   (void) program; (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glProgramUniformMatrix4fv");
}

static void APIENTRY noopProgramUniformMatrix4x2dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   (void) program; (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glProgramUniformMatrix4x2dv");
}

static void APIENTRY noopProgramUniformMatrix4x2fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   (void) program; (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glProgramUniformMatrix4x2fv");
}

static void APIENTRY noopProgramUniformMatrix4x3dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   (void) program; (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glProgramUniformMatrix4x3dv");
}

static void APIENTRY noopProgramUniformMatrix4x3fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   (void) program; (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glProgramUniformMatrix4x3fv");
}

static void APIENTRY noopProvokingVertex(GLenum mode)
{
   (void) mode;
   noop_warn("glProvokingVertex");
}

static void APIENTRY noopPushAttrib(GLbitfield mask)
{
   (void) mask;
   noop_warn("glPushAttrib");
}

static void APIENTRY noopPushClientAttrib(GLbitfield mask)
{
   (void) mask;
   noop_warn("glPushClientAttrib");
}

static void APIENTRY noopPushDebugGroup(GLenum source, GLuint id, GLsizei length, const GLchar *message)
{
   (void) source; (void) id; (void) length; (void) message;
   noop_warn("glPushDebugGroup");
}

static void APIENTRY noopPushMatrix(void)
{
   noop_warn("glPushMatrix");
}

static void APIENTRY noopPushName(GLuint name)
{
   (void) name;
   noop_warn("glPushName");
}

static void APIENTRY noopQueryCounter(GLuint id, GLenum target)
{
   (void) id; (void) target;
   noop_warn("glQueryCounter");
}

static void APIENTRY noopRasterPos2d(GLdouble x, GLdouble y)
{
   (void) x; (void) y;
   noop_warn("glRasterPos2d");
}

static void APIENTRY noopRasterPos2dv(const GLdouble *v)
{
   (void) v;
   noop_warn("glRasterPos2dv");
}

static void APIENTRY noopRasterPos2f(GLfloat x, GLfloat y)
{
   (void) x; (void) y;
   noop_warn("glRasterPos2f");
}

static void APIENTRY noopRasterPos2fv(const GLfloat *v)
{
   (void) v;
   noop_warn("glRasterPos2fv");
}

static void APIENTRY noopRasterPos2i(GLint x, GLint y)
{
   (void) x; (void) y;
   noop_warn("glRasterPos2i");
}

static void APIENTRY noopRasterPos2iv(const GLint *v)
{
   (void) v;
   noop_warn("glRasterPos2iv");
}

static void APIENTRY noopRasterPos2s(GLshort x, GLshort y)
{
   (void) x; (void) y;
   noop_warn("glRasterPos2s");
}

static void APIENTRY noopRasterPos2sv(const GLshort *v)
{
   (void) v;
   noop_warn("glRasterPos2sv");
}

static void APIENTRY noopRasterPos3d(GLdouble x, GLdouble y, GLdouble z)
{
   (void) x; (void) y; (void) z;
   noop_warn("glRasterPos3d");
}

static void APIENTRY noopRasterPos3dv(const GLdouble *v)
{
   (void) v;
   noop_warn("glRasterPos3dv");
}

static void APIENTRY noopRasterPos3f(GLfloat x, GLfloat y, GLfloat z)
{
   (void) x; (void) y; (void) z;
   noop_warn("glRasterPos3f");
}

static void APIENTRY noopRasterPos3fv(const GLfloat *v)
{
   (void) v;
   noop_warn("glRasterPos3fv");
}

static void APIENTRY noopRasterPos3i(GLint x, GLint y, GLint z)
{
   (void) x; (void) y; (void) z;
   noop_warn("glRasterPos3i");
}

static void APIENTRY noopRasterPos3iv(const GLint *v)
{
   (void) v;
   noop_warn("glRasterPos3iv");
}

static void APIENTRY noopRasterPos3s(GLshort x, GLshort y, GLshort z)
{
   (void) x; (void) y; (void) z;
   noop_warn("glRasterPos3s");
}

static void APIENTRY noopRasterPos3sv(const GLshort *v)
{
   (void) v;
   noop_warn("glRasterPos3sv");
}

static void APIENTRY noopRasterPos4d(GLdouble x, GLdouble y, GLdouble z, GLdouble w)
{
   (void) x; (void) y; (void) z; (void) w;
   noop_warn("glRasterPos4d");
}

static void APIENTRY noopRasterPos4dv(const GLdouble *v)
{
   (void) v;
   noop_warn("glRasterPos4dv");
}

static void APIENTRY noopRasterPos4f(GLfloat x, GLfloat y, GLfloat z, GLfloat w)
{
   (void) x; (void) y; (void) z; (void) w;
   noop_warn("glRasterPos4f");
}

static void APIENTRY noopRasterPos4fv(const GLfloat *v)
{
   (void) v;
   noop_warn("glRasterPos4fv");
}

static void APIENTRY noopRasterPos4i(GLint x, GLint y, GLint z, GLint w)
{
   (void) x; (void) y; (void) z; (void) w;
   noop_warn("glRasterPos4i");
}

static void APIENTRY noopRasterPos4iv(const GLint *v)
{
   (void) v;
   noop_warn("glRasterPos4iv");
}

static void APIENTRY noopRasterPos4s(GLshort x, GLshort y, GLshort z, GLshort w)
{
   (void) x; (void) y; (void) z; (void) w;
   noop_warn("glRasterPos4s");
}

static void APIENTRY noopRasterPos4sv(const GLshort *v)
{
   (void) v;
   noop_warn("glRasterPos4sv");
}

static void APIENTRY noopReadBuffer(GLenum src)
{
   (void) src;
   noop_warn("glReadBuffer");
}

static void APIENTRY noopReadPixels(GLint x, GLint y, GLsizei width, GLsizei height, GLenum format, GLenum type, void *pixels)
{
   (void) x; (void) y; (void) width; (void) height; (void) format; (void) type; (void) pixels;
   noop_warn("glReadPixels");
}

static void APIENTRY noopReadnPixels(GLint x, GLint y, GLsizei width, GLsizei height, GLenum format, GLenum type, GLsizei bufSize, void *data)
{
   (void) x; (void) y; (void) width; (void) height; (void) format; (void) type; (void) bufSize; (void) data;
   noop_warn("glReadnPixels");
}

static void APIENTRY noopRectd(GLdouble x1, GLdouble y1, GLdouble x2, GLdouble y2)
{
   (void) x1; (void) y1; (void) x2; (void) y2;
   noop_warn("glRectd");
}

static void APIENTRY noopRectdv(const GLdouble *v1, const GLdouble *v2)
{
   (void) v1; (void) v2;
   noop_warn("glRectdv");
}

static void APIENTRY noopRectf(GLfloat x1, GLfloat y1, GLfloat x2, GLfloat y2)
{
   (void) x1; (void) y1; (void) x2; (void) y2;
   noop_warn("glRectf");
}

static void APIENTRY noopRectfv(const GLfloat *v1, const GLfloat *v2)
{
   (void) v1; (void) v2;
   noop_warn("glRectfv");
}

static void APIENTRY noopRecti(GLint x1, GLint y1, GLint x2, GLint y2)
{
   (void) x1; (void) y1; (void) x2; (void) y2;
   noop_warn("glRecti");
}

static void APIENTRY noopRectiv(const GLint *v1, const GLint *v2)
{
   (void) v1; (void) v2;
   noop_warn("glRectiv");
}

static void APIENTRY noopRects(GLshort x1, GLshort y1, GLshort x2, GLshort y2)
{
   (void) x1; (void) y1; (void) x2; (void) y2;
   noop_warn("glRects");
}

static void APIENTRY noopRectsv(const GLshort *v1, const GLshort *v2)
{
   (void) v1; (void) v2;
   noop_warn("glRectsv");
}

static void APIENTRY noopReleaseShaderCompiler(void)
{
   noop_warn("glReleaseShaderCompiler");
}

static GLint APIENTRY noopRenderMode(GLenum mode)
{
   (void) mode;
   noop_warn("glRenderMode");
   return (GLint) 0;
}

static void APIENTRY noopRenderbufferStorage(GLenum target, GLenum internalformat, GLsizei width, GLsizei height)
{
   (void) target; (void) internalformat; (void) width; (void) height;
   noop_warn("glRenderbufferStorage");
}

static void APIENTRY noopRenderbufferStorageMultisample(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height)
{
   (void) target; (void) samples; (void) internalformat; (void) width; (void) height;
   noop_warn("glRenderbufferStorageMultisample");
}

static void APIENTRY noopResumeTransformFeedback(void)
{
   noop_warn("glResumeTransformFeedback");
}

static void APIENTRY noopRotated(GLdouble angle, GLdouble x, GLdouble y, GLdouble z)
{
   (void) angle; (void) x; (void) y; (void) z;
   noop_warn("glRotated");
}

static void APIENTRY noopRotatef(GLfloat angle, GLfloat x, GLfloat y, GLfloat z)
{
   (void) angle; (void) x; (void) y; (void) z;
   noop_warn("glRotatef");
}

static void APIENTRY noopSampleCoverage(GLfloat value, GLboolean invert)
{
   (void) value; (void) invert;
   noop_warn("glSampleCoverage");
}

static void APIENTRY noopSampleMaski(GLuint maskNumber, GLbitfield mask)
{
   (void) maskNumber; (void) mask;
   noop_warn("glSampleMaski");
}

static void APIENTRY noopSamplerParameterIiv(GLuint sampler, GLenum pname, const GLint *param)
{
   (void) sampler; (void) pname; (void) param;
   noop_warn("glSamplerParameterIiv");
}

static void APIENTRY noopSamplerParameterIuiv(GLuint sampler, GLenum pname, const GLuint *param)
{
   (void) sampler; (void) pname; (void) param;
   noop_warn("glSamplerParameterIuiv");
}

static void APIENTRY noopSamplerParameterf(GLuint sampler, GLenum pname, GLfloat param)
{
   (void) sampler; (void) pname; (void) param;
   noop_warn("glSamplerParameterf");
}

static void APIENTRY noopSamplerParameterfv(GLuint sampler, GLenum pname, const GLfloat *param)
{
   (void) sampler; (void) pname; (void) param;
   noop_warn("glSamplerParameterfv");
}

static void APIENTRY noopSamplerParameteri(GLuint sampler, GLenum pname, GLint param)
{
   (void) sampler; (void) pname; (void) param;
   noop_warn("glSamplerParameteri");
}

static void APIENTRY noopSamplerParameteriv(GLuint sampler, GLenum pname, const GLint *param)
{
   (void) sampler; (void) pname; (void) param;
   noop_warn("glSamplerParameteriv");
}

static void APIENTRY noopScaled(GLdouble x, GLdouble y, GLdouble z)
{
   (void) x; (void) y; (void) z;
   noop_warn("glScaled");
}

static void APIENTRY noopScalef(GLfloat x, GLfloat y, GLfloat z)
{
   (void) x; (void) y; (void) z;
   noop_warn("glScalef");
}

static void APIENTRY noopScissor(GLint x, GLint y, GLsizei width, GLsizei height)
{
   (void) x; (void) y; (void) width; (void) height;
   noop_warn("glScissor");
}

static void APIENTRY noopScissorArrayv(GLuint first, GLsizei count, const GLint *v)
{
   (void) first; (void) count; (void) v;
   noop_warn("glScissorArrayv");
}

static void APIENTRY noopScissorIndexed(GLuint index, GLint left, GLint bottom, GLsizei width, GLsizei height)
{
   (void) index; (void) left; (void) bottom; (void) width; (void) height;
   noop_warn("glScissorIndexed");
}

static void APIENTRY noopScissorIndexedv(GLuint index, const GLint *v)
{
   (void) index; (void) v;
   noop_warn("glScissorIndexedv");
}

static void APIENTRY noopSecondaryColor3b(GLbyte red, GLbyte green, GLbyte blue)
{
   (void) red; (void) green; (void) blue;
   noop_warn("glSecondaryColor3b");
}

static void APIENTRY noopSecondaryColor3bv(const GLbyte *v)
{
   (void) v;
   noop_warn("glSecondaryColor3bv");
}

static void APIENTRY noopSecondaryColor3d(GLdouble red, GLdouble green, GLdouble blue)
{
   (void) red; (void) green; (void) blue;
   noop_warn("glSecondaryColor3d");
}

static void APIENTRY noopSecondaryColor3dv(const GLdouble *v)
{
   (void) v;
   noop_warn("glSecondaryColor3dv");
}

static void APIENTRY noopSecondaryColor3f(GLfloat red, GLfloat green, GLfloat blue)
{
   (void) red; (void) green; (void) blue;
   noop_warn("glSecondaryColor3f");
}

static void APIENTRY noopSecondaryColor3fv(const GLfloat *v)
{
   (void) v;
   noop_warn("glSecondaryColor3fv");
}

static void APIENTRY noopSecondaryColor3i(GLint red, GLint green, GLint blue)
{
   (void) red; (void) green; (void) blue;
   noop_warn("glSecondaryColor3i");
}

static void APIENTRY noopSecondaryColor3iv(const GLint *v)
{
   (void) v;
   noop_warn("glSecondaryColor3iv");
}

static void APIENTRY noopSecondaryColor3s(GLshort red, GLshort green, GLshort blue)
{
   (void) red; (void) green; (void) blue;
   noop_warn("glSecondaryColor3s");
}

static void APIENTRY noopSecondaryColor3sv(const GLshort *v)
{
   (void) v;
   noop_warn("glSecondaryColor3sv");
}

static void APIENTRY noopSecondaryColor3ub(GLubyte red, GLubyte green, GLubyte blue)
{
   (void) red; (void) green; (void) blue;
   noop_warn("glSecondaryColor3ub");
}

static void APIENTRY noopSecondaryColor3ubv(const GLubyte *v)
{
   (void) v;
   noop_warn("glSecondaryColor3ubv");
}

static void APIENTRY noopSecondaryColor3ui(GLuint red, GLuint green, GLuint blue)
{
   (void) red; (void) green; (void) blue;
   noop_warn("glSecondaryColor3ui");
}

static void APIENTRY noopSecondaryColor3uiv(const GLuint *v)
{
   (void) v;
   noop_warn("glSecondaryColor3uiv");
}

static void APIENTRY noopSecondaryColor3us(GLushort red, GLushort green, GLushort blue)
{
   (void) red; (void) green; (void) blue;
   noop_warn("glSecondaryColor3us");
}

static void APIENTRY noopSecondaryColor3usv(const GLushort *v)
{
   (void) v;
   noop_warn("glSecondaryColor3usv");
}

static void APIENTRY noopSecondaryColorP3ui(GLenum type, GLuint color)
{
   (void) type; (void) color;
   noop_warn("glSecondaryColorP3ui");
}

static void APIENTRY noopSecondaryColorP3uiv(GLenum type, const GLuint *color)
{
   (void) type; (void) color;
   noop_warn("glSecondaryColorP3uiv");
}

static void APIENTRY noopSecondaryColorPointer(GLint size, GLenum type, GLsizei stride, const void *pointer)
{
   (void) size; (void) type; (void) stride; (void) pointer;
   noop_warn("glSecondaryColorPointer");
}

static void APIENTRY noopSelectBuffer(GLsizei size, GLuint *buffer)
{
   (void) size; (void) buffer;
   noop_warn("glSelectBuffer");
}

static void APIENTRY noopShadeModel(GLenum mode)
{
   (void) mode;
   noop_warn("glShadeModel");
}

static void APIENTRY noopShaderBinary(GLsizei count, const GLuint *shaders, GLenum binaryFormat, const void *binary, GLsizei length)
{
   (void) count; (void) shaders; (void) binaryFormat; (void) binary; (void) length;
   noop_warn("glShaderBinary");
}

static void APIENTRY noopShaderSource(GLuint shader, GLsizei count, const GLchar *const *string, const GLint *length)
{
   (void) shader; (void) count; (void) string; (void) length;
   noop_warn("glShaderSource");
}

static void APIENTRY noopShaderStorageBlockBinding(GLuint program, GLuint storageBlockIndex, GLuint storageBlockBinding)
{
   (void) program; (void) storageBlockIndex; (void) storageBlockBinding;
   noop_warn("glShaderStorageBlockBinding");
}

static void APIENTRY noopStencilFunc(GLenum func, GLint ref, GLuint mask)
{
   (void) func; (void) ref; (void) mask;
   noop_warn("glStencilFunc");
}

static void APIENTRY noopStencilFuncSeparate(GLenum face, GLenum func, GLint ref, GLuint mask)
{
   (void) face; (void) func; (void) ref; (void) mask;
   noop_warn("glStencilFuncSeparate");
}

static void APIENTRY noopStencilMask(GLuint mask)
{
   (void) mask;
   noop_warn("glStencilMask");
}

static void APIENTRY noopStencilMaskSeparate(GLenum face, GLuint mask)
{
   (void) face; (void) mask;
   noop_warn("glStencilMaskSeparate");
}

static void APIENTRY noopStencilOp(GLenum fail, GLenum zfail, GLenum zpass)
{
   (void) fail; (void) zfail; (void) zpass;
   noop_warn("glStencilOp");
}

static void APIENTRY noopStencilOpSeparate(GLenum face, GLenum sfail, GLenum dpfail, GLenum dppass)
{
   (void) face; (void) sfail; (void) dpfail; (void) dppass;
   noop_warn("glStencilOpSeparate");
}

static void APIENTRY noopTexBuffer(GLenum target, GLenum internalformat, GLuint buffer)
{
   (void) target; (void) internalformat; (void) buffer;
   noop_warn("glTexBuffer");
}

static void APIENTRY noopTexBufferRange(GLenum target, GLenum internalformat, GLuint buffer, GLintptr offset, GLsizeiptr size)
{
   (void) target; (void) internalformat; (void) buffer; (void) offset; (void) size;
   noop_warn("glTexBufferRange");
}

static void APIENTRY noopTexCoord1d(GLdouble s)
{
   (void) s;
   noop_warn("glTexCoord1d");
}

static void APIENTRY noopTexCoord1dv(const GLdouble *v)
{
   (void) v;
   noop_warn("glTexCoord1dv");
}

static void APIENTRY noopTexCoord1f(GLfloat s)
{
   (void) s;
   noop_warn("glTexCoord1f");
}

static void APIENTRY noopTexCoord1fv(const GLfloat *v)
{
   (void) v;
   noop_warn("glTexCoord1fv");
}

static void APIENTRY noopTexCoord1i(GLint s)
{
   (void) s;
   noop_warn("glTexCoord1i");
}

static void APIENTRY noopTexCoord1iv(const GLint *v)
{
   (void) v;
   noop_warn("glTexCoord1iv");
}

static void APIENTRY noopTexCoord1s(GLshort s)
{
   (void) s;
   noop_warn("glTexCoord1s");
}

static void APIENTRY noopTexCoord1sv(const GLshort *v)
{
   (void) v;
   noop_warn("glTexCoord1sv");
}

static void APIENTRY noopTexCoord2d(GLdouble s, GLdouble t)
{
   (void) s; (void) t;
   noop_warn("glTexCoord2d");
}

static void APIENTRY noopTexCoord2dv(const GLdouble *v)
{
   (void) v;
   noop_warn("glTexCoord2dv");
}

static void APIENTRY noopTexCoord2f(GLfloat s, GLfloat t)
{
   (void) s; (void) t;
   noop_warn("glTexCoord2f");
}

static void APIENTRY noopTexCoord2fv(const GLfloat *v)
{
   (void) v;
   noop_warn("glTexCoord2fv");
}

static void APIENTRY noopTexCoord2i(GLint s, GLint t)
{
   (void) s; (void) t;
   noop_warn("glTexCoord2i");
}

static void APIENTRY noopTexCoord2iv(const GLint *v)
{
   (void) v;
   noop_warn("glTexCoord2iv");
}

static void APIENTRY noopTexCoord2s(GLshort s, GLshort t)
{
   (void) s; (void) t;
   noop_warn("glTexCoord2s");
}

static void APIENTRY noopTexCoord2sv(const GLshort *v)
{
   (void) v;
   noop_warn("glTexCoord2sv");
}

static void APIENTRY noopTexCoord3d(GLdouble s, GLdouble t, GLdouble r)
{
   (void) s; (void) t; (void) r;
   noop_warn("glTexCoord3d");
}

static void APIENTRY noopTexCoord3dv(const GLdouble *v)
{
   (void) v;
   noop_warn("glTexCoord3dv");
}

static void APIENTRY noopTexCoord3f(GLfloat s, GLfloat t, GLfloat r)
{
   (void) s; (void) t; (void) r;
   noop_warn("glTexCoord3f");
}

static void APIENTRY noopTexCoord3fv(const GLfloat *v)
{
   (void) v;
   noop_warn("glTexCoord3fv");
}

static void APIENTRY noopTexCoord3i(GLint s, GLint t, GLint r)
{
   (void) s; (void) t; (void) r;
   noop_warn("glTexCoord3i");
}

static void APIENTRY noopTexCoord3iv(const GLint *v)
{
   (void) v;
   noop_warn("glTexCoord3iv");
}

static void APIENTRY noopTexCoord3s(GLshort s, GLshort t, GLshort r)
{
   (void) s; (void) t; (void) r;
   noop_warn("glTexCoord3s");
}

static void APIENTRY noopTexCoord3sv(const GLshort *v)
{
   (void) v;
   noop_warn("glTexCoord3sv");
}

static void APIENTRY noopTexCoord4d(GLdouble s, GLdouble t, GLdouble r, GLdouble q)
{
   (void) s; (void) t; (void) r; (void) q;
   noop_warn("glTexCoord4d");
}

static void APIENTRY noopTexCoord4dv(const GLdouble *v)
{
   (void) v;
   noop_warn("glTexCoord4dv");
}

static void APIENTRY noopTexCoord4f(GLfloat s, GLfloat t, GLfloat r, GLfloat q)
{
   (void) s; (void) t; (void) r; (void) q;
   noop_warn("glTexCoord4f");
}

static void APIENTRY noopTexCoord4fv(const GLfloat *v)
{
   (void) v;
   noop_warn("glTexCoord4fv");
}

static void APIENTRY noopTexCoord4i(GLint s, GLint t, GLint r, GLint q)
{
   (void) s; (void) t; (void) r; (void) q;
   noop_warn("glTexCoord4i");
}

static void APIENTRY noopTexCoord4iv(const GLint *v)
{
   (void) v;
   noop_warn("glTexCoord4iv");
}

static void APIENTRY noopTexCoord4s(GLshort s, GLshort t, GLshort r, GLshort q)
{
   (void) s; (void) t; (void) r; (void) q;
   noop_warn("glTexCoord4s");
}

static void APIENTRY noopTexCoord4sv(const GLshort *v)
{
   (void) v;
   noop_warn("glTexCoord4sv");
}

static void APIENTRY noopTexCoordP1ui(GLenum type, GLuint coords)
{
   (void) type; (void) coords;
   noop_warn("glTexCoordP1ui");
}

static void APIENTRY noopTexCoordP1uiv(GLenum type, const GLuint *coords)
{
   (void) type; (void) coords;
   noop_warn("glTexCoordP1uiv");
}

static void APIENTRY noopTexCoordP2ui(GLenum type, GLuint coords)
{
   (void) type; (void) coords;
   noop_warn("glTexCoordP2ui");
}

static void APIENTRY noopTexCoordP2uiv(GLenum type, const GLuint *coords)
{
   (void) type; (void) coords;
   noop_warn("glTexCoordP2uiv");
}

static void APIENTRY noopTexCoordP3ui(GLenum type, GLuint coords)
{
   (void) type; (void) coords;
   noop_warn("glTexCoordP3ui");
}

static void APIENTRY noopTexCoordP3uiv(GLenum type, const GLuint *coords)
{
   (void) type; (void) coords;
   noop_warn("glTexCoordP3uiv");
}

static void APIENTRY noopTexCoordP4ui(GLenum type, GLuint coords)
{
   (void) type; (void) coords;
   noop_warn("glTexCoordP4ui");
}

static void APIENTRY noopTexCoordP4uiv(GLenum type, const GLuint *coords)
{
   (void) type; (void) coords;
   noop_warn("glTexCoordP4uiv");
}

static void APIENTRY noopTexCoordPointer(GLint size, GLenum type, GLsizei stride, const void *pointer)
{
   (void) size; (void) type; (void) stride; (void) pointer;
   noop_warn("glTexCoordPointer");
}

static void APIENTRY noopTexEnvf(GLenum target, GLenum pname, GLfloat param)
{
   (void) target; (void) pname; (void) param;
   noop_warn("glTexEnvf");
}

static void APIENTRY noopTexEnvfv(GLenum target, GLenum pname, const GLfloat *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glTexEnvfv");
}

static void APIENTRY noopTexEnvi(GLenum target, GLenum pname, GLint param)
{
   (void) target; (void) pname; (void) param;
   noop_warn("glTexEnvi");
}

static void APIENTRY noopTexEnviv(GLenum target, GLenum pname, const GLint *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glTexEnviv");
}

static void APIENTRY noopTexGend(GLenum coord, GLenum pname, GLdouble param)
{
   (void) coord; (void) pname; (void) param;
   noop_warn("glTexGend");
}

static void APIENTRY noopTexGendv(GLenum coord, GLenum pname, const GLdouble *params)
{
   (void) coord; (void) pname; (void) params;
   noop_warn("glTexGendv");
}

static void APIENTRY noopTexGenf(GLenum coord, GLenum pname, GLfloat param)
{
   (void) coord; (void) pname; (void) param;
   noop_warn("glTexGenf");
}

static void APIENTRY noopTexGenfv(GLenum coord, GLenum pname, const GLfloat *params)
{
   (void) coord; (void) pname; (void) params;
   noop_warn("glTexGenfv");
}

static void APIENTRY noopTexGeni(GLenum coord, GLenum pname, GLint param)
{
   (void) coord; (void) pname; (void) param;
   noop_warn("glTexGeni");
}

static void APIENTRY noopTexGeniv(GLenum coord, GLenum pname, const GLint *params)
{
   (void) coord; (void) pname; (void) params;
   noop_warn("glTexGeniv");
}

static void APIENTRY noopTexImage1D(GLenum target, GLint level, GLint internalformat, GLsizei width, GLint border, GLenum format, GLenum type, const void *pixels)
{
   (void) target; (void) level; (void) internalformat; (void) width; (void) border; (void) format; (void) type; (void) pixels;
   noop_warn("glTexImage1D");
}

static void APIENTRY noopTexImage2D(GLenum target, GLint level, GLint internalformat, GLsizei width, GLsizei height, GLint border, GLenum format, GLenum type, const void *pixels)
{
   (void) target; (void) level; (void) internalformat; (void) width; (void) height; (void) border; (void) format; (void) type; (void) pixels;
   noop_warn("glTexImage2D");
}

static void APIENTRY noopTexImage2DMultisample(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLboolean fixedsamplelocations)
{
   (void) target; (void) samples; (void) internalformat; (void) width; (void) height; (void) fixedsamplelocations;
   noop_warn("glTexImage2DMultisample");
}

static void APIENTRY noopTexImage3D(GLenum target, GLint level, GLint internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLenum format, GLenum type, const void *pixels)
{
   (void) target; (void) level; (void) internalformat; (void) width; (void) height; (void) depth; (void) border; (void) format; (void) type; (void) pixels;
   noop_warn("glTexImage3D");
}

static void APIENTRY noopTexImage3DMultisample(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedsamplelocations)
{
   (void) target; (void) samples; (void) internalformat; (void) width; (void) height; (void) depth; (void) fixedsamplelocations;
   noop_warn("glTexImage3DMultisample");
}

static void APIENTRY noopTexParameterIiv(GLenum target, GLenum pname, const GLint *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glTexParameterIiv");
}

static void APIENTRY noopTexParameterIuiv(GLenum target, GLenum pname, const GLuint *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glTexParameterIuiv");
}

static void APIENTRY noopTexParameterf(GLenum target, GLenum pname, GLfloat param)
{
   (void) target; (void) pname; (void) param;
   noop_warn("glTexParameterf");
}

static void APIENTRY noopTexParameterfv(GLenum target, GLenum pname, const GLfloat *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glTexParameterfv");
}

static void APIENTRY noopTexParameteri(GLenum target, GLenum pname, GLint param)
{
   (void) target; (void) pname; (void) param;
   noop_warn("glTexParameteri");
}

static void APIENTRY noopTexParameteriv(GLenum target, GLenum pname, const GLint *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glTexParameteriv");
}

static void APIENTRY noopTexStorage1D(GLenum target, GLsizei levels, GLenum internalformat, GLsizei width)
{
   (void) target; (void) levels; (void) internalformat; (void) width;
   noop_warn("glTexStorage1D");
}

static void APIENTRY noopTexStorage2D(GLenum target, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height)
{
   (void) target; (void) levels; (void) internalformat; (void) width; (void) height;
   noop_warn("glTexStorage2D");
}

static void APIENTRY noopTexStorage2DMultisample(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLboolean fixedsamplelocations)
{
   (void) target; (void) samples; (void) internalformat; (void) width; (void) height; (void) fixedsamplelocations;
   noop_warn("glTexStorage2DMultisample");
}

static void APIENTRY noopTexStorage3D(GLenum target, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth)
{
   (void) target; (void) levels; (void) internalformat; (void) width; (void) height; (void) depth;
   noop_warn("glTexStorage3D");
}

static void APIENTRY noopTexStorage3DMultisample(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedsamplelocations)
{
   (void) target; (void) samples; (void) internalformat; (void) width; (void) height; (void) depth; (void) fixedsamplelocations;
   noop_warn("glTexStorage3DMultisample");
}

static void APIENTRY noopTexSubImage1D(GLenum target, GLint level, GLint xoffset, GLsizei width, GLenum format, GLenum type, const void *pixels)
{
   (void) target; (void) level; (void) xoffset; (void) width; (void) format; (void) type; (void) pixels;
   noop_warn("glTexSubImage1D");
}

static void APIENTRY noopTexSubImage2D(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLenum type, const void *pixels)
{
   (void) target; (void) level; (void) xoffset; (void) yoffset; (void) width; (void) height; (void) format; (void) type; (void) pixels;
   noop_warn("glTexSubImage2D");
}

static void APIENTRY noopTexSubImage3D(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void *pixels)
{
   (void) target; (void) level; (void) xoffset; (void) yoffset; (void) zoffset; (void) width; (void) height; (void) depth; (void) format; (void) type; (void) pixels;
   noop_warn("glTexSubImage3D");
}

static void APIENTRY noopTextureBarrier(void)
{
   noop_warn("glTextureBarrier");
}

static void APIENTRY noopTextureBuffer(GLuint texture, GLenum internalformat, GLuint buffer)
{
   (void) texture; (void) internalformat; (void) buffer;
   noop_warn("glTextureBuffer");
}

static void APIENTRY noopTextureBufferRange(GLuint texture, GLenum internalformat, GLuint buffer, GLintptr offset, GLsizeiptr size)
{
   (void) texture; (void) internalformat; (void) buffer; (void) offset; (void) size;
   noop_warn("glTextureBufferRange");
}

static void APIENTRY noopTextureParameterIiv(GLuint texture, GLenum pname, const GLint *params)
{
   (void) texture; (void) pname; (void) params;
   noop_warn("glTextureParameterIiv");
}

static void APIENTRY noopTextureParameterIuiv(GLuint texture, GLenum pname, const GLuint *params)
{
   (void) texture; (void) pname; (void) params;
   noop_warn("glTextureParameterIuiv");
}

static void APIENTRY noopTextureParameterf(GLuint texture, GLenum pname, GLfloat param)
{
   (void) texture; (void) pname; (void) param;
   noop_warn("glTextureParameterf");
}

static void APIENTRY noopTextureParameterfv(GLuint texture, GLenum pname, const GLfloat *param)
{
   (void) texture; (void) pname; (void) param;
   noop_warn("glTextureParameterfv");
}

static void APIENTRY noopTextureParameteri(GLuint texture, GLenum pname, GLint param)
{
   (void) texture; (void) pname; (void) param;
   noop_warn("glTextureParameteri");
}

static void APIENTRY noopTextureParameteriv(GLuint texture, GLenum pname, const GLint *param)
{
   (void) texture; (void) pname; (void) param;
   noop_warn("glTextureParameteriv");
}

static void APIENTRY noopTextureStorage1D(GLuint texture, GLsizei levels, GLenum internalformat, GLsizei width)
{
   (void) texture; (void) levels; (void) internalformat; (void) width;
   noop_warn("glTextureStorage1D");
}

static void APIENTRY noopTextureStorage2D(GLuint texture, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height)
{
   (void) texture; (void) levels; (void) internalformat; (void) width; (void) height;
   noop_warn("glTextureStorage2D");
}

static void APIENTRY noopTextureStorage2DMultisample(GLuint texture, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLboolean fixedsamplelocations)
{
   (void) texture; (void) samples; (void) internalformat; (void) width; (void) height; (void) fixedsamplelocations;
   noop_warn("glTextureStorage2DMultisample");
}

static void APIENTRY noopTextureStorage3D(GLuint texture, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth)
{
   (void) texture; (void) levels; (void) internalformat; (void) width; (void) height; (void) depth;
   noop_warn("glTextureStorage3D");
}

static void APIENTRY noopTextureStorage3DMultisample(GLuint texture, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedsamplelocations)
{
   (void) texture; (void) samples; (void) internalformat; (void) width; (void) height; (void) depth; (void) fixedsamplelocations;
   noop_warn("glTextureStorage3DMultisample");
}

static void APIENTRY noopTextureSubImage1D(GLuint texture, GLint level, GLint xoffset, GLsizei width, GLenum format, GLenum type, const void *pixels)
{
   (void) texture; (void) level; (void) xoffset; (void) width; (void) format; (void) type; (void) pixels;
   noop_warn("glTextureSubImage1D");
}

static void APIENTRY noopTextureSubImage2D(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLenum type, const void *pixels)
{
   (void) texture; (void) level; (void) xoffset; (void) yoffset; (void) width; (void) height; (void) format; (void) type; (void) pixels;
   noop_warn("glTextureSubImage2D");
}

static void APIENTRY noopTextureSubImage3D(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void *pixels)
{
   (void) texture; (void) level; (void) xoffset; (void) yoffset; (void) zoffset; (void) width; (void) height; (void) depth; (void) format; (void) type; (void) pixels;
   noop_warn("glTextureSubImage3D");
}

static void APIENTRY noopTextureView(GLuint texture, GLenum target, GLuint origtexture, GLenum internalformat, GLuint minlevel, GLuint numlevels, GLuint minlayer, GLuint numlayers)
{
   (void) texture; (void) target; (void) origtexture; (void) internalformat; (void) minlevel; (void) numlevels; (void) minlayer; (void) numlayers;
   noop_warn("glTextureView");
}

static void APIENTRY noopTransformFeedbackBufferBase(GLuint xfb, GLuint index, GLuint buffer)
{
   (void) xfb; (void) index; (void) buffer;
   noop_warn("glTransformFeedbackBufferBase");
}

static void APIENTRY noopTransformFeedbackBufferRange(GLuint xfb, GLuint index, GLuint buffer, GLintptr offset, GLsizeiptr size)
{
   (void) xfb; (void) index; (void) buffer; (void) offset; (void) size;
   noop_warn("glTransformFeedbackBufferRange");
}

static void APIENTRY noopTransformFeedbackVaryings(GLuint program, GLsizei count, const GLchar *const *varyings, GLenum bufferMode)
{
   (void) program; (void) count; (void) varyings; (void) bufferMode;
   noop_warn("glTransformFeedbackVaryings");
}

static void APIENTRY noopTranslated(GLdouble x, GLdouble y, GLdouble z)
{
   (void) x; (void) y; (void) z;
   noop_warn("glTranslated");
}

static void APIENTRY noopTranslatef(GLfloat x, GLfloat y, GLfloat z)
{
   (void) x; (void) y; (void) z;
   noop_warn("glTranslatef");
}

static void APIENTRY noopUniform1d(GLint location, GLdouble x)
{
   (void) location; (void) x;
   noop_warn("glUniform1d");
}

static void APIENTRY noopUniform1dv(GLint location, GLsizei count, const GLdouble *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform1dv");
}

static void APIENTRY noopUniform1f(GLint location, GLfloat v0)
{
   (void) location; (void) v0;
   noop_warn("glUniform1f");
}

static void APIENTRY noopUniform1fv(GLint location, GLsizei count, const GLfloat *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform1fv");
}

static void APIENTRY noopUniform1i(GLint location, GLint v0)
{
   (void) location; (void) v0;
   noop_warn("glUniform1i");
}

static void APIENTRY noopUniform1iv(GLint location, GLsizei count, const GLint *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform1iv");
}

static void APIENTRY noopUniform1ui(GLint location, GLuint v0)
{
   (void) location; (void) v0;
   noop_warn("glUniform1ui");
}

static void APIENTRY noopUniform1uiv(GLint location, GLsizei count, const GLuint *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform1uiv");
}

static void APIENTRY noopUniform2d(GLint location, GLdouble x, GLdouble y)
{
   (void) location; (void) x; (void) y;
   noop_warn("glUniform2d");
}

static void APIENTRY noopUniform2dv(GLint location, GLsizei count, const GLdouble *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform2dv");
}

static void APIENTRY noopUniform2f(GLint location, GLfloat v0, GLfloat v1)
{
   (void) location; (void) v0; (void) v1;
   noop_warn("glUniform2f");
}

static void APIENTRY noopUniform2fv(GLint location, GLsizei count, const GLfloat *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform2fv");
}

static void APIENTRY noopUniform2i(GLint location, GLint v0, GLint v1)
{
   (void) location; (void) v0; (void) v1;
   noop_warn("glUniform2i");
}

static void APIENTRY noopUniform2iv(GLint location, GLsizei count, const GLint *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform2iv");
}

static void APIENTRY noopUniform2ui(GLint location, GLuint v0, GLuint v1)
{
   (void) location; (void) v0; (void) v1;
   noop_warn("glUniform2ui");
}

static void APIENTRY noopUniform2uiv(GLint location, GLsizei count, const GLuint *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform2uiv");
}

static void APIENTRY noopUniform3d(GLint location, GLdouble x, GLdouble y, GLdouble z)
{
   (void) location; (void) x; (void) y; (void) z;
   noop_warn("glUniform3d");
}

static void APIENTRY noopUniform3dv(GLint location, GLsizei count, const GLdouble *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform3dv");
}

static void APIENTRY noopUniform3f(GLint location, GLfloat v0, GLfloat v1, GLfloat v2)
{
   (void) location; (void) v0; (void) v1; (void) v2;
   noop_warn("glUniform3f");
}

static void APIENTRY noopUniform3fv(GLint location, GLsizei count, const GLfloat *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform3fv");
}

static void APIENTRY noopUniform3i(GLint location, GLint v0, GLint v1, GLint v2)
{
   (void) location; (void) v0; (void) v1; (void) v2;
   noop_warn("glUniform3i");
}

static void APIENTRY noopUniform3iv(GLint location, GLsizei count, const GLint *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform3iv");
}

static void APIENTRY noopUniform3ui(GLint location, GLuint v0, GLuint v1, GLuint v2)
{
   (void) location; (void) v0; (void) v1; (void) v2;
   noop_warn("glUniform3ui");
}

static void APIENTRY noopUniform3uiv(GLint location, GLsizei count, const GLuint *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform3uiv");
}

static void APIENTRY noopUniform4d(GLint location, GLdouble x, GLdouble y, GLdouble z, GLdouble w)
{
   (void) location; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glUniform4d");
}

static void APIENTRY noopUniform4dv(GLint location, GLsizei count, const GLdouble *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform4dv");
}

static void APIENTRY noopUniform4f(GLint location, GLfloat v0, GLfloat v1, GLfloat v2, GLfloat v3)
{
   (void) location; (void) v0; (void) v1; (void) v2; (void) v3;
   noop_warn("glUniform4f");
}

static void APIENTRY noopUniform4fv(GLint location, GLsizei count, const GLfloat *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform4fv");
}

static void APIENTRY noopUniform4i(GLint location, GLint v0, GLint v1, GLint v2, GLint v3)
{
   (void) location; (void) v0; (void) v1; (void) v2; (void) v3;
   noop_warn("glUniform4i");
}

static void APIENTRY noopUniform4iv(GLint location, GLsizei count, const GLint *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform4iv");
}

static void APIENTRY noopUniform4ui(GLint location, GLuint v0, GLuint v1, GLuint v2, GLuint v3)
{
   (void) location; (void) v0; (void) v1; (void) v2; (void) v3;
   noop_warn("glUniform4ui");
}

static void APIENTRY noopUniform4uiv(GLint location, GLsizei count, const GLuint *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform4uiv");
}

static void APIENTRY noopUniformBlockBinding(GLuint program, GLuint uniformBlockIndex, GLuint uniformBlockBinding)
{
   (void) program; (void) uniformBlockIndex; (void) uniformBlockBinding;
   noop_warn("glUniformBlockBinding");
}

static void APIENTRY noopUniformMatrix2dv(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glUniformMatrix2dv");
}

static void APIENTRY noopUniformMatrix2fv(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glUniformMatrix2fv");
}

static void APIENTRY noopUniformMatrix2x3dv(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glUniformMatrix2x3dv");
}

static void APIENTRY noopUniformMatrix2x3fv(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glUniformMatrix2x3fv");
}

static void APIENTRY noopUniformMatrix2x4dv(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glUniformMatrix2x4dv");
}

static void APIENTRY noopUniformMatrix2x4fv(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glUniformMatrix2x4fv");
}

static void APIENTRY noopUniformMatrix3dv(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glUniformMatrix3dv");
}

static void APIENTRY noopUniformMatrix3fv(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glUniformMatrix3fv");
}

static void APIENTRY noopUniformMatrix3x2dv(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glUniformMatrix3x2dv");
}

static void APIENTRY noopUniformMatrix3x2fv(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glUniformMatrix3x2fv");
}

static void APIENTRY noopUniformMatrix3x4dv(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glUniformMatrix3x4dv");
}

static void APIENTRY noopUniformMatrix3x4fv(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glUniformMatrix3x4fv");
}

static void APIENTRY noopUniformMatrix4dv(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glUniformMatrix4dv");
}

static void APIENTRY noopUniformMatrix4fv(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glUniformMatrix4fv");
}

static void APIENTRY noopUniformMatrix4x2dv(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glUniformMatrix4x2dv");
}

static void APIENTRY noopUniformMatrix4x2fv(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glUniformMatrix4x2fv");
}

static void APIENTRY noopUniformMatrix4x3dv(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glUniformMatrix4x3dv");
}

static void APIENTRY noopUniformMatrix4x3fv(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glUniformMatrix4x3fv");
}

static void APIENTRY noopUniformSubroutinesuiv(GLenum shadertype, GLsizei count, const GLuint *indices)
{
   (void) shadertype; (void) count; (void) indices;
   noop_warn("glUniformSubroutinesuiv");
}

static GLboolean APIENTRY noopUnmapBuffer(GLenum target)
{
   (void) target;
   noop_warn("glUnmapBuffer");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopUnmapNamedBuffer(GLuint buffer)
{
   (void) buffer;
   noop_warn("glUnmapNamedBuffer");
   return (GLboolean) 0;
}

static void APIENTRY noopUseProgram(GLuint program)
{
   (void) program;
   noop_warn("glUseProgram");
}

static void APIENTRY noopUseProgramStages(GLuint pipeline, GLbitfield stages, GLuint program)
{
   (void) pipeline; (void) stages; (void) program;
   noop_warn("glUseProgramStages");
}

static void APIENTRY noopValidateProgram(GLuint program)
{
   (void) program;
   noop_warn("glValidateProgram");
}

static void APIENTRY noopValidateProgramPipeline(GLuint pipeline)
{
   (void) pipeline;
   noop_warn("glValidateProgramPipeline");
}

static void APIENTRY noopVertex2d(GLdouble x, GLdouble y)
{
   (void) x; (void) y;
   noop_warn("glVertex2d");
}

static void APIENTRY noopVertex2dv(const GLdouble *v)
{
   (void) v;
   noop_warn("glVertex2dv");
}

static void APIENTRY noopVertex2f(GLfloat x, GLfloat y)
{
   (void) x; (void) y;
   noop_warn("glVertex2f");
}

static void APIENTRY noopVertex2fv(const GLfloat *v)
{
   (void) v;
   noop_warn("glVertex2fv");
}

static void APIENTRY noopVertex2i(GLint x, GLint y)
{
   (void) x; (void) y;
   noop_warn("glVertex2i");
}

static void APIENTRY noopVertex2iv(const GLint *v)
{
   (void) v;
   noop_warn("glVertex2iv");
}

static void APIENTRY noopVertex2s(GLshort x, GLshort y)
{
   (void) x; (void) y;
   noop_warn("glVertex2s");
}

static void APIENTRY noopVertex2sv(const GLshort *v)
{
   (void) v;
   noop_warn("glVertex2sv");
}

static void APIENTRY noopVertex3d(GLdouble x, GLdouble y, GLdouble z)
{
   (void) x; (void) y; (void) z;
   noop_warn("glVertex3d");
}

static void APIENTRY noopVertex3dv(const GLdouble *v)
{
   (void) v;
   noop_warn("glVertex3dv");
}

static void APIENTRY noopVertex3f(GLfloat x, GLfloat y, GLfloat z)
{
   (void) x; (void) y; (void) z;
   noop_warn("glVertex3f");
}

static void APIENTRY noopVertex3fv(const GLfloat *v)
{
   (void) v;
   noop_warn("glVertex3fv");
}

static void APIENTRY noopVertex3i(GLint x, GLint y, GLint z)
{
   (void) x; (void) y; (void) z;
   noop_warn("glVertex3i");
}

static void APIENTRY noopVertex3iv(const GLint *v)
{
   (void) v;
   noop_warn("glVertex3iv");
}

static void APIENTRY noopVertex3s(GLshort x, GLshort y, GLshort z)
{
   (void) x; (void) y; (void) z;
   noop_warn("glVertex3s");
}

static void APIENTRY noopVertex3sv(const GLshort *v)
{
   (void) v;
   noop_warn("glVertex3sv");
}

static void APIENTRY noopVertex4d(GLdouble x, GLdouble y, GLdouble z, GLdouble w)
{
   (void) x; (void) y; (void) z; (void) w;
   noop_warn("glVertex4d");
}

static void APIENTRY noopVertex4dv(const GLdouble *v)
{
   (void) v;
   noop_warn("glVertex4dv");
}

static void APIENTRY noopVertex4f(GLfloat x, GLfloat y, GLfloat z, GLfloat w)
{
   (void) x; (void) y; (void) z; (void) w;
   noop_warn("glVertex4f");
}

static void APIENTRY noopVertex4fv(const GLfloat *v)
{
   (void) v;
   noop_warn("glVertex4fv");
}

static void APIENTRY noopVertex4i(GLint x, GLint y, GLint z, GLint w)
{
   (void) x; (void) y; (void) z; (void) w;
   noop_warn("glVertex4i");
}

static void APIENTRY noopVertex4iv(const GLint *v)
{
   (void) v;
   noop_warn("glVertex4iv");
}

static void APIENTRY noopVertex4s(GLshort x, GLshort y, GLshort z, GLshort w)
{
   (void) x; (void) y; (void) z; (void) w;
   noop_warn("glVertex4s");
}

static void APIENTRY noopVertex4sv(const GLshort *v)
{
   (void) v;
   noop_warn("glVertex4sv");
}

static void APIENTRY noopVertexArrayAttribBinding(GLuint vaobj, GLuint attribindex, GLuint bindingindex)
{
   (void) vaobj; (void) attribindex; (void) bindingindex;
   noop_warn("glVertexArrayAttribBinding");
}

static void APIENTRY noopVertexArrayAttribFormat(GLuint vaobj, GLuint attribindex, GLint size, GLenum type, GLboolean normalized, GLuint relativeoffset)
{
   (void) vaobj; (void) attribindex; (void) size; (void) type; (void) normalized; (void) relativeoffset;
   noop_warn("glVertexArrayAttribFormat");
}

static void APIENTRY noopVertexArrayAttribIFormat(GLuint vaobj, GLuint attribindex, GLint size, GLenum type, GLuint relativeoffset)
{
   (void) vaobj; (void) attribindex; (void) size; (void) type; (void) relativeoffset;
   noop_warn("glVertexArrayAttribIFormat");
}

static void APIENTRY noopVertexArrayAttribLFormat(GLuint vaobj, GLuint attribindex, GLint size, GLenum type, GLuint relativeoffset)
{
   (void) vaobj; (void) attribindex; (void) size; (void) type; (void) relativeoffset;
   noop_warn("glVertexArrayAttribLFormat");
}

static void APIENTRY noopVertexArrayBindingDivisor(GLuint vaobj, GLuint bindingindex, GLuint divisor)
{
   (void) vaobj; (void) bindingindex; (void) divisor;
   noop_warn("glVertexArrayBindingDivisor");
}

static void APIENTRY noopVertexArrayElementBuffer(GLuint vaobj, GLuint buffer)
{
   (void) vaobj; (void) buffer;
   noop_warn("glVertexArrayElementBuffer");
}

static void APIENTRY noopVertexArrayVertexBuffer(GLuint vaobj, GLuint bindingindex, GLuint buffer, GLintptr offset, GLsizei stride)
{
   (void) vaobj; (void) bindingindex; (void) buffer; (void) offset; (void) stride;
   noop_warn("glVertexArrayVertexBuffer");
}

static void APIENTRY noopVertexArrayVertexBuffers(GLuint vaobj, GLuint first, GLsizei count, const GLuint *buffers, const GLintptr *offsets, const GLsizei *strides)
{
   (void) vaobj; (void) first; (void) count; (void) buffers; (void) offsets; (void) strides;
   noop_warn("glVertexArrayVertexBuffers");
}

static void APIENTRY noopVertexAttrib1d(GLuint index, GLdouble x)
{
   (void) index; (void) x;
   noop_warn("glVertexAttrib1d");
}

static void APIENTRY noopVertexAttrib1dv(GLuint index, const GLdouble *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib1dv");
}

static void APIENTRY noopVertexAttrib1f(GLuint index, GLfloat x)
{
   (void) index; (void) x;
   noop_warn("glVertexAttrib1f");
}

static void APIENTRY noopVertexAttrib1fv(GLuint index, const GLfloat *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib1fv");
}

static void APIENTRY noopVertexAttrib1s(GLuint index, GLshort x)
{
   (void) index; (void) x;
   noop_warn("glVertexAttrib1s");
}

static void APIENTRY noopVertexAttrib1sv(GLuint index, const GLshort *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib1sv");
}

static void APIENTRY noopVertexAttrib2d(GLuint index, GLdouble x, GLdouble y)
{
   (void) index; (void) x; (void) y;
   noop_warn("glVertexAttrib2d");
}

static void APIENTRY noopVertexAttrib2dv(GLuint index, const GLdouble *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib2dv");
}

static void APIENTRY noopVertexAttrib2f(GLuint index, GLfloat x, GLfloat y)
{
   (void) index; (void) x; (void) y;
   noop_warn("glVertexAttrib2f");
}

static void APIENTRY noopVertexAttrib2fv(GLuint index, const GLfloat *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib2fv");
}

static void APIENTRY noopVertexAttrib2s(GLuint index, GLshort x, GLshort y)
{
   (void) index; (void) x; (void) y;
   noop_warn("glVertexAttrib2s");
}

static void APIENTRY noopVertexAttrib2sv(GLuint index, const GLshort *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib2sv");
}

static void APIENTRY noopVertexAttrib3d(GLuint index, GLdouble x, GLdouble y, GLdouble z)
{
   (void) index; (void) x; (void) y; (void) z;
   noop_warn("glVertexAttrib3d");
}

static void APIENTRY noopVertexAttrib3dv(GLuint index, const GLdouble *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib3dv");
}

static void APIENTRY noopVertexAttrib3f(GLuint index, GLfloat x, GLfloat y, GLfloat z)
{
   (void) index; (void) x; (void) y; (void) z;
   noop_warn("glVertexAttrib3f");
}

static void APIENTRY noopVertexAttrib3fv(GLuint index, const GLfloat *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib3fv");
}

static void APIENTRY noopVertexAttrib3s(GLuint index, GLshort x, GLshort y, GLshort z)
{
   (void) index; (void) x; (void) y; (void) z;
   noop_warn("glVertexAttrib3s");
}

static void APIENTRY noopVertexAttrib3sv(GLuint index, const GLshort *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib3sv");
}

static void APIENTRY noopVertexAttrib4Nbv(GLuint index, const GLbyte *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib4Nbv");
}

static void APIENTRY noopVertexAttrib4Niv(GLuint index, const GLint *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib4Niv");
}

static void APIENTRY noopVertexAttrib4Nsv(GLuint index, const GLshort *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib4Nsv");
}

static void APIENTRY noopVertexAttrib4Nub(GLuint index, GLubyte x, GLubyte y, GLubyte z, GLubyte w)
{
   (void) index; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glVertexAttrib4Nub");
}

static void APIENTRY noopVertexAttrib4Nubv(GLuint index, const GLubyte *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib4Nubv");
}

static void APIENTRY noopVertexAttrib4Nuiv(GLuint index, const GLuint *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib4Nuiv");
}

static void APIENTRY noopVertexAttrib4Nusv(GLuint index, const GLushort *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib4Nusv");
}

static void APIENTRY noopVertexAttrib4bv(GLuint index, const GLbyte *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib4bv");
}

static void APIENTRY noopVertexAttrib4d(GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w)
{
   (void) index; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glVertexAttrib4d");
}

static void APIENTRY noopVertexAttrib4dv(GLuint index, const GLdouble *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib4dv");
}

static void APIENTRY noopVertexAttrib4f(GLuint index, GLfloat x, GLfloat y, GLfloat z, GLfloat w)
{
   (void) index; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glVertexAttrib4f");
}

static void APIENTRY noopVertexAttrib4fv(GLuint index, const GLfloat *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib4fv");
}

static void APIENTRY noopVertexAttrib4iv(GLuint index, const GLint *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib4iv");
}

static void APIENTRY noopVertexAttrib4s(GLuint index, GLshort x, GLshort y, GLshort z, GLshort w)
{
   (void) index; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glVertexAttrib4s");
}

static void APIENTRY noopVertexAttrib4sv(GLuint index, const GLshort *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib4sv");
}

static void APIENTRY noopVertexAttrib4ubv(GLuint index, const GLubyte *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib4ubv");
}

static void APIENTRY noopVertexAttrib4uiv(GLuint index, const GLuint *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib4uiv");
}

static void APIENTRY noopVertexAttrib4usv(GLuint index, const GLushort *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib4usv");
}

static void APIENTRY noopVertexAttribBinding(GLuint attribindex, GLuint bindingindex)
{
   (void) attribindex; (void) bindingindex;
   noop_warn("glVertexAttribBinding");
}

static void APIENTRY noopVertexAttribDivisor(GLuint index, GLuint divisor)
{
   (void) index; (void) divisor;
   noop_warn("glVertexAttribDivisor");
}

static void APIENTRY noopVertexAttribFormat(GLuint attribindex, GLint size, GLenum type, GLboolean normalized, GLuint relativeoffset)
{
   (void) attribindex; (void) size; (void) type; (void) normalized; (void) relativeoffset;
   noop_warn("glVertexAttribFormat");
}

static void APIENTRY noopVertexAttribI1i(GLuint index, GLint x)
{
   (void) index; (void) x;
   noop_warn("glVertexAttribI1i");
}

static void APIENTRY noopVertexAttribI1iv(GLuint index, const GLint *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttribI1iv");
}

static void APIENTRY noopVertexAttribI1ui(GLuint index, GLuint x)
{
   (void) index; (void) x;
   noop_warn("glVertexAttribI1ui");
}

static void APIENTRY noopVertexAttribI1uiv(GLuint index, const GLuint *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttribI1uiv");
}

static void APIENTRY noopVertexAttribI2i(GLuint index, GLint x, GLint y)
{
   (void) index; (void) x; (void) y;
   noop_warn("glVertexAttribI2i");
}

static void APIENTRY noopVertexAttribI2iv(GLuint index, const GLint *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttribI2iv");
}

static void APIENTRY noopVertexAttribI2ui(GLuint index, GLuint x, GLuint y)
{
   (void) index; (void) x; (void) y;
   noop_warn("glVertexAttribI2ui");
}

static void APIENTRY noopVertexAttribI2uiv(GLuint index, const GLuint *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttribI2uiv");
}

static void APIENTRY noopVertexAttribI3i(GLuint index, GLint x, GLint y, GLint z)
{
   (void) index; (void) x; (void) y; (void) z;
   noop_warn("glVertexAttribI3i");
}

static void APIENTRY noopVertexAttribI3iv(GLuint index, const GLint *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttribI3iv");
}

static void APIENTRY noopVertexAttribI3ui(GLuint index, GLuint x, GLuint y, GLuint z)
{
   (void) index; (void) x; (void) y; (void) z;
   noop_warn("glVertexAttribI3ui");
}

static void APIENTRY noopVertexAttribI3uiv(GLuint index, const GLuint *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttribI3uiv");
}

static void APIENTRY noopVertexAttribI4bv(GLuint index, const GLbyte *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttribI4bv");
}

static void APIENTRY noopVertexAttribI4i(GLuint index, GLint x, GLint y, GLint z, GLint w)
{
   (void) index; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glVertexAttribI4i");
}

static void APIENTRY noopVertexAttribI4iv(GLuint index, const GLint *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttribI4iv");
}

static void APIENTRY noopVertexAttribI4sv(GLuint index, const GLshort *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttribI4sv");
}

static void APIENTRY noopVertexAttribI4ubv(GLuint index, const GLubyte *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttribI4ubv");
}

static void APIENTRY noopVertexAttribI4ui(GLuint index, GLuint x, GLuint y, GLuint z, GLuint w)
{
   (void) index; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glVertexAttribI4ui");
}

static void APIENTRY noopVertexAttribI4uiv(GLuint index, const GLuint *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttribI4uiv");
}

static void APIENTRY noopVertexAttribI4usv(GLuint index, const GLushort *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttribI4usv");
}

static void APIENTRY noopVertexAttribIFormat(GLuint attribindex, GLint size, GLenum type, GLuint relativeoffset)
{
   (void) attribindex; (void) size; (void) type; (void) relativeoffset;
   noop_warn("glVertexAttribIFormat");
}

static void APIENTRY noopVertexAttribIPointer(GLuint index, GLint size, GLenum type, GLsizei stride, const void *pointer)
{
   (void) index; (void) size; (void) type; (void) stride; (void) pointer;
   noop_warn("glVertexAttribIPointer");
}

static void APIENTRY noopVertexAttribL1d(GLuint index, GLdouble x)
{
   (void) index; (void) x;
   noop_warn("glVertexAttribL1d");
}

static void APIENTRY noopVertexAttribL1dv(GLuint index, const GLdouble *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttribL1dv");
}

static void APIENTRY noopVertexAttribL2d(GLuint index, GLdouble x, GLdouble y)
{
   (void) index; (void) x; (void) y;
   noop_warn("glVertexAttribL2d");
}

static void APIENTRY noopVertexAttribL2dv(GLuint index, const GLdouble *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttribL2dv");
}

static void APIENTRY noopVertexAttribL3d(GLuint index, GLdouble x, GLdouble y, GLdouble z)
{
   (void) index; (void) x; (void) y; (void) z;
   noop_warn("glVertexAttribL3d");
}

static void APIENTRY noopVertexAttribL3dv(GLuint index, const GLdouble *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttribL3dv");
}

static void APIENTRY noopVertexAttribL4d(GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w)
{
   (void) index; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glVertexAttribL4d");
}

static void APIENTRY noopVertexAttribL4dv(GLuint index, const GLdouble *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttribL4dv");
}

static void APIENTRY noopVertexAttribLFormat(GLuint attribindex, GLint size, GLenum type, GLuint relativeoffset)
{
   (void) attribindex; (void) size; (void) type; (void) relativeoffset;
   noop_warn("glVertexAttribLFormat");
}

static void APIENTRY noopVertexAttribLPointer(GLuint index, GLint size, GLenum type, GLsizei stride, const void *pointer)
{
   (void) index; (void) size; (void) type; (void) stride; (void) pointer;
   noop_warn("glVertexAttribLPointer");
}

static void APIENTRY noopVertexAttribP1ui(GLuint index, GLenum type, GLboolean normalized, GLuint value)
{
   (void) index; (void) type; (void) normalized; (void) value;
   noop_warn("glVertexAttribP1ui");
}

static void APIENTRY noopVertexAttribP1uiv(GLuint index, GLenum type, GLboolean normalized, const GLuint *value)
{
   (void) index; (void) type; (void) normalized; (void) value;
   noop_warn("glVertexAttribP1uiv");
}

static void APIENTRY noopVertexAttribP2ui(GLuint index, GLenum type, GLboolean normalized, GLuint value)
{
   (void) index; (void) type; (void) normalized; (void) value;
   noop_warn("glVertexAttribP2ui");
}

static void APIENTRY noopVertexAttribP2uiv(GLuint index, GLenum type, GLboolean normalized, const GLuint *value)
{
   (void) index; (void) type; (void) normalized; (void) value;
   noop_warn("glVertexAttribP2uiv");
}

static void APIENTRY noopVertexAttribP3ui(GLuint index, GLenum type, GLboolean normalized, GLuint value)
{
   (void) index; (void) type; (void) normalized; (void) value;
   noop_warn("glVertexAttribP3ui");
}

static void APIENTRY noopVertexAttribP3uiv(GLuint index, GLenum type, GLboolean normalized, const GLuint *value)
{
   (void) index; (void) type; (void) normalized; (void) value;
   noop_warn("glVertexAttribP3uiv");
}

static void APIENTRY noopVertexAttribP4ui(GLuint index, GLenum type, GLboolean normalized, GLuint value)
{
   (void) index; (void) type; (void) normalized; (void) value;
   noop_warn("glVertexAttribP4ui");
}

static void APIENTRY noopVertexAttribP4uiv(GLuint index, GLenum type, GLboolean normalized, const GLuint *value)
{
   (void) index; (void) type; (void) normalized; (void) value;
   noop_warn("glVertexAttribP4uiv");
}

static void APIENTRY noopVertexAttribPointer(GLuint index, GLint size, GLenum type, GLboolean normalized, GLsizei stride, const void *pointer)
{
   (void) index; (void) size; (void) type; (void) normalized; (void) stride; (void) pointer;
   noop_warn("glVertexAttribPointer");
}

static void APIENTRY noopVertexBindingDivisor(GLuint bindingindex, GLuint divisor)
{
   (void) bindingindex; (void) divisor;
   noop_warn("glVertexBindingDivisor");
}

static void APIENTRY noopVertexP2ui(GLenum type, GLuint value)
{
   (void) type; (void) value;
   noop_warn("glVertexP2ui");
}

static void APIENTRY noopVertexP2uiv(GLenum type, const GLuint *value)
{
   (void) type; (void) value;
   noop_warn("glVertexP2uiv");
}

static void APIENTRY noopVertexP3ui(GLenum type, GLuint value)
{
   (void) type; (void) value;
   noop_warn("glVertexP3ui");
}

static void APIENTRY noopVertexP3uiv(GLenum type, const GLuint *value)
{
   (void) type; (void) value;
   noop_warn("glVertexP3uiv");
}

static void APIENTRY noopVertexP4ui(GLenum type, GLuint value)
{
   (void) type; (void) value;
   noop_warn("glVertexP4ui");
}

static void APIENTRY noopVertexP4uiv(GLenum type, const GLuint *value)
{
   (void) type; (void) value;
   noop_warn("glVertexP4uiv");
}

static void APIENTRY noopVertexPointer(GLint size, GLenum type, GLsizei stride, const void *pointer)
{
   (void) size; (void) type; (void) stride; (void) pointer;
   noop_warn("glVertexPointer");
}

static void APIENTRY noopViewport(GLint x, GLint y, GLsizei width, GLsizei height)
{
   (void) x; (void) y; (void) width; (void) height;
   noop_warn("glViewport");
}

static void APIENTRY noopViewportArrayv(GLuint first, GLsizei count, const GLfloat *v)
{
   (void) first; (void) count; (void) v;
   noop_warn("glViewportArrayv");
}

static void APIENTRY noopViewportIndexedf(GLuint index, GLfloat x, GLfloat y, GLfloat w, GLfloat h)
{
   (void) index; (void) x; (void) y; (void) w; (void) h;
   noop_warn("glViewportIndexedf");
}

static void APIENTRY noopViewportIndexedfv(GLuint index, const GLfloat *v)
{
   (void) index; (void) v;
   noop_warn("glViewportIndexedfv");
}

static void APIENTRY noopWaitSync(GLsync sync, GLbitfield flags, GLuint64 timeout)
{
   (void) sync; (void) flags; (void) timeout;
   noop_warn("glWaitSync");
}

static void APIENTRY noopWindowPos2d(GLdouble x, GLdouble y)
{
   (void) x; (void) y;
   noop_warn("glWindowPos2d");
}

static void APIENTRY noopWindowPos2dv(const GLdouble *v)
{
   (void) v;
   noop_warn("glWindowPos2dv");
}

static void APIENTRY noopWindowPos2f(GLfloat x, GLfloat y)
{
   (void) x; (void) y;
   noop_warn("glWindowPos2f");
}

static void APIENTRY noopWindowPos2fv(const GLfloat *v)
{
   (void) v;
   noop_warn("glWindowPos2fv");
}

static void APIENTRY noopWindowPos2i(GLint x, GLint y)
{
   (void) x; (void) y;
   noop_warn("glWindowPos2i");
}

static void APIENTRY noopWindowPos2iv(const GLint *v)
{
   (void) v;
   noop_warn("glWindowPos2iv");
}

static void APIENTRY noopWindowPos2s(GLshort x, GLshort y)
{
   (void) x; (void) y;
   noop_warn("glWindowPos2s");
}

static void APIENTRY noopWindowPos2sv(const GLshort *v)
{
   (void) v;
   noop_warn("glWindowPos2sv");
}

static void APIENTRY noopWindowPos3d(GLdouble x, GLdouble y, GLdouble z)
{
   (void) x; (void) y; (void) z;
   noop_warn("glWindowPos3d");
}

static void APIENTRY noopWindowPos3dv(const GLdouble *v)
{
   (void) v;
   noop_warn("glWindowPos3dv");
}

static void APIENTRY noopWindowPos3f(GLfloat x, GLfloat y, GLfloat z)
{
   (void) x; (void) y; (void) z;
   noop_warn("glWindowPos3f");
}

static void APIENTRY noopWindowPos3fv(const GLfloat *v)
{
   (void) v;
   noop_warn("glWindowPos3fv");
}

static void APIENTRY noopWindowPos3i(GLint x, GLint y, GLint z)
{
   (void) x; (void) y; (void) z;
   noop_warn("glWindowPos3i");
}

static void APIENTRY noopWindowPos3iv(const GLint *v)
{
   (void) v;
   noop_warn("glWindowPos3iv");
}

static void APIENTRY noopWindowPos3s(GLshort x, GLshort y, GLshort z)
{
   (void) x; (void) y; (void) z;
   noop_warn("glWindowPos3s");
}

static void APIENTRY noopWindowPos3sv(const GLshort *v)
{
   (void) v;
   noop_warn("glWindowPos3sv");
}

const mapi_func table_noop_array[] = {
   (mapi_func) noopAccum,
   (mapi_func) noopActiveShaderProgram,
   (mapi_func) noopActiveTexture,
   (mapi_func) noopAlphaFunc,
   (mapi_func) noopAreTexturesResident,
   (mapi_func) noopArrayElement,
   (mapi_func) noopAttachShader,
   (mapi_func) noopBegin,
   (mapi_func) noopBeginConditionalRender,
   (mapi_func) noopBeginQuery,
   (mapi_func) noopBeginQueryIndexed,
   (mapi_func) noopBeginTransformFeedback,
   (mapi_func) noopBindAttribLocation,
   (mapi_func) noopBindBuffer,
   (mapi_func) noopBindBufferBase,
   (mapi_func) noopBindBufferRange,
   (mapi_func) noopBindBuffersBase,
   (mapi_func) noopBindBuffersRange,
   (mapi_func) noopBindFragDataLocation,
   (mapi_func) noopBindFragDataLocationIndexed,
   (mapi_func) noopBindFramebuffer,
   (mapi_func) noopBindImageTexture,
   (mapi_func) noopBindImageTextures,
   (mapi_func) noopBindProgramPipeline,
   (mapi_func) noopBindRenderbuffer,
   (mapi_func) noopBindSampler,
   (mapi_func) noopBindSamplers,
   (mapi_func) noopBindTexture,
   (mapi_func) noopBindTextureUnit,
   (mapi_func) noopBindTextures,
   (mapi_func) noopBindTransformFeedback,
   (mapi_func) noopBindVertexArray,
   (mapi_func) noopBindVertexBuffer,
   (mapi_func) noopBindVertexBuffers,
   (mapi_func) noopBitmap,
   (mapi_func) noopBlendColor,
   (mapi_func) noopBlendEquation,
   (mapi_func) noopBlendEquationSeparate,
   (mapi_func) noopBlendEquationSeparatei,
   (mapi_func) noopBlendEquationi,
   (mapi_func) noopBlendFunc,
   (mapi_func) noopBlendFuncSeparate,
   (mapi_func) noopBlendFuncSeparatei,
   (mapi_func) noopBlendFunci,
   (mapi_func) noopBlitFramebuffer,
   (mapi_func) noopBlitNamedFramebuffer,
   (mapi_func) noopBufferData,
   (mapi_func) noopBufferStorage,
   (mapi_func) noopBufferSubData,
   (mapi_func) noopCallList,
   (mapi_func) noopCallLists,
   (mapi_func) noopCheckFramebufferStatus,
   (mapi_func) noopCheckNamedFramebufferStatus,
   (mapi_func) noopClampColor,
   (mapi_func) noopClear,
   (mapi_func) noopClearAccum,
   (mapi_func) noopClearBufferData,
   (mapi_func) noopClearBufferSubData,
   (mapi_func) noopClearBufferfi,
   (mapi_func) noopClearBufferfv,
   (mapi_func) noopClearBufferiv,
   (mapi_func) noopClearBufferuiv,
   (mapi_func) noopClearColor,
   (mapi_func) noopClearDepth,
   (mapi_func) noopClearDepthf,
   (mapi_func) noopClearIndex,
   (mapi_func) noopClearNamedBufferData,
   (mapi_func) noopClearNamedBufferSubData,
   (mapi_func) noopClearNamedFramebufferfi,
   (mapi_func) noopClearNamedFramebufferfv,
   (mapi_func) noopClearNamedFramebufferiv,
   (mapi_func) noopClearNamedFramebufferuiv,
   (mapi_func) noopClearStencil,
   (mapi_func) noopClearTexImage,
   (mapi_func) noopClearTexSubImage,
   (mapi_func) noopClientActiveTexture,
   (mapi_func) noopClientWaitSync,
   (mapi_func) noopClipControl,
   (mapi_func) noopClipPlane,
   (mapi_func) noopColor3b,
   (mapi_func) noopColor3bv,
   (mapi_func) noopColor3d,
   (mapi_func) noopColor3dv,
   (mapi_func) noopColor3f,
   (mapi_func) noopColor3fv,
   (mapi_func) noopColor3i,
   (mapi_func) noopColor3iv,
   (mapi_func) noopColor3s,
   (mapi_func) noopColor3sv,
   (mapi_func) noopColor3ub,
   (mapi_func) noopColor3ubv,
   (mapi_func) noopColor3ui,
   (mapi_func) noopColor3uiv,
   (mapi_func) noopColor3us,
   (mapi_func) noopColor3usv,
   (mapi_func) noopColor4b,
   (mapi_func) noopColor4bv,
   (mapi_func) noopColor4d,
   (mapi_func) noopColor4dv,
   (mapi_func) noopColor4f,
   (mapi_func) noopColor4fv,
   (mapi_func) noopColor4i,
   (mapi_func) noopColor4iv,
   (mapi_func) noopColor4s,
   (mapi_func) noopColor4sv,
   (mapi_func) noopColor4ub,
   (mapi_func) noopColor4ubv,
   (mapi_func) noopColor4ui,
   (mapi_func) noopColor4uiv,
   (mapi_func) noopColor4us,
   (mapi_func) noopColor4usv,
   (mapi_func) noopColorMask,
   (mapi_func) noopColorMaski,
   (mapi_func) noopColorMaterial,
   (mapi_func) noopColorP3ui,
   (mapi_func) noopColorP3uiv,
   (mapi_func) noopColorP4ui,
   (mapi_func) noopColorP4uiv,
   (mapi_func) noopColorPointer,
   (mapi_func) noopCompileShader,
   (mapi_func) noopCompressedTexImage1D,
   (mapi_func) noopCompressedTexImage2D,
   (mapi_func) noopCompressedTexImage3D,
   (mapi_func) noopCompressedTexSubImage1D,
   (mapi_func) noopCompressedTexSubImage2D,
   (mapi_func) noopCompressedTexSubImage3D,
   (mapi_func) noopCompressedTextureSubImage1D,
   (mapi_func) noopCompressedTextureSubImage2D,
   (mapi_func) noopCompressedTextureSubImage3D,
   (mapi_func) noopCopyBufferSubData,
   (mapi_func) noopCopyImageSubData,
   (mapi_func) noopCopyNamedBufferSubData,
   (mapi_func) noopCopyPixels,
   (mapi_func) noopCopyTexImage1D,
   (mapi_func) noopCopyTexImage2D,
   (mapi_func) noopCopyTexSubImage1D,
   (mapi_func) noopCopyTexSubImage2D,
   (mapi_func) noopCopyTexSubImage3D,
   (mapi_func) noopCopyTextureSubImage1D,
   (mapi_func) noopCopyTextureSubImage2D,
   (mapi_func) noopCopyTextureSubImage3D,
   (mapi_func) noopCreateBuffers,
   (mapi_func) noopCreateFramebuffers,
   (mapi_func) noopCreateProgram,
   (mapi_func) noopCreateProgramPipelines,
   (mapi_func) noopCreateQueries,
   (mapi_func) noopCreateRenderbuffers,
   (mapi_func) noopCreateSamplers,
   (mapi_func) noopCreateShader,
   (mapi_func) noopCreateShaderProgramv,
   (mapi_func) noopCreateTextures,
   (mapi_func) noopCreateTransformFeedbacks,
   (mapi_func) noopCreateVertexArrays,
   (mapi_func) noopCullFace,
   (mapi_func) noopDebugMessageCallback,
   (mapi_func) noopDebugMessageControl,
   (mapi_func) noopDebugMessageInsert,
   (mapi_func) noopDeleteBuffers,
   (mapi_func) noopDeleteFramebuffers,
   (mapi_func) noopDeleteLists,
   (mapi_func) noopDeleteProgram,
   (mapi_func) noopDeleteProgramPipelines,
   (mapi_func) noopDeleteQueries,
   (mapi_func) noopDeleteRenderbuffers,
   (mapi_func) noopDeleteSamplers,
   (mapi_func) noopDeleteShader,
   (mapi_func) noopDeleteSync,
   (mapi_func) noopDeleteTextures,
   (mapi_func) noopDeleteTransformFeedbacks,
   (mapi_func) noopDeleteVertexArrays,
   (mapi_func) noopDepthFunc,
   (mapi_func) noopDepthMask,
   (mapi_func) noopDepthRange,
   (mapi_func) noopDepthRangeArrayv,
   (mapi_func) noopDepthRangeIndexed,
   (mapi_func) noopDepthRangef,
   (mapi_func) noopDetachShader,
   (mapi_func) noopDisable,
   (mapi_func) noopDisableClientState,
   (mapi_func) noopDisableVertexArrayAttrib,
   (mapi_func) noopDisableVertexAttribArray,
   (mapi_func) noopDisablei,
   (mapi_func) noopDispatchCompute,
   (mapi_func) noopDispatchComputeIndirect,
   (mapi_func) noopDrawArrays,
   (mapi_func) noopDrawArraysIndirect,
   (mapi_func) noopDrawArraysInstanced,
   (mapi_func) noopDrawArraysInstancedBaseInstance,
   (mapi_func) noopDrawBuffer,
   (mapi_func) noopDrawBuffers,
   (mapi_func) noopDrawElements,
   (mapi_func) noopDrawElementsBaseVertex,
   (mapi_func) noopDrawElementsIndirect,
   (mapi_func) noopDrawElementsInstanced,
   (mapi_func) noopDrawElementsInstancedBaseInstance,
   (mapi_func) noopDrawElementsInstancedBaseVertex,
   (mapi_func) noopDrawElementsInstancedBaseVertexBaseInstance,
   (mapi_func) noopDrawPixels,
   (mapi_func) noopDrawRangeElements,
   (mapi_func) noopDrawRangeElementsBaseVertex,
   (mapi_func) noopDrawTransformFeedback,
   (mapi_func) noopDrawTransformFeedbackInstanced,
   (mapi_func) noopDrawTransformFeedbackStream,
   (mapi_func) noopDrawTransformFeedbackStreamInstanced,
   (mapi_func) noopEdgeFlag,
   (mapi_func) noopEdgeFlagPointer,
   (mapi_func) noopEdgeFlagv,
   (mapi_func) noopEnable,
   (mapi_func) noopEnableClientState,
   (mapi_func) noopEnableVertexArrayAttrib,
   (mapi_func) noopEnableVertexAttribArray,
   (mapi_func) noopEnablei,
   (mapi_func) noopEnd,
   (mapi_func) noopEndConditionalRender,
   (mapi_func) noopEndList,
   (mapi_func) noopEndQuery,
   (mapi_func) noopEndQueryIndexed,
   (mapi_func) noopEndTransformFeedback,
   (mapi_func) noopEvalCoord1d,
   (mapi_func) noopEvalCoord1dv,
   (mapi_func) noopEvalCoord1f,
   (mapi_func) noopEvalCoord1fv,
   (mapi_func) noopEvalCoord2d,
   (mapi_func) noopEvalCoord2dv,
   (mapi_func) noopEvalCoord2f,
   (mapi_func) noopEvalCoord2fv,
   (mapi_func) noopEvalMesh1,
   (mapi_func) noopEvalMesh2,
   (mapi_func) noopEvalPoint1,
   (mapi_func) noopEvalPoint2,
   (mapi_func) noopFeedbackBuffer,
   (mapi_func) noopFenceSync,
   (mapi_func) noopFinish,
   (mapi_func) noopFlush,
   (mapi_func) noopFlushMappedBufferRange,
   (mapi_func) noopFlushMappedNamedBufferRange,
   (mapi_func) noopFogCoordPointer,
   (mapi_func) noopFogCoordd,
   (mapi_func) noopFogCoorddv,
   (mapi_func) noopFogCoordf,
   (mapi_func) noopFogCoordfv,
   (mapi_func) noopFogf,
   (mapi_func) noopFogfv,
   (mapi_func) noopFogi,
   (mapi_func) noopFogiv,
   (mapi_func) noopFramebufferParameteri,
   (mapi_func) noopFramebufferRenderbuffer,
   (mapi_func) noopFramebufferTexture,
   (mapi_func) noopFramebufferTexture1D,
   (mapi_func) noopFramebufferTexture2D,
   (mapi_func) noopFramebufferTexture3D,
   (mapi_func) noopFramebufferTextureLayer,
   (mapi_func) noopFrontFace,
   (mapi_func) noopFrustum,
   (mapi_func) noopGenBuffers,
   (mapi_func) noopGenFramebuffers,
   (mapi_func) noopGenLists,
   (mapi_func) noopGenProgramPipelines,
   (mapi_func) noopGenQueries,
   (mapi_func) noopGenRenderbuffers,
   (mapi_func) noopGenSamplers,
   (mapi_func) noopGenTextures,
   (mapi_func) noopGenTransformFeedbacks,
   (mapi_func) noopGenVertexArrays,
   (mapi_func) noopGenerateMipmap,
   (mapi_func) noopGenerateTextureMipmap,
   (mapi_func) noopGetActiveAtomicCounterBufferiv,
   (mapi_func) noopGetActiveAttrib,
   (mapi_func) noopGetActiveSubroutineName,
   (mapi_func) noopGetActiveSubroutineUniformName,
   (mapi_func) noopGetActiveSubroutineUniformiv,
   (mapi_func) noopGetActiveUniform,
   (mapi_func) noopGetActiveUniformBlockName,
   (mapi_func) noopGetActiveUniformBlockiv,
   (mapi_func) noopGetActiveUniformName,
   (mapi_func) noopGetActiveUniformsiv,
   (mapi_func) noopGetAttachedShaders,
   (mapi_func) noopGetAttribLocation,
   (mapi_func) noopGetBooleani_v,
   (mapi_func) noopGetBooleanv,
   (mapi_func) noopGetBufferParameteri64v,
   (mapi_func) noopGetBufferParameteriv,
   (mapi_func) noopGetBufferPointerv,
   (mapi_func) noopGetBufferSubData,
   (mapi_func) noopGetClipPlane,
   (mapi_func) noopGetCompressedTexImage,
   (mapi_func) noopGetCompressedTextureImage,
   (mapi_func) noopGetCompressedTextureSubImage,
   (mapi_func) noopGetDebugMessageLog,
   (mapi_func) noopGetDoublei_v,
   (mapi_func) noopGetDoublev,
   (mapi_func) noopGetError,
   (mapi_func) noopGetFloati_v,
   (mapi_func) noopGetFloatv,
   (mapi_func) noopGetFragDataIndex,
   (mapi_func) noopGetFragDataLocation,
   (mapi_func) noopGetFramebufferAttachmentParameteriv,
   (mapi_func) noopGetFramebufferParameteriv,
   (mapi_func) noopGetGraphicsResetStatus,
   (mapi_func) noopGetInteger64i_v,
   (mapi_func) noopGetInteger64v,
   (mapi_func) noopGetIntegeri_v,
   (mapi_func) noopGetIntegerv,
   (mapi_func) noopGetInternalformati64v,
   (mapi_func) noopGetInternalformativ,
   (mapi_func) noopGetLightfv,
   (mapi_func) noopGetLightiv,
   (mapi_func) noopGetMapdv,
   (mapi_func) noopGetMapfv,
   (mapi_func) noopGetMapiv,
   (mapi_func) noopGetMaterialfv,
   (mapi_func) noopGetMaterialiv,
   (mapi_func) noopGetMultisamplefv,
   (mapi_func) noopGetNamedBufferParameteri64v,
   (mapi_func) noopGetNamedBufferParameteriv,
   (mapi_func) noopGetNamedBufferPointerv,
   (mapi_func) noopGetNamedBufferSubData,
   (mapi_func) noopGetNamedFramebufferAttachmentParameteriv,
   (mapi_func) noopGetNamedFramebufferParameteriv,
   (mapi_func) noopGetNamedRenderbufferParameteriv,
   (mapi_func) noopGetObjectLabel,
   (mapi_func) noopGetObjectPtrLabel,
   (mapi_func) noopGetPixelMapfv,
   (mapi_func) noopGetPixelMapuiv,
   (mapi_func) noopGetPixelMapusv,
   (mapi_func) noopGetPointerv,
   (mapi_func) noopGetPolygonStipple,
   (mapi_func) noopGetProgramBinary,
   (mapi_func) noopGetProgramInfoLog,
   (mapi_func) noopGetProgramInterfaceiv,
   (mapi_func) noopGetProgramPipelineInfoLog,
   (mapi_func) noopGetProgramPipelineiv,
   (mapi_func) noopGetProgramResourceIndex,
   (mapi_func) noopGetProgramResourceLocation,
   (mapi_func) noopGetProgramResourceLocationIndex,
   (mapi_func) noopGetProgramResourceName,
   (mapi_func) noopGetProgramResourceiv,
   (mapi_func) noopGetProgramStageiv,
   (mapi_func) noopGetProgramiv,
   (mapi_func) noopGetQueryBufferObjecti64v,
   (mapi_func) noopGetQueryBufferObjectiv,
   (mapi_func) noopGetQueryBufferObjectui64v,
   (mapi_func) noopGetQueryBufferObjectuiv,
   (mapi_func) noopGetQueryIndexediv,
   (mapi_func) noopGetQueryObjecti64v,
   (mapi_func) noopGetQueryObjectiv,
   (mapi_func) noopGetQueryObjectui64v,
   (mapi_func) noopGetQueryObjectuiv,
   (mapi_func) noopGetQueryiv,
   (mapi_func) noopGetRenderbufferParameteriv,
   (mapi_func) noopGetSamplerParameterIiv,
   (mapi_func) noopGetSamplerParameterIuiv,
   (mapi_func) noopGetSamplerParameterfv,
   (mapi_func) noopGetSamplerParameteriv,
   (mapi_func) noopGetShaderInfoLog,
   (mapi_func) noopGetShaderPrecisionFormat,
   (mapi_func) noopGetShaderSource,
   (mapi_func) noopGetShaderiv,
   (mapi_func) noopGetString,
   (mapi_func) noopGetStringi,
   (mapi_func) noopGetSubroutineIndex,
   (mapi_func) noopGetSubroutineUniformLocation,
   (mapi_func) noopGetSynciv,
   (mapi_func) noopGetTexEnvfv,
   (mapi_func) noopGetTexEnviv,
   (mapi_func) noopGetTexGendv,
   (mapi_func) noopGetTexGenfv,
   (mapi_func) noopGetTexGeniv,
   (mapi_func) noopGetTexImage,
   (mapi_func) noopGetTexLevelParameterfv,
   (mapi_func) noopGetTexLevelParameteriv,
   (mapi_func) noopGetTexParameterIiv,
   (mapi_func) noopGetTexParameterIuiv,
   (mapi_func) noopGetTexParameterfv,
   (mapi_func) noopGetTexParameteriv,
   (mapi_func) noopGetTextureImage,
   (mapi_func) noopGetTextureLevelParameterfv,
   (mapi_func) noopGetTextureLevelParameteriv,
   (mapi_func) noopGetTextureParameterIiv,
   (mapi_func) noopGetTextureParameterIuiv,
   (mapi_func) noopGetTextureParameterfv,
   (mapi_func) noopGetTextureParameteriv,
   (mapi_func) noopGetTextureSubImage,
   (mapi_func) noopGetTransformFeedbackVarying,
   (mapi_func) noopGetTransformFeedbacki64_v,
   (mapi_func) noopGetTransformFeedbacki_v,
   (mapi_func) noopGetTransformFeedbackiv,
   (mapi_func) noopGetUniformBlockIndex,
   (mapi_func) noopGetUniformIndices,
   (mapi_func) noopGetUniformLocation,
   (mapi_func) noopGetUniformSubroutineuiv,
   (mapi_func) noopGetUniformdv,
   (mapi_func) noopGetUniformfv,
   (mapi_func) noopGetUniformiv,
   (mapi_func) noopGetUniformuiv,
   (mapi_func) noopGetVertexArrayIndexed64iv,
   (mapi_func) noopGetVertexArrayIndexediv,
   (mapi_func) noopGetVertexArrayiv,
   (mapi_func) noopGetVertexAttribIiv,
   (mapi_func) noopGetVertexAttribIuiv,
   (mapi_func) noopGetVertexAttribLdv,
   (mapi_func) noopGetVertexAttribPointerv,
   (mapi_func) noopGetVertexAttribdv,
   (mapi_func) noopGetVertexAttribfv,
   (mapi_func) noopGetVertexAttribiv,
   (mapi_func) noopGetnColorTable,
   (mapi_func) noopGetnCompressedTexImage,
   (mapi_func) noopGetnConvolutionFilter,
   (mapi_func) noopGetnHistogram,
   (mapi_func) noopGetnMapdv,
   (mapi_func) noopGetnMapfv,
   (mapi_func) noopGetnMapiv,
   (mapi_func) noopGetnMinmax,
   (mapi_func) noopGetnPixelMapfv,
   (mapi_func) noopGetnPixelMapuiv,
   (mapi_func) noopGetnPixelMapusv,
   (mapi_func) noopGetnPolygonStipple,
   (mapi_func) noopGetnSeparableFilter,
   (mapi_func) noopGetnTexImage,
   (mapi_func) noopGetnUniformdv,
   (mapi_func) noopGetnUniformfv,
   (mapi_func) noopGetnUniformiv,
   (mapi_func) noopGetnUniformuiv,
   (mapi_func) noopHint,
   (mapi_func) noopIndexMask,
   (mapi_func) noopIndexPointer,
   (mapi_func) noopIndexd,
   (mapi_func) noopIndexdv,
   (mapi_func) noopIndexf,
   (mapi_func) noopIndexfv,
   (mapi_func) noopIndexi,
   (mapi_func) noopIndexiv,
   (mapi_func) noopIndexs,
   (mapi_func) noopIndexsv,
   (mapi_func) noopIndexub,
   (mapi_func) noopIndexubv,
   (mapi_func) noopInitNames,
   (mapi_func) noopInterleavedArrays,
   (mapi_func) noopInvalidateBufferData,
   (mapi_func) noopInvalidateBufferSubData,
   (mapi_func) noopInvalidateFramebuffer,
   (mapi_func) noopInvalidateNamedFramebufferData,
   (mapi_func) noopInvalidateNamedFramebufferSubData,
   (mapi_func) noopInvalidateSubFramebuffer,
   (mapi_func) noopInvalidateTexImage,
   (mapi_func) noopInvalidateTexSubImage,
   (mapi_func) noopIsBuffer,
   (mapi_func) noopIsEnabled,
   (mapi_func) noopIsEnabledi,
   (mapi_func) noopIsFramebuffer,
   (mapi_func) noopIsList,
   (mapi_func) noopIsProgram,
   (mapi_func) noopIsProgramPipeline,
   (mapi_func) noopIsQuery,
   (mapi_func) noopIsRenderbuffer,
   (mapi_func) noopIsSampler,
   (mapi_func) noopIsShader,
   (mapi_func) noopIsSync,
   (mapi_func) noopIsTexture,
   (mapi_func) noopIsTransformFeedback,
   (mapi_func) noopIsVertexArray,
   (mapi_func) noopLightModelf,
   (mapi_func) noopLightModelfv,
   (mapi_func) noopLightModeli,
   (mapi_func) noopLightModeliv,
   (mapi_func) noopLightf,
   (mapi_func) noopLightfv,
   (mapi_func) noopLighti,
   (mapi_func) noopLightiv,
   (mapi_func) noopLineStipple,
   (mapi_func) noopLineWidth,
   (mapi_func) noopLinkProgram,
   (mapi_func) noopListBase,
   (mapi_func) noopLoadIdentity,
   (mapi_func) noopLoadMatrixd,
   (mapi_func) noopLoadMatrixf,
   (mapi_func) noopLoadName,
   (mapi_func) noopLoadTransposeMatrixd,
   (mapi_func) noopLoadTransposeMatrixf,
   (mapi_func) noopLogicOp,
   (mapi_func) noopMap1d,
   (mapi_func) noopMap1f,
   (mapi_func) noopMap2d,
   (mapi_func) noopMap2f,
   (mapi_func) noopMapBuffer,
   (mapi_func) noopMapBufferRange,
   (mapi_func) noopMapGrid1d,
   (mapi_func) noopMapGrid1f,
   (mapi_func) noopMapGrid2d,
   (mapi_func) noopMapGrid2f,
   (mapi_func) noopMapNamedBuffer,
   (mapi_func) noopMapNamedBufferRange,
   (mapi_func) noopMaterialf,
   (mapi_func) noopMaterialfv,
   (mapi_func) noopMateriali,
   (mapi_func) noopMaterialiv,
   (mapi_func) noopMatrixMode,
   (mapi_func) noopMemoryBarrier,
   (mapi_func) noopMemoryBarrierByRegion,
   (mapi_func) noopMinSampleShading,
   (mapi_func) noopMultMatrixd,
   (mapi_func) noopMultMatrixf,
   (mapi_func) noopMultTransposeMatrixd,
   (mapi_func) noopMultTransposeMatrixf,
   (mapi_func) noopMultiDrawArrays,
   (mapi_func) noopMultiDrawArraysIndirect,
   (mapi_func) noopMultiDrawElements,
   (mapi_func) noopMultiDrawElementsBaseVertex,
   (mapi_func) noopMultiDrawElementsIndirect,
   (mapi_func) noopMultiTexCoord1d,
   (mapi_func) noopMultiTexCoord1dv,
   (mapi_func) noopMultiTexCoord1f,
   (mapi_func) noopMultiTexCoord1fv,
   (mapi_func) noopMultiTexCoord1i,
   (mapi_func) noopMultiTexCoord1iv,
   (mapi_func) noopMultiTexCoord1s,
   (mapi_func) noopMultiTexCoord1sv,
   (mapi_func) noopMultiTexCoord2d,
   (mapi_func) noopMultiTexCoord2dv,
   (mapi_func) noopMultiTexCoord2f,
   (mapi_func) noopMultiTexCoord2fv,
   (mapi_func) noopMultiTexCoord2i,
   (mapi_func) noopMultiTexCoord2iv,
   (mapi_func) noopMultiTexCoord2s,
   (mapi_func) noopMultiTexCoord2sv,
   (mapi_func) noopMultiTexCoord3d,
   (mapi_func) noopMultiTexCoord3dv,
   (mapi_func) noopMultiTexCoord3f,
   (mapi_func) noopMultiTexCoord3fv,
   (mapi_func) noopMultiTexCoord3i,
   (mapi_func) noopMultiTexCoord3iv,
   (mapi_func) noopMultiTexCoord3s,
   (mapi_func) noopMultiTexCoord3sv,
   (mapi_func) noopMultiTexCoord4d,
   (mapi_func) noopMultiTexCoord4dv,
   (mapi_func) noopMultiTexCoord4f,
   (mapi_func) noopMultiTexCoord4fv,
   (mapi_func) noopMultiTexCoord4i,
   (mapi_func) noopMultiTexCoord4iv,
   (mapi_func) noopMultiTexCoord4s,
   (mapi_func) noopMultiTexCoord4sv,
   (mapi_func) noopMultiTexCoordP1ui,
   (mapi_func) noopMultiTexCoordP1uiv,
   (mapi_func) noopMultiTexCoordP2ui,
   (mapi_func) noopMultiTexCoordP2uiv,
   (mapi_func) noopMultiTexCoordP3ui,
   (mapi_func) noopMultiTexCoordP3uiv,
   (mapi_func) noopMultiTexCoordP4ui,
   (mapi_func) noopMultiTexCoordP4uiv,
   (mapi_func) noopNamedBufferData,
   (mapi_func) noopNamedBufferStorage,
   (mapi_func) noopNamedBufferSubData,
   (mapi_func) noopNamedFramebufferDrawBuffer,
   (mapi_func) noopNamedFramebufferDrawBuffers,
   (mapi_func) noopNamedFramebufferParameteri,
   (mapi_func) noopNamedFramebufferReadBuffer,
   (mapi_func) noopNamedFramebufferRenderbuffer,
   (mapi_func) noopNamedFramebufferTexture,
   (mapi_func) noopNamedFramebufferTextureLayer,
   (mapi_func) noopNamedRenderbufferStorage,
   (mapi_func) noopNamedRenderbufferStorageMultisample,
   (mapi_func) noopNewList,
   (mapi_func) noopNormal3b,
   (mapi_func) noopNormal3bv,
   (mapi_func) noopNormal3d,
   (mapi_func) noopNormal3dv,
   (mapi_func) noopNormal3f,
   (mapi_func) noopNormal3fv,
   (mapi_func) noopNormal3i,
   (mapi_func) noopNormal3iv,
   (mapi_func) noopNormal3s,
   (mapi_func) noopNormal3sv,
   (mapi_func) noopNormalP3ui,
   (mapi_func) noopNormalP3uiv,
   (mapi_func) noopNormalPointer,
   (mapi_func) noopObjectLabel,
   (mapi_func) noopObjectPtrLabel,
   (mapi_func) noopOrtho,
   (mapi_func) noopPassThrough,
   (mapi_func) noopPatchParameterfv,
   (mapi_func) noopPatchParameteri,
   (mapi_func) noopPauseTransformFeedback,
   (mapi_func) noopPixelMapfv,
   (mapi_func) noopPixelMapuiv,
   (mapi_func) noopPixelMapusv,
   (mapi_func) noopPixelStoref,
   (mapi_func) noopPixelStorei,
   (mapi_func) noopPixelTransferf,
   (mapi_func) noopPixelTransferi,
   (mapi_func) noopPixelZoom,
   (mapi_func) noopPointParameterf,
   (mapi_func) noopPointParameterfv,
   (mapi_func) noopPointParameteri,
   (mapi_func) noopPointParameteriv,
   (mapi_func) noopPointSize,
   (mapi_func) noopPolygonMode,
   (mapi_func) noopPolygonOffset,
   (mapi_func) noopPolygonStipple,
   (mapi_func) noopPopAttrib,
   (mapi_func) noopPopClientAttrib,
   (mapi_func) noopPopDebugGroup,
   (mapi_func) noopPopMatrix,
   (mapi_func) noopPopName,
   (mapi_func) noopPrimitiveRestartIndex,
   (mapi_func) noopPrioritizeTextures,
   (mapi_func) noopProgramBinary,
   (mapi_func) noopProgramParameteri,
   (mapi_func) noopProgramUniform1d,
   (mapi_func) noopProgramUniform1dv,
   (mapi_func) noopProgramUniform1f,
   (mapi_func) noopProgramUniform1fv,
   (mapi_func) noopProgramUniform1i,
   (mapi_func) noopProgramUniform1iv,
   (mapi_func) noopProgramUniform1ui,
   (mapi_func) noopProgramUniform1uiv,
   (mapi_func) noopProgramUniform2d,
   (mapi_func) noopProgramUniform2dv,
   (mapi_func) noopProgramUniform2f,
   (mapi_func) noopProgramUniform2fv,
   (mapi_func) noopProgramUniform2i,
   (mapi_func) noopProgramUniform2iv,
   (mapi_func) noopProgramUniform2ui,
   (mapi_func) noopProgramUniform2uiv,
   (mapi_func) noopProgramUniform3d,
   (mapi_func) noopProgramUniform3dv,
   (mapi_func) noopProgramUniform3f,
   (mapi_func) noopProgramUniform3fv,
   (mapi_func) noopProgramUniform3i,
   (mapi_func) noopProgramUniform3iv,
   (mapi_func) noopProgramUniform3ui,
   (mapi_func) noopProgramUniform3uiv,
   (mapi_func) noopProgramUniform4d,
   (mapi_func) noopProgramUniform4dv,
   (mapi_func) noopProgramUniform4f,
   (mapi_func) noopProgramUniform4fv,
   (mapi_func) noopProgramUniform4i,
   (mapi_func) noopProgramUniform4iv,
   (mapi_func) noopProgramUniform4ui,
   (mapi_func) noopProgramUniform4uiv,
   (mapi_func) noopProgramUniformMatrix2dv,
   (mapi_func) noopProgramUniformMatrix2fv,
   (mapi_func) noopProgramUniformMatrix2x3dv,
   (mapi_func) noopProgramUniformMatrix2x3fv,
   (mapi_func) noopProgramUniformMatrix2x4dv,
   (mapi_func) noopProgramUniformMatrix2x4fv,
   (mapi_func) noopProgramUniformMatrix3dv,
   (mapi_func) noopProgramUniformMatrix3fv,
   (mapi_func) noopProgramUniformMatrix3x2dv,
   (mapi_func) noopProgramUniformMatrix3x2fv,
   (mapi_func) noopProgramUniformMatrix3x4dv,
   (mapi_func) noopProgramUniformMatrix3x4fv,
   (mapi_func) noopProgramUniformMatrix4dv,
   (mapi_func) noopProgramUniformMatrix4fv,
   (mapi_func) noopProgramUniformMatrix4x2dv,
   (mapi_func) noopProgramUniformMatrix4x2fv,
   (mapi_func) noopProgramUniformMatrix4x3dv,
   (mapi_func) noopProgramUniformMatrix4x3fv,
   (mapi_func) noopProvokingVertex,
   (mapi_func) noopPushAttrib,
   (mapi_func) noopPushClientAttrib,
   (mapi_func) noopPushDebugGroup,
   (mapi_func) noopPushMatrix,
   (mapi_func) noopPushName,
   (mapi_func) noopQueryCounter,
   (mapi_func) noopRasterPos2d,
   (mapi_func) noopRasterPos2dv,
   (mapi_func) noopRasterPos2f,
   (mapi_func) noopRasterPos2fv,
   (mapi_func) noopRasterPos2i,
   (mapi_func) noopRasterPos2iv,
   (mapi_func) noopRasterPos2s,
   (mapi_func) noopRasterPos2sv,
   (mapi_func) noopRasterPos3d,
   (mapi_func) noopRasterPos3dv,
   (mapi_func) noopRasterPos3f,
   (mapi_func) noopRasterPos3fv,
   (mapi_func) noopRasterPos3i,
   (mapi_func) noopRasterPos3iv,
   (mapi_func) noopRasterPos3s,
   (mapi_func) noopRasterPos3sv,
   (mapi_func) noopRasterPos4d,
   (mapi_func) noopRasterPos4dv,
   (mapi_func) noopRasterPos4f,
   (mapi_func) noopRasterPos4fv,
   (mapi_func) noopRasterPos4i,
   (mapi_func) noopRasterPos4iv,
   (mapi_func) noopRasterPos4s,
   (mapi_func) noopRasterPos4sv,
   (mapi_func) noopReadBuffer,
   (mapi_func) noopReadPixels,
   (mapi_func) noopReadnPixels,
   (mapi_func) noopRectd,
   (mapi_func) noopRectdv,
   (mapi_func) noopRectf,
   (mapi_func) noopRectfv,
   (mapi_func) noopRecti,
   (mapi_func) noopRectiv,
   (mapi_func) noopRects,
   (mapi_func) noopRectsv,
   (mapi_func) noopReleaseShaderCompiler,
   (mapi_func) noopRenderMode,
   (mapi_func) noopRenderbufferStorage,
   (mapi_func) noopRenderbufferStorageMultisample,
   (mapi_func) noopResumeTransformFeedback,
   (mapi_func) noopRotated,
   (mapi_func) noopRotatef,
   (mapi_func) noopSampleCoverage,
   (mapi_func) noopSampleMaski,
   (mapi_func) noopSamplerParameterIiv,
   (mapi_func) noopSamplerParameterIuiv,
   (mapi_func) noopSamplerParameterf,
   (mapi_func) noopSamplerParameterfv,
   (mapi_func) noopSamplerParameteri,
   (mapi_func) noopSamplerParameteriv,
   (mapi_func) noopScaled,
   (mapi_func) noopScalef,
   (mapi_func) noopScissor,
   (mapi_func) noopScissorArrayv,
   (mapi_func) noopScissorIndexed,
   (mapi_func) noopScissorIndexedv,
   (mapi_func) noopSecondaryColor3b,
   (mapi_func) noopSecondaryColor3bv,
   (mapi_func) noopSecondaryColor3d,
   (mapi_func) noopSecondaryColor3dv,
   (mapi_func) noopSecondaryColor3f,
   (mapi_func) noopSecondaryColor3fv,
   (mapi_func) noopSecondaryColor3i,
   (mapi_func) noopSecondaryColor3iv,
   (mapi_func) noopSecondaryColor3s,
   (mapi_func) noopSecondaryColor3sv,
   (mapi_func) noopSecondaryColor3ub,
   (mapi_func) noopSecondaryColor3ubv,
   (mapi_func) noopSecondaryColor3ui,
   (mapi_func) noopSecondaryColor3uiv,
   (mapi_func) noopSecondaryColor3us,
   (mapi_func) noopSecondaryColor3usv,
   (mapi_func) noopSecondaryColorP3ui,
   (mapi_func) noopSecondaryColorP3uiv,
   (mapi_func) noopSecondaryColorPointer,
   (mapi_func) noopSelectBuffer,
   (mapi_func) noopShadeModel,
   (mapi_func) noopShaderBinary,
   (mapi_func) noopShaderSource,
   (mapi_func) noopShaderStorageBlockBinding,
   (mapi_func) noopStencilFunc,
   (mapi_func) noopStencilFuncSeparate,
   (mapi_func) noopStencilMask,
   (mapi_func) noopStencilMaskSeparate,
   (mapi_func) noopStencilOp,
   (mapi_func) noopStencilOpSeparate,
   (mapi_func) noopTexBuffer,
   (mapi_func) noopTexBufferRange,
   (mapi_func) noopTexCoord1d,
   (mapi_func) noopTexCoord1dv,
   (mapi_func) noopTexCoord1f,
   (mapi_func) noopTexCoord1fv,
   (mapi_func) noopTexCoord1i,
   (mapi_func) noopTexCoord1iv,
   (mapi_func) noopTexCoord1s,
   (mapi_func) noopTexCoord1sv,
   (mapi_func) noopTexCoord2d,
   (mapi_func) noopTexCoord2dv,
   (mapi_func) noopTexCoord2f,
   (mapi_func) noopTexCoord2fv,
   (mapi_func) noopTexCoord2i,
   (mapi_func) noopTexCoord2iv,
   (mapi_func) noopTexCoord2s,
   (mapi_func) noopTexCoord2sv,
   (mapi_func) noopTexCoord3d,
   (mapi_func) noopTexCoord3dv,
   (mapi_func) noopTexCoord3f,
   (mapi_func) noopTexCoord3fv,
   (mapi_func) noopTexCoord3i,
   (mapi_func) noopTexCoord3iv,
   (mapi_func) noopTexCoord3s,
   (mapi_func) noopTexCoord3sv,
   (mapi_func) noopTexCoord4d,
   (mapi_func) noopTexCoord4dv,
   (mapi_func) noopTexCoord4f,
   (mapi_func) noopTexCoord4fv,
   (mapi_func) noopTexCoord4i,
   (mapi_func) noopTexCoord4iv,
   (mapi_func) noopTexCoord4s,
   (mapi_func) noopTexCoord4sv,
   (mapi_func) noopTexCoordP1ui,
   (mapi_func) noopTexCoordP1uiv,
   (mapi_func) noopTexCoordP2ui,
   (mapi_func) noopTexCoordP2uiv,
   (mapi_func) noopTexCoordP3ui,
   (mapi_func) noopTexCoordP3uiv,
   (mapi_func) noopTexCoordP4ui,
   (mapi_func) noopTexCoordP4uiv,
   (mapi_func) noopTexCoordPointer,
   (mapi_func) noopTexEnvf,
   (mapi_func) noopTexEnvfv,
   (mapi_func) noopTexEnvi,
   (mapi_func) noopTexEnviv,
   (mapi_func) noopTexGend,
   (mapi_func) noopTexGendv,
   (mapi_func) noopTexGenf,
   (mapi_func) noopTexGenfv,
   (mapi_func) noopTexGeni,
   (mapi_func) noopTexGeniv,
   (mapi_func) noopTexImage1D,
   (mapi_func) noopTexImage2D,
   (mapi_func) noopTexImage2DMultisample,
   (mapi_func) noopTexImage3D,
   (mapi_func) noopTexImage3DMultisample,
   (mapi_func) noopTexParameterIiv,
   (mapi_func) noopTexParameterIuiv,
   (mapi_func) noopTexParameterf,
   (mapi_func) noopTexParameterfv,
   (mapi_func) noopTexParameteri,
   (mapi_func) noopTexParameteriv,
   (mapi_func) noopTexStorage1D,
   (mapi_func) noopTexStorage2D,
   (mapi_func) noopTexStorage2DMultisample,
   (mapi_func) noopTexStorage3D,
   (mapi_func) noopTexStorage3DMultisample,
   (mapi_func) noopTexSubImage1D,
   (mapi_func) noopTexSubImage2D,
   (mapi_func) noopTexSubImage3D,
   (mapi_func) noopTextureBarrier,
   (mapi_func) noopTextureBuffer,
   (mapi_func) noopTextureBufferRange,
   (mapi_func) noopTextureParameterIiv,
   (mapi_func) noopTextureParameterIuiv,
   (mapi_func) noopTextureParameterf,
   (mapi_func) noopTextureParameterfv,
   (mapi_func) noopTextureParameteri,
   (mapi_func) noopTextureParameteriv,
   (mapi_func) noopTextureStorage1D,
   (mapi_func) noopTextureStorage2D,
   (mapi_func) noopTextureStorage2DMultisample,
   (mapi_func) noopTextureStorage3D,
   (mapi_func) noopTextureStorage3DMultisample,
   (mapi_func) noopTextureSubImage1D,
   (mapi_func) noopTextureSubImage2D,
   (mapi_func) noopTextureSubImage3D,
   (mapi_func) noopTextureView,
   (mapi_func) noopTransformFeedbackBufferBase,
   (mapi_func) noopTransformFeedbackBufferRange,
   (mapi_func) noopTransformFeedbackVaryings,
   (mapi_func) noopTranslated,
   (mapi_func) noopTranslatef,
   (mapi_func) noopUniform1d,
   (mapi_func) noopUniform1dv,
   (mapi_func) noopUniform1f,
   (mapi_func) noopUniform1fv,
   (mapi_func) noopUniform1i,
   (mapi_func) noopUniform1iv,
   (mapi_func) noopUniform1ui,
   (mapi_func) noopUniform1uiv,
   (mapi_func) noopUniform2d,
   (mapi_func) noopUniform2dv,
   (mapi_func) noopUniform2f,
   (mapi_func) noopUniform2fv,
   (mapi_func) noopUniform2i,
   (mapi_func) noopUniform2iv,
   (mapi_func) noopUniform2ui,
   (mapi_func) noopUniform2uiv,
   (mapi_func) noopUniform3d,
   (mapi_func) noopUniform3dv,
   (mapi_func) noopUniform3f,
   (mapi_func) noopUniform3fv,
   (mapi_func) noopUniform3i,
   (mapi_func) noopUniform3iv,
   (mapi_func) noopUniform3ui,
   (mapi_func) noopUniform3uiv,
   (mapi_func) noopUniform4d,
   (mapi_func) noopUniform4dv,
   (mapi_func) noopUniform4f,
   (mapi_func) noopUniform4fv,
   (mapi_func) noopUniform4i,
   (mapi_func) noopUniform4iv,
   (mapi_func) noopUniform4ui,
   (mapi_func) noopUniform4uiv,
   (mapi_func) noopUniformBlockBinding,
   (mapi_func) noopUniformMatrix2dv,
   (mapi_func) noopUniformMatrix2fv,
   (mapi_func) noopUniformMatrix2x3dv,
   (mapi_func) noopUniformMatrix2x3fv,
   (mapi_func) noopUniformMatrix2x4dv,
   (mapi_func) noopUniformMatrix2x4fv,
   (mapi_func) noopUniformMatrix3dv,
   (mapi_func) noopUniformMatrix3fv,
   (mapi_func) noopUniformMatrix3x2dv,
   (mapi_func) noopUniformMatrix3x2fv,
   (mapi_func) noopUniformMatrix3x4dv,
   (mapi_func) noopUniformMatrix3x4fv,
   (mapi_func) noopUniformMatrix4dv,
   (mapi_func) noopUniformMatrix4fv,
   (mapi_func) noopUniformMatrix4x2dv,
   (mapi_func) noopUniformMatrix4x2fv,
   (mapi_func) noopUniformMatrix4x3dv,
   (mapi_func) noopUniformMatrix4x3fv,
   (mapi_func) noopUniformSubroutinesuiv,
   (mapi_func) noopUnmapBuffer,
   (mapi_func) noopUnmapNamedBuffer,
   (mapi_func) noopUseProgram,
   (mapi_func) noopUseProgramStages,
   (mapi_func) noopValidateProgram,
   (mapi_func) noopValidateProgramPipeline,
   (mapi_func) noopVertex2d,
   (mapi_func) noopVertex2dv,
   (mapi_func) noopVertex2f,
   (mapi_func) noopVertex2fv,
   (mapi_func) noopVertex2i,
   (mapi_func) noopVertex2iv,
   (mapi_func) noopVertex2s,
   (mapi_func) noopVertex2sv,
   (mapi_func) noopVertex3d,
   (mapi_func) noopVertex3dv,
   (mapi_func) noopVertex3f,
   (mapi_func) noopVertex3fv,
   (mapi_func) noopVertex3i,
   (mapi_func) noopVertex3iv,
   (mapi_func) noopVertex3s,
   (mapi_func) noopVertex3sv,
   (mapi_func) noopVertex4d,
   (mapi_func) noopVertex4dv,
   (mapi_func) noopVertex4f,
   (mapi_func) noopVertex4fv,
   (mapi_func) noopVertex4i,
   (mapi_func) noopVertex4iv,
   (mapi_func) noopVertex4s,
   (mapi_func) noopVertex4sv,
   (mapi_func) noopVertexArrayAttribBinding,
   (mapi_func) noopVertexArrayAttribFormat,
   (mapi_func) noopVertexArrayAttribIFormat,
   (mapi_func) noopVertexArrayAttribLFormat,
   (mapi_func) noopVertexArrayBindingDivisor,
   (mapi_func) noopVertexArrayElementBuffer,
   (mapi_func) noopVertexArrayVertexBuffer,
   (mapi_func) noopVertexArrayVertexBuffers,
   (mapi_func) noopVertexAttrib1d,
   (mapi_func) noopVertexAttrib1dv,
   (mapi_func) noopVertexAttrib1f,
   (mapi_func) noopVertexAttrib1fv,
   (mapi_func) noopVertexAttrib1s,
   (mapi_func) noopVertexAttrib1sv,
   (mapi_func) noopVertexAttrib2d,
   (mapi_func) noopVertexAttrib2dv,
   (mapi_func) noopVertexAttrib2f,
   (mapi_func) noopVertexAttrib2fv,
   (mapi_func) noopVertexAttrib2s,
   (mapi_func) noopVertexAttrib2sv,
   (mapi_func) noopVertexAttrib3d,
   (mapi_func) noopVertexAttrib3dv,
   (mapi_func) noopVertexAttrib3f,
   (mapi_func) noopVertexAttrib3fv,
   (mapi_func) noopVertexAttrib3s,
   (mapi_func) noopVertexAttrib3sv,
   (mapi_func) noopVertexAttrib4Nbv,
   (mapi_func) noopVertexAttrib4Niv,
   (mapi_func) noopVertexAttrib4Nsv,
   (mapi_func) noopVertexAttrib4Nub,
   (mapi_func) noopVertexAttrib4Nubv,
   (mapi_func) noopVertexAttrib4Nuiv,
   (mapi_func) noopVertexAttrib4Nusv,
   (mapi_func) noopVertexAttrib4bv,
   (mapi_func) noopVertexAttrib4d,
   (mapi_func) noopVertexAttrib4dv,
   (mapi_func) noopVertexAttrib4f,
   (mapi_func) noopVertexAttrib4fv,
   (mapi_func) noopVertexAttrib4iv,
   (mapi_func) noopVertexAttrib4s,
   (mapi_func) noopVertexAttrib4sv,
   (mapi_func) noopVertexAttrib4ubv,
   (mapi_func) noopVertexAttrib4uiv,
   (mapi_func) noopVertexAttrib4usv,
   (mapi_func) noopVertexAttribBinding,
   (mapi_func) noopVertexAttribDivisor,
   (mapi_func) noopVertexAttribFormat,
   (mapi_func) noopVertexAttribI1i,
   (mapi_func) noopVertexAttribI1iv,
   (mapi_func) noopVertexAttribI1ui,
   (mapi_func) noopVertexAttribI1uiv,
   (mapi_func) noopVertexAttribI2i,
   (mapi_func) noopVertexAttribI2iv,
   (mapi_func) noopVertexAttribI2ui,
   (mapi_func) noopVertexAttribI2uiv,
   (mapi_func) noopVertexAttribI3i,
   (mapi_func) noopVertexAttribI3iv,
   (mapi_func) noopVertexAttribI3ui,
   (mapi_func) noopVertexAttribI3uiv,
   (mapi_func) noopVertexAttribI4bv,
   (mapi_func) noopVertexAttribI4i,
   (mapi_func) noopVertexAttribI4iv,
   (mapi_func) noopVertexAttribI4sv,
   (mapi_func) noopVertexAttribI4ubv,
   (mapi_func) noopVertexAttribI4ui,
   (mapi_func) noopVertexAttribI4uiv,
   (mapi_func) noopVertexAttribI4usv,
   (mapi_func) noopVertexAttribIFormat,
   (mapi_func) noopVertexAttribIPointer,
   (mapi_func) noopVertexAttribL1d,
   (mapi_func) noopVertexAttribL1dv,
   (mapi_func) noopVertexAttribL2d,
   (mapi_func) noopVertexAttribL2dv,
   (mapi_func) noopVertexAttribL3d,
   (mapi_func) noopVertexAttribL3dv,
   (mapi_func) noopVertexAttribL4d,
   (mapi_func) noopVertexAttribL4dv,
   (mapi_func) noopVertexAttribLFormat,
   (mapi_func) noopVertexAttribLPointer,
   (mapi_func) noopVertexAttribP1ui,
   (mapi_func) noopVertexAttribP1uiv,
   (mapi_func) noopVertexAttribP2ui,
   (mapi_func) noopVertexAttribP2uiv,
   (mapi_func) noopVertexAttribP3ui,
   (mapi_func) noopVertexAttribP3uiv,
   (mapi_func) noopVertexAttribP4ui,
   (mapi_func) noopVertexAttribP4uiv,
   (mapi_func) noopVertexAttribPointer,
   (mapi_func) noopVertexBindingDivisor,
   (mapi_func) noopVertexP2ui,
   (mapi_func) noopVertexP2uiv,
   (mapi_func) noopVertexP3ui,
   (mapi_func) noopVertexP3uiv,
   (mapi_func) noopVertexP4ui,
   (mapi_func) noopVertexP4uiv,
   (mapi_func) noopVertexPointer,
   (mapi_func) noopViewport,
   (mapi_func) noopViewportArrayv,
   (mapi_func) noopViewportIndexedf,
   (mapi_func) noopViewportIndexedfv,
   (mapi_func) noopWaitSync,
   (mapi_func) noopWindowPos2d,
   (mapi_func) noopWindowPos2dv,
   (mapi_func) noopWindowPos2f,
   (mapi_func) noopWindowPos2fv,
   (mapi_func) noopWindowPos2i,
   (mapi_func) noopWindowPos2iv,
   (mapi_func) noopWindowPos2s,
   (mapi_func) noopWindowPos2sv,
   (mapi_func) noopWindowPos3d,
   (mapi_func) noopWindowPos3dv,
   (mapi_func) noopWindowPos3f,
   (mapi_func) noopWindowPos3fv,
   (mapi_func) noopWindowPos3i,
   (mapi_func) noopWindowPos3iv,
   (mapi_func) noopWindowPos3s,
   (mapi_func) noopWindowPos3sv,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic
};

#else /* DEBUG */

const mapi_func table_noop_array[] = {
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic
};

#endif /* DEBUG */
#undef MAPI_TMP_NOOP_ARRAY
#endif /* MAPI_TMP_NOOP_ARRAY */

#ifdef MAPI_TMP_PUBLIC_STUBS
static const struct mapi_stub public_stubs[] = {
   { "glAccum", 0 },
   { "glActiveShaderProgram", 4 },
   { "glActiveTexture", 7 },
   { "glAlphaFunc", 13 },
   { "glAreTexturesResident", 21 },
   { "glArrayElement", 23 },
   { "glAttachShader", 30 },
   { "glBegin", 31 },
   { "glBeginConditionalRender", 32 },
   { "glBeginQuery", 39 },
   { "glBeginQueryIndexed", 42 },
   { "glBeginTransformFeedback", 43 },
   { "glBindAttribLocation", 49 },
   { "glBindBuffer", 51 },
   { "glBindBufferBase", 53 },
   { "glBindBufferRange", 58 },
   { "glBindBuffersBase", 61 },
   { "glBindBuffersRange", 62 },
   { "glBindFragDataLocation", 63 },
   { "glBindFragDataLocationIndexed", 65 },
   { "glBindFramebuffer", 68 },
   { "glBindImageTexture", 71 },
   { "glBindImageTextures", 73 },
   { "glBindProgramPipeline", 80 },
   { "glBindRenderbuffer", 82 },
   { "glBindSampler", 85 },
   { "glBindSamplers", 86 },
   { "glBindTexture", 89 },
   { "glBindTextureUnit", 91 },
   { "glBindTextures", 93 },
   { "glBindTransformFeedback", 94 },
   { "glBindVertexArray", 97 },
   { "glBindVertexBuffer", 100 },
   { "glBindVertexBuffers", 101 },
   { "glBitmap", 116 },
   { "glBlendColor", 121 },
   { "glBlendEquation", 124 },
   { "glBlendEquationSeparate", 128 },
   { "glBlendEquationSeparatei", 132 },
   { "glBlendEquationi", 136 },
   { "glBlendFunc", 140 },
   { "glBlendFuncSeparate", 142 },
   { "glBlendFuncSeparatei", 147 },
   { "glBlendFunci", 151 },
   { "glBlitFramebuffer", 156 },
   { "glBlitNamedFramebuffer", 160 },
   { "glBufferData", 163 },
   { "glBufferStorage", 169 },
   { "glBufferSubData", 173 },
   { "glCallList", 176 },
   { "glCallLists", 177 },
   { "glCheckFramebufferStatus", 178 },
   { "glCheckNamedFramebufferStatus", 181 },
   { "glClampColor", 183 },
   { "glClear", 185 },
   { "glClearAccum", 186 },
   { "glClearBufferData", 188 },
   { "glClearBufferSubData", 189 },
   { "glClearBufferfi", 190 },
   { "glClearBufferfv", 191 },
   { "glClearBufferiv", 192 },
   { "glClearBufferuiv", 193 },
   { "glClearColor", 194 },
   { "glClearDepth", 199 },
   { "glClearDepthf", 201 },
   { "glClearIndex", 205 },
   { "glClearNamedBufferData", 206 },
   { "glClearNamedBufferSubData", 208 },
   { "glClearNamedFramebufferfi", 210 },
   { "glClearNamedFramebufferfv", 211 },
   { "glClearNamedFramebufferiv", 212 },
   { "glClearNamedFramebufferuiv", 213 },
   { "glClearStencil", 215 },
   { "glClearTexImage", 216 },
   { "glClearTexSubImage", 218 },
   { "glClientActiveTexture", 220 },
   { "glClientWaitSync", 225 },
   { "glClipControl", 228 },
   { "glClipPlane", 230 },
   { "glColor3b", 237 },
   { "glColor3bv", 238 },
   { "glColor3d", 239 },
   { "glColor3dv", 240 },
   { "glColor3f", 241 },
   { "glColor3fv", 244 },
   { "glColor3i", 247 },
   { "glColor3iv", 248 },
   { "glColor3s", 249 },
   { "glColor3sv", 250 },
   { "glColor3ub", 251 },
   { "glColor3ubv", 252 },
   { "glColor3ui", 253 },
   { "glColor3uiv", 254 },
   { "glColor3us", 255 },
   { "glColor3usv", 256 },
   { "glColor4b", 260 },
   { "glColor4bv", 261 },
   { "glColor4d", 262 },
   { "glColor4dv", 263 },
   { "glColor4f", 264 },
   { "glColor4fv", 267 },
   { "glColor4i", 270 },
   { "glColor4iv", 271 },
   { "glColor4s", 272 },
   { "glColor4sv", 273 },
   { "glColor4ub", 274 },
   { "glColor4ubv", 279 },
   { "glColor4ui", 280 },
   { "glColor4uiv", 281 },
   { "glColor4us", 282 },
   { "glColor4usv", 283 },
   { "glColorMask", 291 },
   { "glColorMaski", 293 },
   { "glColorMaterial", 296 },
   { "glColorP3ui", 297 },
   { "glColorP3uiv", 298 },
   { "glColorP4ui", 299 },
   { "glColorP4uiv", 300 },
   { "glColorPointer", 301 },
   { "glCompileShader", 323 },
   { "glCompressedTexImage1D", 332 },
   { "glCompressedTexImage2D", 334 },
   { "glCompressedTexImage3D", 336 },
   { "glCompressedTexSubImage1D", 340 },
   { "glCompressedTexSubImage2D", 342 },
   { "glCompressedTexSubImage3D", 344 },
   { "glCompressedTextureSubImage1D", 351 },
   { "glCompressedTextureSubImage2D", 353 },
   { "glCompressedTextureSubImage3D", 355 },
   { "glCopyBufferSubData", 373 },
   { "glCopyImageSubData", 383 },
   { "glCopyNamedBufferSubData", 392 },
   { "glCopyPixels", 394 },
   { "glCopyTexImage1D", 395 },
   { "glCopyTexImage2D", 397 },
   { "glCopyTexSubImage1D", 399 },
   { "glCopyTexSubImage2D", 401 },
   { "glCopyTexSubImage3D", 403 },
   { "glCopyTextureSubImage1D", 410 },
   { "glCopyTextureSubImage2D", 412 },
   { "glCopyTextureSubImage3D", 414 },
   { "glCreateBuffers", 424 },
   { "glCreateFramebuffers", 426 },
   { "glCreateProgram", 429 },
   { "glCreateProgramPipelines", 431 },
   { "glCreateQueries", 433 },
   { "glCreateRenderbuffers", 434 },
   { "glCreateSamplers", 435 },
   { "glCreateShader", 437 },
   { "glCreateShaderProgramv", 440 },
   { "glCreateTextures", 444 },
   { "glCreateTransformFeedbacks", 445 },
   { "glCreateVertexArrays", 446 },
   { "glCullFace", 447 },
   { "glDebugMessageCallback", 452 },
   { "glDebugMessageControl", 457 },
   { "glDebugMessageInsert", 462 },
   { "glDeleteBuffers", 471 },
   { "glDeleteFramebuffers", 477 },
   { "glDeleteLists", 480 },
   { "glDeleteProgram", 489 },
   { "glDeleteProgramPipelines", 490 },
   { "glDeleteQueries", 494 },
   { "glDeleteRenderbuffers", 498 },
   { "glDeleteSamplers", 501 },
   { "glDeleteShader", 503 },
   { "glDeleteSync", 505 },
   { "glDeleteTextures", 507 },
   { "glDeleteTransformFeedbacks", 509 },
   { "glDeleteVertexArrays", 512 },
   { "glDepthFunc", 518 },
   { "glDepthMask", 519 },
   { "glDepthRange", 520 },
   { "glDepthRangeArrayv", 524 },
   { "glDepthRangeIndexed", 525 },
   { "glDepthRangef", 530 },
   { "glDetachShader", 535 },
   { "glDisable", 539 },
   { "glDisableClientState", 540 },
   { "glDisableVertexArrayAttrib", 546 },
   { "glDisableVertexAttribArray", 550 },
   { "glDisablei", 552 },
   { "glDispatchCompute", 557 },
   { "glDispatchComputeIndirect", 559 },
   { "glDrawArrays", 560 },
   { "glDrawArraysIndirect", 562 },
   { "glDrawArraysInstanced", 563 },
   { "glDrawArraysInstancedBaseInstance", 566 },
   { "glDrawBuffer", 570 },
   { "glDrawBuffers", 571 },
   { "glDrawElements", 583 },
   { "glDrawElementsBaseVertex", 584 },
   { "glDrawElementsIndirect", 587 },
   { "glDrawElementsInstanced", 588 },
   { "glDrawElementsInstancedBaseInstance", 591 },
   { "glDrawElementsInstancedBaseVertex", 593 },
   { "glDrawElementsInstancedBaseVertexBaseInstance", 594 },
   { "glDrawPixels", 604 },
   { "glDrawRangeElements", 607 },
   { "glDrawRangeElementsBaseVertex", 608 },
   { "glDrawTransformFeedback", 621 },
   { "glDrawTransformFeedbackInstanced", 623 },
   { "glDrawTransformFeedbackStream", 626 },
   { "glDrawTransformFeedbackStreamInstanced", 627 },
   { "glEdgeFlag", 633 },
   { "glEdgeFlagPointer", 635 },
   { "glEdgeFlagv", 638 },
   { "glEnable", 641 },
   { "glEnableClientState", 642 },
   { "glEnableVertexArrayAttrib", 648 },
   { "glEnableVertexAttribArray", 652 },
   { "glEnablei", 654 },
   { "glEnd", 658 },
   { "glEndConditionalRender", 659 },
   { "glEndList", 663 },
   { "glEndQuery", 667 },
   { "glEndQueryIndexed", 670 },
   { "glEndTransformFeedback", 672 },
   { "glEvalCoord1d", 677 },
   { "glEvalCoord1dv", 678 },
   { "glEvalCoord1f", 679 },
   { "glEvalCoord1fv", 680 },
   { "glEvalCoord2d", 683 },
   { "glEvalCoord2dv", 684 },
   { "glEvalCoord2f", 685 },
   { "glEvalCoord2fv", 686 },
   { "glEvalMesh1", 690 },
   { "glEvalMesh2", 691 },
   { "glEvalPoint1", 692 },
   { "glEvalPoint2", 693 },
   { "glFeedbackBuffer", 710 },
   { "glFenceSync", 712 },
   { "glFinish", 716 },
   { "glFlush", 722 },
   { "glFlushMappedBufferRange", 723 },
   { "glFlushMappedNamedBufferRange", 726 },
   { "glFogCoordPointer", 734 },
   { "glFogCoordd", 737 },
   { "glFogCoorddv", 739 },
   { "glFogCoordf", 741 },
   { "glFogCoordfv", 743 },
   { "glFogf", 748 },
   { "glFogfv", 749 },
   { "glFogi", 750 },
   { "glFogiv", 751 },
   { "glFramebufferParameteri", 778 },
   { "glFramebufferRenderbuffer", 782 },
   { "glFramebufferTexture", 789 },
   { "glFramebufferTexture1D", 790 },
   { "glFramebufferTexture2D", 792 },
   { "glFramebufferTexture3D", 798 },
   { "glFramebufferTextureLayer", 805 },
   { "glFrontFace", 814 },
   { "glFrustum", 815 },
   { "glGenBuffers", 821 },
   { "glGenFramebuffers", 826 },
   { "glGenLists", 829 },
   { "glGenProgramPipelines", 834 },
   { "glGenQueries", 838 },
   { "glGenRenderbuffers", 842 },
   { "glGenSamplers", 845 },
   { "glGenTextures", 848 },
   { "glGenTransformFeedbacks", 850 },
   { "glGenVertexArrays", 853 },
   { "glGenerateMipmap", 857 },
   { "glGenerateTextureMipmap", 861 },
   { "glGetActiveAtomicCounterBufferiv", 863 },
   { "glGetActiveAttrib", 864 },
   { "glGetActiveSubroutineName", 866 },
   { "glGetActiveSubroutineUniformName", 867 },
   { "glGetActiveSubroutineUniformiv", 868 },
   { "glGetActiveUniform", 869 },
   { "glGetActiveUniformBlockName", 871 },
   { "glGetActiveUniformBlockiv", 872 },
   { "glGetActiveUniformName", 873 },
   { "glGetActiveUniformsiv", 874 },
   { "glGetAttachedShaders", 879 },
   { "glGetAttribLocation", 880 },
   { "glGetBooleani_v", 883 },
   { "glGetBooleanv", 884 },
   { "glGetBufferParameteri64v", 885 },
   { "glGetBufferParameteriv", 886 },
   { "glGetBufferPointerv", 889 },
   { "glGetBufferSubData", 892 },
   { "glGetClipPlane", 894 },
   { "glGetCompressedTexImage", 915 },
   { "glGetCompressedTextureImage", 918 },
   { "glGetCompressedTextureSubImage", 920 },
   { "glGetDebugMessageLog", 929 },
   { "glGetDoublei_v", 936 },
   { "glGetDoublev", 938 },
   { "glGetError", 941 },
   { "glGetFloati_v", 949 },
   { "glGetFloatv", 953 },
   { "glGetFragDataIndex", 955 },
   { "glGetFragDataLocation", 957 },
   { "glGetFramebufferAttachmentParameteriv", 964 },
   { "glGetFramebufferParameteriv", 968 },
   { "glGetGraphicsResetStatus", 972 },
   { "glGetInteger64i_v", 990 },
   { "glGetInteger64v", 991 },
   { "glGetIntegeri_v", 995 },
   { "glGetIntegerv", 999 },
   { "glGetInternalformati64v", 1001 },
   { "glGetInternalformativ", 1002 },
   { "glGetLightfv", 1006 },
   { "glGetLightiv", 1007 },
   { "glGetMapdv", 1021 },
   { "glGetMapfv", 1022 },
   { "glGetMapiv", 1023 },
   { "glGetMaterialfv", 1025 },
   { "glGetMaterialiv", 1026 },
   { "glGetMultisamplefv", 1050 },
   { "glGetNamedBufferParameteri64v", 1052 },
   { "glGetNamedBufferParameteriv", 1054 },
   { "glGetNamedBufferPointerv", 1057 },
   { "glGetNamedBufferSubData", 1059 },
   { "glGetNamedFramebufferAttachmentParameteriv", 1061 },
   { "glGetNamedFramebufferParameteriv", 1064 },
   { "glGetNamedRenderbufferParameteriv", 1072 },
   { "glGetObjectLabel", 1079 },
   { "glGetObjectPtrLabel", 1086 },
   { "glGetPixelMapfv", 1114 },
   { "glGetPixelMapuiv", 1115 },
   { "glGetPixelMapusv", 1116 },
   { "glGetPointerv", 1124 },
   { "glGetPolygonStipple", 1128 },
   { "glGetProgramBinary", 1129 },
   { "glGetProgramInfoLog", 1135 },
   { "glGetProgramInterfaceiv", 1136 },
   { "glGetProgramPipelineInfoLog", 1145 },
   { "glGetProgramPipelineiv", 1147 },
   { "glGetProgramResourceIndex", 1149 },
   { "glGetProgramResourceLocation", 1150 },
   { "glGetProgramResourceLocationIndex", 1151 },
   { "glGetProgramResourceName", 1153 },
   { "glGetProgramResourceiv", 1155 },
   { "glGetProgramStageiv", 1156 },
   { "glGetProgramiv", 1160 },
   { "glGetQueryBufferObjecti64v", 1163 },
   { "glGetQueryBufferObjectiv", 1164 },
   { "glGetQueryBufferObjectui64v", 1165 },
   { "glGetQueryBufferObjectuiv", 1166 },
   { "glGetQueryIndexediv", 1167 },
   { "glGetQueryObjecti64v", 1168 },
   { "glGetQueryObjectiv", 1170 },
   { "glGetQueryObjectui64v", 1173 },
   { "glGetQueryObjectuiv", 1176 },
   { "glGetQueryiv", 1179 },
   { "glGetRenderbufferParameteriv", 1182 },
   { "glGetSamplerParameterIiv", 1185 },
   { "glGetSamplerParameterIuiv", 1188 },
   { "glGetSamplerParameterfv", 1191 },
   { "glGetSamplerParameteriv", 1192 },
   { "glGetShaderInfoLog", 1197 },
   { "glGetShaderPrecisionFormat", 1198 },
   { "glGetShaderSource", 1199 },
   { "glGetShaderiv", 1201 },
   { "glGetString", 1206 },
   { "glGetStringi", 1207 },
   { "glGetSubroutineIndex", 1208 },
   { "glGetSubroutineUniformLocation", 1209 },
   { "glGetSynciv", 1210 },
   { "glGetTexEnvfv", 1215 },
   { "glGetTexEnviv", 1216 },
   { "glGetTexGendv", 1220 },
   { "glGetTexGenfv", 1221 },
   { "glGetTexGeniv", 1223 },
   { "glGetTexImage", 1226 },
   { "glGetTexLevelParameterfv", 1228 },
   { "glGetTexLevelParameteriv", 1230 },
   { "glGetTexParameterIiv", 1233 },
   { "glGetTexParameterIuiv", 1236 },
   { "glGetTexParameterfv", 1240 },
   { "glGetTexParameteriv", 1241 },
   { "glGetTextureImage", 1247 },
   { "glGetTextureLevelParameterfv", 1249 },
   { "glGetTextureLevelParameteriv", 1251 },
   { "glGetTextureParameterIiv", 1253 },
   { "glGetTextureParameterIuiv", 1255 },
   { "glGetTextureParameterfv", 1257 },
   { "glGetTextureParameteriv", 1259 },
   { "glGetTextureSubImage", 1264 },
   { "glGetTransformFeedbackVarying", 1266 },
   { "glGetTransformFeedbacki64_v", 1269 },
   { "glGetTransformFeedbacki_v", 1270 },
   { "glGetTransformFeedbackiv", 1271 },
   { "glGetUniformBlockIndex", 1273 },
   { "glGetUniformIndices", 1275 },
   { "glGetUniformLocation", 1276 },
   { "glGetUniformSubroutineuiv", 1279 },
   { "glGetUniformdv", 1280 },
   { "glGetUniformfv", 1281 },
   { "glGetUniformiv", 1285 },
   { "glGetUniformuiv", 1289 },
   { "glGetVertexArrayIndexed64iv", 1300 },
   { "glGetVertexArrayIndexediv", 1301 },
   { "glGetVertexArrayiv", 1306 },
   { "glGetVertexAttribIiv", 1309 },
   { "glGetVertexAttribIuiv", 1311 },
   { "glGetVertexAttribLdv", 1313 },
   { "glGetVertexAttribPointerv", 1318 },
   { "glGetVertexAttribdv", 1321 },
   { "glGetVertexAttribfv", 1324 },
   { "glGetVertexAttribiv", 1327 },
   { "glGetnColorTable", 1340 },
   { "glGetnCompressedTexImage", 1342 },
   { "glGetnConvolutionFilter", 1344 },
   { "glGetnHistogram", 1346 },
   { "glGetnMapdv", 1348 },
   { "glGetnMapfv", 1350 },
   { "glGetnMapiv", 1352 },
   { "glGetnMinmax", 1354 },
   { "glGetnPixelMapfv", 1356 },
   { "glGetnPixelMapuiv", 1358 },
   { "glGetnPixelMapusv", 1360 },
   { "glGetnPolygonStipple", 1362 },
   { "glGetnSeparableFilter", 1364 },
   { "glGetnTexImage", 1366 },
   { "glGetnUniformdv", 1368 },
   { "glGetnUniformfv", 1370 },
   { "glGetnUniformiv", 1375 },
   { "glGetnUniformuiv", 1380 },
   { "glHint", 1395 },
   { "glIndexMask", 1413 },
   { "glIndexPointer", 1415 },
   { "glIndexd", 1418 },
   { "glIndexdv", 1419 },
   { "glIndexf", 1420 },
   { "glIndexfv", 1421 },
   { "glIndexi", 1422 },
   { "glIndexiv", 1423 },
   { "glIndexs", 1424 },
   { "glIndexsv", 1425 },
   { "glIndexub", 1426 },
   { "glIndexubv", 1427 },
   { "glInitNames", 1430 },
   { "glInterleavedArrays", 1434 },
   { "glInvalidateBufferData", 1436 },
   { "glInvalidateBufferSubData", 1437 },
   { "glInvalidateFramebuffer", 1438 },
   { "glInvalidateNamedFramebufferData", 1439 },
   { "glInvalidateNamedFramebufferSubData", 1440 },
   { "glInvalidateSubFramebuffer", 1441 },
   { "glInvalidateTexImage", 1442 },
   { "glInvalidateTexSubImage", 1443 },
   { "glIsBuffer", 1445 },
   { "glIsEnabled", 1449 },
   { "glIsEnabledi", 1451 },
   { "glIsFramebuffer", 1457 },
   { "glIsList", 1462 },
   { "glIsProgram", 1472 },
   { "glIsProgramPipeline", 1475 },
   { "glIsQuery", 1477 },
   { "glIsRenderbuffer", 1480 },
   { "glIsSampler", 1483 },
   { "glIsShader", 1485 },
   { "glIsSync", 1487 },
   { "glIsTexture", 1489 },
   { "glIsTransformFeedback", 1493 },
   { "glIsVertexArray", 1497 },
   { "glLightModelf", 1506 },
   { "glLightModelfv", 1507 },
   { "glLightModeli", 1508 },
   { "glLightModeliv", 1509 },
   { "glLightf", 1514 },
   { "glLightfv", 1515 },
   { "glLighti", 1516 },
   { "glLightiv", 1517 },
   { "glLineStipple", 1522 },
   { "glLineWidth", 1523 },
   { "glLinkProgram", 1526 },
   { "glListBase", 1528 },
   { "glLoadIdentity", 1534 },
   { "glLoadMatrixd", 1536 },
   { "glLoadMatrixf", 1537 },
   { "glLoadName", 1540 },
   { "glLoadTransposeMatrixd", 1544 },
   { "glLoadTransposeMatrixf", 1546 },
   { "glLogicOp", 1550 },
   { "glMap1d", 1563 },
   { "glMap1f", 1564 },
   { "glMap2d", 1566 },
   { "glMap2f", 1567 },
   { "glMapBuffer", 1569 },
   { "glMapBufferRange", 1572 },
   { "glMapGrid1d", 1575 },
   { "glMapGrid1f", 1576 },
   { "glMapGrid2d", 1578 },
   { "glMapGrid2f", 1579 },
   { "glMapNamedBuffer", 1581 },
   { "glMapNamedBufferRange", 1583 },
   { "glMaterialf", 1593 },
   { "glMaterialfv", 1594 },
   { "glMateriali", 1595 },
   { "glMaterialiv", 1596 },
   { "glMatrixMode", 1615 },
   { "glMemoryBarrier", 1634 },
   { "glMemoryBarrierByRegion", 1635 },
   { "glMinSampleShading", 1638 },
   { "glMultMatrixd", 1643 },
   { "glMultMatrixf", 1644 },
   { "glMultTransposeMatrixd", 1648 },
   { "glMultTransposeMatrixf", 1650 },
   { "glMultiDrawArrays", 1653 },
   { "glMultiDrawArraysIndirect", 1655 },
   { "glMultiDrawElements", 1663 },
   { "glMultiDrawElementsBaseVertex", 1664 },
   { "glMultiDrawElementsIndirect", 1667 },
   { "glMultiTexCoord1d", 1682 },
   { "glMultiTexCoord1dv", 1684 },
   { "glMultiTexCoord1f", 1686 },
   { "glMultiTexCoord1fv", 1688 },
   { "glMultiTexCoord1i", 1692 },
   { "glMultiTexCoord1iv", 1694 },
   { "glMultiTexCoord1s", 1696 },
   { "glMultiTexCoord1sv", 1698 },
   { "glMultiTexCoord2d", 1706 },
   { "glMultiTexCoord2dv", 1708 },
   { "glMultiTexCoord2f", 1710 },
   { "glMultiTexCoord2fv", 1712 },
   { "glMultiTexCoord2i", 1716 },
   { "glMultiTexCoord2iv", 1718 },
   { "glMultiTexCoord2s", 1720 },
   { "glMultiTexCoord2sv", 1722 },
   { "glMultiTexCoord3d", 1730 },
   { "glMultiTexCoord3dv", 1732 },
   { "glMultiTexCoord3f", 1734 },
   { "glMultiTexCoord3fv", 1736 },
   { "glMultiTexCoord3i", 1740 },
   { "glMultiTexCoord3iv", 1742 },
   { "glMultiTexCoord3s", 1744 },
   { "glMultiTexCoord3sv", 1746 },
   { "glMultiTexCoord4d", 1754 },
   { "glMultiTexCoord4dv", 1756 },
   { "glMultiTexCoord4f", 1758 },
   { "glMultiTexCoord4fv", 1760 },
   { "glMultiTexCoord4i", 1764 },
   { "glMultiTexCoord4iv", 1766 },
   { "glMultiTexCoord4s", 1768 },
   { "glMultiTexCoord4sv", 1770 },
   { "glMultiTexCoordP1ui", 1776 },
   { "glMultiTexCoordP1uiv", 1777 },
   { "glMultiTexCoordP2ui", 1778 },
   { "glMultiTexCoordP2uiv", 1779 },
   { "glMultiTexCoordP3ui", 1780 },
   { "glMultiTexCoordP3uiv", 1781 },
   { "glMultiTexCoordP4ui", 1782 },
   { "glMultiTexCoordP4uiv", 1783 },
   { "glNamedBufferData", 1824 },
   { "glNamedBufferStorage", 1829 },
   { "glNamedBufferSubData", 1833 },
   { "glNamedFramebufferDrawBuffer", 1836 },
   { "glNamedFramebufferDrawBuffers", 1837 },
   { "glNamedFramebufferParameteri", 1838 },
   { "glNamedFramebufferReadBuffer", 1840 },
   { "glNamedFramebufferRenderbuffer", 1841 },
   { "glNamedFramebufferTexture", 1846 },
   { "glNamedFramebufferTextureLayer", 1852 },
   { "glNamedRenderbufferStorage", 1866 },
   { "glNamedRenderbufferStorageMultisample", 1868 },
   { "glNewList", 1873 },
   { "glNormal3b", 1875 },
   { "glNormal3bv", 1876 },
   { "glNormal3d", 1877 },
   { "glNormal3dv", 1878 },
   { "glNormal3f", 1879 },
   { "glNormal3fv", 1882 },
   { "glNormal3i", 1885 },
   { "glNormal3iv", 1886 },
   { "glNormal3s", 1887 },
   { "glNormal3sv", 1888 },
   { "glNormalP3ui", 1893 },
   { "glNormalP3uiv", 1894 },
   { "glNormalPointer", 1895 },
   { "glObjectLabel", 1909 },
   { "glObjectPtrLabel", 1912 },
   { "glOrtho", 1917 },
   { "glPassThrough", 1925 },
   { "glPatchParameterfv", 1927 },
   { "glPatchParameteri", 1930 },
   { "glPauseTransformFeedback", 1955 },
   { "glPixelMapfv", 1959 },
   { "glPixelMapuiv", 1960 },
   { "glPixelMapusv", 1961 },
   { "glPixelStoref", 1963 },
   { "glPixelStorei", 1964 },
   { "glPixelTransferf", 1971 },
   { "glPixelTransferi", 1972 },
   { "glPixelZoom", 1978 },
   { "glPointParameterf", 1981 },
   { "glPointParameterfv", 1985 },
   { "glPointParameteri", 1989 },
   { "glPointParameteriv", 1991 },
   { "glPointSize", 1997 },
   { "glPolygonMode", 2003 },
   { "glPolygonOffset", 2005 },
   { "glPolygonStipple", 2011 },
   { "glPopAttrib", 2012 },
   { "glPopClientAttrib", 2013 },
   { "glPopDebugGroup", 2014 },
   { "glPopMatrix", 2018 },
   { "glPopName", 2019 },
   { "glPrimitiveRestartIndex", 2027 },
   { "glPrioritizeTextures", 2030 },
   { "glProgramBinary", 2033 },
   { "glProgramParameteri", 2068 },
   { "glProgramUniform1d", 2076 },
   { "glProgramUniform1dv", 2078 },
   { "glProgramUniform1f", 2080 },
   { "glProgramUniform1fv", 2082 },
   { "glProgramUniform1i", 2084 },
   { "glProgramUniform1iv", 2090 },
   { "glProgramUniform1ui", 2092 },
   { "glProgramUniform1uiv", 2098 },
   { "glProgramUniform2d", 2100 },
   { "glProgramUniform2dv", 2102 },
   { "glProgramUniform2f", 2104 },
   { "glProgramUniform2fv", 2106 },
   { "glProgramUniform2i", 2108 },
   { "glProgramUniform2iv", 2114 },
   { "glProgramUniform2ui", 2116 },
   { "glProgramUniform2uiv", 2122 },
   { "glProgramUniform3d", 2124 },
   { "glProgramUniform3dv", 2126 },
   { "glProgramUniform3f", 2128 },
   { "glProgramUniform3fv", 2130 },
   { "glProgramUniform3i", 2132 },
   { "glProgramUniform3iv", 2138 },
   { "glProgramUniform3ui", 2140 },
   { "glProgramUniform3uiv", 2146 },
   { "glProgramUniform4d", 2148 },
   { "glProgramUniform4dv", 2150 },
   { "glProgramUniform4f", 2152 },
   { "glProgramUniform4fv", 2154 },
   { "glProgramUniform4i", 2156 },
   { "glProgramUniform4iv", 2162 },
   { "glProgramUniform4ui", 2164 },
   { "glProgramUniform4uiv", 2170 },
   { "glProgramUniformMatrix2dv", 2178 },
   { "glProgramUniformMatrix2fv", 2180 },
   { "glProgramUniformMatrix2x3dv", 2182 },
   { "glProgramUniformMatrix2x3fv", 2184 },
   { "glProgramUniformMatrix2x4dv", 2186 },
   { "glProgramUniformMatrix2x4fv", 2188 },
   { "glProgramUniformMatrix3dv", 2190 },
   { "glProgramUniformMatrix3fv", 2192 },
   { "glProgramUniformMatrix3x2dv", 2194 },
   { "glProgramUniformMatrix3x2fv", 2196 },
   { "glProgramUniformMatrix3x4dv", 2198 },
   { "glProgramUniformMatrix3x4fv", 2200 },
   { "glProgramUniformMatrix4dv", 2202 },
   { "glProgramUniformMatrix4fv", 2204 },
   { "glProgramUniformMatrix4x2dv", 2206 },
   { "glProgramUniformMatrix4x2fv", 2208 },
   { "glProgramUniformMatrix4x3dv", 2210 },
   { "glProgramUniformMatrix4x3fv", 2212 },
   { "glProvokingVertex", 2217 },
   { "glPushAttrib", 2219 },
   { "glPushClientAttrib", 2220 },
   { "glPushDebugGroup", 2222 },
   { "glPushMatrix", 2226 },
   { "glPushName", 2227 },
   { "glQueryCounter", 2228 },
   { "glRasterPos2d", 2235 },
   { "glRasterPos2dv", 2236 },
   { "glRasterPos2f", 2237 },
   { "glRasterPos2fv", 2238 },
   { "glRasterPos2i", 2239 },
   { "glRasterPos2iv", 2240 },
   { "glRasterPos2s", 2241 },
   { "glRasterPos2sv", 2242 },
   { "glRasterPos3d", 2245 },
   { "glRasterPos3dv", 2246 },
   { "glRasterPos3f", 2247 },
   { "glRasterPos3fv", 2248 },
   { "glRasterPos3i", 2249 },
   { "glRasterPos3iv", 2250 },
   { "glRasterPos3s", 2251 },
   { "glRasterPos3sv", 2252 },
   { "glRasterPos4d", 2255 },
   { "glRasterPos4dv", 2256 },
   { "glRasterPos4f", 2257 },
   { "glRasterPos4fv", 2258 },
   { "glRasterPos4i", 2259 },
   { "glRasterPos4iv", 2260 },
   { "glRasterPos4s", 2261 },
   { "glRasterPos4sv", 2262 },
   { "glReadBuffer", 2266 },
   { "glReadPixels", 2270 },
   { "glReadnPixels", 2271 },
   { "glRectd", 2275 },
   { "glRectdv", 2276 },
   { "glRectf", 2277 },
   { "glRectfv", 2278 },
   { "glRecti", 2279 },
   { "glRectiv", 2280 },
   { "glRects", 2281 },
   { "glRectsv", 2282 },
   { "glReleaseShaderCompiler", 2287 },
   { "glRenderMode", 2289 },
   { "glRenderbufferStorage", 2290 },
   { "glRenderbufferStorageMultisample", 2292 },
   { "glResumeTransformFeedback", 2333 },
   { "glRotated", 2336 },
   { "glRotatef", 2337 },
   { "glSampleCoverage", 2340 },
   { "glSampleMaski", 2348 },
   { "glSamplerParameterIiv", 2351 },
   { "glSamplerParameterIuiv", 2354 },
   { "glSamplerParameterf", 2357 },
   { "glSamplerParameterfv", 2358 },
   { "glSamplerParameteri", 2359 },
   { "glSamplerParameteriv", 2360 },
   { "glScaled", 2361 },
   { "glScalef", 2362 },
   { "glScissor", 2365 },
   { "glScissorArrayv", 2366 },
   { "glScissorIndexed", 2371 },
   { "glScissorIndexedv", 2374 },
   { "glSecondaryColor3b", 2377 },
   { "glSecondaryColor3bv", 2379 },
   { "glSecondaryColor3d", 2381 },
   { "glSecondaryColor3dv", 2383 },
   { "glSecondaryColor3f", 2385 },
   { "glSecondaryColor3fv", 2387 },
   { "glSecondaryColor3i", 2391 },
   { "glSecondaryColor3iv", 2393 },
   { "glSecondaryColor3s", 2395 },
   { "glSecondaryColor3sv", 2397 },
   { "glSecondaryColor3ub", 2399 },
   { "glSecondaryColor3ubv", 2401 },
   { "glSecondaryColor3ui", 2403 },
   { "glSecondaryColor3uiv", 2405 },
   { "glSecondaryColor3us", 2407 },
   { "glSecondaryColor3usv", 2409 },
   { "glSecondaryColorP3ui", 2412 },
   { "glSecondaryColorP3uiv", 2413 },
   { "glSecondaryColorPointer", 2414 },
   { "glSelectBuffer", 2417 },
   { "glShadeModel", 2429 },
   { "glShaderBinary", 2430 },
   { "glShaderSource", 2434 },
   { "glShaderStorageBlockBinding", 2436 },
   { "glStencilFunc", 2461 },
   { "glStencilFuncSeparate", 2462 },
   { "glStencilMask", 2464 },
   { "glStencilMaskSeparate", 2465 },
   { "glStencilOp", 2466 },
   { "glStencilOpSeparate", 2467 },
   { "glTexBuffer", 2500 },
   { "glTexBufferRange", 2504 },
   { "glTexCoord1d", 2511 },
   { "glTexCoord1dv", 2512 },
   { "glTexCoord1f", 2513 },
   { "glTexCoord1fv", 2514 },
   { "glTexCoord1i", 2517 },
   { "glTexCoord1iv", 2518 },
   { "glTexCoord1s", 2519 },
   { "glTexCoord1sv", 2520 },
   { "glTexCoord2d", 2525 },
   { "glTexCoord2dv", 2526 },
   { "glTexCoord2f", 2527 },
   { "glTexCoord2fv", 2538 },
   { "glTexCoord2i", 2541 },
   { "glTexCoord2iv", 2542 },
   { "glTexCoord2s", 2543 },
   { "glTexCoord2sv", 2544 },
   { "glTexCoord3d", 2549 },
   { "glTexCoord3dv", 2550 },
   { "glTexCoord3f", 2551 },
   { "glTexCoord3fv", 2552 },
   { "glTexCoord3i", 2555 },
   { "glTexCoord3iv", 2556 },
   { "glTexCoord3s", 2557 },
   { "glTexCoord3sv", 2558 },
   { "glTexCoord4d", 2563 },
   { "glTexCoord4dv", 2564 },
   { "glTexCoord4f", 2565 },
   { "glTexCoord4fv", 2570 },
   { "glTexCoord4i", 2573 },
   { "glTexCoord4iv", 2574 },
   { "glTexCoord4s", 2575 },
   { "glTexCoord4sv", 2576 },
   { "glTexCoordP1ui", 2580 },
   { "glTexCoordP1uiv", 2581 },
   { "glTexCoordP2ui", 2582 },
   { "glTexCoordP2uiv", 2583 },
   { "glTexCoordP3ui", 2584 },
   { "glTexCoordP3uiv", 2585 },
   { "glTexCoordP4ui", 2586 },
   { "glTexCoordP4uiv", 2587 },
   { "glTexCoordPointer", 2588 },
   { "glTexEnvf", 2592 },
   { "glTexEnvfv", 2593 },
   { "glTexEnvi", 2594 },
   { "glTexEnviv", 2595 },
   { "glTexGend", 2603 },
   { "glTexGendv", 2604 },
   { "glTexGenf", 2605 },
   { "glTexGenfv", 2607 },
   { "glTexGeni", 2609 },
   { "glTexGeniv", 2611 },
   { "glTexImage1D", 2615 },
   { "glTexImage2D", 2616 },
   { "glTexImage2DMultisample", 2617 },
   { "glTexImage3D", 2619 },
   { "glTexImage3DMultisample", 2621 },
   { "glTexParameterIiv", 2629 },
   { "glTexParameterIuiv", 2632 },
   { "glTexParameterf", 2635 },
   { "glTexParameterfv", 2636 },
   { "glTexParameteri", 2637 },
   { "glTexParameteriv", 2638 },
   { "glTexStorage1D", 2644 },
   { "glTexStorage2D", 2646 },
   { "glTexStorage2DMultisample", 2648 },
   { "glTexStorage3D", 2649 },
   { "glTexStorage3DMultisample", 2651 },
   { "glTexSubImage1D", 2661 },
   { "glTexSubImage2D", 2663 },
   { "glTexSubImage3D", 2665 },
   { "glTextureBarrier", 2671 },
   { "glTextureBuffer", 2673 },
   { "glTextureBufferRange", 2675 },
   { "glTextureParameterIiv", 2691 },
   { "glTextureParameterIuiv", 2693 },
   { "glTextureParameterf", 2695 },
   { "glTextureParameterfv", 2697 },
   { "glTextureParameteri", 2699 },
   { "glTextureParameteriv", 2701 },
   { "glTextureStorage1D", 2705 },
   { "glTextureStorage2D", 2707 },
   { "glTextureStorage2DMultisample", 2709 },
   { "glTextureStorage3D", 2711 },
   { "glTextureStorage3DMultisample", 2713 },
   { "glTextureSubImage1D", 2721 },
   { "glTextureSubImage2D", 2723 },
   { "glTextureSubImage3D", 2725 },
   { "glTextureView", 2727 },
   { "glTransformFeedbackBufferBase", 2732 },
   { "glTransformFeedbackBufferRange", 2733 },
   { "glTransformFeedbackVaryings", 2735 },
   { "glTranslated", 2739 },
   { "glTranslatef", 2740 },
   { "glUniform1d", 2743 },
   { "glUniform1dv", 2744 },
   { "glUniform1f", 2745 },
   { "glUniform1fv", 2747 },
   { "glUniform1i", 2749 },
   { "glUniform1iv", 2755 },
   { "glUniform1ui", 2757 },
   { "glUniform1uiv", 2763 },
   { "glUniform2d", 2765 },
   { "glUniform2dv", 2766 },
   { "glUniform2f", 2767 },
   { "glUniform2fv", 2769 },
   { "glUniform2i", 2771 },
   { "glUniform2iv", 2777 },
   { "glUniform2ui", 2779 },
   { "glUniform2uiv", 2785 },
   { "glUniform3d", 2787 },
   { "glUniform3dv", 2788 },
   { "glUniform3f", 2789 },
   { "glUniform3fv", 2791 },
   { "glUniform3i", 2793 },
   { "glUniform3iv", 2799 },
   { "glUniform3ui", 2801 },
   { "glUniform3uiv", 2807 },
   { "glUniform4d", 2809 },
   { "glUniform4dv", 2810 },
   { "glUniform4f", 2811 },
   { "glUniform4fv", 2813 },
   { "glUniform4i", 2815 },
   { "glUniform4iv", 2821 },
   { "glUniform4ui", 2823 },
   { "glUniform4uiv", 2829 },
   { "glUniformBlockBinding", 2831 },
   { "glUniformMatrix2dv", 2839 },
   { "glUniformMatrix2fv", 2840 },
   { "glUniformMatrix2x3dv", 2842 },
   { "glUniformMatrix2x3fv", 2843 },
   { "glUniformMatrix2x4dv", 2845 },
   { "glUniformMatrix2x4fv", 2846 },
   { "glUniformMatrix3dv", 2848 },
   { "glUniformMatrix3fv", 2849 },
   { "glUniformMatrix3x2dv", 2851 },
   { "glUniformMatrix3x2fv", 2852 },
   { "glUniformMatrix3x4dv", 2854 },
   { "glUniformMatrix3x4fv", 2855 },
   { "glUniformMatrix4dv", 2857 },
   { "glUniformMatrix4fv", 2858 },
   { "glUniformMatrix4x2dv", 2860 },
   { "glUniformMatrix4x2fv", 2861 },
   { "glUniformMatrix4x3dv", 2863 },
   { "glUniformMatrix4x3fv", 2864 },
   { "glUniformSubroutinesuiv", 2866 },
   { "glUnmapBuffer", 2870 },
   { "glUnmapNamedBuffer", 2873 },
   { "glUseProgram", 2879 },
   { "glUseProgramStages", 2881 },
   { "glValidateProgram", 2896 },
   { "glValidateProgramPipeline", 2898 },
   { "glVertex2d", 2912 },
   { "glVertex2dv", 2913 },
   { "glVertex2f", 2914 },
   { "glVertex2fv", 2915 },
   { "glVertex2i", 2918 },
   { "glVertex2iv", 2919 },
   { "glVertex2s", 2920 },
   { "glVertex2sv", 2921 },
   { "glVertex3d", 2926 },
   { "glVertex3dv", 2927 },
   { "glVertex3f", 2928 },
   { "glVertex3fv", 2929 },
   { "glVertex3i", 2932 },
   { "glVertex3iv", 2933 },
   { "glVertex3s", 2934 },
   { "glVertex3sv", 2935 },
   { "glVertex4d", 2940 },
   { "glVertex4dv", 2941 },
   { "glVertex4f", 2942 },
   { "glVertex4fv", 2943 },
   { "glVertex4i", 2946 },
   { "glVertex4iv", 2947 },
   { "glVertex4s", 2948 },
   { "glVertex4sv", 2949 },
   { "glVertexArrayAttribBinding", 2952 },
   { "glVertexArrayAttribFormat", 2953 },
   { "glVertexArrayAttribIFormat", 2954 },
   { "glVertexArrayAttribLFormat", 2955 },
   { "glVertexArrayBindingDivisor", 2957 },
   { "glVertexArrayElementBuffer", 2960 },
   { "glVertexArrayVertexBuffer", 2979 },
   { "glVertexArrayVertexBuffers", 2980 },
   { "glVertexAttrib1d", 2982 },
   { "glVertexAttrib1dv", 2985 },
   { "glVertexAttrib1f", 2988 },
   { "glVertexAttrib1fv", 2991 },
   { "glVertexAttrib1s", 2996 },
   { "glVertexAttrib1sv", 2999 },
   { "glVertexAttrib2d", 3002 },
   { "glVertexAttrib2dv", 3005 },
   { "glVertexAttrib2f", 3008 },
   { "glVertexAttrib2fv", 3011 },
   { "glVertexAttrib2s", 3016 },
   { "glVertexAttrib2sv", 3019 },
   { "glVertexAttrib3d", 3022 },
   { "glVertexAttrib3dv", 3025 },
   { "glVertexAttrib3f", 3028 },
   { "glVertexAttrib3fv", 3031 },
   { "glVertexAttrib3s", 3036 },
   { "glVertexAttrib3sv", 3039 },
   { "glVertexAttrib4Nbv", 3042 },
   { "glVertexAttrib4Niv", 3044 },
   { "glVertexAttrib4Nsv", 3046 },
   { "glVertexAttrib4Nub", 3048 },
   { "glVertexAttrib4Nubv", 3050 },
   { "glVertexAttrib4Nuiv", 3052 },
   { "glVertexAttrib4Nusv", 3054 },
   { "glVertexAttrib4bv", 3056 },
   { "glVertexAttrib4d", 3058 },
   { "glVertexAttrib4dv", 3061 },
   { "glVertexAttrib4f", 3064 },
   { "glVertexAttrib4fv", 3067 },
   { "glVertexAttrib4iv", 3072 },
   { "glVertexAttrib4s", 3074 },
   { "glVertexAttrib4sv", 3077 },
   { "glVertexAttrib4ubv", 3081 },
   { "glVertexAttrib4uiv", 3084 },
   { "glVertexAttrib4usv", 3086 },
   { "glVertexAttribBinding", 3089 },
   { "glVertexAttribDivisor", 3090 },
   { "glVertexAttribFormat", 3095 },
   { "glVertexAttribI1i", 3097 },
   { "glVertexAttribI1iv", 3099 },
   { "glVertexAttribI1ui", 3101 },
   { "glVertexAttribI1uiv", 3103 },
   { "glVertexAttribI2i", 3105 },
   { "glVertexAttribI2iv", 3107 },
   { "glVertexAttribI2ui", 3109 },
   { "glVertexAttribI2uiv", 3111 },
   { "glVertexAttribI3i", 3113 },
   { "glVertexAttribI3iv", 3115 },
   { "glVertexAttribI3ui", 3117 },
   { "glVertexAttribI3uiv", 3119 },
   { "glVertexAttribI4bv", 3121 },
   { "glVertexAttribI4i", 3123 },
   { "glVertexAttribI4iv", 3125 },
   { "glVertexAttribI4sv", 3127 },
   { "glVertexAttribI4ubv", 3129 },
   { "glVertexAttribI4ui", 3131 },
   { "glVertexAttribI4uiv", 3133 },
   { "glVertexAttribI4usv", 3135 },
   { "glVertexAttribIFormat", 3137 },
   { "glVertexAttribIPointer", 3139 },
   { "glVertexAttribL1d", 3141 },
   { "glVertexAttribL1dv", 3143 },
   { "glVertexAttribL2d", 3151 },
   { "glVertexAttribL2dv", 3153 },
   { "glVertexAttribL3d", 3159 },
   { "glVertexAttribL3dv", 3161 },
   { "glVertexAttribL4d", 3167 },
   { "glVertexAttribL4dv", 3169 },
   { "glVertexAttribLFormat", 3175 },
   { "glVertexAttribLPointer", 3177 },
   { "glVertexAttribP1ui", 3179 },
   { "glVertexAttribP1uiv", 3180 },
   { "glVertexAttribP2ui", 3181 },
   { "glVertexAttribP2uiv", 3182 },
   { "glVertexAttribP3ui", 3183 },
   { "glVertexAttribP3uiv", 3184 },
   { "glVertexAttribP4ui", 3185 },
   { "glVertexAttribP4uiv", 3186 },
   { "glVertexAttribPointer", 3188 },
   { "glVertexBindingDivisor", 3208 },
   { "glVertexP2ui", 3213 },
   { "glVertexP2uiv", 3214 },
   { "glVertexP3ui", 3215 },
   { "glVertexP3uiv", 3216 },
   { "glVertexP4ui", 3217 },
   { "glVertexP4uiv", 3218 },
   { "glVertexPointer", 3219 },
   { "glViewport", 3264 },
   { "glViewportArrayv", 3265 },
   { "glViewportIndexedf", 3268 },
   { "glViewportIndexedfv", 3271 },
   { "glWaitSync", 3278 },
   { "glWindowPos2d", 3294 },
   { "glWindowPos2dv", 3297 },
   { "glWindowPos2f", 3300 },
   { "glWindowPos2fv", 3303 },
   { "glWindowPos2i", 3306 },
   { "glWindowPos2iv", 3309 },
   { "glWindowPos2s", 3312 },
   { "glWindowPos2sv", 3315 },
   { "glWindowPos3d", 3318 },
   { "glWindowPos3dv", 3321 },
   { "glWindowPos3f", 3324 },
   { "glWindowPos3fv", 3327 },
   { "glWindowPos3i", 3330 },
   { "glWindowPos3iv", 3333 },
   { "glWindowPos3s", 3336 },
   { "glWindowPos3sv", 3339 },
};
#undef MAPI_TMP_PUBLIC_STUBS
#endif /* MAPI_TMP_PUBLIC_STUBS */

#ifdef MAPI_TMP_PUBLIC_ENTRIES
GLAPI void APIENTRY glAccum(GLenum op, GLfloat value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[0];
   ((void (APIENTRY *)(GLenum op, GLfloat value)) _func)(op, value);
}

GLAPI void APIENTRY glActiveShaderProgram(GLuint pipeline, GLuint program)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[4];
   ((void (APIENTRY *)(GLuint pipeline, GLuint program)) _func)(pipeline, program);
}

GLAPI void APIENTRY glActiveTexture(GLenum texture)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[7];
   ((void (APIENTRY *)(GLenum texture)) _func)(texture);
}

GLAPI void APIENTRY glAlphaFunc(GLenum func, GLfloat ref)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[13];
   ((void (APIENTRY *)(GLenum func, GLfloat ref)) _func)(func, ref);
}

GLAPI GLboolean APIENTRY glAreTexturesResident(GLsizei n, const GLuint *textures, GLboolean *residences)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[21];
   return ((GLboolean (APIENTRY *)(GLsizei n, const GLuint *textures, GLboolean *residences)) _func)(n, textures, residences);
}

GLAPI void APIENTRY glArrayElement(GLint i)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[23];
   ((void (APIENTRY *)(GLint i)) _func)(i);
}

GLAPI void APIENTRY glAttachShader(GLuint program, GLuint shader)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[30];
   ((void (APIENTRY *)(GLuint program, GLuint shader)) _func)(program, shader);
}

GLAPI void APIENTRY glBegin(GLenum mode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[31];
   ((void (APIENTRY *)(GLenum mode)) _func)(mode);
}

GLAPI void APIENTRY glBeginConditionalRender(GLuint id, GLenum mode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[32];
   ((void (APIENTRY *)(GLuint id, GLenum mode)) _func)(id, mode);
}

GLAPI void APIENTRY glBeginQuery(GLenum target, GLuint id)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[39];
   ((void (APIENTRY *)(GLenum target, GLuint id)) _func)(target, id);
}

GLAPI void APIENTRY glBeginQueryIndexed(GLenum target, GLuint index, GLuint id)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[42];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLuint id)) _func)(target, index, id);
}

GLAPI void APIENTRY glBeginTransformFeedback(GLenum primitiveMode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[43];
   ((void (APIENTRY *)(GLenum primitiveMode)) _func)(primitiveMode);
}

GLAPI void APIENTRY glBindAttribLocation(GLuint program, GLuint index, const GLchar *name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[49];
   ((void (APIENTRY *)(GLuint program, GLuint index, const GLchar *name)) _func)(program, index, name);
}

GLAPI void APIENTRY glBindBuffer(GLenum target, GLuint buffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[51];
   ((void (APIENTRY *)(GLenum target, GLuint buffer)) _func)(target, buffer);
}

GLAPI void APIENTRY glBindBufferBase(GLenum target, GLuint index, GLuint buffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[53];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLuint buffer)) _func)(target, index, buffer);
}

GLAPI void APIENTRY glBindBufferRange(GLenum target, GLuint index, GLuint buffer, GLintptr offset, GLsizeiptr size)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[58];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLuint buffer, GLintptr offset, GLsizeiptr size)) _func)(target, index, buffer, offset, size);
}

GLAPI void APIENTRY glBindBuffersBase(GLenum target, GLuint first, GLsizei count, const GLuint *buffers)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[61];
   ((void (APIENTRY *)(GLenum target, GLuint first, GLsizei count, const GLuint *buffers)) _func)(target, first, count, buffers);
}

GLAPI void APIENTRY glBindBuffersRange(GLenum target, GLuint first, GLsizei count, const GLuint *buffers, const GLintptr *offsets, const GLsizeiptr *sizes)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[62];
   ((void (APIENTRY *)(GLenum target, GLuint first, GLsizei count, const GLuint *buffers, const GLintptr *offsets, const GLsizeiptr *sizes)) _func)(target, first, count, buffers, offsets, sizes);
}

GLAPI void APIENTRY glBindFragDataLocation(GLuint program, GLuint color, const GLchar *name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[63];
   ((void (APIENTRY *)(GLuint program, GLuint color, const GLchar *name)) _func)(program, color, name);
}

GLAPI void APIENTRY glBindFragDataLocationIndexed(GLuint program, GLuint colorNumber, GLuint index, const GLchar *name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[65];
   ((void (APIENTRY *)(GLuint program, GLuint colorNumber, GLuint index, const GLchar *name)) _func)(program, colorNumber, index, name);
}

GLAPI void APIENTRY glBindFramebuffer(GLenum target, GLuint framebuffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[68];
   ((void (APIENTRY *)(GLenum target, GLuint framebuffer)) _func)(target, framebuffer);
}

GLAPI void APIENTRY glBindImageTexture(GLuint unit, GLuint texture, GLint level, GLboolean layered, GLint layer, GLenum access, GLenum format)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[71];
   ((void (APIENTRY *)(GLuint unit, GLuint texture, GLint level, GLboolean layered, GLint layer, GLenum access, GLenum format)) _func)(unit, texture, level, layered, layer, access, format);
}

GLAPI void APIENTRY glBindImageTextures(GLuint first, GLsizei count, const GLuint *textures)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[73];
   ((void (APIENTRY *)(GLuint first, GLsizei count, const GLuint *textures)) _func)(first, count, textures);
}

GLAPI void APIENTRY glBindProgramPipeline(GLuint pipeline)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[80];
   ((void (APIENTRY *)(GLuint pipeline)) _func)(pipeline);
}

GLAPI void APIENTRY glBindRenderbuffer(GLenum target, GLuint renderbuffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[82];
   ((void (APIENTRY *)(GLenum target, GLuint renderbuffer)) _func)(target, renderbuffer);
}

GLAPI void APIENTRY glBindSampler(GLuint unit, GLuint sampler)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[85];
   ((void (APIENTRY *)(GLuint unit, GLuint sampler)) _func)(unit, sampler);
}

GLAPI void APIENTRY glBindSamplers(GLuint first, GLsizei count, const GLuint *samplers)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[86];
   ((void (APIENTRY *)(GLuint first, GLsizei count, const GLuint *samplers)) _func)(first, count, samplers);
}

GLAPI void APIENTRY glBindTexture(GLenum target, GLuint texture)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[89];
   ((void (APIENTRY *)(GLenum target, GLuint texture)) _func)(target, texture);
}

GLAPI void APIENTRY glBindTextureUnit(GLuint unit, GLuint texture)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[91];
   ((void (APIENTRY *)(GLuint unit, GLuint texture)) _func)(unit, texture);
}

GLAPI void APIENTRY glBindTextures(GLuint first, GLsizei count, const GLuint *textures)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[93];
   ((void (APIENTRY *)(GLuint first, GLsizei count, const GLuint *textures)) _func)(first, count, textures);
}

GLAPI void APIENTRY glBindTransformFeedback(GLenum target, GLuint id)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[94];
   ((void (APIENTRY *)(GLenum target, GLuint id)) _func)(target, id);
}

GLAPI void APIENTRY glBindVertexArray(GLuint array)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[97];
   ((void (APIENTRY *)(GLuint array)) _func)(array);
}

GLAPI void APIENTRY glBindVertexBuffer(GLuint bindingindex, GLuint buffer, GLintptr offset, GLsizei stride)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[100];
   ((void (APIENTRY *)(GLuint bindingindex, GLuint buffer, GLintptr offset, GLsizei stride)) _func)(bindingindex, buffer, offset, stride);
}

GLAPI void APIENTRY glBindVertexBuffers(GLuint first, GLsizei count, const GLuint *buffers, const GLintptr *offsets, const GLsizei *strides)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[101];
   ((void (APIENTRY *)(GLuint first, GLsizei count, const GLuint *buffers, const GLintptr *offsets, const GLsizei *strides)) _func)(first, count, buffers, offsets, strides);
}

GLAPI void APIENTRY glBitmap(GLsizei width, GLsizei height, GLfloat xorig, GLfloat yorig, GLfloat xmove, GLfloat ymove, const GLubyte *bitmap)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[116];
   ((void (APIENTRY *)(GLsizei width, GLsizei height, GLfloat xorig, GLfloat yorig, GLfloat xmove, GLfloat ymove, const GLubyte *bitmap)) _func)(width, height, xorig, yorig, xmove, ymove, bitmap);
}

GLAPI void APIENTRY glBlendColor(GLfloat red, GLfloat green, GLfloat blue, GLfloat alpha)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[121];
   ((void (APIENTRY *)(GLfloat red, GLfloat green, GLfloat blue, GLfloat alpha)) _func)(red, green, blue, alpha);
}

GLAPI void APIENTRY glBlendEquation(GLenum mode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[124];
   ((void (APIENTRY *)(GLenum mode)) _func)(mode);
}

GLAPI void APIENTRY glBlendEquationSeparate(GLenum modeRGB, GLenum modeAlpha)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[128];
   ((void (APIENTRY *)(GLenum modeRGB, GLenum modeAlpha)) _func)(modeRGB, modeAlpha);
}

GLAPI void APIENTRY glBlendEquationSeparatei(GLuint buf, GLenum modeRGB, GLenum modeAlpha)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[132];
   ((void (APIENTRY *)(GLuint buf, GLenum modeRGB, GLenum modeAlpha)) _func)(buf, modeRGB, modeAlpha);
}

GLAPI void APIENTRY glBlendEquationi(GLuint buf, GLenum mode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[136];
   ((void (APIENTRY *)(GLuint buf, GLenum mode)) _func)(buf, mode);
}

GLAPI void APIENTRY glBlendFunc(GLenum sfactor, GLenum dfactor)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[140];
   ((void (APIENTRY *)(GLenum sfactor, GLenum dfactor)) _func)(sfactor, dfactor);
}

GLAPI void APIENTRY glBlendFuncSeparate(GLenum sfactorRGB, GLenum dfactorRGB, GLenum sfactorAlpha, GLenum dfactorAlpha)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[142];
   ((void (APIENTRY *)(GLenum sfactorRGB, GLenum dfactorRGB, GLenum sfactorAlpha, GLenum dfactorAlpha)) _func)(sfactorRGB, dfactorRGB, sfactorAlpha, dfactorAlpha);
}

GLAPI void APIENTRY glBlendFuncSeparatei(GLuint buf, GLenum srcRGB, GLenum dstRGB, GLenum srcAlpha, GLenum dstAlpha)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[147];
   ((void (APIENTRY *)(GLuint buf, GLenum srcRGB, GLenum dstRGB, GLenum srcAlpha, GLenum dstAlpha)) _func)(buf, srcRGB, dstRGB, srcAlpha, dstAlpha);
}

GLAPI void APIENTRY glBlendFunci(GLuint buf, GLenum src, GLenum dst)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[151];
   ((void (APIENTRY *)(GLuint buf, GLenum src, GLenum dst)) _func)(buf, src, dst);
}

GLAPI void APIENTRY glBlitFramebuffer(GLint srcX0, GLint srcY0, GLint srcX1, GLint srcY1, GLint dstX0, GLint dstY0, GLint dstX1, GLint dstY1, GLbitfield mask, GLenum filter)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[156];
   ((void (APIENTRY *)(GLint srcX0, GLint srcY0, GLint srcX1, GLint srcY1, GLint dstX0, GLint dstY0, GLint dstX1, GLint dstY1, GLbitfield mask, GLenum filter)) _func)(srcX0, srcY0, srcX1, srcY1, dstX0, dstY0, dstX1, dstY1, mask, filter);
}

GLAPI void APIENTRY glBlitNamedFramebuffer(GLuint readFramebuffer, GLuint drawFramebuffer, GLint srcX0, GLint srcY0, GLint srcX1, GLint srcY1, GLint dstX0, GLint dstY0, GLint dstX1, GLint dstY1, GLbitfield mask, GLenum filter)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[160];
   ((void (APIENTRY *)(GLuint readFramebuffer, GLuint drawFramebuffer, GLint srcX0, GLint srcY0, GLint srcX1, GLint srcY1, GLint dstX0, GLint dstY0, GLint dstX1, GLint dstY1, GLbitfield mask, GLenum filter)) _func)(readFramebuffer, drawFramebuffer, srcX0, srcY0, srcX1, srcY1, dstX0, dstY0, dstX1, dstY1, mask, filter);
}

GLAPI void APIENTRY glBufferData(GLenum target, GLsizeiptr size, const void *data, GLenum usage)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[163];
   ((void (APIENTRY *)(GLenum target, GLsizeiptr size, const void *data, GLenum usage)) _func)(target, size, data, usage);
}

GLAPI void APIENTRY glBufferStorage(GLenum target, GLsizeiptr size, const void *data, GLbitfield flags)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[169];
   ((void (APIENTRY *)(GLenum target, GLsizeiptr size, const void *data, GLbitfield flags)) _func)(target, size, data, flags);
}

GLAPI void APIENTRY glBufferSubData(GLenum target, GLintptr offset, GLsizeiptr size, const void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[173];
   ((void (APIENTRY *)(GLenum target, GLintptr offset, GLsizeiptr size, const void *data)) _func)(target, offset, size, data);
}

GLAPI void APIENTRY glCallList(GLuint list)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[176];
   ((void (APIENTRY *)(GLuint list)) _func)(list);
}

GLAPI void APIENTRY glCallLists(GLsizei n, GLenum type, const void *lists)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[177];
   ((void (APIENTRY *)(GLsizei n, GLenum type, const void *lists)) _func)(n, type, lists);
}

GLAPI GLenum APIENTRY glCheckFramebufferStatus(GLenum target)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[178];
   return ((GLenum (APIENTRY *)(GLenum target)) _func)(target);
}

GLAPI GLenum APIENTRY glCheckNamedFramebufferStatus(GLuint framebuffer, GLenum target)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[181];
   return ((GLenum (APIENTRY *)(GLuint framebuffer, GLenum target)) _func)(framebuffer, target);
}

GLAPI void APIENTRY glClampColor(GLenum target, GLenum clamp)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[183];
   ((void (APIENTRY *)(GLenum target, GLenum clamp)) _func)(target, clamp);
}

GLAPI void APIENTRY glClear(GLbitfield mask)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[185];
   ((void (APIENTRY *)(GLbitfield mask)) _func)(mask);
}

GLAPI void APIENTRY glClearAccum(GLfloat red, GLfloat green, GLfloat blue, GLfloat alpha)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[186];
   ((void (APIENTRY *)(GLfloat red, GLfloat green, GLfloat blue, GLfloat alpha)) _func)(red, green, blue, alpha);
}

GLAPI void APIENTRY glClearBufferData(GLenum target, GLenum internalformat, GLenum format, GLenum type, const void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[188];
   ((void (APIENTRY *)(GLenum target, GLenum internalformat, GLenum format, GLenum type, const void *data)) _func)(target, internalformat, format, type, data);
}

GLAPI void APIENTRY glClearBufferSubData(GLenum target, GLenum internalformat, GLintptr offset, GLsizeiptr size, GLenum format, GLenum type, const void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[189];
   ((void (APIENTRY *)(GLenum target, GLenum internalformat, GLintptr offset, GLsizeiptr size, GLenum format, GLenum type, const void *data)) _func)(target, internalformat, offset, size, format, type, data);
}

GLAPI void APIENTRY glClearBufferfi(GLenum buffer, GLint drawbuffer, GLfloat depth, GLint stencil)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[190];
   ((void (APIENTRY *)(GLenum buffer, GLint drawbuffer, GLfloat depth, GLint stencil)) _func)(buffer, drawbuffer, depth, stencil);
}

GLAPI void APIENTRY glClearBufferfv(GLenum buffer, GLint drawbuffer, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[191];
   ((void (APIENTRY *)(GLenum buffer, GLint drawbuffer, const GLfloat *value)) _func)(buffer, drawbuffer, value);
}

GLAPI void APIENTRY glClearBufferiv(GLenum buffer, GLint drawbuffer, const GLint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[192];
   ((void (APIENTRY *)(GLenum buffer, GLint drawbuffer, const GLint *value)) _func)(buffer, drawbuffer, value);
}

GLAPI void APIENTRY glClearBufferuiv(GLenum buffer, GLint drawbuffer, const GLuint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[193];
   ((void (APIENTRY *)(GLenum buffer, GLint drawbuffer, const GLuint *value)) _func)(buffer, drawbuffer, value);
}

GLAPI void APIENTRY glClearColor(GLfloat red, GLfloat green, GLfloat blue, GLfloat alpha)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[194];
   ((void (APIENTRY *)(GLfloat red, GLfloat green, GLfloat blue, GLfloat alpha)) _func)(red, green, blue, alpha);
}

GLAPI void APIENTRY glClearDepth(GLdouble depth)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[199];
   ((void (APIENTRY *)(GLdouble depth)) _func)(depth);
}

GLAPI void APIENTRY glClearDepthf(GLfloat d)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[201];
   ((void (APIENTRY *)(GLfloat d)) _func)(d);
}

GLAPI void APIENTRY glClearIndex(GLfloat c)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[205];
   ((void (APIENTRY *)(GLfloat c)) _func)(c);
}

GLAPI void APIENTRY glClearNamedBufferData(GLuint buffer, GLenum internalformat, GLenum format, GLenum type, const void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[206];
   ((void (APIENTRY *)(GLuint buffer, GLenum internalformat, GLenum format, GLenum type, const void *data)) _func)(buffer, internalformat, format, type, data);
}

GLAPI void APIENTRY glClearNamedBufferSubData(GLuint buffer, GLenum internalformat, GLintptr offset, GLsizeiptr size, GLenum format, GLenum type, const void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[208];
   ((void (APIENTRY *)(GLuint buffer, GLenum internalformat, GLintptr offset, GLsizeiptr size, GLenum format, GLenum type, const void *data)) _func)(buffer, internalformat, offset, size, format, type, data);
}

GLAPI void APIENTRY glClearNamedFramebufferfi(GLuint framebuffer, GLenum buffer, GLint drawbuffer, GLfloat depth, GLint stencil)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[210];
   ((void (APIENTRY *)(GLuint framebuffer, GLenum buffer, GLint drawbuffer, GLfloat depth, GLint stencil)) _func)(framebuffer, buffer, drawbuffer, depth, stencil);
}

GLAPI void APIENTRY glClearNamedFramebufferfv(GLuint framebuffer, GLenum buffer, GLint drawbuffer, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[211];
   ((void (APIENTRY *)(GLuint framebuffer, GLenum buffer, GLint drawbuffer, const GLfloat *value)) _func)(framebuffer, buffer, drawbuffer, value);
}

GLAPI void APIENTRY glClearNamedFramebufferiv(GLuint framebuffer, GLenum buffer, GLint drawbuffer, const GLint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[212];
   ((void (APIENTRY *)(GLuint framebuffer, GLenum buffer, GLint drawbuffer, const GLint *value)) _func)(framebuffer, buffer, drawbuffer, value);
}

GLAPI void APIENTRY glClearNamedFramebufferuiv(GLuint framebuffer, GLenum buffer, GLint drawbuffer, const GLuint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[213];
   ((void (APIENTRY *)(GLuint framebuffer, GLenum buffer, GLint drawbuffer, const GLuint *value)) _func)(framebuffer, buffer, drawbuffer, value);
}

GLAPI void APIENTRY glClearStencil(GLint s)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[215];
   ((void (APIENTRY *)(GLint s)) _func)(s);
}

GLAPI void APIENTRY glClearTexImage(GLuint texture, GLint level, GLenum format, GLenum type, const void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[216];
   ((void (APIENTRY *)(GLuint texture, GLint level, GLenum format, GLenum type, const void *data)) _func)(texture, level, format, type, data);
}

GLAPI void APIENTRY glClearTexSubImage(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[218];
   ((void (APIENTRY *)(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void *data)) _func)(texture, level, xoffset, yoffset, zoffset, width, height, depth, format, type, data);
}

GLAPI void APIENTRY glClientActiveTexture(GLenum texture)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[220];
   ((void (APIENTRY *)(GLenum texture)) _func)(texture);
}

GLAPI GLenum APIENTRY glClientWaitSync(GLsync sync, GLbitfield flags, GLuint64 timeout)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[225];
   return ((GLenum (APIENTRY *)(GLsync sync, GLbitfield flags, GLuint64 timeout)) _func)(sync, flags, timeout);
}

GLAPI void APIENTRY glClipControl(GLenum origin, GLenum depth)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[228];
   ((void (APIENTRY *)(GLenum origin, GLenum depth)) _func)(origin, depth);
}

GLAPI void APIENTRY glClipPlane(GLenum plane, const GLdouble *equation)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[230];
   ((void (APIENTRY *)(GLenum plane, const GLdouble *equation)) _func)(plane, equation);
}

GLAPI void APIENTRY glColor3b(GLbyte red, GLbyte green, GLbyte blue)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[237];
   ((void (APIENTRY *)(GLbyte red, GLbyte green, GLbyte blue)) _func)(red, green, blue);
}

GLAPI void APIENTRY glColor3bv(const GLbyte *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[238];
   ((void (APIENTRY *)(const GLbyte *v)) _func)(v);
}

GLAPI void APIENTRY glColor3d(GLdouble red, GLdouble green, GLdouble blue)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[239];
   ((void (APIENTRY *)(GLdouble red, GLdouble green, GLdouble blue)) _func)(red, green, blue);
}

GLAPI void APIENTRY glColor3dv(const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[240];
   ((void (APIENTRY *)(const GLdouble *v)) _func)(v);
}

GLAPI void APIENTRY glColor3f(GLfloat red, GLfloat green, GLfloat blue)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[241];
   ((void (APIENTRY *)(GLfloat red, GLfloat green, GLfloat blue)) _func)(red, green, blue);
}

GLAPI void APIENTRY glColor3fv(const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[244];
   ((void (APIENTRY *)(const GLfloat *v)) _func)(v);
}

GLAPI void APIENTRY glColor3i(GLint red, GLint green, GLint blue)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[247];
   ((void (APIENTRY *)(GLint red, GLint green, GLint blue)) _func)(red, green, blue);
}

GLAPI void APIENTRY glColor3iv(const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[248];
   ((void (APIENTRY *)(const GLint *v)) _func)(v);
}

GLAPI void APIENTRY glColor3s(GLshort red, GLshort green, GLshort blue)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[249];
   ((void (APIENTRY *)(GLshort red, GLshort green, GLshort blue)) _func)(red, green, blue);
}

GLAPI void APIENTRY glColor3sv(const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[250];
   ((void (APIENTRY *)(const GLshort *v)) _func)(v);
}

GLAPI void APIENTRY glColor3ub(GLubyte red, GLubyte green, GLubyte blue)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[251];
   ((void (APIENTRY *)(GLubyte red, GLubyte green, GLubyte blue)) _func)(red, green, blue);
}

GLAPI void APIENTRY glColor3ubv(const GLubyte *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[252];
   ((void (APIENTRY *)(const GLubyte *v)) _func)(v);
}

GLAPI void APIENTRY glColor3ui(GLuint red, GLuint green, GLuint blue)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[253];
   ((void (APIENTRY *)(GLuint red, GLuint green, GLuint blue)) _func)(red, green, blue);
}

GLAPI void APIENTRY glColor3uiv(const GLuint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[254];
   ((void (APIENTRY *)(const GLuint *v)) _func)(v);
}

GLAPI void APIENTRY glColor3us(GLushort red, GLushort green, GLushort blue)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[255];
   ((void (APIENTRY *)(GLushort red, GLushort green, GLushort blue)) _func)(red, green, blue);
}

GLAPI void APIENTRY glColor3usv(const GLushort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[256];
   ((void (APIENTRY *)(const GLushort *v)) _func)(v);
}

GLAPI void APIENTRY glColor4b(GLbyte red, GLbyte green, GLbyte blue, GLbyte alpha)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[260];
   ((void (APIENTRY *)(GLbyte red, GLbyte green, GLbyte blue, GLbyte alpha)) _func)(red, green, blue, alpha);
}

GLAPI void APIENTRY glColor4bv(const GLbyte *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[261];
   ((void (APIENTRY *)(const GLbyte *v)) _func)(v);
}

GLAPI void APIENTRY glColor4d(GLdouble red, GLdouble green, GLdouble blue, GLdouble alpha)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[262];
   ((void (APIENTRY *)(GLdouble red, GLdouble green, GLdouble blue, GLdouble alpha)) _func)(red, green, blue, alpha);
}

GLAPI void APIENTRY glColor4dv(const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[263];
   ((void (APIENTRY *)(const GLdouble *v)) _func)(v);
}

GLAPI void APIENTRY glColor4f(GLfloat red, GLfloat green, GLfloat blue, GLfloat alpha)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[264];
   ((void (APIENTRY *)(GLfloat red, GLfloat green, GLfloat blue, GLfloat alpha)) _func)(red, green, blue, alpha);
}

GLAPI void APIENTRY glColor4fv(const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[267];
   ((void (APIENTRY *)(const GLfloat *v)) _func)(v);
}

GLAPI void APIENTRY glColor4i(GLint red, GLint green, GLint blue, GLint alpha)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[270];
   ((void (APIENTRY *)(GLint red, GLint green, GLint blue, GLint alpha)) _func)(red, green, blue, alpha);
}

GLAPI void APIENTRY glColor4iv(const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[271];
   ((void (APIENTRY *)(const GLint *v)) _func)(v);
}

GLAPI void APIENTRY glColor4s(GLshort red, GLshort green, GLshort blue, GLshort alpha)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[272];
   ((void (APIENTRY *)(GLshort red, GLshort green, GLshort blue, GLshort alpha)) _func)(red, green, blue, alpha);
}

GLAPI void APIENTRY glColor4sv(const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[273];
   ((void (APIENTRY *)(const GLshort *v)) _func)(v);
}

GLAPI void APIENTRY glColor4ub(GLubyte red, GLubyte green, GLubyte blue, GLubyte alpha)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[274];
   ((void (APIENTRY *)(GLubyte red, GLubyte green, GLubyte blue, GLubyte alpha)) _func)(red, green, blue, alpha);
}

GLAPI void APIENTRY glColor4ubv(const GLubyte *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[279];
   ((void (APIENTRY *)(const GLubyte *v)) _func)(v);
}

GLAPI void APIENTRY glColor4ui(GLuint red, GLuint green, GLuint blue, GLuint alpha)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[280];
   ((void (APIENTRY *)(GLuint red, GLuint green, GLuint blue, GLuint alpha)) _func)(red, green, blue, alpha);
}

GLAPI void APIENTRY glColor4uiv(const GLuint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[281];
   ((void (APIENTRY *)(const GLuint *v)) _func)(v);
}

GLAPI void APIENTRY glColor4us(GLushort red, GLushort green, GLushort blue, GLushort alpha)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[282];
   ((void (APIENTRY *)(GLushort red, GLushort green, GLushort blue, GLushort alpha)) _func)(red, green, blue, alpha);
}

GLAPI void APIENTRY glColor4usv(const GLushort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[283];
   ((void (APIENTRY *)(const GLushort *v)) _func)(v);
}

GLAPI void APIENTRY glColorMask(GLboolean red, GLboolean green, GLboolean blue, GLboolean alpha)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[291];
   ((void (APIENTRY *)(GLboolean red, GLboolean green, GLboolean blue, GLboolean alpha)) _func)(red, green, blue, alpha);
}

GLAPI void APIENTRY glColorMaski(GLuint index, GLboolean r, GLboolean g, GLboolean b, GLboolean a)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[293];
   ((void (APIENTRY *)(GLuint index, GLboolean r, GLboolean g, GLboolean b, GLboolean a)) _func)(index, r, g, b, a);
}

GLAPI void APIENTRY glColorMaterial(GLenum face, GLenum mode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[296];
   ((void (APIENTRY *)(GLenum face, GLenum mode)) _func)(face, mode);
}

GLAPI void APIENTRY glColorP3ui(GLenum type, GLuint color)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[297];
   ((void (APIENTRY *)(GLenum type, GLuint color)) _func)(type, color);
}

GLAPI void APIENTRY glColorP3uiv(GLenum type, const GLuint *color)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[298];
   ((void (APIENTRY *)(GLenum type, const GLuint *color)) _func)(type, color);
}

GLAPI void APIENTRY glColorP4ui(GLenum type, GLuint color)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[299];
   ((void (APIENTRY *)(GLenum type, GLuint color)) _func)(type, color);
}

GLAPI void APIENTRY glColorP4uiv(GLenum type, const GLuint *color)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[300];
   ((void (APIENTRY *)(GLenum type, const GLuint *color)) _func)(type, color);
}

GLAPI void APIENTRY glColorPointer(GLint size, GLenum type, GLsizei stride, const void *pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[301];
   ((void (APIENTRY *)(GLint size, GLenum type, GLsizei stride, const void *pointer)) _func)(size, type, stride, pointer);
}

GLAPI void APIENTRY glCompileShader(GLuint shader)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[323];
   ((void (APIENTRY *)(GLuint shader)) _func)(shader);
}

GLAPI void APIENTRY glCompressedTexImage1D(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLint border, GLsizei imageSize, const void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[332];
   ((void (APIENTRY *)(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLint border, GLsizei imageSize, const void *data)) _func)(target, level, internalformat, width, border, imageSize, data);
}

GLAPI void APIENTRY glCompressedTexImage2D(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLint border, GLsizei imageSize, const void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[334];
   ((void (APIENTRY *)(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLint border, GLsizei imageSize, const void *data)) _func)(target, level, internalformat, width, height, border, imageSize, data);
}

GLAPI void APIENTRY glCompressedTexImage3D(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLsizei imageSize, const void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[336];
   ((void (APIENTRY *)(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLsizei imageSize, const void *data)) _func)(target, level, internalformat, width, height, depth, border, imageSize, data);
}

GLAPI void APIENTRY glCompressedTexSubImage1D(GLenum target, GLint level, GLint xoffset, GLsizei width, GLenum format, GLsizei imageSize, const void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[340];
   ((void (APIENTRY *)(GLenum target, GLint level, GLint xoffset, GLsizei width, GLenum format, GLsizei imageSize, const void *data)) _func)(target, level, xoffset, width, format, imageSize, data);
}

GLAPI void APIENTRY glCompressedTexSubImage2D(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLsizei imageSize, const void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[342];
   ((void (APIENTRY *)(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLsizei imageSize, const void *data)) _func)(target, level, xoffset, yoffset, width, height, format, imageSize, data);
}

GLAPI void APIENTRY glCompressedTexSubImage3D(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLsizei imageSize, const void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[344];
   ((void (APIENTRY *)(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLsizei imageSize, const void *data)) _func)(target, level, xoffset, yoffset, zoffset, width, height, depth, format, imageSize, data);
}

GLAPI void APIENTRY glCompressedTextureSubImage1D(GLuint texture, GLint level, GLint xoffset, GLsizei width, GLenum format, GLsizei imageSize, const void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[351];
   ((void (APIENTRY *)(GLuint texture, GLint level, GLint xoffset, GLsizei width, GLenum format, GLsizei imageSize, const void *data)) _func)(texture, level, xoffset, width, format, imageSize, data);
}

GLAPI void APIENTRY glCompressedTextureSubImage2D(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLsizei imageSize, const void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[353];
   ((void (APIENTRY *)(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLsizei imageSize, const void *data)) _func)(texture, level, xoffset, yoffset, width, height, format, imageSize, data);
}

GLAPI void APIENTRY glCompressedTextureSubImage3D(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLsizei imageSize, const void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[355];
   ((void (APIENTRY *)(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLsizei imageSize, const void *data)) _func)(texture, level, xoffset, yoffset, zoffset, width, height, depth, format, imageSize, data);
}

GLAPI void APIENTRY glCopyBufferSubData(GLenum readTarget, GLenum writeTarget, GLintptr readOffset, GLintptr writeOffset, GLsizeiptr size)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[373];
   ((void (APIENTRY *)(GLenum readTarget, GLenum writeTarget, GLintptr readOffset, GLintptr writeOffset, GLsizeiptr size)) _func)(readTarget, writeTarget, readOffset, writeOffset, size);
}

GLAPI void APIENTRY glCopyImageSubData(GLuint srcName, GLenum srcTarget, GLint srcLevel, GLint srcX, GLint srcY, GLint srcZ, GLuint dstName, GLenum dstTarget, GLint dstLevel, GLint dstX, GLint dstY, GLint dstZ, GLsizei srcWidth, GLsizei srcHeight, GLsizei srcDepth)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[383];
   ((void (APIENTRY *)(GLuint srcName, GLenum srcTarget, GLint srcLevel, GLint srcX, GLint srcY, GLint srcZ, GLuint dstName, GLenum dstTarget, GLint dstLevel, GLint dstX, GLint dstY, GLint dstZ, GLsizei srcWidth, GLsizei srcHeight, GLsizei srcDepth)) _func)(srcName, srcTarget, srcLevel, srcX, srcY, srcZ, dstName, dstTarget, dstLevel, dstX, dstY, dstZ, srcWidth, srcHeight, srcDepth);
}

GLAPI void APIENTRY glCopyNamedBufferSubData(GLuint readBuffer, GLuint writeBuffer, GLintptr readOffset, GLintptr writeOffset, GLsizeiptr size)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[392];
   ((void (APIENTRY *)(GLuint readBuffer, GLuint writeBuffer, GLintptr readOffset, GLintptr writeOffset, GLsizeiptr size)) _func)(readBuffer, writeBuffer, readOffset, writeOffset, size);
}

GLAPI void APIENTRY glCopyPixels(GLint x, GLint y, GLsizei width, GLsizei height, GLenum type)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[394];
   ((void (APIENTRY *)(GLint x, GLint y, GLsizei width, GLsizei height, GLenum type)) _func)(x, y, width, height, type);
}

GLAPI void APIENTRY glCopyTexImage1D(GLenum target, GLint level, GLenum internalformat, GLint x, GLint y, GLsizei width, GLint border)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[395];
   ((void (APIENTRY *)(GLenum target, GLint level, GLenum internalformat, GLint x, GLint y, GLsizei width, GLint border)) _func)(target, level, internalformat, x, y, width, border);
}

GLAPI void APIENTRY glCopyTexImage2D(GLenum target, GLint level, GLenum internalformat, GLint x, GLint y, GLsizei width, GLsizei height, GLint border)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[397];
   ((void (APIENTRY *)(GLenum target, GLint level, GLenum internalformat, GLint x, GLint y, GLsizei width, GLsizei height, GLint border)) _func)(target, level, internalformat, x, y, width, height, border);
}

GLAPI void APIENTRY glCopyTexSubImage1D(GLenum target, GLint level, GLint xoffset, GLint x, GLint y, GLsizei width)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[399];
   ((void (APIENTRY *)(GLenum target, GLint level, GLint xoffset, GLint x, GLint y, GLsizei width)) _func)(target, level, xoffset, x, y, width);
}

GLAPI void APIENTRY glCopyTexSubImage2D(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint x, GLint y, GLsizei width, GLsizei height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[401];
   ((void (APIENTRY *)(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint x, GLint y, GLsizei width, GLsizei height)) _func)(target, level, xoffset, yoffset, x, y, width, height);
}

GLAPI void APIENTRY glCopyTexSubImage3D(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLint x, GLint y, GLsizei width, GLsizei height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[403];
   ((void (APIENTRY *)(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLint x, GLint y, GLsizei width, GLsizei height)) _func)(target, level, xoffset, yoffset, zoffset, x, y, width, height);
}

GLAPI void APIENTRY glCopyTextureSubImage1D(GLuint texture, GLint level, GLint xoffset, GLint x, GLint y, GLsizei width)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[410];
   ((void (APIENTRY *)(GLuint texture, GLint level, GLint xoffset, GLint x, GLint y, GLsizei width)) _func)(texture, level, xoffset, x, y, width);
}

GLAPI void APIENTRY glCopyTextureSubImage2D(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint x, GLint y, GLsizei width, GLsizei height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[412];
   ((void (APIENTRY *)(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint x, GLint y, GLsizei width, GLsizei height)) _func)(texture, level, xoffset, yoffset, x, y, width, height);
}

GLAPI void APIENTRY glCopyTextureSubImage3D(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLint x, GLint y, GLsizei width, GLsizei height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[414];
   ((void (APIENTRY *)(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLint x, GLint y, GLsizei width, GLsizei height)) _func)(texture, level, xoffset, yoffset, zoffset, x, y, width, height);
}

GLAPI void APIENTRY glCreateBuffers(GLsizei n, GLuint *buffers)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[424];
   ((void (APIENTRY *)(GLsizei n, GLuint *buffers)) _func)(n, buffers);
}

GLAPI void APIENTRY glCreateFramebuffers(GLsizei n, GLuint *framebuffers)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[426];
   ((void (APIENTRY *)(GLsizei n, GLuint *framebuffers)) _func)(n, framebuffers);
}

GLAPI GLuint APIENTRY glCreateProgram(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[429];
   return ((GLuint (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glCreateProgramPipelines(GLsizei n, GLuint *pipelines)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[431];
   ((void (APIENTRY *)(GLsizei n, GLuint *pipelines)) _func)(n, pipelines);
}

GLAPI void APIENTRY glCreateQueries(GLenum target, GLsizei n, GLuint *ids)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[433];
   ((void (APIENTRY *)(GLenum target, GLsizei n, GLuint *ids)) _func)(target, n, ids);
}

GLAPI void APIENTRY glCreateRenderbuffers(GLsizei n, GLuint *renderbuffers)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[434];
   ((void (APIENTRY *)(GLsizei n, GLuint *renderbuffers)) _func)(n, renderbuffers);
}

GLAPI void APIENTRY glCreateSamplers(GLsizei n, GLuint *samplers)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[435];
   ((void (APIENTRY *)(GLsizei n, GLuint *samplers)) _func)(n, samplers);
}

GLAPI GLuint APIENTRY glCreateShader(GLenum type)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[437];
   return ((GLuint (APIENTRY *)(GLenum type)) _func)(type);
}

GLAPI GLuint APIENTRY glCreateShaderProgramv(GLenum type, GLsizei count, const GLchar *const *strings)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[440];
   return ((GLuint (APIENTRY *)(GLenum type, GLsizei count, const GLchar *const *strings)) _func)(type, count, strings);
}

GLAPI void APIENTRY glCreateTextures(GLenum target, GLsizei n, GLuint *textures)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[444];
   ((void (APIENTRY *)(GLenum target, GLsizei n, GLuint *textures)) _func)(target, n, textures);
}

GLAPI void APIENTRY glCreateTransformFeedbacks(GLsizei n, GLuint *ids)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[445];
   ((void (APIENTRY *)(GLsizei n, GLuint *ids)) _func)(n, ids);
}

GLAPI void APIENTRY glCreateVertexArrays(GLsizei n, GLuint *arrays)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[446];
   ((void (APIENTRY *)(GLsizei n, GLuint *arrays)) _func)(n, arrays);
}

GLAPI void APIENTRY glCullFace(GLenum mode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[447];
   ((void (APIENTRY *)(GLenum mode)) _func)(mode);
}

GLAPI void APIENTRY glDebugMessageCallback(GLDEBUGPROC callback, const void *userParam)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[452];
   ((void (APIENTRY *)(GLDEBUGPROC callback, const void *userParam)) _func)(callback, userParam);
}

GLAPI void APIENTRY glDebugMessageControl(GLenum source, GLenum type, GLenum severity, GLsizei count, const GLuint *ids, GLboolean enabled)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[457];
   ((void (APIENTRY *)(GLenum source, GLenum type, GLenum severity, GLsizei count, const GLuint *ids, GLboolean enabled)) _func)(source, type, severity, count, ids, enabled);
}

GLAPI void APIENTRY glDebugMessageInsert(GLenum source, GLenum type, GLuint id, GLenum severity, GLsizei length, const GLchar *buf)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[462];
   ((void (APIENTRY *)(GLenum source, GLenum type, GLuint id, GLenum severity, GLsizei length, const GLchar *buf)) _func)(source, type, id, severity, length, buf);
}

GLAPI void APIENTRY glDeleteBuffers(GLsizei n, const GLuint *buffers)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[471];
   ((void (APIENTRY *)(GLsizei n, const GLuint *buffers)) _func)(n, buffers);
}

GLAPI void APIENTRY glDeleteFramebuffers(GLsizei n, const GLuint *framebuffers)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[477];
   ((void (APIENTRY *)(GLsizei n, const GLuint *framebuffers)) _func)(n, framebuffers);
}

GLAPI void APIENTRY glDeleteLists(GLuint list, GLsizei range)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[480];
   ((void (APIENTRY *)(GLuint list, GLsizei range)) _func)(list, range);
}

GLAPI void APIENTRY glDeleteProgram(GLuint program)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[489];
   ((void (APIENTRY *)(GLuint program)) _func)(program);
}

GLAPI void APIENTRY glDeleteProgramPipelines(GLsizei n, const GLuint *pipelines)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[490];
   ((void (APIENTRY *)(GLsizei n, const GLuint *pipelines)) _func)(n, pipelines);
}

GLAPI void APIENTRY glDeleteQueries(GLsizei n, const GLuint *ids)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[494];
   ((void (APIENTRY *)(GLsizei n, const GLuint *ids)) _func)(n, ids);
}

GLAPI void APIENTRY glDeleteRenderbuffers(GLsizei n, const GLuint *renderbuffers)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[498];
   ((void (APIENTRY *)(GLsizei n, const GLuint *renderbuffers)) _func)(n, renderbuffers);
}

GLAPI void APIENTRY glDeleteSamplers(GLsizei count, const GLuint *samplers)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[501];
   ((void (APIENTRY *)(GLsizei count, const GLuint *samplers)) _func)(count, samplers);
}

GLAPI void APIENTRY glDeleteShader(GLuint shader)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[503];
   ((void (APIENTRY *)(GLuint shader)) _func)(shader);
}

GLAPI void APIENTRY glDeleteSync(GLsync sync)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[505];
   ((void (APIENTRY *)(GLsync sync)) _func)(sync);
}

GLAPI void APIENTRY glDeleteTextures(GLsizei n, const GLuint *textures)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[507];
   ((void (APIENTRY *)(GLsizei n, const GLuint *textures)) _func)(n, textures);
}

GLAPI void APIENTRY glDeleteTransformFeedbacks(GLsizei n, const GLuint *ids)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[509];
   ((void (APIENTRY *)(GLsizei n, const GLuint *ids)) _func)(n, ids);
}

GLAPI void APIENTRY glDeleteVertexArrays(GLsizei n, const GLuint *arrays)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[512];
   ((void (APIENTRY *)(GLsizei n, const GLuint *arrays)) _func)(n, arrays);
}

GLAPI void APIENTRY glDepthFunc(GLenum func)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[518];
   ((void (APIENTRY *)(GLenum func)) _func)(func);
}

GLAPI void APIENTRY glDepthMask(GLboolean flag)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[519];
   ((void (APIENTRY *)(GLboolean flag)) _func)(flag);
}

GLAPI void APIENTRY glDepthRange(GLdouble n, GLdouble f)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[520];
   ((void (APIENTRY *)(GLdouble n, GLdouble f)) _func)(n, f);
}

GLAPI void APIENTRY glDepthRangeArrayv(GLuint first, GLsizei count, const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[524];
   ((void (APIENTRY *)(GLuint first, GLsizei count, const GLdouble *v)) _func)(first, count, v);
}

GLAPI void APIENTRY glDepthRangeIndexed(GLuint index, GLdouble n, GLdouble f)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[525];
   ((void (APIENTRY *)(GLuint index, GLdouble n, GLdouble f)) _func)(index, n, f);
}

GLAPI void APIENTRY glDepthRangef(GLfloat n, GLfloat f)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[530];
   ((void (APIENTRY *)(GLfloat n, GLfloat f)) _func)(n, f);
}

GLAPI void APIENTRY glDetachShader(GLuint program, GLuint shader)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[535];
   ((void (APIENTRY *)(GLuint program, GLuint shader)) _func)(program, shader);
}

GLAPI void APIENTRY glDisable(GLenum cap)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[539];
   ((void (APIENTRY *)(GLenum cap)) _func)(cap);
}

GLAPI void APIENTRY glDisableClientState(GLenum array)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[540];
   ((void (APIENTRY *)(GLenum array)) _func)(array);
}

GLAPI void APIENTRY glDisableVertexArrayAttrib(GLuint vaobj, GLuint index)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[546];
   ((void (APIENTRY *)(GLuint vaobj, GLuint index)) _func)(vaobj, index);
}

GLAPI void APIENTRY glDisableVertexAttribArray(GLuint index)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[550];
   ((void (APIENTRY *)(GLuint index)) _func)(index);
}

GLAPI void APIENTRY glDisablei(GLenum target, GLuint index)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[552];
   ((void (APIENTRY *)(GLenum target, GLuint index)) _func)(target, index);
}

GLAPI void APIENTRY glDispatchCompute(GLuint num_groups_x, GLuint num_groups_y, GLuint num_groups_z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[557];
   ((void (APIENTRY *)(GLuint num_groups_x, GLuint num_groups_y, GLuint num_groups_z)) _func)(num_groups_x, num_groups_y, num_groups_z);
}

GLAPI void APIENTRY glDispatchComputeIndirect(GLintptr indirect)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[559];
   ((void (APIENTRY *)(GLintptr indirect)) _func)(indirect);
}

GLAPI void APIENTRY glDrawArrays(GLenum mode, GLint first, GLsizei count)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[560];
   ((void (APIENTRY *)(GLenum mode, GLint first, GLsizei count)) _func)(mode, first, count);
}

GLAPI void APIENTRY glDrawArraysIndirect(GLenum mode, const void *indirect)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[562];
   ((void (APIENTRY *)(GLenum mode, const void *indirect)) _func)(mode, indirect);
}

GLAPI void APIENTRY glDrawArraysInstanced(GLenum mode, GLint first, GLsizei count, GLsizei instancecount)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[563];
   ((void (APIENTRY *)(GLenum mode, GLint first, GLsizei count, GLsizei instancecount)) _func)(mode, first, count, instancecount);
}

GLAPI void APIENTRY glDrawArraysInstancedBaseInstance(GLenum mode, GLint first, GLsizei count, GLsizei instancecount, GLuint baseinstance)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[566];
   ((void (APIENTRY *)(GLenum mode, GLint first, GLsizei count, GLsizei instancecount, GLuint baseinstance)) _func)(mode, first, count, instancecount, baseinstance);
}

GLAPI void APIENTRY glDrawBuffer(GLenum buf)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[570];
   ((void (APIENTRY *)(GLenum buf)) _func)(buf);
}

GLAPI void APIENTRY glDrawBuffers(GLsizei n, const GLenum *bufs)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[571];
   ((void (APIENTRY *)(GLsizei n, const GLenum *bufs)) _func)(n, bufs);
}

GLAPI void APIENTRY glDrawElements(GLenum mode, GLsizei count, GLenum type, const void *indices)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[583];
   ((void (APIENTRY *)(GLenum mode, GLsizei count, GLenum type, const void *indices)) _func)(mode, count, type, indices);
}

GLAPI void APIENTRY glDrawElementsBaseVertex(GLenum mode, GLsizei count, GLenum type, const void *indices, GLint basevertex)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[584];
   ((void (APIENTRY *)(GLenum mode, GLsizei count, GLenum type, const void *indices, GLint basevertex)) _func)(mode, count, type, indices, basevertex);
}

GLAPI void APIENTRY glDrawElementsIndirect(GLenum mode, GLenum type, const void *indirect)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[587];
   ((void (APIENTRY *)(GLenum mode, GLenum type, const void *indirect)) _func)(mode, type, indirect);
}

GLAPI void APIENTRY glDrawElementsInstanced(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei instancecount)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[588];
   ((void (APIENTRY *)(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei instancecount)) _func)(mode, count, type, indices, instancecount);
}

GLAPI void APIENTRY glDrawElementsInstancedBaseInstance(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei instancecount, GLuint baseinstance)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[591];
   ((void (APIENTRY *)(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei instancecount, GLuint baseinstance)) _func)(mode, count, type, indices, instancecount, baseinstance);
}

GLAPI void APIENTRY glDrawElementsInstancedBaseVertex(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei instancecount, GLint basevertex)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[593];
   ((void (APIENTRY *)(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei instancecount, GLint basevertex)) _func)(mode, count, type, indices, instancecount, basevertex);
}

GLAPI void APIENTRY glDrawElementsInstancedBaseVertexBaseInstance(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei instancecount, GLint basevertex, GLuint baseinstance)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[594];
   ((void (APIENTRY *)(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei instancecount, GLint basevertex, GLuint baseinstance)) _func)(mode, count, type, indices, instancecount, basevertex, baseinstance);
}

GLAPI void APIENTRY glDrawPixels(GLsizei width, GLsizei height, GLenum format, GLenum type, const void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[604];
   ((void (APIENTRY *)(GLsizei width, GLsizei height, GLenum format, GLenum type, const void *pixels)) _func)(width, height, format, type, pixels);
}

GLAPI void APIENTRY glDrawRangeElements(GLenum mode, GLuint start, GLuint end, GLsizei count, GLenum type, const void *indices)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[607];
   ((void (APIENTRY *)(GLenum mode, GLuint start, GLuint end, GLsizei count, GLenum type, const void *indices)) _func)(mode, start, end, count, type, indices);
}

GLAPI void APIENTRY glDrawRangeElementsBaseVertex(GLenum mode, GLuint start, GLuint end, GLsizei count, GLenum type, const void *indices, GLint basevertex)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[608];
   ((void (APIENTRY *)(GLenum mode, GLuint start, GLuint end, GLsizei count, GLenum type, const void *indices, GLint basevertex)) _func)(mode, start, end, count, type, indices, basevertex);
}

GLAPI void APIENTRY glDrawTransformFeedback(GLenum mode, GLuint id)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[621];
   ((void (APIENTRY *)(GLenum mode, GLuint id)) _func)(mode, id);
}

GLAPI void APIENTRY glDrawTransformFeedbackInstanced(GLenum mode, GLuint id, GLsizei instancecount)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[623];
   ((void (APIENTRY *)(GLenum mode, GLuint id, GLsizei instancecount)) _func)(mode, id, instancecount);
}

GLAPI void APIENTRY glDrawTransformFeedbackStream(GLenum mode, GLuint id, GLuint stream)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[626];
   ((void (APIENTRY *)(GLenum mode, GLuint id, GLuint stream)) _func)(mode, id, stream);
}

GLAPI void APIENTRY glDrawTransformFeedbackStreamInstanced(GLenum mode, GLuint id, GLuint stream, GLsizei instancecount)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[627];
   ((void (APIENTRY *)(GLenum mode, GLuint id, GLuint stream, GLsizei instancecount)) _func)(mode, id, stream, instancecount);
}

GLAPI void APIENTRY glEdgeFlag(GLboolean flag)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[633];
   ((void (APIENTRY *)(GLboolean flag)) _func)(flag);
}

GLAPI void APIENTRY glEdgeFlagPointer(GLsizei stride, const void *pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[635];
   ((void (APIENTRY *)(GLsizei stride, const void *pointer)) _func)(stride, pointer);
}

GLAPI void APIENTRY glEdgeFlagv(const GLboolean *flag)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[638];
   ((void (APIENTRY *)(const GLboolean *flag)) _func)(flag);
}

GLAPI void APIENTRY glEnable(GLenum cap)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[641];
   ((void (APIENTRY *)(GLenum cap)) _func)(cap);
}

GLAPI void APIENTRY glEnableClientState(GLenum array)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[642];
   ((void (APIENTRY *)(GLenum array)) _func)(array);
}

GLAPI void APIENTRY glEnableVertexArrayAttrib(GLuint vaobj, GLuint index)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[648];
   ((void (APIENTRY *)(GLuint vaobj, GLuint index)) _func)(vaobj, index);
}

GLAPI void APIENTRY glEnableVertexAttribArray(GLuint index)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[652];
   ((void (APIENTRY *)(GLuint index)) _func)(index);
}

GLAPI void APIENTRY glEnablei(GLenum target, GLuint index)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[654];
   ((void (APIENTRY *)(GLenum target, GLuint index)) _func)(target, index);
}

GLAPI void APIENTRY glEnd(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[658];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glEndConditionalRender(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[659];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glEndList(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[663];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glEndQuery(GLenum target)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[667];
   ((void (APIENTRY *)(GLenum target)) _func)(target);
}

GLAPI void APIENTRY glEndQueryIndexed(GLenum target, GLuint index)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[670];
   ((void (APIENTRY *)(GLenum target, GLuint index)) _func)(target, index);
}

GLAPI void APIENTRY glEndTransformFeedback(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[672];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glEvalCoord1d(GLdouble u)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[677];
   ((void (APIENTRY *)(GLdouble u)) _func)(u);
}

GLAPI void APIENTRY glEvalCoord1dv(const GLdouble *u)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[678];
   ((void (APIENTRY *)(const GLdouble *u)) _func)(u);
}

GLAPI void APIENTRY glEvalCoord1f(GLfloat u)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[679];
   ((void (APIENTRY *)(GLfloat u)) _func)(u);
}

GLAPI void APIENTRY glEvalCoord1fv(const GLfloat *u)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[680];
   ((void (APIENTRY *)(const GLfloat *u)) _func)(u);
}

GLAPI void APIENTRY glEvalCoord2d(GLdouble u, GLdouble v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[683];
   ((void (APIENTRY *)(GLdouble u, GLdouble v)) _func)(u, v);
}

GLAPI void APIENTRY glEvalCoord2dv(const GLdouble *u)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[684];
   ((void (APIENTRY *)(const GLdouble *u)) _func)(u);
}

GLAPI void APIENTRY glEvalCoord2f(GLfloat u, GLfloat v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[685];
   ((void (APIENTRY *)(GLfloat u, GLfloat v)) _func)(u, v);
}

GLAPI void APIENTRY glEvalCoord2fv(const GLfloat *u)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[686];
   ((void (APIENTRY *)(const GLfloat *u)) _func)(u);
}

GLAPI void APIENTRY glEvalMesh1(GLenum mode, GLint i1, GLint i2)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[690];
   ((void (APIENTRY *)(GLenum mode, GLint i1, GLint i2)) _func)(mode, i1, i2);
}

GLAPI void APIENTRY glEvalMesh2(GLenum mode, GLint i1, GLint i2, GLint j1, GLint j2)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[691];
   ((void (APIENTRY *)(GLenum mode, GLint i1, GLint i2, GLint j1, GLint j2)) _func)(mode, i1, i2, j1, j2);
}

GLAPI void APIENTRY glEvalPoint1(GLint i)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[692];
   ((void (APIENTRY *)(GLint i)) _func)(i);
}

GLAPI void APIENTRY glEvalPoint2(GLint i, GLint j)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[693];
   ((void (APIENTRY *)(GLint i, GLint j)) _func)(i, j);
}

GLAPI void APIENTRY glFeedbackBuffer(GLsizei size, GLenum type, GLfloat *buffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[710];
   ((void (APIENTRY *)(GLsizei size, GLenum type, GLfloat *buffer)) _func)(size, type, buffer);
}

GLAPI GLsync APIENTRY glFenceSync(GLenum condition, GLbitfield flags)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[712];
   return ((GLsync (APIENTRY *)(GLenum condition, GLbitfield flags)) _func)(condition, flags);
}

GLAPI void APIENTRY glFinish(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[716];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glFlush(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[722];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glFlushMappedBufferRange(GLenum target, GLintptr offset, GLsizeiptr length)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[723];
   ((void (APIENTRY *)(GLenum target, GLintptr offset, GLsizeiptr length)) _func)(target, offset, length);
}

GLAPI void APIENTRY glFlushMappedNamedBufferRange(GLuint buffer, GLintptr offset, GLsizeiptr length)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[726];
   ((void (APIENTRY *)(GLuint buffer, GLintptr offset, GLsizeiptr length)) _func)(buffer, offset, length);
}

GLAPI void APIENTRY glFogCoordPointer(GLenum type, GLsizei stride, const void *pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[734];
   ((void (APIENTRY *)(GLenum type, GLsizei stride, const void *pointer)) _func)(type, stride, pointer);
}

GLAPI void APIENTRY glFogCoordd(GLdouble coord)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[737];
   ((void (APIENTRY *)(GLdouble coord)) _func)(coord);
}

GLAPI void APIENTRY glFogCoorddv(const GLdouble *coord)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[739];
   ((void (APIENTRY *)(const GLdouble *coord)) _func)(coord);
}

GLAPI void APIENTRY glFogCoordf(GLfloat coord)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[741];
   ((void (APIENTRY *)(GLfloat coord)) _func)(coord);
}

GLAPI void APIENTRY glFogCoordfv(const GLfloat *coord)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[743];
   ((void (APIENTRY *)(const GLfloat *coord)) _func)(coord);
}

GLAPI void APIENTRY glFogf(GLenum pname, GLfloat param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[748];
   ((void (APIENTRY *)(GLenum pname, GLfloat param)) _func)(pname, param);
}

GLAPI void APIENTRY glFogfv(GLenum pname, const GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[749];
   ((void (APIENTRY *)(GLenum pname, const GLfloat *params)) _func)(pname, params);
}

GLAPI void APIENTRY glFogi(GLenum pname, GLint param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[750];
   ((void (APIENTRY *)(GLenum pname, GLint param)) _func)(pname, param);
}

GLAPI void APIENTRY glFogiv(GLenum pname, const GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[751];
   ((void (APIENTRY *)(GLenum pname, const GLint *params)) _func)(pname, params);
}

GLAPI void APIENTRY glFramebufferParameteri(GLenum target, GLenum pname, GLint param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[778];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLint param)) _func)(target, pname, param);
}

GLAPI void APIENTRY glFramebufferRenderbuffer(GLenum target, GLenum attachment, GLenum renderbuffertarget, GLuint renderbuffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[782];
   ((void (APIENTRY *)(GLenum target, GLenum attachment, GLenum renderbuffertarget, GLuint renderbuffer)) _func)(target, attachment, renderbuffertarget, renderbuffer);
}

GLAPI void APIENTRY glFramebufferTexture(GLenum target, GLenum attachment, GLuint texture, GLint level)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[789];
   ((void (APIENTRY *)(GLenum target, GLenum attachment, GLuint texture, GLint level)) _func)(target, attachment, texture, level);
}

GLAPI void APIENTRY glFramebufferTexture1D(GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[790];
   ((void (APIENTRY *)(GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level)) _func)(target, attachment, textarget, texture, level);
}

GLAPI void APIENTRY glFramebufferTexture2D(GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[792];
   ((void (APIENTRY *)(GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level)) _func)(target, attachment, textarget, texture, level);
}

GLAPI void APIENTRY glFramebufferTexture3D(GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level, GLint zoffset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[798];
   ((void (APIENTRY *)(GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level, GLint zoffset)) _func)(target, attachment, textarget, texture, level, zoffset);
}

GLAPI void APIENTRY glFramebufferTextureLayer(GLenum target, GLenum attachment, GLuint texture, GLint level, GLint layer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[805];
   ((void (APIENTRY *)(GLenum target, GLenum attachment, GLuint texture, GLint level, GLint layer)) _func)(target, attachment, texture, level, layer);
}

GLAPI void APIENTRY glFrontFace(GLenum mode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[814];
   ((void (APIENTRY *)(GLenum mode)) _func)(mode);
}

GLAPI void APIENTRY glFrustum(GLdouble left, GLdouble right, GLdouble bottom, GLdouble top, GLdouble zNear, GLdouble zFar)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[815];
   ((void (APIENTRY *)(GLdouble left, GLdouble right, GLdouble bottom, GLdouble top, GLdouble zNear, GLdouble zFar)) _func)(left, right, bottom, top, zNear, zFar);
}

GLAPI void APIENTRY glGenBuffers(GLsizei n, GLuint *buffers)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[821];
   ((void (APIENTRY *)(GLsizei n, GLuint *buffers)) _func)(n, buffers);
}

GLAPI void APIENTRY glGenFramebuffers(GLsizei n, GLuint *framebuffers)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[826];
   ((void (APIENTRY *)(GLsizei n, GLuint *framebuffers)) _func)(n, framebuffers);
}

GLAPI GLuint APIENTRY glGenLists(GLsizei range)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[829];
   return ((GLuint (APIENTRY *)(GLsizei range)) _func)(range);
}

GLAPI void APIENTRY glGenProgramPipelines(GLsizei n, GLuint *pipelines)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[834];
   ((void (APIENTRY *)(GLsizei n, GLuint *pipelines)) _func)(n, pipelines);
}

GLAPI void APIENTRY glGenQueries(GLsizei n, GLuint *ids)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[838];
   ((void (APIENTRY *)(GLsizei n, GLuint *ids)) _func)(n, ids);
}

GLAPI void APIENTRY glGenRenderbuffers(GLsizei n, GLuint *renderbuffers)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[842];
   ((void (APIENTRY *)(GLsizei n, GLuint *renderbuffers)) _func)(n, renderbuffers);
}

GLAPI void APIENTRY glGenSamplers(GLsizei count, GLuint *samplers)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[845];
   ((void (APIENTRY *)(GLsizei count, GLuint *samplers)) _func)(count, samplers);
}

GLAPI void APIENTRY glGenTextures(GLsizei n, GLuint *textures)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[848];
   ((void (APIENTRY *)(GLsizei n, GLuint *textures)) _func)(n, textures);
}

GLAPI void APIENTRY glGenTransformFeedbacks(GLsizei n, GLuint *ids)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[850];
   ((void (APIENTRY *)(GLsizei n, GLuint *ids)) _func)(n, ids);
}

GLAPI void APIENTRY glGenVertexArrays(GLsizei n, GLuint *arrays)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[853];
   ((void (APIENTRY *)(GLsizei n, GLuint *arrays)) _func)(n, arrays);
}

GLAPI void APIENTRY glGenerateMipmap(GLenum target)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[857];
   ((void (APIENTRY *)(GLenum target)) _func)(target);
}

GLAPI void APIENTRY glGenerateTextureMipmap(GLuint texture)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[861];
   ((void (APIENTRY *)(GLuint texture)) _func)(texture);
}

GLAPI void APIENTRY glGetActiveAtomicCounterBufferiv(GLuint program, GLuint bufferIndex, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[863];
   ((void (APIENTRY *)(GLuint program, GLuint bufferIndex, GLenum pname, GLint *params)) _func)(program, bufferIndex, pname, params);
}

GLAPI void APIENTRY glGetActiveAttrib(GLuint program, GLuint index, GLsizei bufSize, GLsizei *length, GLint *size, GLenum *type, GLchar *name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[864];
   ((void (APIENTRY *)(GLuint program, GLuint index, GLsizei bufSize, GLsizei *length, GLint *size, GLenum *type, GLchar *name)) _func)(program, index, bufSize, length, size, type, name);
}

GLAPI void APIENTRY glGetActiveSubroutineName(GLuint program, GLenum shadertype, GLuint index, GLsizei bufSize, GLsizei *length, GLchar *name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[866];
   ((void (APIENTRY *)(GLuint program, GLenum shadertype, GLuint index, GLsizei bufSize, GLsizei *length, GLchar *name)) _func)(program, shadertype, index, bufSize, length, name);
}

GLAPI void APIENTRY glGetActiveSubroutineUniformName(GLuint program, GLenum shadertype, GLuint index, GLsizei bufSize, GLsizei *length, GLchar *name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[867];
   ((void (APIENTRY *)(GLuint program, GLenum shadertype, GLuint index, GLsizei bufSize, GLsizei *length, GLchar *name)) _func)(program, shadertype, index, bufSize, length, name);
}

GLAPI void APIENTRY glGetActiveSubroutineUniformiv(GLuint program, GLenum shadertype, GLuint index, GLenum pname, GLint *values)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[868];
   ((void (APIENTRY *)(GLuint program, GLenum shadertype, GLuint index, GLenum pname, GLint *values)) _func)(program, shadertype, index, pname, values);
}

GLAPI void APIENTRY glGetActiveUniform(GLuint program, GLuint index, GLsizei bufSize, GLsizei *length, GLint *size, GLenum *type, GLchar *name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[869];
   ((void (APIENTRY *)(GLuint program, GLuint index, GLsizei bufSize, GLsizei *length, GLint *size, GLenum *type, GLchar *name)) _func)(program, index, bufSize, length, size, type, name);
}

GLAPI void APIENTRY glGetActiveUniformBlockName(GLuint program, GLuint uniformBlockIndex, GLsizei bufSize, GLsizei *length, GLchar *uniformBlockName)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[871];
   ((void (APIENTRY *)(GLuint program, GLuint uniformBlockIndex, GLsizei bufSize, GLsizei *length, GLchar *uniformBlockName)) _func)(program, uniformBlockIndex, bufSize, length, uniformBlockName);
}

GLAPI void APIENTRY glGetActiveUniformBlockiv(GLuint program, GLuint uniformBlockIndex, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[872];
   ((void (APIENTRY *)(GLuint program, GLuint uniformBlockIndex, GLenum pname, GLint *params)) _func)(program, uniformBlockIndex, pname, params);
}

GLAPI void APIENTRY glGetActiveUniformName(GLuint program, GLuint uniformIndex, GLsizei bufSize, GLsizei *length, GLchar *uniformName)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[873];
   ((void (APIENTRY *)(GLuint program, GLuint uniformIndex, GLsizei bufSize, GLsizei *length, GLchar *uniformName)) _func)(program, uniformIndex, bufSize, length, uniformName);
}

GLAPI void APIENTRY glGetActiveUniformsiv(GLuint program, GLsizei uniformCount, const GLuint *uniformIndices, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[874];
   ((void (APIENTRY *)(GLuint program, GLsizei uniformCount, const GLuint *uniformIndices, GLenum pname, GLint *params)) _func)(program, uniformCount, uniformIndices, pname, params);
}

GLAPI void APIENTRY glGetAttachedShaders(GLuint program, GLsizei maxCount, GLsizei *count, GLuint *shaders)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[879];
   ((void (APIENTRY *)(GLuint program, GLsizei maxCount, GLsizei *count, GLuint *shaders)) _func)(program, maxCount, count, shaders);
}

GLAPI GLint APIENTRY glGetAttribLocation(GLuint program, const GLchar *name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[880];
   return ((GLint (APIENTRY *)(GLuint program, const GLchar *name)) _func)(program, name);
}

GLAPI void APIENTRY glGetBooleani_v(GLenum target, GLuint index, GLboolean *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[883];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLboolean *data)) _func)(target, index, data);
}

GLAPI void APIENTRY glGetBooleanv(GLenum pname, GLboolean *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[884];
   ((void (APIENTRY *)(GLenum pname, GLboolean *data)) _func)(pname, data);
}

GLAPI void APIENTRY glGetBufferParameteri64v(GLenum target, GLenum pname, GLint64 *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[885];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLint64 *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetBufferParameteriv(GLenum target, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[886];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLint *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetBufferPointerv(GLenum target, GLenum pname, void **params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[889];
   ((void (APIENTRY *)(GLenum target, GLenum pname, void **params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetBufferSubData(GLenum target, GLintptr offset, GLsizeiptr size, void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[892];
   ((void (APIENTRY *)(GLenum target, GLintptr offset, GLsizeiptr size, void *data)) _func)(target, offset, size, data);
}

GLAPI void APIENTRY glGetClipPlane(GLenum plane, GLdouble *equation)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[894];
   ((void (APIENTRY *)(GLenum plane, GLdouble *equation)) _func)(plane, equation);
}

GLAPI void APIENTRY glGetCompressedTexImage(GLenum target, GLint level, void *img)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[915];
   ((void (APIENTRY *)(GLenum target, GLint level, void *img)) _func)(target, level, img);
}

GLAPI void APIENTRY glGetCompressedTextureImage(GLuint texture, GLint level, GLsizei bufSize, void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[918];
   ((void (APIENTRY *)(GLuint texture, GLint level, GLsizei bufSize, void *pixels)) _func)(texture, level, bufSize, pixels);
}

GLAPI void APIENTRY glGetCompressedTextureSubImage(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLsizei bufSize, void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[920];
   ((void (APIENTRY *)(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLsizei bufSize, void *pixels)) _func)(texture, level, xoffset, yoffset, zoffset, width, height, depth, bufSize, pixels);
}

GLAPI GLuint APIENTRY glGetDebugMessageLog(GLuint count, GLsizei bufSize, GLenum *sources, GLenum *types, GLuint *ids, GLenum *severities, GLsizei *lengths, GLchar *messageLog)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[929];
   return ((GLuint (APIENTRY *)(GLuint count, GLsizei bufSize, GLenum *sources, GLenum *types, GLuint *ids, GLenum *severities, GLsizei *lengths, GLchar *messageLog)) _func)(count, bufSize, sources, types, ids, severities, lengths, messageLog);
}

GLAPI void APIENTRY glGetDoublei_v(GLenum target, GLuint index, GLdouble *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[936];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLdouble *data)) _func)(target, index, data);
}

GLAPI void APIENTRY glGetDoublev(GLenum pname, GLdouble *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[938];
   ((void (APIENTRY *)(GLenum pname, GLdouble *data)) _func)(pname, data);
}

GLAPI GLenum APIENTRY glGetError(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[941];
   return ((GLenum (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glGetFloati_v(GLenum target, GLuint index, GLfloat *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[949];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLfloat *data)) _func)(target, index, data);
}

GLAPI void APIENTRY glGetFloatv(GLenum pname, GLfloat *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[953];
   ((void (APIENTRY *)(GLenum pname, GLfloat *data)) _func)(pname, data);
}

GLAPI GLint APIENTRY glGetFragDataIndex(GLuint program, const GLchar *name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[955];
   return ((GLint (APIENTRY *)(GLuint program, const GLchar *name)) _func)(program, name);
}

GLAPI GLint APIENTRY glGetFragDataLocation(GLuint program, const GLchar *name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[957];
   return ((GLint (APIENTRY *)(GLuint program, const GLchar *name)) _func)(program, name);
}

GLAPI void APIENTRY glGetFramebufferAttachmentParameteriv(GLenum target, GLenum attachment, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[964];
   ((void (APIENTRY *)(GLenum target, GLenum attachment, GLenum pname, GLint *params)) _func)(target, attachment, pname, params);
}

GLAPI void APIENTRY glGetFramebufferParameteriv(GLenum target, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[968];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLint *params)) _func)(target, pname, params);
}

GLAPI GLenum APIENTRY glGetGraphicsResetStatus(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[972];
   return ((GLenum (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glGetInteger64i_v(GLenum target, GLuint index, GLint64 *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[990];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLint64 *data)) _func)(target, index, data);
}

GLAPI void APIENTRY glGetInteger64v(GLenum pname, GLint64 *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[991];
   ((void (APIENTRY *)(GLenum pname, GLint64 *data)) _func)(pname, data);
}

GLAPI void APIENTRY glGetIntegeri_v(GLenum target, GLuint index, GLint *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[995];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLint *data)) _func)(target, index, data);
}

GLAPI void APIENTRY glGetIntegerv(GLenum pname, GLint *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[999];
   ((void (APIENTRY *)(GLenum pname, GLint *data)) _func)(pname, data);
}

GLAPI void APIENTRY glGetInternalformati64v(GLenum target, GLenum internalformat, GLenum pname, GLsizei count, GLint64 *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1001];
   ((void (APIENTRY *)(GLenum target, GLenum internalformat, GLenum pname, GLsizei count, GLint64 *params)) _func)(target, internalformat, pname, count, params);
}

GLAPI void APIENTRY glGetInternalformativ(GLenum target, GLenum internalformat, GLenum pname, GLsizei count, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1002];
   ((void (APIENTRY *)(GLenum target, GLenum internalformat, GLenum pname, GLsizei count, GLint *params)) _func)(target, internalformat, pname, count, params);
}

GLAPI void APIENTRY glGetLightfv(GLenum light, GLenum pname, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1006];
   ((void (APIENTRY *)(GLenum light, GLenum pname, GLfloat *params)) _func)(light, pname, params);
}

GLAPI void APIENTRY glGetLightiv(GLenum light, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1007];
   ((void (APIENTRY *)(GLenum light, GLenum pname, GLint *params)) _func)(light, pname, params);
}

GLAPI void APIENTRY glGetMapdv(GLenum target, GLenum query, GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1021];
   ((void (APIENTRY *)(GLenum target, GLenum query, GLdouble *v)) _func)(target, query, v);
}

GLAPI void APIENTRY glGetMapfv(GLenum target, GLenum query, GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1022];
   ((void (APIENTRY *)(GLenum target, GLenum query, GLfloat *v)) _func)(target, query, v);
}

GLAPI void APIENTRY glGetMapiv(GLenum target, GLenum query, GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1023];
   ((void (APIENTRY *)(GLenum target, GLenum query, GLint *v)) _func)(target, query, v);
}

GLAPI void APIENTRY glGetMaterialfv(GLenum face, GLenum pname, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1025];
   ((void (APIENTRY *)(GLenum face, GLenum pname, GLfloat *params)) _func)(face, pname, params);
}

GLAPI void APIENTRY glGetMaterialiv(GLenum face, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1026];
   ((void (APIENTRY *)(GLenum face, GLenum pname, GLint *params)) _func)(face, pname, params);
}

GLAPI void APIENTRY glGetMultisamplefv(GLenum pname, GLuint index, GLfloat *val)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1050];
   ((void (APIENTRY *)(GLenum pname, GLuint index, GLfloat *val)) _func)(pname, index, val);
}

GLAPI void APIENTRY glGetNamedBufferParameteri64v(GLuint buffer, GLenum pname, GLint64 *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1052];
   ((void (APIENTRY *)(GLuint buffer, GLenum pname, GLint64 *params)) _func)(buffer, pname, params);
}

GLAPI void APIENTRY glGetNamedBufferParameteriv(GLuint buffer, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1054];
   ((void (APIENTRY *)(GLuint buffer, GLenum pname, GLint *params)) _func)(buffer, pname, params);
}

GLAPI void APIENTRY glGetNamedBufferPointerv(GLuint buffer, GLenum pname, void **params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1057];
   ((void (APIENTRY *)(GLuint buffer, GLenum pname, void **params)) _func)(buffer, pname, params);
}

GLAPI void APIENTRY glGetNamedBufferSubData(GLuint buffer, GLintptr offset, GLsizeiptr size, void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1059];
   ((void (APIENTRY *)(GLuint buffer, GLintptr offset, GLsizeiptr size, void *data)) _func)(buffer, offset, size, data);
}

GLAPI void APIENTRY glGetNamedFramebufferAttachmentParameteriv(GLuint framebuffer, GLenum attachment, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1061];
   ((void (APIENTRY *)(GLuint framebuffer, GLenum attachment, GLenum pname, GLint *params)) _func)(framebuffer, attachment, pname, params);
}

GLAPI void APIENTRY glGetNamedFramebufferParameteriv(GLuint framebuffer, GLenum pname, GLint *param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1064];
   ((void (APIENTRY *)(GLuint framebuffer, GLenum pname, GLint *param)) _func)(framebuffer, pname, param);
}

GLAPI void APIENTRY glGetNamedRenderbufferParameteriv(GLuint renderbuffer, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1072];
   ((void (APIENTRY *)(GLuint renderbuffer, GLenum pname, GLint *params)) _func)(renderbuffer, pname, params);
}

GLAPI void APIENTRY glGetObjectLabel(GLenum identifier, GLuint name, GLsizei bufSize, GLsizei *length, GLchar *label)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1079];
   ((void (APIENTRY *)(GLenum identifier, GLuint name, GLsizei bufSize, GLsizei *length, GLchar *label)) _func)(identifier, name, bufSize, length, label);
}

GLAPI void APIENTRY glGetObjectPtrLabel(const void *ptr, GLsizei bufSize, GLsizei *length, GLchar *label)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1086];
   ((void (APIENTRY *)(const void *ptr, GLsizei bufSize, GLsizei *length, GLchar *label)) _func)(ptr, bufSize, length, label);
}

GLAPI void APIENTRY glGetPixelMapfv(GLenum map, GLfloat *values)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1114];
   ((void (APIENTRY *)(GLenum map, GLfloat *values)) _func)(map, values);
}

GLAPI void APIENTRY glGetPixelMapuiv(GLenum map, GLuint *values)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1115];
   ((void (APIENTRY *)(GLenum map, GLuint *values)) _func)(map, values);
}

GLAPI void APIENTRY glGetPixelMapusv(GLenum map, GLushort *values)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1116];
   ((void (APIENTRY *)(GLenum map, GLushort *values)) _func)(map, values);
}

GLAPI void APIENTRY glGetPointerv(GLenum pname, void **params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1124];
   ((void (APIENTRY *)(GLenum pname, void **params)) _func)(pname, params);
}

GLAPI void APIENTRY glGetPolygonStipple(GLubyte *mask)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1128];
   ((void (APIENTRY *)(GLubyte *mask)) _func)(mask);
}

GLAPI void APIENTRY glGetProgramBinary(GLuint program, GLsizei bufSize, GLsizei *length, GLenum *binaryFormat, void *binary)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1129];
   ((void (APIENTRY *)(GLuint program, GLsizei bufSize, GLsizei *length, GLenum *binaryFormat, void *binary)) _func)(program, bufSize, length, binaryFormat, binary);
}

GLAPI void APIENTRY glGetProgramInfoLog(GLuint program, GLsizei bufSize, GLsizei *length, GLchar *infoLog)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1135];
   ((void (APIENTRY *)(GLuint program, GLsizei bufSize, GLsizei *length, GLchar *infoLog)) _func)(program, bufSize, length, infoLog);
}

GLAPI void APIENTRY glGetProgramInterfaceiv(GLuint program, GLenum programInterface, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1136];
   ((void (APIENTRY *)(GLuint program, GLenum programInterface, GLenum pname, GLint *params)) _func)(program, programInterface, pname, params);
}

GLAPI void APIENTRY glGetProgramPipelineInfoLog(GLuint pipeline, GLsizei bufSize, GLsizei *length, GLchar *infoLog)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1145];
   ((void (APIENTRY *)(GLuint pipeline, GLsizei bufSize, GLsizei *length, GLchar *infoLog)) _func)(pipeline, bufSize, length, infoLog);
}

GLAPI void APIENTRY glGetProgramPipelineiv(GLuint pipeline, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1147];
   ((void (APIENTRY *)(GLuint pipeline, GLenum pname, GLint *params)) _func)(pipeline, pname, params);
}

GLAPI GLuint APIENTRY glGetProgramResourceIndex(GLuint program, GLenum programInterface, const GLchar *name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1149];
   return ((GLuint (APIENTRY *)(GLuint program, GLenum programInterface, const GLchar *name)) _func)(program, programInterface, name);
}

GLAPI GLint APIENTRY glGetProgramResourceLocation(GLuint program, GLenum programInterface, const GLchar *name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1150];
   return ((GLint (APIENTRY *)(GLuint program, GLenum programInterface, const GLchar *name)) _func)(program, programInterface, name);
}

GLAPI GLint APIENTRY glGetProgramResourceLocationIndex(GLuint program, GLenum programInterface, const GLchar *name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1151];
   return ((GLint (APIENTRY *)(GLuint program, GLenum programInterface, const GLchar *name)) _func)(program, programInterface, name);
}

GLAPI void APIENTRY glGetProgramResourceName(GLuint program, GLenum programInterface, GLuint index, GLsizei bufSize, GLsizei *length, GLchar *name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1153];
   ((void (APIENTRY *)(GLuint program, GLenum programInterface, GLuint index, GLsizei bufSize, GLsizei *length, GLchar *name)) _func)(program, programInterface, index, bufSize, length, name);
}

GLAPI void APIENTRY glGetProgramResourceiv(GLuint program, GLenum programInterface, GLuint index, GLsizei propCount, const GLenum *props, GLsizei count, GLsizei *length, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1155];
   ((void (APIENTRY *)(GLuint program, GLenum programInterface, GLuint index, GLsizei propCount, const GLenum *props, GLsizei count, GLsizei *length, GLint *params)) _func)(program, programInterface, index, propCount, props, count, length, params);
}

GLAPI void APIENTRY glGetProgramStageiv(GLuint program, GLenum shadertype, GLenum pname, GLint *values)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1156];
   ((void (APIENTRY *)(GLuint program, GLenum shadertype, GLenum pname, GLint *values)) _func)(program, shadertype, pname, values);
}

GLAPI void APIENTRY glGetProgramiv(GLuint program, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1160];
   ((void (APIENTRY *)(GLuint program, GLenum pname, GLint *params)) _func)(program, pname, params);
}

GLAPI void APIENTRY glGetQueryBufferObjecti64v(GLuint id, GLuint buffer, GLenum pname, GLintptr offset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1163];
   ((void (APIENTRY *)(GLuint id, GLuint buffer, GLenum pname, GLintptr offset)) _func)(id, buffer, pname, offset);
}

GLAPI void APIENTRY glGetQueryBufferObjectiv(GLuint id, GLuint buffer, GLenum pname, GLintptr offset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1164];
   ((void (APIENTRY *)(GLuint id, GLuint buffer, GLenum pname, GLintptr offset)) _func)(id, buffer, pname, offset);
}

GLAPI void APIENTRY glGetQueryBufferObjectui64v(GLuint id, GLuint buffer, GLenum pname, GLintptr offset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1165];
   ((void (APIENTRY *)(GLuint id, GLuint buffer, GLenum pname, GLintptr offset)) _func)(id, buffer, pname, offset);
}

GLAPI void APIENTRY glGetQueryBufferObjectuiv(GLuint id, GLuint buffer, GLenum pname, GLintptr offset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1166];
   ((void (APIENTRY *)(GLuint id, GLuint buffer, GLenum pname, GLintptr offset)) _func)(id, buffer, pname, offset);
}

GLAPI void APIENTRY glGetQueryIndexediv(GLenum target, GLuint index, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1167];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLenum pname, GLint *params)) _func)(target, index, pname, params);
}

GLAPI void APIENTRY glGetQueryObjecti64v(GLuint id, GLenum pname, GLint64 *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1168];
   ((void (APIENTRY *)(GLuint id, GLenum pname, GLint64 *params)) _func)(id, pname, params);
}

GLAPI void APIENTRY glGetQueryObjectiv(GLuint id, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1170];
   ((void (APIENTRY *)(GLuint id, GLenum pname, GLint *params)) _func)(id, pname, params);
}

GLAPI void APIENTRY glGetQueryObjectui64v(GLuint id, GLenum pname, GLuint64 *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1173];
   ((void (APIENTRY *)(GLuint id, GLenum pname, GLuint64 *params)) _func)(id, pname, params);
}

GLAPI void APIENTRY glGetQueryObjectuiv(GLuint id, GLenum pname, GLuint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1176];
   ((void (APIENTRY *)(GLuint id, GLenum pname, GLuint *params)) _func)(id, pname, params);
}

GLAPI void APIENTRY glGetQueryiv(GLenum target, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1179];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLint *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetRenderbufferParameteriv(GLenum target, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1182];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLint *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetSamplerParameterIiv(GLuint sampler, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1185];
   ((void (APIENTRY *)(GLuint sampler, GLenum pname, GLint *params)) _func)(sampler, pname, params);
}

GLAPI void APIENTRY glGetSamplerParameterIuiv(GLuint sampler, GLenum pname, GLuint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1188];
   ((void (APIENTRY *)(GLuint sampler, GLenum pname, GLuint *params)) _func)(sampler, pname, params);
}

GLAPI void APIENTRY glGetSamplerParameterfv(GLuint sampler, GLenum pname, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1191];
   ((void (APIENTRY *)(GLuint sampler, GLenum pname, GLfloat *params)) _func)(sampler, pname, params);
}

GLAPI void APIENTRY glGetSamplerParameteriv(GLuint sampler, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1192];
   ((void (APIENTRY *)(GLuint sampler, GLenum pname, GLint *params)) _func)(sampler, pname, params);
}

GLAPI void APIENTRY glGetShaderInfoLog(GLuint shader, GLsizei bufSize, GLsizei *length, GLchar *infoLog)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1197];
   ((void (APIENTRY *)(GLuint shader, GLsizei bufSize, GLsizei *length, GLchar *infoLog)) _func)(shader, bufSize, length, infoLog);
}

GLAPI void APIENTRY glGetShaderPrecisionFormat(GLenum shadertype, GLenum precisiontype, GLint *range, GLint *precision)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1198];
   ((void (APIENTRY *)(GLenum shadertype, GLenum precisiontype, GLint *range, GLint *precision)) _func)(shadertype, precisiontype, range, precision);
}

GLAPI void APIENTRY glGetShaderSource(GLuint shader, GLsizei bufSize, GLsizei *length, GLchar *source)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1199];
   ((void (APIENTRY *)(GLuint shader, GLsizei bufSize, GLsizei *length, GLchar *source)) _func)(shader, bufSize, length, source);
}

GLAPI void APIENTRY glGetShaderiv(GLuint shader, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1201];
   ((void (APIENTRY *)(GLuint shader, GLenum pname, GLint *params)) _func)(shader, pname, params);
}

GLAPI const GLubyte * APIENTRY glGetString(GLenum name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1206];
   return ((const GLubyte * (APIENTRY *)(GLenum name)) _func)(name);
}

GLAPI const GLubyte * APIENTRY glGetStringi(GLenum name, GLuint index)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1207];
   return ((const GLubyte * (APIENTRY *)(GLenum name, GLuint index)) _func)(name, index);
}

GLAPI GLuint APIENTRY glGetSubroutineIndex(GLuint program, GLenum shadertype, const GLchar *name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1208];
   return ((GLuint (APIENTRY *)(GLuint program, GLenum shadertype, const GLchar *name)) _func)(program, shadertype, name);
}

GLAPI GLint APIENTRY glGetSubroutineUniformLocation(GLuint program, GLenum shadertype, const GLchar *name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1209];
   return ((GLint (APIENTRY *)(GLuint program, GLenum shadertype, const GLchar *name)) _func)(program, shadertype, name);
}

GLAPI void APIENTRY glGetSynciv(GLsync sync, GLenum pname, GLsizei count, GLsizei *length, GLint *values)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1210];
   ((void (APIENTRY *)(GLsync sync, GLenum pname, GLsizei count, GLsizei *length, GLint *values)) _func)(sync, pname, count, length, values);
}

GLAPI void APIENTRY glGetTexEnvfv(GLenum target, GLenum pname, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1215];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLfloat *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetTexEnviv(GLenum target, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1216];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLint *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetTexGendv(GLenum coord, GLenum pname, GLdouble *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1220];
   ((void (APIENTRY *)(GLenum coord, GLenum pname, GLdouble *params)) _func)(coord, pname, params);
}

GLAPI void APIENTRY glGetTexGenfv(GLenum coord, GLenum pname, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1221];
   ((void (APIENTRY *)(GLenum coord, GLenum pname, GLfloat *params)) _func)(coord, pname, params);
}

GLAPI void APIENTRY glGetTexGeniv(GLenum coord, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1223];
   ((void (APIENTRY *)(GLenum coord, GLenum pname, GLint *params)) _func)(coord, pname, params);
}

GLAPI void APIENTRY glGetTexImage(GLenum target, GLint level, GLenum format, GLenum type, void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1226];
   ((void (APIENTRY *)(GLenum target, GLint level, GLenum format, GLenum type, void *pixels)) _func)(target, level, format, type, pixels);
}

GLAPI void APIENTRY glGetTexLevelParameterfv(GLenum target, GLint level, GLenum pname, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1228];
   ((void (APIENTRY *)(GLenum target, GLint level, GLenum pname, GLfloat *params)) _func)(target, level, pname, params);
}

GLAPI void APIENTRY glGetTexLevelParameteriv(GLenum target, GLint level, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1230];
   ((void (APIENTRY *)(GLenum target, GLint level, GLenum pname, GLint *params)) _func)(target, level, pname, params);
}

GLAPI void APIENTRY glGetTexParameterIiv(GLenum target, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1233];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLint *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetTexParameterIuiv(GLenum target, GLenum pname, GLuint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1236];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLuint *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetTexParameterfv(GLenum target, GLenum pname, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1240];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLfloat *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetTexParameteriv(GLenum target, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1241];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLint *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetTextureImage(GLuint texture, GLint level, GLenum format, GLenum type, GLsizei bufSize, void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1247];
   ((void (APIENTRY *)(GLuint texture, GLint level, GLenum format, GLenum type, GLsizei bufSize, void *pixels)) _func)(texture, level, format, type, bufSize, pixels);
}

GLAPI void APIENTRY glGetTextureLevelParameterfv(GLuint texture, GLint level, GLenum pname, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1249];
   ((void (APIENTRY *)(GLuint texture, GLint level, GLenum pname, GLfloat *params)) _func)(texture, level, pname, params);
}

GLAPI void APIENTRY glGetTextureLevelParameteriv(GLuint texture, GLint level, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1251];
   ((void (APIENTRY *)(GLuint texture, GLint level, GLenum pname, GLint *params)) _func)(texture, level, pname, params);
}

GLAPI void APIENTRY glGetTextureParameterIiv(GLuint texture, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1253];
   ((void (APIENTRY *)(GLuint texture, GLenum pname, GLint *params)) _func)(texture, pname, params);
}

GLAPI void APIENTRY glGetTextureParameterIuiv(GLuint texture, GLenum pname, GLuint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1255];
   ((void (APIENTRY *)(GLuint texture, GLenum pname, GLuint *params)) _func)(texture, pname, params);
}

GLAPI void APIENTRY glGetTextureParameterfv(GLuint texture, GLenum pname, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1257];
   ((void (APIENTRY *)(GLuint texture, GLenum pname, GLfloat *params)) _func)(texture, pname, params);
}

GLAPI void APIENTRY glGetTextureParameteriv(GLuint texture, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1259];
   ((void (APIENTRY *)(GLuint texture, GLenum pname, GLint *params)) _func)(texture, pname, params);
}

GLAPI void APIENTRY glGetTextureSubImage(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, GLsizei bufSize, void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1264];
   ((void (APIENTRY *)(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, GLsizei bufSize, void *pixels)) _func)(texture, level, xoffset, yoffset, zoffset, width, height, depth, format, type, bufSize, pixels);
}

GLAPI void APIENTRY glGetTransformFeedbackVarying(GLuint program, GLuint index, GLsizei bufSize, GLsizei *length, GLsizei *size, GLenum *type, GLchar *name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1266];
   ((void (APIENTRY *)(GLuint program, GLuint index, GLsizei bufSize, GLsizei *length, GLsizei *size, GLenum *type, GLchar *name)) _func)(program, index, bufSize, length, size, type, name);
}

GLAPI void APIENTRY glGetTransformFeedbacki64_v(GLuint xfb, GLenum pname, GLuint index, GLint64 *param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1269];
   ((void (APIENTRY *)(GLuint xfb, GLenum pname, GLuint index, GLint64 *param)) _func)(xfb, pname, index, param);
}

GLAPI void APIENTRY glGetTransformFeedbacki_v(GLuint xfb, GLenum pname, GLuint index, GLint *param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1270];
   ((void (APIENTRY *)(GLuint xfb, GLenum pname, GLuint index, GLint *param)) _func)(xfb, pname, index, param);
}

GLAPI void APIENTRY glGetTransformFeedbackiv(GLuint xfb, GLenum pname, GLint *param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1271];
   ((void (APIENTRY *)(GLuint xfb, GLenum pname, GLint *param)) _func)(xfb, pname, param);
}

GLAPI GLuint APIENTRY glGetUniformBlockIndex(GLuint program, const GLchar *uniformBlockName)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1273];
   return ((GLuint (APIENTRY *)(GLuint program, const GLchar *uniformBlockName)) _func)(program, uniformBlockName);
}

GLAPI void APIENTRY glGetUniformIndices(GLuint program, GLsizei uniformCount, const GLchar *const *uniformNames, GLuint *uniformIndices)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1275];
   ((void (APIENTRY *)(GLuint program, GLsizei uniformCount, const GLchar *const *uniformNames, GLuint *uniformIndices)) _func)(program, uniformCount, uniformNames, uniformIndices);
}

GLAPI GLint APIENTRY glGetUniformLocation(GLuint program, const GLchar *name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1276];
   return ((GLint (APIENTRY *)(GLuint program, const GLchar *name)) _func)(program, name);
}

GLAPI void APIENTRY glGetUniformSubroutineuiv(GLenum shadertype, GLint location, GLuint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1279];
   ((void (APIENTRY *)(GLenum shadertype, GLint location, GLuint *params)) _func)(shadertype, location, params);
}

GLAPI void APIENTRY glGetUniformdv(GLuint program, GLint location, GLdouble *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1280];
   ((void (APIENTRY *)(GLuint program, GLint location, GLdouble *params)) _func)(program, location, params);
}

GLAPI void APIENTRY glGetUniformfv(GLuint program, GLint location, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1281];
   ((void (APIENTRY *)(GLuint program, GLint location, GLfloat *params)) _func)(program, location, params);
}

GLAPI void APIENTRY glGetUniformiv(GLuint program, GLint location, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1285];
   ((void (APIENTRY *)(GLuint program, GLint location, GLint *params)) _func)(program, location, params);
}

GLAPI void APIENTRY glGetUniformuiv(GLuint program, GLint location, GLuint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1289];
   ((void (APIENTRY *)(GLuint program, GLint location, GLuint *params)) _func)(program, location, params);
}

GLAPI void APIENTRY glGetVertexArrayIndexed64iv(GLuint vaobj, GLuint index, GLenum pname, GLint64 *param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1300];
   ((void (APIENTRY *)(GLuint vaobj, GLuint index, GLenum pname, GLint64 *param)) _func)(vaobj, index, pname, param);
}

GLAPI void APIENTRY glGetVertexArrayIndexediv(GLuint vaobj, GLuint index, GLenum pname, GLint *param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1301];
   ((void (APIENTRY *)(GLuint vaobj, GLuint index, GLenum pname, GLint *param)) _func)(vaobj, index, pname, param);
}

GLAPI void APIENTRY glGetVertexArrayiv(GLuint vaobj, GLenum pname, GLint *param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1306];
   ((void (APIENTRY *)(GLuint vaobj, GLenum pname, GLint *param)) _func)(vaobj, pname, param);
}

GLAPI void APIENTRY glGetVertexAttribIiv(GLuint index, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1309];
   ((void (APIENTRY *)(GLuint index, GLenum pname, GLint *params)) _func)(index, pname, params);
}

GLAPI void APIENTRY glGetVertexAttribIuiv(GLuint index, GLenum pname, GLuint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1311];
   ((void (APIENTRY *)(GLuint index, GLenum pname, GLuint *params)) _func)(index, pname, params);
}

GLAPI void APIENTRY glGetVertexAttribLdv(GLuint index, GLenum pname, GLdouble *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1313];
   ((void (APIENTRY *)(GLuint index, GLenum pname, GLdouble *params)) _func)(index, pname, params);
}

GLAPI void APIENTRY glGetVertexAttribPointerv(GLuint index, GLenum pname, void **pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1318];
   ((void (APIENTRY *)(GLuint index, GLenum pname, void **pointer)) _func)(index, pname, pointer);
}

GLAPI void APIENTRY glGetVertexAttribdv(GLuint index, GLenum pname, GLdouble *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1321];
   ((void (APIENTRY *)(GLuint index, GLenum pname, GLdouble *params)) _func)(index, pname, params);
}

GLAPI void APIENTRY glGetVertexAttribfv(GLuint index, GLenum pname, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1324];
   ((void (APIENTRY *)(GLuint index, GLenum pname, GLfloat *params)) _func)(index, pname, params);
}

GLAPI void APIENTRY glGetVertexAttribiv(GLuint index, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1327];
   ((void (APIENTRY *)(GLuint index, GLenum pname, GLint *params)) _func)(index, pname, params);
}

GLAPI void APIENTRY glGetnColorTable(GLenum target, GLenum format, GLenum type, GLsizei bufSize, void *table)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1340];
   ((void (APIENTRY *)(GLenum target, GLenum format, GLenum type, GLsizei bufSize, void *table)) _func)(target, format, type, bufSize, table);
}

GLAPI void APIENTRY glGetnCompressedTexImage(GLenum target, GLint lod, GLsizei bufSize, void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1342];
   ((void (APIENTRY *)(GLenum target, GLint lod, GLsizei bufSize, void *pixels)) _func)(target, lod, bufSize, pixels);
}

GLAPI void APIENTRY glGetnConvolutionFilter(GLenum target, GLenum format, GLenum type, GLsizei bufSize, void *image)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1344];
   ((void (APIENTRY *)(GLenum target, GLenum format, GLenum type, GLsizei bufSize, void *image)) _func)(target, format, type, bufSize, image);
}

GLAPI void APIENTRY glGetnHistogram(GLenum target, GLboolean reset, GLenum format, GLenum type, GLsizei bufSize, void *values)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1346];
   ((void (APIENTRY *)(GLenum target, GLboolean reset, GLenum format, GLenum type, GLsizei bufSize, void *values)) _func)(target, reset, format, type, bufSize, values);
}

GLAPI void APIENTRY glGetnMapdv(GLenum target, GLenum query, GLsizei bufSize, GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1348];
   ((void (APIENTRY *)(GLenum target, GLenum query, GLsizei bufSize, GLdouble *v)) _func)(target, query, bufSize, v);
}

GLAPI void APIENTRY glGetnMapfv(GLenum target, GLenum query, GLsizei bufSize, GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1350];
   ((void (APIENTRY *)(GLenum target, GLenum query, GLsizei bufSize, GLfloat *v)) _func)(target, query, bufSize, v);
}

GLAPI void APIENTRY glGetnMapiv(GLenum target, GLenum query, GLsizei bufSize, GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1352];
   ((void (APIENTRY *)(GLenum target, GLenum query, GLsizei bufSize, GLint *v)) _func)(target, query, bufSize, v);
}

GLAPI void APIENTRY glGetnMinmax(GLenum target, GLboolean reset, GLenum format, GLenum type, GLsizei bufSize, void *values)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1354];
   ((void (APIENTRY *)(GLenum target, GLboolean reset, GLenum format, GLenum type, GLsizei bufSize, void *values)) _func)(target, reset, format, type, bufSize, values);
}

GLAPI void APIENTRY glGetnPixelMapfv(GLenum map, GLsizei bufSize, GLfloat *values)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1356];
   ((void (APIENTRY *)(GLenum map, GLsizei bufSize, GLfloat *values)) _func)(map, bufSize, values);
}

GLAPI void APIENTRY glGetnPixelMapuiv(GLenum map, GLsizei bufSize, GLuint *values)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1358];
   ((void (APIENTRY *)(GLenum map, GLsizei bufSize, GLuint *values)) _func)(map, bufSize, values);
}

GLAPI void APIENTRY glGetnPixelMapusv(GLenum map, GLsizei bufSize, GLushort *values)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1360];
   ((void (APIENTRY *)(GLenum map, GLsizei bufSize, GLushort *values)) _func)(map, bufSize, values);
}

GLAPI void APIENTRY glGetnPolygonStipple(GLsizei bufSize, GLubyte *pattern)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1362];
   ((void (APIENTRY *)(GLsizei bufSize, GLubyte *pattern)) _func)(bufSize, pattern);
}

GLAPI void APIENTRY glGetnSeparableFilter(GLenum target, GLenum format, GLenum type, GLsizei rowBufSize, void *row, GLsizei columnBufSize, void *column, void *span)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1364];
   ((void (APIENTRY *)(GLenum target, GLenum format, GLenum type, GLsizei rowBufSize, void *row, GLsizei columnBufSize, void *column, void *span)) _func)(target, format, type, rowBufSize, row, columnBufSize, column, span);
}

GLAPI void APIENTRY glGetnTexImage(GLenum target, GLint level, GLenum format, GLenum type, GLsizei bufSize, void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1366];
   ((void (APIENTRY *)(GLenum target, GLint level, GLenum format, GLenum type, GLsizei bufSize, void *pixels)) _func)(target, level, format, type, bufSize, pixels);
}

GLAPI void APIENTRY glGetnUniformdv(GLuint program, GLint location, GLsizei bufSize, GLdouble *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1368];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei bufSize, GLdouble *params)) _func)(program, location, bufSize, params);
}

GLAPI void APIENTRY glGetnUniformfv(GLuint program, GLint location, GLsizei bufSize, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1370];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei bufSize, GLfloat *params)) _func)(program, location, bufSize, params);
}

GLAPI void APIENTRY glGetnUniformiv(GLuint program, GLint location, GLsizei bufSize, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1375];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei bufSize, GLint *params)) _func)(program, location, bufSize, params);
}

GLAPI void APIENTRY glGetnUniformuiv(GLuint program, GLint location, GLsizei bufSize, GLuint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1380];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei bufSize, GLuint *params)) _func)(program, location, bufSize, params);
}

GLAPI void APIENTRY glHint(GLenum target, GLenum mode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1395];
   ((void (APIENTRY *)(GLenum target, GLenum mode)) _func)(target, mode);
}

GLAPI void APIENTRY glIndexMask(GLuint mask)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1413];
   ((void (APIENTRY *)(GLuint mask)) _func)(mask);
}

GLAPI void APIENTRY glIndexPointer(GLenum type, GLsizei stride, const void *pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1415];
   ((void (APIENTRY *)(GLenum type, GLsizei stride, const void *pointer)) _func)(type, stride, pointer);
}

GLAPI void APIENTRY glIndexd(GLdouble c)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1418];
   ((void (APIENTRY *)(GLdouble c)) _func)(c);
}

GLAPI void APIENTRY glIndexdv(const GLdouble *c)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1419];
   ((void (APIENTRY *)(const GLdouble *c)) _func)(c);
}

GLAPI void APIENTRY glIndexf(GLfloat c)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1420];
   ((void (APIENTRY *)(GLfloat c)) _func)(c);
}

GLAPI void APIENTRY glIndexfv(const GLfloat *c)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1421];
   ((void (APIENTRY *)(const GLfloat *c)) _func)(c);
}

GLAPI void APIENTRY glIndexi(GLint c)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1422];
   ((void (APIENTRY *)(GLint c)) _func)(c);
}

GLAPI void APIENTRY glIndexiv(const GLint *c)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1423];
   ((void (APIENTRY *)(const GLint *c)) _func)(c);
}

GLAPI void APIENTRY glIndexs(GLshort c)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1424];
   ((void (APIENTRY *)(GLshort c)) _func)(c);
}

GLAPI void APIENTRY glIndexsv(const GLshort *c)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1425];
   ((void (APIENTRY *)(const GLshort *c)) _func)(c);
}

GLAPI void APIENTRY glIndexub(GLubyte c)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1426];
   ((void (APIENTRY *)(GLubyte c)) _func)(c);
}

GLAPI void APIENTRY glIndexubv(const GLubyte *c)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1427];
   ((void (APIENTRY *)(const GLubyte *c)) _func)(c);
}

GLAPI void APIENTRY glInitNames(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1430];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glInterleavedArrays(GLenum format, GLsizei stride, const void *pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1434];
   ((void (APIENTRY *)(GLenum format, GLsizei stride, const void *pointer)) _func)(format, stride, pointer);
}

GLAPI void APIENTRY glInvalidateBufferData(GLuint buffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1436];
   ((void (APIENTRY *)(GLuint buffer)) _func)(buffer);
}

GLAPI void APIENTRY glInvalidateBufferSubData(GLuint buffer, GLintptr offset, GLsizeiptr length)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1437];
   ((void (APIENTRY *)(GLuint buffer, GLintptr offset, GLsizeiptr length)) _func)(buffer, offset, length);
}

GLAPI void APIENTRY glInvalidateFramebuffer(GLenum target, GLsizei numAttachments, const GLenum *attachments)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1438];
   ((void (APIENTRY *)(GLenum target, GLsizei numAttachments, const GLenum *attachments)) _func)(target, numAttachments, attachments);
}

GLAPI void APIENTRY glInvalidateNamedFramebufferData(GLuint framebuffer, GLsizei numAttachments, const GLenum *attachments)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1439];
   ((void (APIENTRY *)(GLuint framebuffer, GLsizei numAttachments, const GLenum *attachments)) _func)(framebuffer, numAttachments, attachments);
}

GLAPI void APIENTRY glInvalidateNamedFramebufferSubData(GLuint framebuffer, GLsizei numAttachments, const GLenum *attachments, GLint x, GLint y, GLsizei width, GLsizei height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1440];
   ((void (APIENTRY *)(GLuint framebuffer, GLsizei numAttachments, const GLenum *attachments, GLint x, GLint y, GLsizei width, GLsizei height)) _func)(framebuffer, numAttachments, attachments, x, y, width, height);
}

GLAPI void APIENTRY glInvalidateSubFramebuffer(GLenum target, GLsizei numAttachments, const GLenum *attachments, GLint x, GLint y, GLsizei width, GLsizei height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1441];
   ((void (APIENTRY *)(GLenum target, GLsizei numAttachments, const GLenum *attachments, GLint x, GLint y, GLsizei width, GLsizei height)) _func)(target, numAttachments, attachments, x, y, width, height);
}

GLAPI void APIENTRY glInvalidateTexImage(GLuint texture, GLint level)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1442];
   ((void (APIENTRY *)(GLuint texture, GLint level)) _func)(texture, level);
}

GLAPI void APIENTRY glInvalidateTexSubImage(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1443];
   ((void (APIENTRY *)(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth)) _func)(texture, level, xoffset, yoffset, zoffset, width, height, depth);
}

GLAPI GLboolean APIENTRY glIsBuffer(GLuint buffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1445];
   return ((GLboolean (APIENTRY *)(GLuint buffer)) _func)(buffer);
}

GLAPI GLboolean APIENTRY glIsEnabled(GLenum cap)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1449];
   return ((GLboolean (APIENTRY *)(GLenum cap)) _func)(cap);
}

GLAPI GLboolean APIENTRY glIsEnabledi(GLenum target, GLuint index)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1451];
   return ((GLboolean (APIENTRY *)(GLenum target, GLuint index)) _func)(target, index);
}

GLAPI GLboolean APIENTRY glIsFramebuffer(GLuint framebuffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1457];
   return ((GLboolean (APIENTRY *)(GLuint framebuffer)) _func)(framebuffer);
}

GLAPI GLboolean APIENTRY glIsList(GLuint list)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1462];
   return ((GLboolean (APIENTRY *)(GLuint list)) _func)(list);
}

GLAPI GLboolean APIENTRY glIsProgram(GLuint program)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1472];
   return ((GLboolean (APIENTRY *)(GLuint program)) _func)(program);
}

GLAPI GLboolean APIENTRY glIsProgramPipeline(GLuint pipeline)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1475];
   return ((GLboolean (APIENTRY *)(GLuint pipeline)) _func)(pipeline);
}

GLAPI GLboolean APIENTRY glIsQuery(GLuint id)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1477];
   return ((GLboolean (APIENTRY *)(GLuint id)) _func)(id);
}

GLAPI GLboolean APIENTRY glIsRenderbuffer(GLuint renderbuffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1480];
   return ((GLboolean (APIENTRY *)(GLuint renderbuffer)) _func)(renderbuffer);
}

GLAPI GLboolean APIENTRY glIsSampler(GLuint sampler)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1483];
   return ((GLboolean (APIENTRY *)(GLuint sampler)) _func)(sampler);
}

GLAPI GLboolean APIENTRY glIsShader(GLuint shader)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1485];
   return ((GLboolean (APIENTRY *)(GLuint shader)) _func)(shader);
}

GLAPI GLboolean APIENTRY glIsSync(GLsync sync)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1487];
   return ((GLboolean (APIENTRY *)(GLsync sync)) _func)(sync);
}

GLAPI GLboolean APIENTRY glIsTexture(GLuint texture)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1489];
   return ((GLboolean (APIENTRY *)(GLuint texture)) _func)(texture);
}

GLAPI GLboolean APIENTRY glIsTransformFeedback(GLuint id)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1493];
   return ((GLboolean (APIENTRY *)(GLuint id)) _func)(id);
}

GLAPI GLboolean APIENTRY glIsVertexArray(GLuint array)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1497];
   return ((GLboolean (APIENTRY *)(GLuint array)) _func)(array);
}

GLAPI void APIENTRY glLightModelf(GLenum pname, GLfloat param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1506];
   ((void (APIENTRY *)(GLenum pname, GLfloat param)) _func)(pname, param);
}

GLAPI void APIENTRY glLightModelfv(GLenum pname, const GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1507];
   ((void (APIENTRY *)(GLenum pname, const GLfloat *params)) _func)(pname, params);
}

GLAPI void APIENTRY glLightModeli(GLenum pname, GLint param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1508];
   ((void (APIENTRY *)(GLenum pname, GLint param)) _func)(pname, param);
}

GLAPI void APIENTRY glLightModeliv(GLenum pname, const GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1509];
   ((void (APIENTRY *)(GLenum pname, const GLint *params)) _func)(pname, params);
}

GLAPI void APIENTRY glLightf(GLenum light, GLenum pname, GLfloat param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1514];
   ((void (APIENTRY *)(GLenum light, GLenum pname, GLfloat param)) _func)(light, pname, param);
}

GLAPI void APIENTRY glLightfv(GLenum light, GLenum pname, const GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1515];
   ((void (APIENTRY *)(GLenum light, GLenum pname, const GLfloat *params)) _func)(light, pname, params);
}

GLAPI void APIENTRY glLighti(GLenum light, GLenum pname, GLint param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1516];
   ((void (APIENTRY *)(GLenum light, GLenum pname, GLint param)) _func)(light, pname, param);
}

GLAPI void APIENTRY glLightiv(GLenum light, GLenum pname, const GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1517];
   ((void (APIENTRY *)(GLenum light, GLenum pname, const GLint *params)) _func)(light, pname, params);
}

GLAPI void APIENTRY glLineStipple(GLint factor, GLushort pattern)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1522];
   ((void (APIENTRY *)(GLint factor, GLushort pattern)) _func)(factor, pattern);
}

GLAPI void APIENTRY glLineWidth(GLfloat width)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1523];
   ((void (APIENTRY *)(GLfloat width)) _func)(width);
}

GLAPI void APIENTRY glLinkProgram(GLuint program)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1526];
   ((void (APIENTRY *)(GLuint program)) _func)(program);
}

GLAPI void APIENTRY glListBase(GLuint base)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1528];
   ((void (APIENTRY *)(GLuint base)) _func)(base);
}

GLAPI void APIENTRY glLoadIdentity(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1534];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glLoadMatrixd(const GLdouble *m)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1536];
   ((void (APIENTRY *)(const GLdouble *m)) _func)(m);
}

GLAPI void APIENTRY glLoadMatrixf(const GLfloat *m)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1537];
   ((void (APIENTRY *)(const GLfloat *m)) _func)(m);
}

GLAPI void APIENTRY glLoadName(GLuint name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1540];
   ((void (APIENTRY *)(GLuint name)) _func)(name);
}

GLAPI void APIENTRY glLoadTransposeMatrixd(const GLdouble *m)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1544];
   ((void (APIENTRY *)(const GLdouble *m)) _func)(m);
}

GLAPI void APIENTRY glLoadTransposeMatrixf(const GLfloat *m)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1546];
   ((void (APIENTRY *)(const GLfloat *m)) _func)(m);
}

GLAPI void APIENTRY glLogicOp(GLenum opcode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1550];
   ((void (APIENTRY *)(GLenum opcode)) _func)(opcode);
}

GLAPI void APIENTRY glMap1d(GLenum target, GLdouble u1, GLdouble u2, GLint stride, GLint order, const GLdouble *points)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1563];
   ((void (APIENTRY *)(GLenum target, GLdouble u1, GLdouble u2, GLint stride, GLint order, const GLdouble *points)) _func)(target, u1, u2, stride, order, points);
}

GLAPI void APIENTRY glMap1f(GLenum target, GLfloat u1, GLfloat u2, GLint stride, GLint order, const GLfloat *points)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1564];
   ((void (APIENTRY *)(GLenum target, GLfloat u1, GLfloat u2, GLint stride, GLint order, const GLfloat *points)) _func)(target, u1, u2, stride, order, points);
}

GLAPI void APIENTRY glMap2d(GLenum target, GLdouble u1, GLdouble u2, GLint ustride, GLint uorder, GLdouble v1, GLdouble v2, GLint vstride, GLint vorder, const GLdouble *points)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1566];
   ((void (APIENTRY *)(GLenum target, GLdouble u1, GLdouble u2, GLint ustride, GLint uorder, GLdouble v1, GLdouble v2, GLint vstride, GLint vorder, const GLdouble *points)) _func)(target, u1, u2, ustride, uorder, v1, v2, vstride, vorder, points);
}

GLAPI void APIENTRY glMap2f(GLenum target, GLfloat u1, GLfloat u2, GLint ustride, GLint uorder, GLfloat v1, GLfloat v2, GLint vstride, GLint vorder, const GLfloat *points)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1567];
   ((void (APIENTRY *)(GLenum target, GLfloat u1, GLfloat u2, GLint ustride, GLint uorder, GLfloat v1, GLfloat v2, GLint vstride, GLint vorder, const GLfloat *points)) _func)(target, u1, u2, ustride, uorder, v1, v2, vstride, vorder, points);
}

GLAPI void * APIENTRY glMapBuffer(GLenum target, GLenum access)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1569];
   return ((void * (APIENTRY *)(GLenum target, GLenum access)) _func)(target, access);
}

GLAPI void * APIENTRY glMapBufferRange(GLenum target, GLintptr offset, GLsizeiptr length, GLbitfield access)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1572];
   return ((void * (APIENTRY *)(GLenum target, GLintptr offset, GLsizeiptr length, GLbitfield access)) _func)(target, offset, length, access);
}

GLAPI void APIENTRY glMapGrid1d(GLint un, GLdouble u1, GLdouble u2)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1575];
   ((void (APIENTRY *)(GLint un, GLdouble u1, GLdouble u2)) _func)(un, u1, u2);
}

GLAPI void APIENTRY glMapGrid1f(GLint un, GLfloat u1, GLfloat u2)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1576];
   ((void (APIENTRY *)(GLint un, GLfloat u1, GLfloat u2)) _func)(un, u1, u2);
}

GLAPI void APIENTRY glMapGrid2d(GLint un, GLdouble u1, GLdouble u2, GLint vn, GLdouble v1, GLdouble v2)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1578];
   ((void (APIENTRY *)(GLint un, GLdouble u1, GLdouble u2, GLint vn, GLdouble v1, GLdouble v2)) _func)(un, u1, u2, vn, v1, v2);
}

GLAPI void APIENTRY glMapGrid2f(GLint un, GLfloat u1, GLfloat u2, GLint vn, GLfloat v1, GLfloat v2)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1579];
   ((void (APIENTRY *)(GLint un, GLfloat u1, GLfloat u2, GLint vn, GLfloat v1, GLfloat v2)) _func)(un, u1, u2, vn, v1, v2);
}

GLAPI void * APIENTRY glMapNamedBuffer(GLuint buffer, GLenum access)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1581];
   return ((void * (APIENTRY *)(GLuint buffer, GLenum access)) _func)(buffer, access);
}

GLAPI void * APIENTRY glMapNamedBufferRange(GLuint buffer, GLintptr offset, GLsizeiptr length, GLbitfield access)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1583];
   return ((void * (APIENTRY *)(GLuint buffer, GLintptr offset, GLsizeiptr length, GLbitfield access)) _func)(buffer, offset, length, access);
}

GLAPI void APIENTRY glMaterialf(GLenum face, GLenum pname, GLfloat param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1593];
   ((void (APIENTRY *)(GLenum face, GLenum pname, GLfloat param)) _func)(face, pname, param);
}

GLAPI void APIENTRY glMaterialfv(GLenum face, GLenum pname, const GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1594];
   ((void (APIENTRY *)(GLenum face, GLenum pname, const GLfloat *params)) _func)(face, pname, params);
}

GLAPI void APIENTRY glMateriali(GLenum face, GLenum pname, GLint param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1595];
   ((void (APIENTRY *)(GLenum face, GLenum pname, GLint param)) _func)(face, pname, param);
}

GLAPI void APIENTRY glMaterialiv(GLenum face, GLenum pname, const GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1596];
   ((void (APIENTRY *)(GLenum face, GLenum pname, const GLint *params)) _func)(face, pname, params);
}

GLAPI void APIENTRY glMatrixMode(GLenum mode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1615];
   ((void (APIENTRY *)(GLenum mode)) _func)(mode);
}

GLAPI void APIENTRY glMemoryBarrier(GLbitfield barriers)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1634];
   ((void (APIENTRY *)(GLbitfield barriers)) _func)(barriers);
}

GLAPI void APIENTRY glMemoryBarrierByRegion(GLbitfield barriers)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1635];
   ((void (APIENTRY *)(GLbitfield barriers)) _func)(barriers);
}

GLAPI void APIENTRY glMinSampleShading(GLfloat value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1638];
   ((void (APIENTRY *)(GLfloat value)) _func)(value);
}

GLAPI void APIENTRY glMultMatrixd(const GLdouble *m)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1643];
   ((void (APIENTRY *)(const GLdouble *m)) _func)(m);
}

GLAPI void APIENTRY glMultMatrixf(const GLfloat *m)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1644];
   ((void (APIENTRY *)(const GLfloat *m)) _func)(m);
}

GLAPI void APIENTRY glMultTransposeMatrixd(const GLdouble *m)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1648];
   ((void (APIENTRY *)(const GLdouble *m)) _func)(m);
}

GLAPI void APIENTRY glMultTransposeMatrixf(const GLfloat *m)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1650];
   ((void (APIENTRY *)(const GLfloat *m)) _func)(m);
}

GLAPI void APIENTRY glMultiDrawArrays(GLenum mode, const GLint *first, const GLsizei *count, GLsizei drawcount)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1653];
   ((void (APIENTRY *)(GLenum mode, const GLint *first, const GLsizei *count, GLsizei drawcount)) _func)(mode, first, count, drawcount);
}

GLAPI void APIENTRY glMultiDrawArraysIndirect(GLenum mode, const void *indirect, GLsizei drawcount, GLsizei stride)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1655];
   ((void (APIENTRY *)(GLenum mode, const void *indirect, GLsizei drawcount, GLsizei stride)) _func)(mode, indirect, drawcount, stride);
}

GLAPI void APIENTRY glMultiDrawElements(GLenum mode, const GLsizei *count, GLenum type, const void *const *indices, GLsizei drawcount)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1663];
   ((void (APIENTRY *)(GLenum mode, const GLsizei *count, GLenum type, const void *const *indices, GLsizei drawcount)) _func)(mode, count, type, indices, drawcount);
}

GLAPI void APIENTRY glMultiDrawElementsBaseVertex(GLenum mode, const GLsizei *count, GLenum type, const void *const *indices, GLsizei drawcount, const GLint *basevertex)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1664];
   ((void (APIENTRY *)(GLenum mode, const GLsizei *count, GLenum type, const void *const *indices, GLsizei drawcount, const GLint *basevertex)) _func)(mode, count, type, indices, drawcount, basevertex);
}

GLAPI void APIENTRY glMultiDrawElementsIndirect(GLenum mode, GLenum type, const void *indirect, GLsizei drawcount, GLsizei stride)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1667];
   ((void (APIENTRY *)(GLenum mode, GLenum type, const void *indirect, GLsizei drawcount, GLsizei stride)) _func)(mode, type, indirect, drawcount, stride);
}

GLAPI void APIENTRY glMultiTexCoord1d(GLenum target, GLdouble s)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1682];
   ((void (APIENTRY *)(GLenum target, GLdouble s)) _func)(target, s);
}

GLAPI void APIENTRY glMultiTexCoord1dv(GLenum target, const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1684];
   ((void (APIENTRY *)(GLenum target, const GLdouble *v)) _func)(target, v);
}

GLAPI void APIENTRY glMultiTexCoord1f(GLenum target, GLfloat s)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1686];
   ((void (APIENTRY *)(GLenum target, GLfloat s)) _func)(target, s);
}

GLAPI void APIENTRY glMultiTexCoord1fv(GLenum target, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1688];
   ((void (APIENTRY *)(GLenum target, const GLfloat *v)) _func)(target, v);
}

GLAPI void APIENTRY glMultiTexCoord1i(GLenum target, GLint s)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1692];
   ((void (APIENTRY *)(GLenum target, GLint s)) _func)(target, s);
}

GLAPI void APIENTRY glMultiTexCoord1iv(GLenum target, const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1694];
   ((void (APIENTRY *)(GLenum target, const GLint *v)) _func)(target, v);
}

GLAPI void APIENTRY glMultiTexCoord1s(GLenum target, GLshort s)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1696];
   ((void (APIENTRY *)(GLenum target, GLshort s)) _func)(target, s);
}

GLAPI void APIENTRY glMultiTexCoord1sv(GLenum target, const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1698];
   ((void (APIENTRY *)(GLenum target, const GLshort *v)) _func)(target, v);
}

GLAPI void APIENTRY glMultiTexCoord2d(GLenum target, GLdouble s, GLdouble t)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1706];
   ((void (APIENTRY *)(GLenum target, GLdouble s, GLdouble t)) _func)(target, s, t);
}

GLAPI void APIENTRY glMultiTexCoord2dv(GLenum target, const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1708];
   ((void (APIENTRY *)(GLenum target, const GLdouble *v)) _func)(target, v);
}

GLAPI void APIENTRY glMultiTexCoord2f(GLenum target, GLfloat s, GLfloat t)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1710];
   ((void (APIENTRY *)(GLenum target, GLfloat s, GLfloat t)) _func)(target, s, t);
}

GLAPI void APIENTRY glMultiTexCoord2fv(GLenum target, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1712];
   ((void (APIENTRY *)(GLenum target, const GLfloat *v)) _func)(target, v);
}

GLAPI void APIENTRY glMultiTexCoord2i(GLenum target, GLint s, GLint t)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1716];
   ((void (APIENTRY *)(GLenum target, GLint s, GLint t)) _func)(target, s, t);
}

GLAPI void APIENTRY glMultiTexCoord2iv(GLenum target, const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1718];
   ((void (APIENTRY *)(GLenum target, const GLint *v)) _func)(target, v);
}

GLAPI void APIENTRY glMultiTexCoord2s(GLenum target, GLshort s, GLshort t)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1720];
   ((void (APIENTRY *)(GLenum target, GLshort s, GLshort t)) _func)(target, s, t);
}

GLAPI void APIENTRY glMultiTexCoord2sv(GLenum target, const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1722];
   ((void (APIENTRY *)(GLenum target, const GLshort *v)) _func)(target, v);
}

GLAPI void APIENTRY glMultiTexCoord3d(GLenum target, GLdouble s, GLdouble t, GLdouble r)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1730];
   ((void (APIENTRY *)(GLenum target, GLdouble s, GLdouble t, GLdouble r)) _func)(target, s, t, r);
}

GLAPI void APIENTRY glMultiTexCoord3dv(GLenum target, const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1732];
   ((void (APIENTRY *)(GLenum target, const GLdouble *v)) _func)(target, v);
}

GLAPI void APIENTRY glMultiTexCoord3f(GLenum target, GLfloat s, GLfloat t, GLfloat r)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1734];
   ((void (APIENTRY *)(GLenum target, GLfloat s, GLfloat t, GLfloat r)) _func)(target, s, t, r);
}

GLAPI void APIENTRY glMultiTexCoord3fv(GLenum target, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1736];
   ((void (APIENTRY *)(GLenum target, const GLfloat *v)) _func)(target, v);
}

GLAPI void APIENTRY glMultiTexCoord3i(GLenum target, GLint s, GLint t, GLint r)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1740];
   ((void (APIENTRY *)(GLenum target, GLint s, GLint t, GLint r)) _func)(target, s, t, r);
}

GLAPI void APIENTRY glMultiTexCoord3iv(GLenum target, const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1742];
   ((void (APIENTRY *)(GLenum target, const GLint *v)) _func)(target, v);
}

GLAPI void APIENTRY glMultiTexCoord3s(GLenum target, GLshort s, GLshort t, GLshort r)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1744];
   ((void (APIENTRY *)(GLenum target, GLshort s, GLshort t, GLshort r)) _func)(target, s, t, r);
}

GLAPI void APIENTRY glMultiTexCoord3sv(GLenum target, const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1746];
   ((void (APIENTRY *)(GLenum target, const GLshort *v)) _func)(target, v);
}

GLAPI void APIENTRY glMultiTexCoord4d(GLenum target, GLdouble s, GLdouble t, GLdouble r, GLdouble q)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1754];
   ((void (APIENTRY *)(GLenum target, GLdouble s, GLdouble t, GLdouble r, GLdouble q)) _func)(target, s, t, r, q);
}

GLAPI void APIENTRY glMultiTexCoord4dv(GLenum target, const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1756];
   ((void (APIENTRY *)(GLenum target, const GLdouble *v)) _func)(target, v);
}

GLAPI void APIENTRY glMultiTexCoord4f(GLenum target, GLfloat s, GLfloat t, GLfloat r, GLfloat q)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1758];
   ((void (APIENTRY *)(GLenum target, GLfloat s, GLfloat t, GLfloat r, GLfloat q)) _func)(target, s, t, r, q);
}

GLAPI void APIENTRY glMultiTexCoord4fv(GLenum target, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1760];
   ((void (APIENTRY *)(GLenum target, const GLfloat *v)) _func)(target, v);
}

GLAPI void APIENTRY glMultiTexCoord4i(GLenum target, GLint s, GLint t, GLint r, GLint q)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1764];
   ((void (APIENTRY *)(GLenum target, GLint s, GLint t, GLint r, GLint q)) _func)(target, s, t, r, q);
}

GLAPI void APIENTRY glMultiTexCoord4iv(GLenum target, const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1766];
   ((void (APIENTRY *)(GLenum target, const GLint *v)) _func)(target, v);
}

GLAPI void APIENTRY glMultiTexCoord4s(GLenum target, GLshort s, GLshort t, GLshort r, GLshort q)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1768];
   ((void (APIENTRY *)(GLenum target, GLshort s, GLshort t, GLshort r, GLshort q)) _func)(target, s, t, r, q);
}

GLAPI void APIENTRY glMultiTexCoord4sv(GLenum target, const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1770];
   ((void (APIENTRY *)(GLenum target, const GLshort *v)) _func)(target, v);
}

GLAPI void APIENTRY glMultiTexCoordP1ui(GLenum texture, GLenum type, GLuint coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1776];
   ((void (APIENTRY *)(GLenum texture, GLenum type, GLuint coords)) _func)(texture, type, coords);
}

GLAPI void APIENTRY glMultiTexCoordP1uiv(GLenum texture, GLenum type, const GLuint *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1777];
   ((void (APIENTRY *)(GLenum texture, GLenum type, const GLuint *coords)) _func)(texture, type, coords);
}

GLAPI void APIENTRY glMultiTexCoordP2ui(GLenum texture, GLenum type, GLuint coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1778];
   ((void (APIENTRY *)(GLenum texture, GLenum type, GLuint coords)) _func)(texture, type, coords);
}

GLAPI void APIENTRY glMultiTexCoordP2uiv(GLenum texture, GLenum type, const GLuint *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1779];
   ((void (APIENTRY *)(GLenum texture, GLenum type, const GLuint *coords)) _func)(texture, type, coords);
}

GLAPI void APIENTRY glMultiTexCoordP3ui(GLenum texture, GLenum type, GLuint coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1780];
   ((void (APIENTRY *)(GLenum texture, GLenum type, GLuint coords)) _func)(texture, type, coords);
}

GLAPI void APIENTRY glMultiTexCoordP3uiv(GLenum texture, GLenum type, const GLuint *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1781];
   ((void (APIENTRY *)(GLenum texture, GLenum type, const GLuint *coords)) _func)(texture, type, coords);
}

GLAPI void APIENTRY glMultiTexCoordP4ui(GLenum texture, GLenum type, GLuint coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1782];
   ((void (APIENTRY *)(GLenum texture, GLenum type, GLuint coords)) _func)(texture, type, coords);
}

GLAPI void APIENTRY glMultiTexCoordP4uiv(GLenum texture, GLenum type, const GLuint *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1783];
   ((void (APIENTRY *)(GLenum texture, GLenum type, const GLuint *coords)) _func)(texture, type, coords);
}

GLAPI void APIENTRY glNamedBufferData(GLuint buffer, GLsizeiptr size, const void *data, GLenum usage)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1824];
   ((void (APIENTRY *)(GLuint buffer, GLsizeiptr size, const void *data, GLenum usage)) _func)(buffer, size, data, usage);
}

GLAPI void APIENTRY glNamedBufferStorage(GLuint buffer, GLsizeiptr size, const void *data, GLbitfield flags)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1829];
   ((void (APIENTRY *)(GLuint buffer, GLsizeiptr size, const void *data, GLbitfield flags)) _func)(buffer, size, data, flags);
}

GLAPI void APIENTRY glNamedBufferSubData(GLuint buffer, GLintptr offset, GLsizeiptr size, const void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1833];
   ((void (APIENTRY *)(GLuint buffer, GLintptr offset, GLsizeiptr size, const void *data)) _func)(buffer, offset, size, data);
}

GLAPI void APIENTRY glNamedFramebufferDrawBuffer(GLuint framebuffer, GLenum buf)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1836];
   ((void (APIENTRY *)(GLuint framebuffer, GLenum buf)) _func)(framebuffer, buf);
}

GLAPI void APIENTRY glNamedFramebufferDrawBuffers(GLuint framebuffer, GLsizei n, const GLenum *bufs)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1837];
   ((void (APIENTRY *)(GLuint framebuffer, GLsizei n, const GLenum *bufs)) _func)(framebuffer, n, bufs);
}

GLAPI void APIENTRY glNamedFramebufferParameteri(GLuint framebuffer, GLenum pname, GLint param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1838];
   ((void (APIENTRY *)(GLuint framebuffer, GLenum pname, GLint param)) _func)(framebuffer, pname, param);
}

GLAPI void APIENTRY glNamedFramebufferReadBuffer(GLuint framebuffer, GLenum src)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1840];
   ((void (APIENTRY *)(GLuint framebuffer, GLenum src)) _func)(framebuffer, src);
}

GLAPI void APIENTRY glNamedFramebufferRenderbuffer(GLuint framebuffer, GLenum attachment, GLenum renderbuffertarget, GLuint renderbuffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1841];
   ((void (APIENTRY *)(GLuint framebuffer, GLenum attachment, GLenum renderbuffertarget, GLuint renderbuffer)) _func)(framebuffer, attachment, renderbuffertarget, renderbuffer);
}

GLAPI void APIENTRY glNamedFramebufferTexture(GLuint framebuffer, GLenum attachment, GLuint texture, GLint level)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1846];
   ((void (APIENTRY *)(GLuint framebuffer, GLenum attachment, GLuint texture, GLint level)) _func)(framebuffer, attachment, texture, level);
}

GLAPI void APIENTRY glNamedFramebufferTextureLayer(GLuint framebuffer, GLenum attachment, GLuint texture, GLint level, GLint layer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1852];
   ((void (APIENTRY *)(GLuint framebuffer, GLenum attachment, GLuint texture, GLint level, GLint layer)) _func)(framebuffer, attachment, texture, level, layer);
}

GLAPI void APIENTRY glNamedRenderbufferStorage(GLuint renderbuffer, GLenum internalformat, GLsizei width, GLsizei height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1866];
   ((void (APIENTRY *)(GLuint renderbuffer, GLenum internalformat, GLsizei width, GLsizei height)) _func)(renderbuffer, internalformat, width, height);
}

GLAPI void APIENTRY glNamedRenderbufferStorageMultisample(GLuint renderbuffer, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1868];
   ((void (APIENTRY *)(GLuint renderbuffer, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height)) _func)(renderbuffer, samples, internalformat, width, height);
}

GLAPI void APIENTRY glNewList(GLuint list, GLenum mode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1873];
   ((void (APIENTRY *)(GLuint list, GLenum mode)) _func)(list, mode);
}

GLAPI void APIENTRY glNormal3b(GLbyte nx, GLbyte ny, GLbyte nz)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1875];
   ((void (APIENTRY *)(GLbyte nx, GLbyte ny, GLbyte nz)) _func)(nx, ny, nz);
}

GLAPI void APIENTRY glNormal3bv(const GLbyte *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1876];
   ((void (APIENTRY *)(const GLbyte *v)) _func)(v);
}

GLAPI void APIENTRY glNormal3d(GLdouble nx, GLdouble ny, GLdouble nz)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1877];
   ((void (APIENTRY *)(GLdouble nx, GLdouble ny, GLdouble nz)) _func)(nx, ny, nz);
}

GLAPI void APIENTRY glNormal3dv(const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1878];
   ((void (APIENTRY *)(const GLdouble *v)) _func)(v);
}

GLAPI void APIENTRY glNormal3f(GLfloat nx, GLfloat ny, GLfloat nz)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1879];
   ((void (APIENTRY *)(GLfloat nx, GLfloat ny, GLfloat nz)) _func)(nx, ny, nz);
}

GLAPI void APIENTRY glNormal3fv(const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1882];
   ((void (APIENTRY *)(const GLfloat *v)) _func)(v);
}

GLAPI void APIENTRY glNormal3i(GLint nx, GLint ny, GLint nz)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1885];
   ((void (APIENTRY *)(GLint nx, GLint ny, GLint nz)) _func)(nx, ny, nz);
}

GLAPI void APIENTRY glNormal3iv(const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1886];
   ((void (APIENTRY *)(const GLint *v)) _func)(v);
}

GLAPI void APIENTRY glNormal3s(GLshort nx, GLshort ny, GLshort nz)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1887];
   ((void (APIENTRY *)(GLshort nx, GLshort ny, GLshort nz)) _func)(nx, ny, nz);
}

GLAPI void APIENTRY glNormal3sv(const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1888];
   ((void (APIENTRY *)(const GLshort *v)) _func)(v);
}

GLAPI void APIENTRY glNormalP3ui(GLenum type, GLuint coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1893];
   ((void (APIENTRY *)(GLenum type, GLuint coords)) _func)(type, coords);
}

GLAPI void APIENTRY glNormalP3uiv(GLenum type, const GLuint *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1894];
   ((void (APIENTRY *)(GLenum type, const GLuint *coords)) _func)(type, coords);
}

GLAPI void APIENTRY glNormalPointer(GLenum type, GLsizei stride, const void *pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1895];
   ((void (APIENTRY *)(GLenum type, GLsizei stride, const void *pointer)) _func)(type, stride, pointer);
}

GLAPI void APIENTRY glObjectLabel(GLenum identifier, GLuint name, GLsizei length, const GLchar *label)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1909];
   ((void (APIENTRY *)(GLenum identifier, GLuint name, GLsizei length, const GLchar *label)) _func)(identifier, name, length, label);
}

GLAPI void APIENTRY glObjectPtrLabel(const void *ptr, GLsizei length, const GLchar *label)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1912];
   ((void (APIENTRY *)(const void *ptr, GLsizei length, const GLchar *label)) _func)(ptr, length, label);
}

GLAPI void APIENTRY glOrtho(GLdouble left, GLdouble right, GLdouble bottom, GLdouble top, GLdouble zNear, GLdouble zFar)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1917];
   ((void (APIENTRY *)(GLdouble left, GLdouble right, GLdouble bottom, GLdouble top, GLdouble zNear, GLdouble zFar)) _func)(left, right, bottom, top, zNear, zFar);
}

GLAPI void APIENTRY glPassThrough(GLfloat token)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1925];
   ((void (APIENTRY *)(GLfloat token)) _func)(token);
}

GLAPI void APIENTRY glPatchParameterfv(GLenum pname, const GLfloat *values)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1927];
   ((void (APIENTRY *)(GLenum pname, const GLfloat *values)) _func)(pname, values);
}

GLAPI void APIENTRY glPatchParameteri(GLenum pname, GLint value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1930];
   ((void (APIENTRY *)(GLenum pname, GLint value)) _func)(pname, value);
}

GLAPI void APIENTRY glPauseTransformFeedback(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1955];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glPixelMapfv(GLenum map, GLsizei mapsize, const GLfloat *values)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1959];
   ((void (APIENTRY *)(GLenum map, GLsizei mapsize, const GLfloat *values)) _func)(map, mapsize, values);
}

GLAPI void APIENTRY glPixelMapuiv(GLenum map, GLsizei mapsize, const GLuint *values)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1960];
   ((void (APIENTRY *)(GLenum map, GLsizei mapsize, const GLuint *values)) _func)(map, mapsize, values);
}

GLAPI void APIENTRY glPixelMapusv(GLenum map, GLsizei mapsize, const GLushort *values)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1961];
   ((void (APIENTRY *)(GLenum map, GLsizei mapsize, const GLushort *values)) _func)(map, mapsize, values);
}

GLAPI void APIENTRY glPixelStoref(GLenum pname, GLfloat param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1963];
   ((void (APIENTRY *)(GLenum pname, GLfloat param)) _func)(pname, param);
}

GLAPI void APIENTRY glPixelStorei(GLenum pname, GLint param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1964];
   ((void (APIENTRY *)(GLenum pname, GLint param)) _func)(pname, param);
}

GLAPI void APIENTRY glPixelTransferf(GLenum pname, GLfloat param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1971];
   ((void (APIENTRY *)(GLenum pname, GLfloat param)) _func)(pname, param);
}

GLAPI void APIENTRY glPixelTransferi(GLenum pname, GLint param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1972];
   ((void (APIENTRY *)(GLenum pname, GLint param)) _func)(pname, param);
}

GLAPI void APIENTRY glPixelZoom(GLfloat xfactor, GLfloat yfactor)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1978];
   ((void (APIENTRY *)(GLfloat xfactor, GLfloat yfactor)) _func)(xfactor, yfactor);
}

GLAPI void APIENTRY glPointParameterf(GLenum pname, GLfloat param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1981];
   ((void (APIENTRY *)(GLenum pname, GLfloat param)) _func)(pname, param);
}

GLAPI void APIENTRY glPointParameterfv(GLenum pname, const GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1985];
   ((void (APIENTRY *)(GLenum pname, const GLfloat *params)) _func)(pname, params);
}

GLAPI void APIENTRY glPointParameteri(GLenum pname, GLint param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1989];
   ((void (APIENTRY *)(GLenum pname, GLint param)) _func)(pname, param);
}

GLAPI void APIENTRY glPointParameteriv(GLenum pname, const GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1991];
   ((void (APIENTRY *)(GLenum pname, const GLint *params)) _func)(pname, params);
}

GLAPI void APIENTRY glPointSize(GLfloat size)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1997];
   ((void (APIENTRY *)(GLfloat size)) _func)(size);
}

GLAPI void APIENTRY glPolygonMode(GLenum face, GLenum mode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2003];
   ((void (APIENTRY *)(GLenum face, GLenum mode)) _func)(face, mode);
}

GLAPI void APIENTRY glPolygonOffset(GLfloat factor, GLfloat units)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2005];
   ((void (APIENTRY *)(GLfloat factor, GLfloat units)) _func)(factor, units);
}

GLAPI void APIENTRY glPolygonStipple(const GLubyte *mask)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2011];
   ((void (APIENTRY *)(const GLubyte *mask)) _func)(mask);
}

GLAPI void APIENTRY glPopAttrib(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2012];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glPopClientAttrib(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2013];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glPopDebugGroup(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2014];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glPopMatrix(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2018];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glPopName(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2019];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glPrimitiveRestartIndex(GLuint index)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2027];
   ((void (APIENTRY *)(GLuint index)) _func)(index);
}

GLAPI void APIENTRY glPrioritizeTextures(GLsizei n, const GLuint *textures, const GLfloat *priorities)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2030];
   ((void (APIENTRY *)(GLsizei n, const GLuint *textures, const GLfloat *priorities)) _func)(n, textures, priorities);
}

GLAPI void APIENTRY glProgramBinary(GLuint program, GLenum binaryFormat, const void *binary, GLsizei length)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2033];
   ((void (APIENTRY *)(GLuint program, GLenum binaryFormat, const void *binary, GLsizei length)) _func)(program, binaryFormat, binary, length);
}

GLAPI void APIENTRY glProgramParameteri(GLuint program, GLenum pname, GLint value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2068];
   ((void (APIENTRY *)(GLuint program, GLenum pname, GLint value)) _func)(program, pname, value);
}

GLAPI void APIENTRY glProgramUniform1d(GLuint program, GLint location, GLdouble v0)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2076];
   ((void (APIENTRY *)(GLuint program, GLint location, GLdouble v0)) _func)(program, location, v0);
}

GLAPI void APIENTRY glProgramUniform1dv(GLuint program, GLint location, GLsizei count, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2078];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLdouble *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform1f(GLuint program, GLint location, GLfloat v0)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2080];
   ((void (APIENTRY *)(GLuint program, GLint location, GLfloat v0)) _func)(program, location, v0);
}

GLAPI void APIENTRY glProgramUniform1fv(GLuint program, GLint location, GLsizei count, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2082];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLfloat *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform1i(GLuint program, GLint location, GLint v0)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2084];
   ((void (APIENTRY *)(GLuint program, GLint location, GLint v0)) _func)(program, location, v0);
}

GLAPI void APIENTRY glProgramUniform1iv(GLuint program, GLint location, GLsizei count, const GLint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2090];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLint *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform1ui(GLuint program, GLint location, GLuint v0)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2092];
   ((void (APIENTRY *)(GLuint program, GLint location, GLuint v0)) _func)(program, location, v0);
}

GLAPI void APIENTRY glProgramUniform1uiv(GLuint program, GLint location, GLsizei count, const GLuint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2098];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLuint *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform2d(GLuint program, GLint location, GLdouble v0, GLdouble v1)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2100];
   ((void (APIENTRY *)(GLuint program, GLint location, GLdouble v0, GLdouble v1)) _func)(program, location, v0, v1);
}

GLAPI void APIENTRY glProgramUniform2dv(GLuint program, GLint location, GLsizei count, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2102];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLdouble *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform2f(GLuint program, GLint location, GLfloat v0, GLfloat v1)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2104];
   ((void (APIENTRY *)(GLuint program, GLint location, GLfloat v0, GLfloat v1)) _func)(program, location, v0, v1);
}

GLAPI void APIENTRY glProgramUniform2fv(GLuint program, GLint location, GLsizei count, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2106];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLfloat *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform2i(GLuint program, GLint location, GLint v0, GLint v1)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2108];
   ((void (APIENTRY *)(GLuint program, GLint location, GLint v0, GLint v1)) _func)(program, location, v0, v1);
}

GLAPI void APIENTRY glProgramUniform2iv(GLuint program, GLint location, GLsizei count, const GLint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2114];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLint *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform2ui(GLuint program, GLint location, GLuint v0, GLuint v1)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2116];
   ((void (APIENTRY *)(GLuint program, GLint location, GLuint v0, GLuint v1)) _func)(program, location, v0, v1);
}

GLAPI void APIENTRY glProgramUniform2uiv(GLuint program, GLint location, GLsizei count, const GLuint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2122];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLuint *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform3d(GLuint program, GLint location, GLdouble v0, GLdouble v1, GLdouble v2)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2124];
   ((void (APIENTRY *)(GLuint program, GLint location, GLdouble v0, GLdouble v1, GLdouble v2)) _func)(program, location, v0, v1, v2);
}

GLAPI void APIENTRY glProgramUniform3dv(GLuint program, GLint location, GLsizei count, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2126];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLdouble *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform3f(GLuint program, GLint location, GLfloat v0, GLfloat v1, GLfloat v2)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2128];
   ((void (APIENTRY *)(GLuint program, GLint location, GLfloat v0, GLfloat v1, GLfloat v2)) _func)(program, location, v0, v1, v2);
}

GLAPI void APIENTRY glProgramUniform3fv(GLuint program, GLint location, GLsizei count, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2130];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLfloat *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform3i(GLuint program, GLint location, GLint v0, GLint v1, GLint v2)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2132];
   ((void (APIENTRY *)(GLuint program, GLint location, GLint v0, GLint v1, GLint v2)) _func)(program, location, v0, v1, v2);
}

GLAPI void APIENTRY glProgramUniform3iv(GLuint program, GLint location, GLsizei count, const GLint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2138];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLint *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform3ui(GLuint program, GLint location, GLuint v0, GLuint v1, GLuint v2)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2140];
   ((void (APIENTRY *)(GLuint program, GLint location, GLuint v0, GLuint v1, GLuint v2)) _func)(program, location, v0, v1, v2);
}

GLAPI void APIENTRY glProgramUniform3uiv(GLuint program, GLint location, GLsizei count, const GLuint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2146];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLuint *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform4d(GLuint program, GLint location, GLdouble v0, GLdouble v1, GLdouble v2, GLdouble v3)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2148];
   ((void (APIENTRY *)(GLuint program, GLint location, GLdouble v0, GLdouble v1, GLdouble v2, GLdouble v3)) _func)(program, location, v0, v1, v2, v3);
}

GLAPI void APIENTRY glProgramUniform4dv(GLuint program, GLint location, GLsizei count, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2150];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLdouble *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform4f(GLuint program, GLint location, GLfloat v0, GLfloat v1, GLfloat v2, GLfloat v3)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2152];
   ((void (APIENTRY *)(GLuint program, GLint location, GLfloat v0, GLfloat v1, GLfloat v2, GLfloat v3)) _func)(program, location, v0, v1, v2, v3);
}

GLAPI void APIENTRY glProgramUniform4fv(GLuint program, GLint location, GLsizei count, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2154];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLfloat *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform4i(GLuint program, GLint location, GLint v0, GLint v1, GLint v2, GLint v3)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2156];
   ((void (APIENTRY *)(GLuint program, GLint location, GLint v0, GLint v1, GLint v2, GLint v3)) _func)(program, location, v0, v1, v2, v3);
}

GLAPI void APIENTRY glProgramUniform4iv(GLuint program, GLint location, GLsizei count, const GLint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2162];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLint *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform4ui(GLuint program, GLint location, GLuint v0, GLuint v1, GLuint v2, GLuint v3)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2164];
   ((void (APIENTRY *)(GLuint program, GLint location, GLuint v0, GLuint v1, GLuint v2, GLuint v3)) _func)(program, location, v0, v1, v2, v3);
}

GLAPI void APIENTRY glProgramUniform4uiv(GLuint program, GLint location, GLsizei count, const GLuint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2170];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLuint *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniformMatrix2dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2178];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)) _func)(program, location, count, transpose, value);
}

GLAPI void APIENTRY glProgramUniformMatrix2fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2180];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)) _func)(program, location, count, transpose, value);
}

GLAPI void APIENTRY glProgramUniformMatrix2x3dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2182];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)) _func)(program, location, count, transpose, value);
}

GLAPI void APIENTRY glProgramUniformMatrix2x3fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2184];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)) _func)(program, location, count, transpose, value);
}

GLAPI void APIENTRY glProgramUniformMatrix2x4dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2186];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)) _func)(program, location, count, transpose, value);
}

GLAPI void APIENTRY glProgramUniformMatrix2x4fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2188];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)) _func)(program, location, count, transpose, value);
}

GLAPI void APIENTRY glProgramUniformMatrix3dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2190];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)) _func)(program, location, count, transpose, value);
}

GLAPI void APIENTRY glProgramUniformMatrix3fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2192];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)) _func)(program, location, count, transpose, value);
}

GLAPI void APIENTRY glProgramUniformMatrix3x2dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2194];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)) _func)(program, location, count, transpose, value);
}

GLAPI void APIENTRY glProgramUniformMatrix3x2fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2196];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)) _func)(program, location, count, transpose, value);
}

GLAPI void APIENTRY glProgramUniformMatrix3x4dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2198];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)) _func)(program, location, count, transpose, value);
}

GLAPI void APIENTRY glProgramUniformMatrix3x4fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2200];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)) _func)(program, location, count, transpose, value);
}

GLAPI void APIENTRY glProgramUniformMatrix4dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2202];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)) _func)(program, location, count, transpose, value);
}

GLAPI void APIENTRY glProgramUniformMatrix4fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2204];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)) _func)(program, location, count, transpose, value);
}

GLAPI void APIENTRY glProgramUniformMatrix4x2dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2206];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)) _func)(program, location, count, transpose, value);
}

GLAPI void APIENTRY glProgramUniformMatrix4x2fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2208];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)) _func)(program, location, count, transpose, value);
}

GLAPI void APIENTRY glProgramUniformMatrix4x3dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2210];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)) _func)(program, location, count, transpose, value);
}

GLAPI void APIENTRY glProgramUniformMatrix4x3fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2212];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)) _func)(program, location, count, transpose, value);
}

GLAPI void APIENTRY glProvokingVertex(GLenum mode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2217];
   ((void (APIENTRY *)(GLenum mode)) _func)(mode);
}

GLAPI void APIENTRY glPushAttrib(GLbitfield mask)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2219];
   ((void (APIENTRY *)(GLbitfield mask)) _func)(mask);
}

GLAPI void APIENTRY glPushClientAttrib(GLbitfield mask)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2220];
   ((void (APIENTRY *)(GLbitfield mask)) _func)(mask);
}

GLAPI void APIENTRY glPushDebugGroup(GLenum source, GLuint id, GLsizei length, const GLchar *message)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2222];
   ((void (APIENTRY *)(GLenum source, GLuint id, GLsizei length, const GLchar *message)) _func)(source, id, length, message);
}

GLAPI void APIENTRY glPushMatrix(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2226];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glPushName(GLuint name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2227];
   ((void (APIENTRY *)(GLuint name)) _func)(name);
}

GLAPI void APIENTRY glQueryCounter(GLuint id, GLenum target)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2228];
   ((void (APIENTRY *)(GLuint id, GLenum target)) _func)(id, target);
}

GLAPI void APIENTRY glRasterPos2d(GLdouble x, GLdouble y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2235];
   ((void (APIENTRY *)(GLdouble x, GLdouble y)) _func)(x, y);
}

GLAPI void APIENTRY glRasterPos2dv(const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2236];
   ((void (APIENTRY *)(const GLdouble *v)) _func)(v);
}

GLAPI void APIENTRY glRasterPos2f(GLfloat x, GLfloat y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2237];
   ((void (APIENTRY *)(GLfloat x, GLfloat y)) _func)(x, y);
}

GLAPI void APIENTRY glRasterPos2fv(const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2238];
   ((void (APIENTRY *)(const GLfloat *v)) _func)(v);
}

GLAPI void APIENTRY glRasterPos2i(GLint x, GLint y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2239];
   ((void (APIENTRY *)(GLint x, GLint y)) _func)(x, y);
}

GLAPI void APIENTRY glRasterPos2iv(const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2240];
   ((void (APIENTRY *)(const GLint *v)) _func)(v);
}

GLAPI void APIENTRY glRasterPos2s(GLshort x, GLshort y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2241];
   ((void (APIENTRY *)(GLshort x, GLshort y)) _func)(x, y);
}

GLAPI void APIENTRY glRasterPos2sv(const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2242];
   ((void (APIENTRY *)(const GLshort *v)) _func)(v);
}

GLAPI void APIENTRY glRasterPos3d(GLdouble x, GLdouble y, GLdouble z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2245];
   ((void (APIENTRY *)(GLdouble x, GLdouble y, GLdouble z)) _func)(x, y, z);
}

GLAPI void APIENTRY glRasterPos3dv(const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2246];
   ((void (APIENTRY *)(const GLdouble *v)) _func)(v);
}

GLAPI void APIENTRY glRasterPos3f(GLfloat x, GLfloat y, GLfloat z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2247];
   ((void (APIENTRY *)(GLfloat x, GLfloat y, GLfloat z)) _func)(x, y, z);
}

GLAPI void APIENTRY glRasterPos3fv(const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2248];
   ((void (APIENTRY *)(const GLfloat *v)) _func)(v);
}

GLAPI void APIENTRY glRasterPos3i(GLint x, GLint y, GLint z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2249];
   ((void (APIENTRY *)(GLint x, GLint y, GLint z)) _func)(x, y, z);
}

GLAPI void APIENTRY glRasterPos3iv(const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2250];
   ((void (APIENTRY *)(const GLint *v)) _func)(v);
}

GLAPI void APIENTRY glRasterPos3s(GLshort x, GLshort y, GLshort z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2251];
   ((void (APIENTRY *)(GLshort x, GLshort y, GLshort z)) _func)(x, y, z);
}

GLAPI void APIENTRY glRasterPos3sv(const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2252];
   ((void (APIENTRY *)(const GLshort *v)) _func)(v);
}

GLAPI void APIENTRY glRasterPos4d(GLdouble x, GLdouble y, GLdouble z, GLdouble w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2255];
   ((void (APIENTRY *)(GLdouble x, GLdouble y, GLdouble z, GLdouble w)) _func)(x, y, z, w);
}

GLAPI void APIENTRY glRasterPos4dv(const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2256];
   ((void (APIENTRY *)(const GLdouble *v)) _func)(v);
}

GLAPI void APIENTRY glRasterPos4f(GLfloat x, GLfloat y, GLfloat z, GLfloat w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2257];
   ((void (APIENTRY *)(GLfloat x, GLfloat y, GLfloat z, GLfloat w)) _func)(x, y, z, w);
}

GLAPI void APIENTRY glRasterPos4fv(const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2258];
   ((void (APIENTRY *)(const GLfloat *v)) _func)(v);
}

GLAPI void APIENTRY glRasterPos4i(GLint x, GLint y, GLint z, GLint w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2259];
   ((void (APIENTRY *)(GLint x, GLint y, GLint z, GLint w)) _func)(x, y, z, w);
}

GLAPI void APIENTRY glRasterPos4iv(const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2260];
   ((void (APIENTRY *)(const GLint *v)) _func)(v);
}

GLAPI void APIENTRY glRasterPos4s(GLshort x, GLshort y, GLshort z, GLshort w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2261];
   ((void (APIENTRY *)(GLshort x, GLshort y, GLshort z, GLshort w)) _func)(x, y, z, w);
}

GLAPI void APIENTRY glRasterPos4sv(const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2262];
   ((void (APIENTRY *)(const GLshort *v)) _func)(v);
}

GLAPI void APIENTRY glReadBuffer(GLenum src)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2266];
   ((void (APIENTRY *)(GLenum src)) _func)(src);
}

GLAPI void APIENTRY glReadPixels(GLint x, GLint y, GLsizei width, GLsizei height, GLenum format, GLenum type, void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2270];
   ((void (APIENTRY *)(GLint x, GLint y, GLsizei width, GLsizei height, GLenum format, GLenum type, void *pixels)) _func)(x, y, width, height, format, type, pixels);
}

GLAPI void APIENTRY glReadnPixels(GLint x, GLint y, GLsizei width, GLsizei height, GLenum format, GLenum type, GLsizei bufSize, void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2271];
   ((void (APIENTRY *)(GLint x, GLint y, GLsizei width, GLsizei height, GLenum format, GLenum type, GLsizei bufSize, void *data)) _func)(x, y, width, height, format, type, bufSize, data);
}

GLAPI void APIENTRY glRectd(GLdouble x1, GLdouble y1, GLdouble x2, GLdouble y2)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2275];
   ((void (APIENTRY *)(GLdouble x1, GLdouble y1, GLdouble x2, GLdouble y2)) _func)(x1, y1, x2, y2);
}

GLAPI void APIENTRY glRectdv(const GLdouble *v1, const GLdouble *v2)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2276];
   ((void (APIENTRY *)(const GLdouble *v1, const GLdouble *v2)) _func)(v1, v2);
}

GLAPI void APIENTRY glRectf(GLfloat x1, GLfloat y1, GLfloat x2, GLfloat y2)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2277];
   ((void (APIENTRY *)(GLfloat x1, GLfloat y1, GLfloat x2, GLfloat y2)) _func)(x1, y1, x2, y2);
}

GLAPI void APIENTRY glRectfv(const GLfloat *v1, const GLfloat *v2)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2278];
   ((void (APIENTRY *)(const GLfloat *v1, const GLfloat *v2)) _func)(v1, v2);
}

GLAPI void APIENTRY glRecti(GLint x1, GLint y1, GLint x2, GLint y2)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2279];
   ((void (APIENTRY *)(GLint x1, GLint y1, GLint x2, GLint y2)) _func)(x1, y1, x2, y2);
}

GLAPI void APIENTRY glRectiv(const GLint *v1, const GLint *v2)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2280];
   ((void (APIENTRY *)(const GLint *v1, const GLint *v2)) _func)(v1, v2);
}

GLAPI void APIENTRY glRects(GLshort x1, GLshort y1, GLshort x2, GLshort y2)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2281];
   ((void (APIENTRY *)(GLshort x1, GLshort y1, GLshort x2, GLshort y2)) _func)(x1, y1, x2, y2);
}

GLAPI void APIENTRY glRectsv(const GLshort *v1, const GLshort *v2)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2282];
   ((void (APIENTRY *)(const GLshort *v1, const GLshort *v2)) _func)(v1, v2);
}

GLAPI void APIENTRY glReleaseShaderCompiler(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2287];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI GLint APIENTRY glRenderMode(GLenum mode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2289];
   return ((GLint (APIENTRY *)(GLenum mode)) _func)(mode);
}

GLAPI void APIENTRY glRenderbufferStorage(GLenum target, GLenum internalformat, GLsizei width, GLsizei height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2290];
   ((void (APIENTRY *)(GLenum target, GLenum internalformat, GLsizei width, GLsizei height)) _func)(target, internalformat, width, height);
}

GLAPI void APIENTRY glRenderbufferStorageMultisample(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2292];
   ((void (APIENTRY *)(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height)) _func)(target, samples, internalformat, width, height);
}

GLAPI void APIENTRY glResumeTransformFeedback(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2333];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glRotated(GLdouble angle, GLdouble x, GLdouble y, GLdouble z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2336];
   ((void (APIENTRY *)(GLdouble angle, GLdouble x, GLdouble y, GLdouble z)) _func)(angle, x, y, z);
}

GLAPI void APIENTRY glRotatef(GLfloat angle, GLfloat x, GLfloat y, GLfloat z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2337];
   ((void (APIENTRY *)(GLfloat angle, GLfloat x, GLfloat y, GLfloat z)) _func)(angle, x, y, z);
}

GLAPI void APIENTRY glSampleCoverage(GLfloat value, GLboolean invert)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2340];
   ((void (APIENTRY *)(GLfloat value, GLboolean invert)) _func)(value, invert);
}

GLAPI void APIENTRY glSampleMaski(GLuint maskNumber, GLbitfield mask)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2348];
   ((void (APIENTRY *)(GLuint maskNumber, GLbitfield mask)) _func)(maskNumber, mask);
}

GLAPI void APIENTRY glSamplerParameterIiv(GLuint sampler, GLenum pname, const GLint *param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2351];
   ((void (APIENTRY *)(GLuint sampler, GLenum pname, const GLint *param)) _func)(sampler, pname, param);
}

GLAPI void APIENTRY glSamplerParameterIuiv(GLuint sampler, GLenum pname, const GLuint *param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2354];
   ((void (APIENTRY *)(GLuint sampler, GLenum pname, const GLuint *param)) _func)(sampler, pname, param);
}

GLAPI void APIENTRY glSamplerParameterf(GLuint sampler, GLenum pname, GLfloat param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2357];
   ((void (APIENTRY *)(GLuint sampler, GLenum pname, GLfloat param)) _func)(sampler, pname, param);
}

GLAPI void APIENTRY glSamplerParameterfv(GLuint sampler, GLenum pname, const GLfloat *param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2358];
   ((void (APIENTRY *)(GLuint sampler, GLenum pname, const GLfloat *param)) _func)(sampler, pname, param);
}

GLAPI void APIENTRY glSamplerParameteri(GLuint sampler, GLenum pname, GLint param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2359];
   ((void (APIENTRY *)(GLuint sampler, GLenum pname, GLint param)) _func)(sampler, pname, param);
}

GLAPI void APIENTRY glSamplerParameteriv(GLuint sampler, GLenum pname, const GLint *param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2360];
   ((void (APIENTRY *)(GLuint sampler, GLenum pname, const GLint *param)) _func)(sampler, pname, param);
}

GLAPI void APIENTRY glScaled(GLdouble x, GLdouble y, GLdouble z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2361];
   ((void (APIENTRY *)(GLdouble x, GLdouble y, GLdouble z)) _func)(x, y, z);
}

GLAPI void APIENTRY glScalef(GLfloat x, GLfloat y, GLfloat z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2362];
   ((void (APIENTRY *)(GLfloat x, GLfloat y, GLfloat z)) _func)(x, y, z);
}

GLAPI void APIENTRY glScissor(GLint x, GLint y, GLsizei width, GLsizei height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2365];
   ((void (APIENTRY *)(GLint x, GLint y, GLsizei width, GLsizei height)) _func)(x, y, width, height);
}

GLAPI void APIENTRY glScissorArrayv(GLuint first, GLsizei count, const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2366];
   ((void (APIENTRY *)(GLuint first, GLsizei count, const GLint *v)) _func)(first, count, v);
}

GLAPI void APIENTRY glScissorIndexed(GLuint index, GLint left, GLint bottom, GLsizei width, GLsizei height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2371];
   ((void (APIENTRY *)(GLuint index, GLint left, GLint bottom, GLsizei width, GLsizei height)) _func)(index, left, bottom, width, height);
}

GLAPI void APIENTRY glScissorIndexedv(GLuint index, const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2374];
   ((void (APIENTRY *)(GLuint index, const GLint *v)) _func)(index, v);
}

GLAPI void APIENTRY glSecondaryColor3b(GLbyte red, GLbyte green, GLbyte blue)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2377];
   ((void (APIENTRY *)(GLbyte red, GLbyte green, GLbyte blue)) _func)(red, green, blue);
}

GLAPI void APIENTRY glSecondaryColor3bv(const GLbyte *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2379];
   ((void (APIENTRY *)(const GLbyte *v)) _func)(v);
}

GLAPI void APIENTRY glSecondaryColor3d(GLdouble red, GLdouble green, GLdouble blue)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2381];
   ((void (APIENTRY *)(GLdouble red, GLdouble green, GLdouble blue)) _func)(red, green, blue);
}

GLAPI void APIENTRY glSecondaryColor3dv(const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2383];
   ((void (APIENTRY *)(const GLdouble *v)) _func)(v);
}

GLAPI void APIENTRY glSecondaryColor3f(GLfloat red, GLfloat green, GLfloat blue)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2385];
   ((void (APIENTRY *)(GLfloat red, GLfloat green, GLfloat blue)) _func)(red, green, blue);
}

GLAPI void APIENTRY glSecondaryColor3fv(const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2387];
   ((void (APIENTRY *)(const GLfloat *v)) _func)(v);
}

GLAPI void APIENTRY glSecondaryColor3i(GLint red, GLint green, GLint blue)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2391];
   ((void (APIENTRY *)(GLint red, GLint green, GLint blue)) _func)(red, green, blue);
}

GLAPI void APIENTRY glSecondaryColor3iv(const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2393];
   ((void (APIENTRY *)(const GLint *v)) _func)(v);
}

GLAPI void APIENTRY glSecondaryColor3s(GLshort red, GLshort green, GLshort blue)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2395];
   ((void (APIENTRY *)(GLshort red, GLshort green, GLshort blue)) _func)(red, green, blue);
}

GLAPI void APIENTRY glSecondaryColor3sv(const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2397];
   ((void (APIENTRY *)(const GLshort *v)) _func)(v);
}

GLAPI void APIENTRY glSecondaryColor3ub(GLubyte red, GLubyte green, GLubyte blue)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2399];
   ((void (APIENTRY *)(GLubyte red, GLubyte green, GLubyte blue)) _func)(red, green, blue);
}

GLAPI void APIENTRY glSecondaryColor3ubv(const GLubyte *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2401];
   ((void (APIENTRY *)(const GLubyte *v)) _func)(v);
}

GLAPI void APIENTRY glSecondaryColor3ui(GLuint red, GLuint green, GLuint blue)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2403];
   ((void (APIENTRY *)(GLuint red, GLuint green, GLuint blue)) _func)(red, green, blue);
}

GLAPI void APIENTRY glSecondaryColor3uiv(const GLuint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2405];
   ((void (APIENTRY *)(const GLuint *v)) _func)(v);
}

GLAPI void APIENTRY glSecondaryColor3us(GLushort red, GLushort green, GLushort blue)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2407];
   ((void (APIENTRY *)(GLushort red, GLushort green, GLushort blue)) _func)(red, green, blue);
}

GLAPI void APIENTRY glSecondaryColor3usv(const GLushort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2409];
   ((void (APIENTRY *)(const GLushort *v)) _func)(v);
}

GLAPI void APIENTRY glSecondaryColorP3ui(GLenum type, GLuint color)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2412];
   ((void (APIENTRY *)(GLenum type, GLuint color)) _func)(type, color);
}

GLAPI void APIENTRY glSecondaryColorP3uiv(GLenum type, const GLuint *color)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2413];
   ((void (APIENTRY *)(GLenum type, const GLuint *color)) _func)(type, color);
}

GLAPI void APIENTRY glSecondaryColorPointer(GLint size, GLenum type, GLsizei stride, const void *pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2414];
   ((void (APIENTRY *)(GLint size, GLenum type, GLsizei stride, const void *pointer)) _func)(size, type, stride, pointer);
}

GLAPI void APIENTRY glSelectBuffer(GLsizei size, GLuint *buffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2417];
   ((void (APIENTRY *)(GLsizei size, GLuint *buffer)) _func)(size, buffer);
}

GLAPI void APIENTRY glShadeModel(GLenum mode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2429];
   ((void (APIENTRY *)(GLenum mode)) _func)(mode);
}

GLAPI void APIENTRY glShaderBinary(GLsizei count, const GLuint *shaders, GLenum binaryFormat, const void *binary, GLsizei length)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2430];
   ((void (APIENTRY *)(GLsizei count, const GLuint *shaders, GLenum binaryFormat, const void *binary, GLsizei length)) _func)(count, shaders, binaryFormat, binary, length);
}

GLAPI void APIENTRY glShaderSource(GLuint shader, GLsizei count, const GLchar *const *string, const GLint *length)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2434];
   ((void (APIENTRY *)(GLuint shader, GLsizei count, const GLchar *const *string, const GLint *length)) _func)(shader, count, string, length);
}

GLAPI void APIENTRY glShaderStorageBlockBinding(GLuint program, GLuint storageBlockIndex, GLuint storageBlockBinding)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2436];
   ((void (APIENTRY *)(GLuint program, GLuint storageBlockIndex, GLuint storageBlockBinding)) _func)(program, storageBlockIndex, storageBlockBinding);
}

GLAPI void APIENTRY glStencilFunc(GLenum func, GLint ref, GLuint mask)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2461];
   ((void (APIENTRY *)(GLenum func, GLint ref, GLuint mask)) _func)(func, ref, mask);
}

GLAPI void APIENTRY glStencilFuncSeparate(GLenum face, GLenum func, GLint ref, GLuint mask)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2462];
   ((void (APIENTRY *)(GLenum face, GLenum func, GLint ref, GLuint mask)) _func)(face, func, ref, mask);
}

GLAPI void APIENTRY glStencilMask(GLuint mask)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2464];
   ((void (APIENTRY *)(GLuint mask)) _func)(mask);
}

GLAPI void APIENTRY glStencilMaskSeparate(GLenum face, GLuint mask)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2465];
   ((void (APIENTRY *)(GLenum face, GLuint mask)) _func)(face, mask);
}

GLAPI void APIENTRY glStencilOp(GLenum fail, GLenum zfail, GLenum zpass)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2466];
   ((void (APIENTRY *)(GLenum fail, GLenum zfail, GLenum zpass)) _func)(fail, zfail, zpass);
}

GLAPI void APIENTRY glStencilOpSeparate(GLenum face, GLenum sfail, GLenum dpfail, GLenum dppass)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2467];
   ((void (APIENTRY *)(GLenum face, GLenum sfail, GLenum dpfail, GLenum dppass)) _func)(face, sfail, dpfail, dppass);
}

GLAPI void APIENTRY glTexBuffer(GLenum target, GLenum internalformat, GLuint buffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2500];
   ((void (APIENTRY *)(GLenum target, GLenum internalformat, GLuint buffer)) _func)(target, internalformat, buffer);
}

GLAPI void APIENTRY glTexBufferRange(GLenum target, GLenum internalformat, GLuint buffer, GLintptr offset, GLsizeiptr size)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2504];
   ((void (APIENTRY *)(GLenum target, GLenum internalformat, GLuint buffer, GLintptr offset, GLsizeiptr size)) _func)(target, internalformat, buffer, offset, size);
}

GLAPI void APIENTRY glTexCoord1d(GLdouble s)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2511];
   ((void (APIENTRY *)(GLdouble s)) _func)(s);
}

GLAPI void APIENTRY glTexCoord1dv(const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2512];
   ((void (APIENTRY *)(const GLdouble *v)) _func)(v);
}

GLAPI void APIENTRY glTexCoord1f(GLfloat s)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2513];
   ((void (APIENTRY *)(GLfloat s)) _func)(s);
}

GLAPI void APIENTRY glTexCoord1fv(const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2514];
   ((void (APIENTRY *)(const GLfloat *v)) _func)(v);
}

GLAPI void APIENTRY glTexCoord1i(GLint s)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2517];
   ((void (APIENTRY *)(GLint s)) _func)(s);
}

GLAPI void APIENTRY glTexCoord1iv(const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2518];
   ((void (APIENTRY *)(const GLint *v)) _func)(v);
}

GLAPI void APIENTRY glTexCoord1s(GLshort s)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2519];
   ((void (APIENTRY *)(GLshort s)) _func)(s);
}

GLAPI void APIENTRY glTexCoord1sv(const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2520];
   ((void (APIENTRY *)(const GLshort *v)) _func)(v);
}

GLAPI void APIENTRY glTexCoord2d(GLdouble s, GLdouble t)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2525];
   ((void (APIENTRY *)(GLdouble s, GLdouble t)) _func)(s, t);
}

GLAPI void APIENTRY glTexCoord2dv(const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2526];
   ((void (APIENTRY *)(const GLdouble *v)) _func)(v);
}

GLAPI void APIENTRY glTexCoord2f(GLfloat s, GLfloat t)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2527];
   ((void (APIENTRY *)(GLfloat s, GLfloat t)) _func)(s, t);
}

GLAPI void APIENTRY glTexCoord2fv(const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2538];
   ((void (APIENTRY *)(const GLfloat *v)) _func)(v);
}

GLAPI void APIENTRY glTexCoord2i(GLint s, GLint t)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2541];
   ((void (APIENTRY *)(GLint s, GLint t)) _func)(s, t);
}

GLAPI void APIENTRY glTexCoord2iv(const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2542];
   ((void (APIENTRY *)(const GLint *v)) _func)(v);
}

GLAPI void APIENTRY glTexCoord2s(GLshort s, GLshort t)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2543];
   ((void (APIENTRY *)(GLshort s, GLshort t)) _func)(s, t);
}

GLAPI void APIENTRY glTexCoord2sv(const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2544];
   ((void (APIENTRY *)(const GLshort *v)) _func)(v);
}

GLAPI void APIENTRY glTexCoord3d(GLdouble s, GLdouble t, GLdouble r)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2549];
   ((void (APIENTRY *)(GLdouble s, GLdouble t, GLdouble r)) _func)(s, t, r);
}

GLAPI void APIENTRY glTexCoord3dv(const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2550];
   ((void (APIENTRY *)(const GLdouble *v)) _func)(v);
}

GLAPI void APIENTRY glTexCoord3f(GLfloat s, GLfloat t, GLfloat r)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2551];
   ((void (APIENTRY *)(GLfloat s, GLfloat t, GLfloat r)) _func)(s, t, r);
}

GLAPI void APIENTRY glTexCoord3fv(const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2552];
   ((void (APIENTRY *)(const GLfloat *v)) _func)(v);
}

GLAPI void APIENTRY glTexCoord3i(GLint s, GLint t, GLint r)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2555];
   ((void (APIENTRY *)(GLint s, GLint t, GLint r)) _func)(s, t, r);
}

GLAPI void APIENTRY glTexCoord3iv(const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2556];
   ((void (APIENTRY *)(const GLint *v)) _func)(v);
}

GLAPI void APIENTRY glTexCoord3s(GLshort s, GLshort t, GLshort r)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2557];
   ((void (APIENTRY *)(GLshort s, GLshort t, GLshort r)) _func)(s, t, r);
}

GLAPI void APIENTRY glTexCoord3sv(const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2558];
   ((void (APIENTRY *)(const GLshort *v)) _func)(v);
}

GLAPI void APIENTRY glTexCoord4d(GLdouble s, GLdouble t, GLdouble r, GLdouble q)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2563];
   ((void (APIENTRY *)(GLdouble s, GLdouble t, GLdouble r, GLdouble q)) _func)(s, t, r, q);
}

GLAPI void APIENTRY glTexCoord4dv(const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2564];
   ((void (APIENTRY *)(const GLdouble *v)) _func)(v);
}

GLAPI void APIENTRY glTexCoord4f(GLfloat s, GLfloat t, GLfloat r, GLfloat q)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2565];
   ((void (APIENTRY *)(GLfloat s, GLfloat t, GLfloat r, GLfloat q)) _func)(s, t, r, q);
}

GLAPI void APIENTRY glTexCoord4fv(const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2570];
   ((void (APIENTRY *)(const GLfloat *v)) _func)(v);
}

GLAPI void APIENTRY glTexCoord4i(GLint s, GLint t, GLint r, GLint q)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2573];
   ((void (APIENTRY *)(GLint s, GLint t, GLint r, GLint q)) _func)(s, t, r, q);
}

GLAPI void APIENTRY glTexCoord4iv(const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2574];
   ((void (APIENTRY *)(const GLint *v)) _func)(v);
}

GLAPI void APIENTRY glTexCoord4s(GLshort s, GLshort t, GLshort r, GLshort q)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2575];
   ((void (APIENTRY *)(GLshort s, GLshort t, GLshort r, GLshort q)) _func)(s, t, r, q);
}

GLAPI void APIENTRY glTexCoord4sv(const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2576];
   ((void (APIENTRY *)(const GLshort *v)) _func)(v);
}

GLAPI void APIENTRY glTexCoordP1ui(GLenum type, GLuint coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2580];
   ((void (APIENTRY *)(GLenum type, GLuint coords)) _func)(type, coords);
}

GLAPI void APIENTRY glTexCoordP1uiv(GLenum type, const GLuint *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2581];
   ((void (APIENTRY *)(GLenum type, const GLuint *coords)) _func)(type, coords);
}

GLAPI void APIENTRY glTexCoordP2ui(GLenum type, GLuint coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2582];
   ((void (APIENTRY *)(GLenum type, GLuint coords)) _func)(type, coords);
}

GLAPI void APIENTRY glTexCoordP2uiv(GLenum type, const GLuint *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2583];
   ((void (APIENTRY *)(GLenum type, const GLuint *coords)) _func)(type, coords);
}

GLAPI void APIENTRY glTexCoordP3ui(GLenum type, GLuint coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2584];
   ((void (APIENTRY *)(GLenum type, GLuint coords)) _func)(type, coords);
}

GLAPI void APIENTRY glTexCoordP3uiv(GLenum type, const GLuint *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2585];
   ((void (APIENTRY *)(GLenum type, const GLuint *coords)) _func)(type, coords);
}

GLAPI void APIENTRY glTexCoordP4ui(GLenum type, GLuint coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2586];
   ((void (APIENTRY *)(GLenum type, GLuint coords)) _func)(type, coords);
}

GLAPI void APIENTRY glTexCoordP4uiv(GLenum type, const GLuint *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2587];
   ((void (APIENTRY *)(GLenum type, const GLuint *coords)) _func)(type, coords);
}

GLAPI void APIENTRY glTexCoordPointer(GLint size, GLenum type, GLsizei stride, const void *pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2588];
   ((void (APIENTRY *)(GLint size, GLenum type, GLsizei stride, const void *pointer)) _func)(size, type, stride, pointer);
}

GLAPI void APIENTRY glTexEnvf(GLenum target, GLenum pname, GLfloat param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2592];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLfloat param)) _func)(target, pname, param);
}

GLAPI void APIENTRY glTexEnvfv(GLenum target, GLenum pname, const GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2593];
   ((void (APIENTRY *)(GLenum target, GLenum pname, const GLfloat *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glTexEnvi(GLenum target, GLenum pname, GLint param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2594];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLint param)) _func)(target, pname, param);
}

GLAPI void APIENTRY glTexEnviv(GLenum target, GLenum pname, const GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2595];
   ((void (APIENTRY *)(GLenum target, GLenum pname, const GLint *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glTexGend(GLenum coord, GLenum pname, GLdouble param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2603];
   ((void (APIENTRY *)(GLenum coord, GLenum pname, GLdouble param)) _func)(coord, pname, param);
}

GLAPI void APIENTRY glTexGendv(GLenum coord, GLenum pname, const GLdouble *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2604];
   ((void (APIENTRY *)(GLenum coord, GLenum pname, const GLdouble *params)) _func)(coord, pname, params);
}

GLAPI void APIENTRY glTexGenf(GLenum coord, GLenum pname, GLfloat param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2605];
   ((void (APIENTRY *)(GLenum coord, GLenum pname, GLfloat param)) _func)(coord, pname, param);
}

GLAPI void APIENTRY glTexGenfv(GLenum coord, GLenum pname, const GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2607];
   ((void (APIENTRY *)(GLenum coord, GLenum pname, const GLfloat *params)) _func)(coord, pname, params);
}

GLAPI void APIENTRY glTexGeni(GLenum coord, GLenum pname, GLint param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2609];
   ((void (APIENTRY *)(GLenum coord, GLenum pname, GLint param)) _func)(coord, pname, param);
}

GLAPI void APIENTRY glTexGeniv(GLenum coord, GLenum pname, const GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2611];
   ((void (APIENTRY *)(GLenum coord, GLenum pname, const GLint *params)) _func)(coord, pname, params);
}

GLAPI void APIENTRY glTexImage1D(GLenum target, GLint level, GLint internalformat, GLsizei width, GLint border, GLenum format, GLenum type, const void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2615];
   ((void (APIENTRY *)(GLenum target, GLint level, GLint internalformat, GLsizei width, GLint border, GLenum format, GLenum type, const void *pixels)) _func)(target, level, internalformat, width, border, format, type, pixels);
}

GLAPI void APIENTRY glTexImage2D(GLenum target, GLint level, GLint internalformat, GLsizei width, GLsizei height, GLint border, GLenum format, GLenum type, const void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2616];
   ((void (APIENTRY *)(GLenum target, GLint level, GLint internalformat, GLsizei width, GLsizei height, GLint border, GLenum format, GLenum type, const void *pixels)) _func)(target, level, internalformat, width, height, border, format, type, pixels);
}

GLAPI void APIENTRY glTexImage2DMultisample(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLboolean fixedsamplelocations)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2617];
   ((void (APIENTRY *)(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLboolean fixedsamplelocations)) _func)(target, samples, internalformat, width, height, fixedsamplelocations);
}

GLAPI void APIENTRY glTexImage3D(GLenum target, GLint level, GLint internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLenum format, GLenum type, const void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2619];
   ((void (APIENTRY *)(GLenum target, GLint level, GLint internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLenum format, GLenum type, const void *pixels)) _func)(target, level, internalformat, width, height, depth, border, format, type, pixels);
}

GLAPI void APIENTRY glTexImage3DMultisample(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedsamplelocations)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2621];
   ((void (APIENTRY *)(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedsamplelocations)) _func)(target, samples, internalformat, width, height, depth, fixedsamplelocations);
}

GLAPI void APIENTRY glTexParameterIiv(GLenum target, GLenum pname, const GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2629];
   ((void (APIENTRY *)(GLenum target, GLenum pname, const GLint *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glTexParameterIuiv(GLenum target, GLenum pname, const GLuint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2632];
   ((void (APIENTRY *)(GLenum target, GLenum pname, const GLuint *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glTexParameterf(GLenum target, GLenum pname, GLfloat param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2635];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLfloat param)) _func)(target, pname, param);
}

GLAPI void APIENTRY glTexParameterfv(GLenum target, GLenum pname, const GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2636];
   ((void (APIENTRY *)(GLenum target, GLenum pname, const GLfloat *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glTexParameteri(GLenum target, GLenum pname, GLint param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2637];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLint param)) _func)(target, pname, param);
}

GLAPI void APIENTRY glTexParameteriv(GLenum target, GLenum pname, const GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2638];
   ((void (APIENTRY *)(GLenum target, GLenum pname, const GLint *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glTexStorage1D(GLenum target, GLsizei levels, GLenum internalformat, GLsizei width)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2644];
   ((void (APIENTRY *)(GLenum target, GLsizei levels, GLenum internalformat, GLsizei width)) _func)(target, levels, internalformat, width);
}

GLAPI void APIENTRY glTexStorage2D(GLenum target, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2646];
   ((void (APIENTRY *)(GLenum target, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height)) _func)(target, levels, internalformat, width, height);
}

GLAPI void APIENTRY glTexStorage2DMultisample(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLboolean fixedsamplelocations)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2648];
   ((void (APIENTRY *)(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLboolean fixedsamplelocations)) _func)(target, samples, internalformat, width, height, fixedsamplelocations);
}

GLAPI void APIENTRY glTexStorage3D(GLenum target, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2649];
   ((void (APIENTRY *)(GLenum target, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth)) _func)(target, levels, internalformat, width, height, depth);
}

GLAPI void APIENTRY glTexStorage3DMultisample(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedsamplelocations)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2651];
   ((void (APIENTRY *)(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedsamplelocations)) _func)(target, samples, internalformat, width, height, depth, fixedsamplelocations);
}

GLAPI void APIENTRY glTexSubImage1D(GLenum target, GLint level, GLint xoffset, GLsizei width, GLenum format, GLenum type, const void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2661];
   ((void (APIENTRY *)(GLenum target, GLint level, GLint xoffset, GLsizei width, GLenum format, GLenum type, const void *pixels)) _func)(target, level, xoffset, width, format, type, pixels);
}

GLAPI void APIENTRY glTexSubImage2D(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLenum type, const void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2663];
   ((void (APIENTRY *)(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLenum type, const void *pixels)) _func)(target, level, xoffset, yoffset, width, height, format, type, pixels);
}

GLAPI void APIENTRY glTexSubImage3D(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2665];
   ((void (APIENTRY *)(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void *pixels)) _func)(target, level, xoffset, yoffset, zoffset, width, height, depth, format, type, pixels);
}

GLAPI void APIENTRY glTextureBarrier(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2671];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glTextureBuffer(GLuint texture, GLenum internalformat, GLuint buffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2673];
   ((void (APIENTRY *)(GLuint texture, GLenum internalformat, GLuint buffer)) _func)(texture, internalformat, buffer);
}

GLAPI void APIENTRY glTextureBufferRange(GLuint texture, GLenum internalformat, GLuint buffer, GLintptr offset, GLsizeiptr size)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2675];
   ((void (APIENTRY *)(GLuint texture, GLenum internalformat, GLuint buffer, GLintptr offset, GLsizeiptr size)) _func)(texture, internalformat, buffer, offset, size);
}

GLAPI void APIENTRY glTextureParameterIiv(GLuint texture, GLenum pname, const GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2691];
   ((void (APIENTRY *)(GLuint texture, GLenum pname, const GLint *params)) _func)(texture, pname, params);
}

GLAPI void APIENTRY glTextureParameterIuiv(GLuint texture, GLenum pname, const GLuint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2693];
   ((void (APIENTRY *)(GLuint texture, GLenum pname, const GLuint *params)) _func)(texture, pname, params);
}

GLAPI void APIENTRY glTextureParameterf(GLuint texture, GLenum pname, GLfloat param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2695];
   ((void (APIENTRY *)(GLuint texture, GLenum pname, GLfloat param)) _func)(texture, pname, param);
}

GLAPI void APIENTRY glTextureParameterfv(GLuint texture, GLenum pname, const GLfloat *param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2697];
   ((void (APIENTRY *)(GLuint texture, GLenum pname, const GLfloat *param)) _func)(texture, pname, param);
}

GLAPI void APIENTRY glTextureParameteri(GLuint texture, GLenum pname, GLint param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2699];
   ((void (APIENTRY *)(GLuint texture, GLenum pname, GLint param)) _func)(texture, pname, param);
}

GLAPI void APIENTRY glTextureParameteriv(GLuint texture, GLenum pname, const GLint *param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2701];
   ((void (APIENTRY *)(GLuint texture, GLenum pname, const GLint *param)) _func)(texture, pname, param);
}

GLAPI void APIENTRY glTextureStorage1D(GLuint texture, GLsizei levels, GLenum internalformat, GLsizei width)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2705];
   ((void (APIENTRY *)(GLuint texture, GLsizei levels, GLenum internalformat, GLsizei width)) _func)(texture, levels, internalformat, width);
}

GLAPI void APIENTRY glTextureStorage2D(GLuint texture, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2707];
   ((void (APIENTRY *)(GLuint texture, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height)) _func)(texture, levels, internalformat, width, height);
}

GLAPI void APIENTRY glTextureStorage2DMultisample(GLuint texture, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLboolean fixedsamplelocations)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2709];
   ((void (APIENTRY *)(GLuint texture, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLboolean fixedsamplelocations)) _func)(texture, samples, internalformat, width, height, fixedsamplelocations);
}

GLAPI void APIENTRY glTextureStorage3D(GLuint texture, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2711];
   ((void (APIENTRY *)(GLuint texture, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth)) _func)(texture, levels, internalformat, width, height, depth);
}

GLAPI void APIENTRY glTextureStorage3DMultisample(GLuint texture, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedsamplelocations)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2713];
   ((void (APIENTRY *)(GLuint texture, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedsamplelocations)) _func)(texture, samples, internalformat, width, height, depth, fixedsamplelocations);
}

GLAPI void APIENTRY glTextureSubImage1D(GLuint texture, GLint level, GLint xoffset, GLsizei width, GLenum format, GLenum type, const void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2721];
   ((void (APIENTRY *)(GLuint texture, GLint level, GLint xoffset, GLsizei width, GLenum format, GLenum type, const void *pixels)) _func)(texture, level, xoffset, width, format, type, pixels);
}

GLAPI void APIENTRY glTextureSubImage2D(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLenum type, const void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2723];
   ((void (APIENTRY *)(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLenum type, const void *pixels)) _func)(texture, level, xoffset, yoffset, width, height, format, type, pixels);
}

GLAPI void APIENTRY glTextureSubImage3D(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2725];
   ((void (APIENTRY *)(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void *pixels)) _func)(texture, level, xoffset, yoffset, zoffset, width, height, depth, format, type, pixels);
}

GLAPI void APIENTRY glTextureView(GLuint texture, GLenum target, GLuint origtexture, GLenum internalformat, GLuint minlevel, GLuint numlevels, GLuint minlayer, GLuint numlayers)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2727];
   ((void (APIENTRY *)(GLuint texture, GLenum target, GLuint origtexture, GLenum internalformat, GLuint minlevel, GLuint numlevels, GLuint minlayer, GLuint numlayers)) _func)(texture, target, origtexture, internalformat, minlevel, numlevels, minlayer, numlayers);
}

GLAPI void APIENTRY glTransformFeedbackBufferBase(GLuint xfb, GLuint index, GLuint buffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2732];
   ((void (APIENTRY *)(GLuint xfb, GLuint index, GLuint buffer)) _func)(xfb, index, buffer);
}

GLAPI void APIENTRY glTransformFeedbackBufferRange(GLuint xfb, GLuint index, GLuint buffer, GLintptr offset, GLsizeiptr size)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2733];
   ((void (APIENTRY *)(GLuint xfb, GLuint index, GLuint buffer, GLintptr offset, GLsizeiptr size)) _func)(xfb, index, buffer, offset, size);
}

GLAPI void APIENTRY glTransformFeedbackVaryings(GLuint program, GLsizei count, const GLchar *const *varyings, GLenum bufferMode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2735];
   ((void (APIENTRY *)(GLuint program, GLsizei count, const GLchar *const *varyings, GLenum bufferMode)) _func)(program, count, varyings, bufferMode);
}

GLAPI void APIENTRY glTranslated(GLdouble x, GLdouble y, GLdouble z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2739];
   ((void (APIENTRY *)(GLdouble x, GLdouble y, GLdouble z)) _func)(x, y, z);
}

GLAPI void APIENTRY glTranslatef(GLfloat x, GLfloat y, GLfloat z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2740];
   ((void (APIENTRY *)(GLfloat x, GLfloat y, GLfloat z)) _func)(x, y, z);
}

GLAPI void APIENTRY glUniform1d(GLint location, GLdouble x)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2743];
   ((void (APIENTRY *)(GLint location, GLdouble x)) _func)(location, x);
}

GLAPI void APIENTRY glUniform1dv(GLint location, GLsizei count, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2744];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLdouble *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniform1f(GLint location, GLfloat v0)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2745];
   ((void (APIENTRY *)(GLint location, GLfloat v0)) _func)(location, v0);
}

GLAPI void APIENTRY glUniform1fv(GLint location, GLsizei count, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2747];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLfloat *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniform1i(GLint location, GLint v0)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2749];
   ((void (APIENTRY *)(GLint location, GLint v0)) _func)(location, v0);
}

GLAPI void APIENTRY glUniform1iv(GLint location, GLsizei count, const GLint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2755];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLint *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniform1ui(GLint location, GLuint v0)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2757];
   ((void (APIENTRY *)(GLint location, GLuint v0)) _func)(location, v0);
}

GLAPI void APIENTRY glUniform1uiv(GLint location, GLsizei count, const GLuint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2763];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLuint *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniform2d(GLint location, GLdouble x, GLdouble y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2765];
   ((void (APIENTRY *)(GLint location, GLdouble x, GLdouble y)) _func)(location, x, y);
}

GLAPI void APIENTRY glUniform2dv(GLint location, GLsizei count, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2766];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLdouble *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniform2f(GLint location, GLfloat v0, GLfloat v1)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2767];
   ((void (APIENTRY *)(GLint location, GLfloat v0, GLfloat v1)) _func)(location, v0, v1);
}

GLAPI void APIENTRY glUniform2fv(GLint location, GLsizei count, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2769];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLfloat *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniform2i(GLint location, GLint v0, GLint v1)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2771];
   ((void (APIENTRY *)(GLint location, GLint v0, GLint v1)) _func)(location, v0, v1);
}

GLAPI void APIENTRY glUniform2iv(GLint location, GLsizei count, const GLint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2777];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLint *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniform2ui(GLint location, GLuint v0, GLuint v1)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2779];
   ((void (APIENTRY *)(GLint location, GLuint v0, GLuint v1)) _func)(location, v0, v1);
}

GLAPI void APIENTRY glUniform2uiv(GLint location, GLsizei count, const GLuint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2785];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLuint *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniform3d(GLint location, GLdouble x, GLdouble y, GLdouble z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2787];
   ((void (APIENTRY *)(GLint location, GLdouble x, GLdouble y, GLdouble z)) _func)(location, x, y, z);
}

GLAPI void APIENTRY glUniform3dv(GLint location, GLsizei count, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2788];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLdouble *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniform3f(GLint location, GLfloat v0, GLfloat v1, GLfloat v2)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2789];
   ((void (APIENTRY *)(GLint location, GLfloat v0, GLfloat v1, GLfloat v2)) _func)(location, v0, v1, v2);
}

GLAPI void APIENTRY glUniform3fv(GLint location, GLsizei count, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2791];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLfloat *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniform3i(GLint location, GLint v0, GLint v1, GLint v2)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2793];
   ((void (APIENTRY *)(GLint location, GLint v0, GLint v1, GLint v2)) _func)(location, v0, v1, v2);
}

GLAPI void APIENTRY glUniform3iv(GLint location, GLsizei count, const GLint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2799];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLint *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniform3ui(GLint location, GLuint v0, GLuint v1, GLuint v2)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2801];
   ((void (APIENTRY *)(GLint location, GLuint v0, GLuint v1, GLuint v2)) _func)(location, v0, v1, v2);
}

GLAPI void APIENTRY glUniform3uiv(GLint location, GLsizei count, const GLuint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2807];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLuint *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniform4d(GLint location, GLdouble x, GLdouble y, GLdouble z, GLdouble w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2809];
   ((void (APIENTRY *)(GLint location, GLdouble x, GLdouble y, GLdouble z, GLdouble w)) _func)(location, x, y, z, w);
}

GLAPI void APIENTRY glUniform4dv(GLint location, GLsizei count, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2810];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLdouble *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniform4f(GLint location, GLfloat v0, GLfloat v1, GLfloat v2, GLfloat v3)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2811];
   ((void (APIENTRY *)(GLint location, GLfloat v0, GLfloat v1, GLfloat v2, GLfloat v3)) _func)(location, v0, v1, v2, v3);
}

GLAPI void APIENTRY glUniform4fv(GLint location, GLsizei count, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2813];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLfloat *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniform4i(GLint location, GLint v0, GLint v1, GLint v2, GLint v3)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2815];
   ((void (APIENTRY *)(GLint location, GLint v0, GLint v1, GLint v2, GLint v3)) _func)(location, v0, v1, v2, v3);
}

GLAPI void APIENTRY glUniform4iv(GLint location, GLsizei count, const GLint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2821];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLint *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniform4ui(GLint location, GLuint v0, GLuint v1, GLuint v2, GLuint v3)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2823];
   ((void (APIENTRY *)(GLint location, GLuint v0, GLuint v1, GLuint v2, GLuint v3)) _func)(location, v0, v1, v2, v3);
}

GLAPI void APIENTRY glUniform4uiv(GLint location, GLsizei count, const GLuint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2829];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLuint *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniformBlockBinding(GLuint program, GLuint uniformBlockIndex, GLuint uniformBlockBinding)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2831];
   ((void (APIENTRY *)(GLuint program, GLuint uniformBlockIndex, GLuint uniformBlockBinding)) _func)(program, uniformBlockIndex, uniformBlockBinding);
}

GLAPI void APIENTRY glUniformMatrix2dv(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2839];
   ((void (APIENTRY *)(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)) _func)(location, count, transpose, value);
}

GLAPI void APIENTRY glUniformMatrix2fv(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2840];
   ((void (APIENTRY *)(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)) _func)(location, count, transpose, value);
}

GLAPI void APIENTRY glUniformMatrix2x3dv(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2842];
   ((void (APIENTRY *)(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)) _func)(location, count, transpose, value);
}

GLAPI void APIENTRY glUniformMatrix2x3fv(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2843];
   ((void (APIENTRY *)(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)) _func)(location, count, transpose, value);
}

GLAPI void APIENTRY glUniformMatrix2x4dv(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2845];
   ((void (APIENTRY *)(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)) _func)(location, count, transpose, value);
}

GLAPI void APIENTRY glUniformMatrix2x4fv(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2846];
   ((void (APIENTRY *)(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)) _func)(location, count, transpose, value);
}

GLAPI void APIENTRY glUniformMatrix3dv(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2848];
   ((void (APIENTRY *)(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)) _func)(location, count, transpose, value);
}

GLAPI void APIENTRY glUniformMatrix3fv(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2849];
   ((void (APIENTRY *)(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)) _func)(location, count, transpose, value);
}

GLAPI void APIENTRY glUniformMatrix3x2dv(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2851];
   ((void (APIENTRY *)(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)) _func)(location, count, transpose, value);
}

GLAPI void APIENTRY glUniformMatrix3x2fv(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2852];
   ((void (APIENTRY *)(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)) _func)(location, count, transpose, value);
}

GLAPI void APIENTRY glUniformMatrix3x4dv(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2854];
   ((void (APIENTRY *)(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)) _func)(location, count, transpose, value);
}

GLAPI void APIENTRY glUniformMatrix3x4fv(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2855];
   ((void (APIENTRY *)(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)) _func)(location, count, transpose, value);
}

GLAPI void APIENTRY glUniformMatrix4dv(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2857];
   ((void (APIENTRY *)(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)) _func)(location, count, transpose, value);
}

GLAPI void APIENTRY glUniformMatrix4fv(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2858];
   ((void (APIENTRY *)(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)) _func)(location, count, transpose, value);
}

GLAPI void APIENTRY glUniformMatrix4x2dv(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2860];
   ((void (APIENTRY *)(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)) _func)(location, count, transpose, value);
}

GLAPI void APIENTRY glUniformMatrix4x2fv(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2861];
   ((void (APIENTRY *)(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)) _func)(location, count, transpose, value);
}

GLAPI void APIENTRY glUniformMatrix4x3dv(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2863];
   ((void (APIENTRY *)(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)) _func)(location, count, transpose, value);
}

GLAPI void APIENTRY glUniformMatrix4x3fv(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2864];
   ((void (APIENTRY *)(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)) _func)(location, count, transpose, value);
}

GLAPI void APIENTRY glUniformSubroutinesuiv(GLenum shadertype, GLsizei count, const GLuint *indices)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2866];
   ((void (APIENTRY *)(GLenum shadertype, GLsizei count, const GLuint *indices)) _func)(shadertype, count, indices);
}

GLAPI GLboolean APIENTRY glUnmapBuffer(GLenum target)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2870];
   return ((GLboolean (APIENTRY *)(GLenum target)) _func)(target);
}

GLAPI GLboolean APIENTRY glUnmapNamedBuffer(GLuint buffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2873];
   return ((GLboolean (APIENTRY *)(GLuint buffer)) _func)(buffer);
}

GLAPI void APIENTRY glUseProgram(GLuint program)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2879];
   ((void (APIENTRY *)(GLuint program)) _func)(program);
}

GLAPI void APIENTRY glUseProgramStages(GLuint pipeline, GLbitfield stages, GLuint program)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2881];
   ((void (APIENTRY *)(GLuint pipeline, GLbitfield stages, GLuint program)) _func)(pipeline, stages, program);
}

GLAPI void APIENTRY glValidateProgram(GLuint program)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2896];
   ((void (APIENTRY *)(GLuint program)) _func)(program);
}

GLAPI void APIENTRY glValidateProgramPipeline(GLuint pipeline)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2898];
   ((void (APIENTRY *)(GLuint pipeline)) _func)(pipeline);
}

GLAPI void APIENTRY glVertex2d(GLdouble x, GLdouble y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2912];
   ((void (APIENTRY *)(GLdouble x, GLdouble y)) _func)(x, y);
}

GLAPI void APIENTRY glVertex2dv(const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2913];
   ((void (APIENTRY *)(const GLdouble *v)) _func)(v);
}

GLAPI void APIENTRY glVertex2f(GLfloat x, GLfloat y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2914];
   ((void (APIENTRY *)(GLfloat x, GLfloat y)) _func)(x, y);
}

GLAPI void APIENTRY glVertex2fv(const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2915];
   ((void (APIENTRY *)(const GLfloat *v)) _func)(v);
}

GLAPI void APIENTRY glVertex2i(GLint x, GLint y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2918];
   ((void (APIENTRY *)(GLint x, GLint y)) _func)(x, y);
}

GLAPI void APIENTRY glVertex2iv(const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2919];
   ((void (APIENTRY *)(const GLint *v)) _func)(v);
}

GLAPI void APIENTRY glVertex2s(GLshort x, GLshort y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2920];
   ((void (APIENTRY *)(GLshort x, GLshort y)) _func)(x, y);
}

GLAPI void APIENTRY glVertex2sv(const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2921];
   ((void (APIENTRY *)(const GLshort *v)) _func)(v);
}

GLAPI void APIENTRY glVertex3d(GLdouble x, GLdouble y, GLdouble z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2926];
   ((void (APIENTRY *)(GLdouble x, GLdouble y, GLdouble z)) _func)(x, y, z);
}

GLAPI void APIENTRY glVertex3dv(const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2927];
   ((void (APIENTRY *)(const GLdouble *v)) _func)(v);
}

GLAPI void APIENTRY glVertex3f(GLfloat x, GLfloat y, GLfloat z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2928];
   ((void (APIENTRY *)(GLfloat x, GLfloat y, GLfloat z)) _func)(x, y, z);
}

GLAPI void APIENTRY glVertex3fv(const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2929];
   ((void (APIENTRY *)(const GLfloat *v)) _func)(v);
}

GLAPI void APIENTRY glVertex3i(GLint x, GLint y, GLint z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2932];
   ((void (APIENTRY *)(GLint x, GLint y, GLint z)) _func)(x, y, z);
}

GLAPI void APIENTRY glVertex3iv(const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2933];
   ((void (APIENTRY *)(const GLint *v)) _func)(v);
}

GLAPI void APIENTRY glVertex3s(GLshort x, GLshort y, GLshort z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2934];
   ((void (APIENTRY *)(GLshort x, GLshort y, GLshort z)) _func)(x, y, z);
}

GLAPI void APIENTRY glVertex3sv(const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2935];
   ((void (APIENTRY *)(const GLshort *v)) _func)(v);
}

GLAPI void APIENTRY glVertex4d(GLdouble x, GLdouble y, GLdouble z, GLdouble w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2940];
   ((void (APIENTRY *)(GLdouble x, GLdouble y, GLdouble z, GLdouble w)) _func)(x, y, z, w);
}

GLAPI void APIENTRY glVertex4dv(const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2941];
   ((void (APIENTRY *)(const GLdouble *v)) _func)(v);
}

GLAPI void APIENTRY glVertex4f(GLfloat x, GLfloat y, GLfloat z, GLfloat w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2942];
   ((void (APIENTRY *)(GLfloat x, GLfloat y, GLfloat z, GLfloat w)) _func)(x, y, z, w);
}

GLAPI void APIENTRY glVertex4fv(const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2943];
   ((void (APIENTRY *)(const GLfloat *v)) _func)(v);
}

GLAPI void APIENTRY glVertex4i(GLint x, GLint y, GLint z, GLint w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2946];
   ((void (APIENTRY *)(GLint x, GLint y, GLint z, GLint w)) _func)(x, y, z, w);
}

GLAPI void APIENTRY glVertex4iv(const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2947];
   ((void (APIENTRY *)(const GLint *v)) _func)(v);
}

GLAPI void APIENTRY glVertex4s(GLshort x, GLshort y, GLshort z, GLshort w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2948];
   ((void (APIENTRY *)(GLshort x, GLshort y, GLshort z, GLshort w)) _func)(x, y, z, w);
}

GLAPI void APIENTRY glVertex4sv(const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2949];
   ((void (APIENTRY *)(const GLshort *v)) _func)(v);
}

GLAPI void APIENTRY glVertexArrayAttribBinding(GLuint vaobj, GLuint attribindex, GLuint bindingindex)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2952];
   ((void (APIENTRY *)(GLuint vaobj, GLuint attribindex, GLuint bindingindex)) _func)(vaobj, attribindex, bindingindex);
}

GLAPI void APIENTRY glVertexArrayAttribFormat(GLuint vaobj, GLuint attribindex, GLint size, GLenum type, GLboolean normalized, GLuint relativeoffset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2953];
   ((void (APIENTRY *)(GLuint vaobj, GLuint attribindex, GLint size, GLenum type, GLboolean normalized, GLuint relativeoffset)) _func)(vaobj, attribindex, size, type, normalized, relativeoffset);
}

GLAPI void APIENTRY glVertexArrayAttribIFormat(GLuint vaobj, GLuint attribindex, GLint size, GLenum type, GLuint relativeoffset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2954];
   ((void (APIENTRY *)(GLuint vaobj, GLuint attribindex, GLint size, GLenum type, GLuint relativeoffset)) _func)(vaobj, attribindex, size, type, relativeoffset);
}

GLAPI void APIENTRY glVertexArrayAttribLFormat(GLuint vaobj, GLuint attribindex, GLint size, GLenum type, GLuint relativeoffset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2955];
   ((void (APIENTRY *)(GLuint vaobj, GLuint attribindex, GLint size, GLenum type, GLuint relativeoffset)) _func)(vaobj, attribindex, size, type, relativeoffset);
}

GLAPI void APIENTRY glVertexArrayBindingDivisor(GLuint vaobj, GLuint bindingindex, GLuint divisor)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2957];
   ((void (APIENTRY *)(GLuint vaobj, GLuint bindingindex, GLuint divisor)) _func)(vaobj, bindingindex, divisor);
}

GLAPI void APIENTRY glVertexArrayElementBuffer(GLuint vaobj, GLuint buffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2960];
   ((void (APIENTRY *)(GLuint vaobj, GLuint buffer)) _func)(vaobj, buffer);
}

GLAPI void APIENTRY glVertexArrayVertexBuffer(GLuint vaobj, GLuint bindingindex, GLuint buffer, GLintptr offset, GLsizei stride)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2979];
   ((void (APIENTRY *)(GLuint vaobj, GLuint bindingindex, GLuint buffer, GLintptr offset, GLsizei stride)) _func)(vaobj, bindingindex, buffer, offset, stride);
}

GLAPI void APIENTRY glVertexArrayVertexBuffers(GLuint vaobj, GLuint first, GLsizei count, const GLuint *buffers, const GLintptr *offsets, const GLsizei *strides)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2980];
   ((void (APIENTRY *)(GLuint vaobj, GLuint first, GLsizei count, const GLuint *buffers, const GLintptr *offsets, const GLsizei *strides)) _func)(vaobj, first, count, buffers, offsets, strides);
}

GLAPI void APIENTRY glVertexAttrib1d(GLuint index, GLdouble x)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2982];
   ((void (APIENTRY *)(GLuint index, GLdouble x)) _func)(index, x);
}

GLAPI void APIENTRY glVertexAttrib1dv(GLuint index, const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2985];
   ((void (APIENTRY *)(GLuint index, const GLdouble *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib1f(GLuint index, GLfloat x)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2988];
   ((void (APIENTRY *)(GLuint index, GLfloat x)) _func)(index, x);
}

GLAPI void APIENTRY glVertexAttrib1fv(GLuint index, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2991];
   ((void (APIENTRY *)(GLuint index, const GLfloat *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib1s(GLuint index, GLshort x)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2996];
   ((void (APIENTRY *)(GLuint index, GLshort x)) _func)(index, x);
}

GLAPI void APIENTRY glVertexAttrib1sv(GLuint index, const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2999];
   ((void (APIENTRY *)(GLuint index, const GLshort *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib2d(GLuint index, GLdouble x, GLdouble y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3002];
   ((void (APIENTRY *)(GLuint index, GLdouble x, GLdouble y)) _func)(index, x, y);
}

GLAPI void APIENTRY glVertexAttrib2dv(GLuint index, const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3005];
   ((void (APIENTRY *)(GLuint index, const GLdouble *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib2f(GLuint index, GLfloat x, GLfloat y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3008];
   ((void (APIENTRY *)(GLuint index, GLfloat x, GLfloat y)) _func)(index, x, y);
}

GLAPI void APIENTRY glVertexAttrib2fv(GLuint index, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3011];
   ((void (APIENTRY *)(GLuint index, const GLfloat *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib2s(GLuint index, GLshort x, GLshort y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3016];
   ((void (APIENTRY *)(GLuint index, GLshort x, GLshort y)) _func)(index, x, y);
}

GLAPI void APIENTRY glVertexAttrib2sv(GLuint index, const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3019];
   ((void (APIENTRY *)(GLuint index, const GLshort *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib3d(GLuint index, GLdouble x, GLdouble y, GLdouble z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3022];
   ((void (APIENTRY *)(GLuint index, GLdouble x, GLdouble y, GLdouble z)) _func)(index, x, y, z);
}

GLAPI void APIENTRY glVertexAttrib3dv(GLuint index, const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3025];
   ((void (APIENTRY *)(GLuint index, const GLdouble *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib3f(GLuint index, GLfloat x, GLfloat y, GLfloat z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3028];
   ((void (APIENTRY *)(GLuint index, GLfloat x, GLfloat y, GLfloat z)) _func)(index, x, y, z);
}

GLAPI void APIENTRY glVertexAttrib3fv(GLuint index, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3031];
   ((void (APIENTRY *)(GLuint index, const GLfloat *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib3s(GLuint index, GLshort x, GLshort y, GLshort z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3036];
   ((void (APIENTRY *)(GLuint index, GLshort x, GLshort y, GLshort z)) _func)(index, x, y, z);
}

GLAPI void APIENTRY glVertexAttrib3sv(GLuint index, const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3039];
   ((void (APIENTRY *)(GLuint index, const GLshort *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib4Nbv(GLuint index, const GLbyte *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3042];
   ((void (APIENTRY *)(GLuint index, const GLbyte *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib4Niv(GLuint index, const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3044];
   ((void (APIENTRY *)(GLuint index, const GLint *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib4Nsv(GLuint index, const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3046];
   ((void (APIENTRY *)(GLuint index, const GLshort *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib4Nub(GLuint index, GLubyte x, GLubyte y, GLubyte z, GLubyte w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3048];
   ((void (APIENTRY *)(GLuint index, GLubyte x, GLubyte y, GLubyte z, GLubyte w)) _func)(index, x, y, z, w);
}

GLAPI void APIENTRY glVertexAttrib4Nubv(GLuint index, const GLubyte *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3050];
   ((void (APIENTRY *)(GLuint index, const GLubyte *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib4Nuiv(GLuint index, const GLuint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3052];
   ((void (APIENTRY *)(GLuint index, const GLuint *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib4Nusv(GLuint index, const GLushort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3054];
   ((void (APIENTRY *)(GLuint index, const GLushort *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib4bv(GLuint index, const GLbyte *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3056];
   ((void (APIENTRY *)(GLuint index, const GLbyte *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib4d(GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3058];
   ((void (APIENTRY *)(GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w)) _func)(index, x, y, z, w);
}

GLAPI void APIENTRY glVertexAttrib4dv(GLuint index, const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3061];
   ((void (APIENTRY *)(GLuint index, const GLdouble *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib4f(GLuint index, GLfloat x, GLfloat y, GLfloat z, GLfloat w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3064];
   ((void (APIENTRY *)(GLuint index, GLfloat x, GLfloat y, GLfloat z, GLfloat w)) _func)(index, x, y, z, w);
}

GLAPI void APIENTRY glVertexAttrib4fv(GLuint index, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3067];
   ((void (APIENTRY *)(GLuint index, const GLfloat *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib4iv(GLuint index, const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3072];
   ((void (APIENTRY *)(GLuint index, const GLint *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib4s(GLuint index, GLshort x, GLshort y, GLshort z, GLshort w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3074];
   ((void (APIENTRY *)(GLuint index, GLshort x, GLshort y, GLshort z, GLshort w)) _func)(index, x, y, z, w);
}

GLAPI void APIENTRY glVertexAttrib4sv(GLuint index, const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3077];
   ((void (APIENTRY *)(GLuint index, const GLshort *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib4ubv(GLuint index, const GLubyte *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3081];
   ((void (APIENTRY *)(GLuint index, const GLubyte *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib4uiv(GLuint index, const GLuint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3084];
   ((void (APIENTRY *)(GLuint index, const GLuint *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib4usv(GLuint index, const GLushort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3086];
   ((void (APIENTRY *)(GLuint index, const GLushort *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttribBinding(GLuint attribindex, GLuint bindingindex)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3089];
   ((void (APIENTRY *)(GLuint attribindex, GLuint bindingindex)) _func)(attribindex, bindingindex);
}

GLAPI void APIENTRY glVertexAttribDivisor(GLuint index, GLuint divisor)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3090];
   ((void (APIENTRY *)(GLuint index, GLuint divisor)) _func)(index, divisor);
}

GLAPI void APIENTRY glVertexAttribFormat(GLuint attribindex, GLint size, GLenum type, GLboolean normalized, GLuint relativeoffset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3095];
   ((void (APIENTRY *)(GLuint attribindex, GLint size, GLenum type, GLboolean normalized, GLuint relativeoffset)) _func)(attribindex, size, type, normalized, relativeoffset);
}

GLAPI void APIENTRY glVertexAttribI1i(GLuint index, GLint x)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3097];
   ((void (APIENTRY *)(GLuint index, GLint x)) _func)(index, x);
}

GLAPI void APIENTRY glVertexAttribI1iv(GLuint index, const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3099];
   ((void (APIENTRY *)(GLuint index, const GLint *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttribI1ui(GLuint index, GLuint x)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3101];
   ((void (APIENTRY *)(GLuint index, GLuint x)) _func)(index, x);
}

GLAPI void APIENTRY glVertexAttribI1uiv(GLuint index, const GLuint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3103];
   ((void (APIENTRY *)(GLuint index, const GLuint *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttribI2i(GLuint index, GLint x, GLint y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3105];
   ((void (APIENTRY *)(GLuint index, GLint x, GLint y)) _func)(index, x, y);
}

GLAPI void APIENTRY glVertexAttribI2iv(GLuint index, const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3107];
   ((void (APIENTRY *)(GLuint index, const GLint *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttribI2ui(GLuint index, GLuint x, GLuint y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3109];
   ((void (APIENTRY *)(GLuint index, GLuint x, GLuint y)) _func)(index, x, y);
}

GLAPI void APIENTRY glVertexAttribI2uiv(GLuint index, const GLuint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3111];
   ((void (APIENTRY *)(GLuint index, const GLuint *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttribI3i(GLuint index, GLint x, GLint y, GLint z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3113];
   ((void (APIENTRY *)(GLuint index, GLint x, GLint y, GLint z)) _func)(index, x, y, z);
}

GLAPI void APIENTRY glVertexAttribI3iv(GLuint index, const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3115];
   ((void (APIENTRY *)(GLuint index, const GLint *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttribI3ui(GLuint index, GLuint x, GLuint y, GLuint z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3117];
   ((void (APIENTRY *)(GLuint index, GLuint x, GLuint y, GLuint z)) _func)(index, x, y, z);
}

GLAPI void APIENTRY glVertexAttribI3uiv(GLuint index, const GLuint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3119];
   ((void (APIENTRY *)(GLuint index, const GLuint *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttribI4bv(GLuint index, const GLbyte *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3121];
   ((void (APIENTRY *)(GLuint index, const GLbyte *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttribI4i(GLuint index, GLint x, GLint y, GLint z, GLint w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3123];
   ((void (APIENTRY *)(GLuint index, GLint x, GLint y, GLint z, GLint w)) _func)(index, x, y, z, w);
}

GLAPI void APIENTRY glVertexAttribI4iv(GLuint index, const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3125];
   ((void (APIENTRY *)(GLuint index, const GLint *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttribI4sv(GLuint index, const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3127];
   ((void (APIENTRY *)(GLuint index, const GLshort *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttribI4ubv(GLuint index, const GLubyte *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3129];
   ((void (APIENTRY *)(GLuint index, const GLubyte *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttribI4ui(GLuint index, GLuint x, GLuint y, GLuint z, GLuint w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3131];
   ((void (APIENTRY *)(GLuint index, GLuint x, GLuint y, GLuint z, GLuint w)) _func)(index, x, y, z, w);
}

GLAPI void APIENTRY glVertexAttribI4uiv(GLuint index, const GLuint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3133];
   ((void (APIENTRY *)(GLuint index, const GLuint *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttribI4usv(GLuint index, const GLushort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3135];
   ((void (APIENTRY *)(GLuint index, const GLushort *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttribIFormat(GLuint attribindex, GLint size, GLenum type, GLuint relativeoffset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3137];
   ((void (APIENTRY *)(GLuint attribindex, GLint size, GLenum type, GLuint relativeoffset)) _func)(attribindex, size, type, relativeoffset);
}

GLAPI void APIENTRY glVertexAttribIPointer(GLuint index, GLint size, GLenum type, GLsizei stride, const void *pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3139];
   ((void (APIENTRY *)(GLuint index, GLint size, GLenum type, GLsizei stride, const void *pointer)) _func)(index, size, type, stride, pointer);
}

GLAPI void APIENTRY glVertexAttribL1d(GLuint index, GLdouble x)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3141];
   ((void (APIENTRY *)(GLuint index, GLdouble x)) _func)(index, x);
}

GLAPI void APIENTRY glVertexAttribL1dv(GLuint index, const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3143];
   ((void (APIENTRY *)(GLuint index, const GLdouble *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttribL2d(GLuint index, GLdouble x, GLdouble y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3151];
   ((void (APIENTRY *)(GLuint index, GLdouble x, GLdouble y)) _func)(index, x, y);
}

GLAPI void APIENTRY glVertexAttribL2dv(GLuint index, const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3153];
   ((void (APIENTRY *)(GLuint index, const GLdouble *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttribL3d(GLuint index, GLdouble x, GLdouble y, GLdouble z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3159];
   ((void (APIENTRY *)(GLuint index, GLdouble x, GLdouble y, GLdouble z)) _func)(index, x, y, z);
}

GLAPI void APIENTRY glVertexAttribL3dv(GLuint index, const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3161];
   ((void (APIENTRY *)(GLuint index, const GLdouble *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttribL4d(GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3167];
   ((void (APIENTRY *)(GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w)) _func)(index, x, y, z, w);
}

GLAPI void APIENTRY glVertexAttribL4dv(GLuint index, const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3169];
   ((void (APIENTRY *)(GLuint index, const GLdouble *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttribLFormat(GLuint attribindex, GLint size, GLenum type, GLuint relativeoffset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3175];
   ((void (APIENTRY *)(GLuint attribindex, GLint size, GLenum type, GLuint relativeoffset)) _func)(attribindex, size, type, relativeoffset);
}

GLAPI void APIENTRY glVertexAttribLPointer(GLuint index, GLint size, GLenum type, GLsizei stride, const void *pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3177];
   ((void (APIENTRY *)(GLuint index, GLint size, GLenum type, GLsizei stride, const void *pointer)) _func)(index, size, type, stride, pointer);
}

GLAPI void APIENTRY glVertexAttribP1ui(GLuint index, GLenum type, GLboolean normalized, GLuint value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3179];
   ((void (APIENTRY *)(GLuint index, GLenum type, GLboolean normalized, GLuint value)) _func)(index, type, normalized, value);
}

GLAPI void APIENTRY glVertexAttribP1uiv(GLuint index, GLenum type, GLboolean normalized, const GLuint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3180];
   ((void (APIENTRY *)(GLuint index, GLenum type, GLboolean normalized, const GLuint *value)) _func)(index, type, normalized, value);
}

GLAPI void APIENTRY glVertexAttribP2ui(GLuint index, GLenum type, GLboolean normalized, GLuint value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3181];
   ((void (APIENTRY *)(GLuint index, GLenum type, GLboolean normalized, GLuint value)) _func)(index, type, normalized, value);
}

GLAPI void APIENTRY glVertexAttribP2uiv(GLuint index, GLenum type, GLboolean normalized, const GLuint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3182];
   ((void (APIENTRY *)(GLuint index, GLenum type, GLboolean normalized, const GLuint *value)) _func)(index, type, normalized, value);
}

GLAPI void APIENTRY glVertexAttribP3ui(GLuint index, GLenum type, GLboolean normalized, GLuint value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3183];
   ((void (APIENTRY *)(GLuint index, GLenum type, GLboolean normalized, GLuint value)) _func)(index, type, normalized, value);
}

GLAPI void APIENTRY glVertexAttribP3uiv(GLuint index, GLenum type, GLboolean normalized, const GLuint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3184];
   ((void (APIENTRY *)(GLuint index, GLenum type, GLboolean normalized, const GLuint *value)) _func)(index, type, normalized, value);
}

GLAPI void APIENTRY glVertexAttribP4ui(GLuint index, GLenum type, GLboolean normalized, GLuint value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3185];
   ((void (APIENTRY *)(GLuint index, GLenum type, GLboolean normalized, GLuint value)) _func)(index, type, normalized, value);
}

GLAPI void APIENTRY glVertexAttribP4uiv(GLuint index, GLenum type, GLboolean normalized, const GLuint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3186];
   ((void (APIENTRY *)(GLuint index, GLenum type, GLboolean normalized, const GLuint *value)) _func)(index, type, normalized, value);
}

GLAPI void APIENTRY glVertexAttribPointer(GLuint index, GLint size, GLenum type, GLboolean normalized, GLsizei stride, const void *pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3188];
   ((void (APIENTRY *)(GLuint index, GLint size, GLenum type, GLboolean normalized, GLsizei stride, const void *pointer)) _func)(index, size, type, normalized, stride, pointer);
}

GLAPI void APIENTRY glVertexBindingDivisor(GLuint bindingindex, GLuint divisor)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3208];
   ((void (APIENTRY *)(GLuint bindingindex, GLuint divisor)) _func)(bindingindex, divisor);
}

GLAPI void APIENTRY glVertexP2ui(GLenum type, GLuint value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3213];
   ((void (APIENTRY *)(GLenum type, GLuint value)) _func)(type, value);
}

GLAPI void APIENTRY glVertexP2uiv(GLenum type, const GLuint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3214];
   ((void (APIENTRY *)(GLenum type, const GLuint *value)) _func)(type, value);
}

GLAPI void APIENTRY glVertexP3ui(GLenum type, GLuint value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3215];
   ((void (APIENTRY *)(GLenum type, GLuint value)) _func)(type, value);
}

GLAPI void APIENTRY glVertexP3uiv(GLenum type, const GLuint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3216];
   ((void (APIENTRY *)(GLenum type, const GLuint *value)) _func)(type, value);
}

GLAPI void APIENTRY glVertexP4ui(GLenum type, GLuint value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3217];
   ((void (APIENTRY *)(GLenum type, GLuint value)) _func)(type, value);
}

GLAPI void APIENTRY glVertexP4uiv(GLenum type, const GLuint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3218];
   ((void (APIENTRY *)(GLenum type, const GLuint *value)) _func)(type, value);
}

GLAPI void APIENTRY glVertexPointer(GLint size, GLenum type, GLsizei stride, const void *pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3219];
   ((void (APIENTRY *)(GLint size, GLenum type, GLsizei stride, const void *pointer)) _func)(size, type, stride, pointer);
}

GLAPI void APIENTRY glViewport(GLint x, GLint y, GLsizei width, GLsizei height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3264];
   ((void (APIENTRY *)(GLint x, GLint y, GLsizei width, GLsizei height)) _func)(x, y, width, height);
}

GLAPI void APIENTRY glViewportArrayv(GLuint first, GLsizei count, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3265];
   ((void (APIENTRY *)(GLuint first, GLsizei count, const GLfloat *v)) _func)(first, count, v);
}

GLAPI void APIENTRY glViewportIndexedf(GLuint index, GLfloat x, GLfloat y, GLfloat w, GLfloat h)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3268];
   ((void (APIENTRY *)(GLuint index, GLfloat x, GLfloat y, GLfloat w, GLfloat h)) _func)(index, x, y, w, h);
}

GLAPI void APIENTRY glViewportIndexedfv(GLuint index, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3271];
   ((void (APIENTRY *)(GLuint index, const GLfloat *v)) _func)(index, v);
}

GLAPI void APIENTRY glWaitSync(GLsync sync, GLbitfield flags, GLuint64 timeout)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3278];
   ((void (APIENTRY *)(GLsync sync, GLbitfield flags, GLuint64 timeout)) _func)(sync, flags, timeout);
}

GLAPI void APIENTRY glWindowPos2d(GLdouble x, GLdouble y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3294];
   ((void (APIENTRY *)(GLdouble x, GLdouble y)) _func)(x, y);
}

GLAPI void APIENTRY glWindowPos2dv(const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3297];
   ((void (APIENTRY *)(const GLdouble *v)) _func)(v);
}

GLAPI void APIENTRY glWindowPos2f(GLfloat x, GLfloat y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3300];
   ((void (APIENTRY *)(GLfloat x, GLfloat y)) _func)(x, y);
}

GLAPI void APIENTRY glWindowPos2fv(const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3303];
   ((void (APIENTRY *)(const GLfloat *v)) _func)(v);
}

GLAPI void APIENTRY glWindowPos2i(GLint x, GLint y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3306];
   ((void (APIENTRY *)(GLint x, GLint y)) _func)(x, y);
}

GLAPI void APIENTRY glWindowPos2iv(const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3309];
   ((void (APIENTRY *)(const GLint *v)) _func)(v);
}

GLAPI void APIENTRY glWindowPos2s(GLshort x, GLshort y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3312];
   ((void (APIENTRY *)(GLshort x, GLshort y)) _func)(x, y);
}

GLAPI void APIENTRY glWindowPos2sv(const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3315];
   ((void (APIENTRY *)(const GLshort *v)) _func)(v);
}

GLAPI void APIENTRY glWindowPos3d(GLdouble x, GLdouble y, GLdouble z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3318];
   ((void (APIENTRY *)(GLdouble x, GLdouble y, GLdouble z)) _func)(x, y, z);
}

GLAPI void APIENTRY glWindowPos3dv(const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3321];
   ((void (APIENTRY *)(const GLdouble *v)) _func)(v);
}

GLAPI void APIENTRY glWindowPos3f(GLfloat x, GLfloat y, GLfloat z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3324];
   ((void (APIENTRY *)(GLfloat x, GLfloat y, GLfloat z)) _func)(x, y, z);
}

GLAPI void APIENTRY glWindowPos3fv(const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3327];
   ((void (APIENTRY *)(const GLfloat *v)) _func)(v);
}

GLAPI void APIENTRY glWindowPos3i(GLint x, GLint y, GLint z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3330];
   ((void (APIENTRY *)(GLint x, GLint y, GLint z)) _func)(x, y, z);
}

GLAPI void APIENTRY glWindowPos3iv(const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3333];
   ((void (APIENTRY *)(const GLint *v)) _func)(v);
}

GLAPI void APIENTRY glWindowPos3s(GLshort x, GLshort y, GLshort z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3336];
   ((void (APIENTRY *)(GLshort x, GLshort y, GLshort z)) _func)(x, y, z);
}

GLAPI void APIENTRY glWindowPos3sv(const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3339];
   ((void (APIENTRY *)(const GLshort *v)) _func)(v);
}


static const mapi_func public_entries[] = {
   (mapi_func) glAccum,
   (mapi_func) glActiveShaderProgram,
   (mapi_func) glActiveTexture,
   (mapi_func) glAlphaFunc,
   (mapi_func) glAreTexturesResident,
   (mapi_func) glArrayElement,
   (mapi_func) glAttachShader,
   (mapi_func) glBegin,
   (mapi_func) glBeginConditionalRender,
   (mapi_func) glBeginQuery,
   (mapi_func) glBeginQueryIndexed,
   (mapi_func) glBeginTransformFeedback,
   (mapi_func) glBindAttribLocation,
   (mapi_func) glBindBuffer,
   (mapi_func) glBindBufferBase,
   (mapi_func) glBindBufferRange,
   (mapi_func) glBindBuffersBase,
   (mapi_func) glBindBuffersRange,
   (mapi_func) glBindFragDataLocation,
   (mapi_func) glBindFragDataLocationIndexed,
   (mapi_func) glBindFramebuffer,
   (mapi_func) glBindImageTexture,
   (mapi_func) glBindImageTextures,
   (mapi_func) glBindProgramPipeline,
   (mapi_func) glBindRenderbuffer,
   (mapi_func) glBindSampler,
   (mapi_func) glBindSamplers,
   (mapi_func) glBindTexture,
   (mapi_func) glBindTextureUnit,
   (mapi_func) glBindTextures,
   (mapi_func) glBindTransformFeedback,
   (mapi_func) glBindVertexArray,
   (mapi_func) glBindVertexBuffer,
   (mapi_func) glBindVertexBuffers,
   (mapi_func) glBitmap,
   (mapi_func) glBlendColor,
   (mapi_func) glBlendEquation,
   (mapi_func) glBlendEquationSeparate,
   (mapi_func) glBlendEquationSeparatei,
   (mapi_func) glBlendEquationi,
   (mapi_func) glBlendFunc,
   (mapi_func) glBlendFuncSeparate,
   (mapi_func) glBlendFuncSeparatei,
   (mapi_func) glBlendFunci,
   (mapi_func) glBlitFramebuffer,
   (mapi_func) glBlitNamedFramebuffer,
   (mapi_func) glBufferData,
   (mapi_func) glBufferStorage,
   (mapi_func) glBufferSubData,
   (mapi_func) glCallList,
   (mapi_func) glCallLists,
   (mapi_func) glCheckFramebufferStatus,
   (mapi_func) glCheckNamedFramebufferStatus,
   (mapi_func) glClampColor,
   (mapi_func) glClear,
   (mapi_func) glClearAccum,
   (mapi_func) glClearBufferData,
   (mapi_func) glClearBufferSubData,
   (mapi_func) glClearBufferfi,
   (mapi_func) glClearBufferfv,
   (mapi_func) glClearBufferiv,
   (mapi_func) glClearBufferuiv,
   (mapi_func) glClearColor,
   (mapi_func) glClearDepth,
   (mapi_func) glClearDepthf,
   (mapi_func) glClearIndex,
   (mapi_func) glClearNamedBufferData,
   (mapi_func) glClearNamedBufferSubData,
   (mapi_func) glClearNamedFramebufferfi,
   (mapi_func) glClearNamedFramebufferfv,
   (mapi_func) glClearNamedFramebufferiv,
   (mapi_func) glClearNamedFramebufferuiv,
   (mapi_func) glClearStencil,
   (mapi_func) glClearTexImage,
   (mapi_func) glClearTexSubImage,
   (mapi_func) glClientActiveTexture,
   (mapi_func) glClientWaitSync,
   (mapi_func) glClipControl,
   (mapi_func) glClipPlane,
   (mapi_func) glColor3b,
   (mapi_func) glColor3bv,
   (mapi_func) glColor3d,
   (mapi_func) glColor3dv,
   (mapi_func) glColor3f,
   (mapi_func) glColor3fv,
   (mapi_func) glColor3i,
   (mapi_func) glColor3iv,
   (mapi_func) glColor3s,
   (mapi_func) glColor3sv,
   (mapi_func) glColor3ub,
   (mapi_func) glColor3ubv,
   (mapi_func) glColor3ui,
   (mapi_func) glColor3uiv,
   (mapi_func) glColor3us,
   (mapi_func) glColor3usv,
   (mapi_func) glColor4b,
   (mapi_func) glColor4bv,
   (mapi_func) glColor4d,
   (mapi_func) glColor4dv,
   (mapi_func) glColor4f,
   (mapi_func) glColor4fv,
   (mapi_func) glColor4i,
   (mapi_func) glColor4iv,
   (mapi_func) glColor4s,
   (mapi_func) glColor4sv,
   (mapi_func) glColor4ub,
   (mapi_func) glColor4ubv,
   (mapi_func) glColor4ui,
   (mapi_func) glColor4uiv,
   (mapi_func) glColor4us,
   (mapi_func) glColor4usv,
   (mapi_func) glColorMask,
   (mapi_func) glColorMaski,
   (mapi_func) glColorMaterial,
   (mapi_func) glColorP3ui,
   (mapi_func) glColorP3uiv,
   (mapi_func) glColorP4ui,
   (mapi_func) glColorP4uiv,
   (mapi_func) glColorPointer,
   (mapi_func) glCompileShader,
   (mapi_func) glCompressedTexImage1D,
   (mapi_func) glCompressedTexImage2D,
   (mapi_func) glCompressedTexImage3D,
   (mapi_func) glCompressedTexSubImage1D,
   (mapi_func) glCompressedTexSubImage2D,
   (mapi_func) glCompressedTexSubImage3D,
   (mapi_func) glCompressedTextureSubImage1D,
   (mapi_func) glCompressedTextureSubImage2D,
   (mapi_func) glCompressedTextureSubImage3D,
   (mapi_func) glCopyBufferSubData,
   (mapi_func) glCopyImageSubData,
   (mapi_func) glCopyNamedBufferSubData,
   (mapi_func) glCopyPixels,
   (mapi_func) glCopyTexImage1D,
   (mapi_func) glCopyTexImage2D,
   (mapi_func) glCopyTexSubImage1D,
   (mapi_func) glCopyTexSubImage2D,
   (mapi_func) glCopyTexSubImage3D,
   (mapi_func) glCopyTextureSubImage1D,
   (mapi_func) glCopyTextureSubImage2D,
   (mapi_func) glCopyTextureSubImage3D,
   (mapi_func) glCreateBuffers,
   (mapi_func) glCreateFramebuffers,
   (mapi_func) glCreateProgram,
   (mapi_func) glCreateProgramPipelines,
   (mapi_func) glCreateQueries,
   (mapi_func) glCreateRenderbuffers,
   (mapi_func) glCreateSamplers,
   (mapi_func) glCreateShader,
   (mapi_func) glCreateShaderProgramv,
   (mapi_func) glCreateTextures,
   (mapi_func) glCreateTransformFeedbacks,
   (mapi_func) glCreateVertexArrays,
   (mapi_func) glCullFace,
   (mapi_func) glDebugMessageCallback,
   (mapi_func) glDebugMessageControl,
   (mapi_func) glDebugMessageInsert,
   (mapi_func) glDeleteBuffers,
   (mapi_func) glDeleteFramebuffers,
   (mapi_func) glDeleteLists,
   (mapi_func) glDeleteProgram,
   (mapi_func) glDeleteProgramPipelines,
   (mapi_func) glDeleteQueries,
   (mapi_func) glDeleteRenderbuffers,
   (mapi_func) glDeleteSamplers,
   (mapi_func) glDeleteShader,
   (mapi_func) glDeleteSync,
   (mapi_func) glDeleteTextures,
   (mapi_func) glDeleteTransformFeedbacks,
   (mapi_func) glDeleteVertexArrays,
   (mapi_func) glDepthFunc,
   (mapi_func) glDepthMask,
   (mapi_func) glDepthRange,
   (mapi_func) glDepthRangeArrayv,
   (mapi_func) glDepthRangeIndexed,
   (mapi_func) glDepthRangef,
   (mapi_func) glDetachShader,
   (mapi_func) glDisable,
   (mapi_func) glDisableClientState,
   (mapi_func) glDisableVertexArrayAttrib,
   (mapi_func) glDisableVertexAttribArray,
   (mapi_func) glDisablei,
   (mapi_func) glDispatchCompute,
   (mapi_func) glDispatchComputeIndirect,
   (mapi_func) glDrawArrays,
   (mapi_func) glDrawArraysIndirect,
   (mapi_func) glDrawArraysInstanced,
   (mapi_func) glDrawArraysInstancedBaseInstance,
   (mapi_func) glDrawBuffer,
   (mapi_func) glDrawBuffers,
   (mapi_func) glDrawElements,
   (mapi_func) glDrawElementsBaseVertex,
   (mapi_func) glDrawElementsIndirect,
   (mapi_func) glDrawElementsInstanced,
   (mapi_func) glDrawElementsInstancedBaseInstance,
   (mapi_func) glDrawElementsInstancedBaseVertex,
   (mapi_func) glDrawElementsInstancedBaseVertexBaseInstance,
   (mapi_func) glDrawPixels,
   (mapi_func) glDrawRangeElements,
   (mapi_func) glDrawRangeElementsBaseVertex,
   (mapi_func) glDrawTransformFeedback,
   (mapi_func) glDrawTransformFeedbackInstanced,
   (mapi_func) glDrawTransformFeedbackStream,
   (mapi_func) glDrawTransformFeedbackStreamInstanced,
   (mapi_func) glEdgeFlag,
   (mapi_func) glEdgeFlagPointer,
   (mapi_func) glEdgeFlagv,
   (mapi_func) glEnable,
   (mapi_func) glEnableClientState,
   (mapi_func) glEnableVertexArrayAttrib,
   (mapi_func) glEnableVertexAttribArray,
   (mapi_func) glEnablei,
   (mapi_func) glEnd,
   (mapi_func) glEndConditionalRender,
   (mapi_func) glEndList,
   (mapi_func) glEndQuery,
   (mapi_func) glEndQueryIndexed,
   (mapi_func) glEndTransformFeedback,
   (mapi_func) glEvalCoord1d,
   (mapi_func) glEvalCoord1dv,
   (mapi_func) glEvalCoord1f,
   (mapi_func) glEvalCoord1fv,
   (mapi_func) glEvalCoord2d,
   (mapi_func) glEvalCoord2dv,
   (mapi_func) glEvalCoord2f,
   (mapi_func) glEvalCoord2fv,
   (mapi_func) glEvalMesh1,
   (mapi_func) glEvalMesh2,
   (mapi_func) glEvalPoint1,
   (mapi_func) glEvalPoint2,
   (mapi_func) glFeedbackBuffer,
   (mapi_func) glFenceSync,
   (mapi_func) glFinish,
   (mapi_func) glFlush,
   (mapi_func) glFlushMappedBufferRange,
   (mapi_func) glFlushMappedNamedBufferRange,
   (mapi_func) glFogCoordPointer,
   (mapi_func) glFogCoordd,
   (mapi_func) glFogCoorddv,
   (mapi_func) glFogCoordf,
   (mapi_func) glFogCoordfv,
   (mapi_func) glFogf,
   (mapi_func) glFogfv,
   (mapi_func) glFogi,
   (mapi_func) glFogiv,
   (mapi_func) glFramebufferParameteri,
   (mapi_func) glFramebufferRenderbuffer,
   (mapi_func) glFramebufferTexture,
   (mapi_func) glFramebufferTexture1D,
   (mapi_func) glFramebufferTexture2D,
   (mapi_func) glFramebufferTexture3D,
   (mapi_func) glFramebufferTextureLayer,
   (mapi_func) glFrontFace,
   (mapi_func) glFrustum,
   (mapi_func) glGenBuffers,
   (mapi_func) glGenFramebuffers,
   (mapi_func) glGenLists,
   (mapi_func) glGenProgramPipelines,
   (mapi_func) glGenQueries,
   (mapi_func) glGenRenderbuffers,
   (mapi_func) glGenSamplers,
   (mapi_func) glGenTextures,
   (mapi_func) glGenTransformFeedbacks,
   (mapi_func) glGenVertexArrays,
   (mapi_func) glGenerateMipmap,
   (mapi_func) glGenerateTextureMipmap,
   (mapi_func) glGetActiveAtomicCounterBufferiv,
   (mapi_func) glGetActiveAttrib,
   (mapi_func) glGetActiveSubroutineName,
   (mapi_func) glGetActiveSubroutineUniformName,
   (mapi_func) glGetActiveSubroutineUniformiv,
   (mapi_func) glGetActiveUniform,
   (mapi_func) glGetActiveUniformBlockName,
   (mapi_func) glGetActiveUniformBlockiv,
   (mapi_func) glGetActiveUniformName,
   (mapi_func) glGetActiveUniformsiv,
   (mapi_func) glGetAttachedShaders,
   (mapi_func) glGetAttribLocation,
   (mapi_func) glGetBooleani_v,
   (mapi_func) glGetBooleanv,
   (mapi_func) glGetBufferParameteri64v,
   (mapi_func) glGetBufferParameteriv,
   (mapi_func) glGetBufferPointerv,
   (mapi_func) glGetBufferSubData,
   (mapi_func) glGetClipPlane,
   (mapi_func) glGetCompressedTexImage,
   (mapi_func) glGetCompressedTextureImage,
   (mapi_func) glGetCompressedTextureSubImage,
   (mapi_func) glGetDebugMessageLog,
   (mapi_func) glGetDoublei_v,
   (mapi_func) glGetDoublev,
   (mapi_func) glGetError,
   (mapi_func) glGetFloati_v,
   (mapi_func) glGetFloatv,
   (mapi_func) glGetFragDataIndex,
   (mapi_func) glGetFragDataLocation,
   (mapi_func) glGetFramebufferAttachmentParameteriv,
   (mapi_func) glGetFramebufferParameteriv,
   (mapi_func) glGetGraphicsResetStatus,
   (mapi_func) glGetInteger64i_v,
   (mapi_func) glGetInteger64v,
   (mapi_func) glGetIntegeri_v,
   (mapi_func) glGetIntegerv,
   (mapi_func) glGetInternalformati64v,
   (mapi_func) glGetInternalformativ,
   (mapi_func) glGetLightfv,
   (mapi_func) glGetLightiv,
   (mapi_func) glGetMapdv,
   (mapi_func) glGetMapfv,
   (mapi_func) glGetMapiv,
   (mapi_func) glGetMaterialfv,
   (mapi_func) glGetMaterialiv,
   (mapi_func) glGetMultisamplefv,
   (mapi_func) glGetNamedBufferParameteri64v,
   (mapi_func) glGetNamedBufferParameteriv,
   (mapi_func) glGetNamedBufferPointerv,
   (mapi_func) glGetNamedBufferSubData,
   (mapi_func) glGetNamedFramebufferAttachmentParameteriv,
   (mapi_func) glGetNamedFramebufferParameteriv,
   (mapi_func) glGetNamedRenderbufferParameteriv,
   (mapi_func) glGetObjectLabel,
   (mapi_func) glGetObjectPtrLabel,
   (mapi_func) glGetPixelMapfv,
   (mapi_func) glGetPixelMapuiv,
   (mapi_func) glGetPixelMapusv,
   (mapi_func) glGetPointerv,
   (mapi_func) glGetPolygonStipple,
   (mapi_func) glGetProgramBinary,
   (mapi_func) glGetProgramInfoLog,
   (mapi_func) glGetProgramInterfaceiv,
   (mapi_func) glGetProgramPipelineInfoLog,
   (mapi_func) glGetProgramPipelineiv,
   (mapi_func) glGetProgramResourceIndex,
   (mapi_func) glGetProgramResourceLocation,
   (mapi_func) glGetProgramResourceLocationIndex,
   (mapi_func) glGetProgramResourceName,
   (mapi_func) glGetProgramResourceiv,
   (mapi_func) glGetProgramStageiv,
   (mapi_func) glGetProgramiv,
   (mapi_func) glGetQueryBufferObjecti64v,
   (mapi_func) glGetQueryBufferObjectiv,
   (mapi_func) glGetQueryBufferObjectui64v,
   (mapi_func) glGetQueryBufferObjectuiv,
   (mapi_func) glGetQueryIndexediv,
   (mapi_func) glGetQueryObjecti64v,
   (mapi_func) glGetQueryObjectiv,
   (mapi_func) glGetQueryObjectui64v,
   (mapi_func) glGetQueryObjectuiv,
   (mapi_func) glGetQueryiv,
   (mapi_func) glGetRenderbufferParameteriv,
   (mapi_func) glGetSamplerParameterIiv,
   (mapi_func) glGetSamplerParameterIuiv,
   (mapi_func) glGetSamplerParameterfv,
   (mapi_func) glGetSamplerParameteriv,
   (mapi_func) glGetShaderInfoLog,
   (mapi_func) glGetShaderPrecisionFormat,
   (mapi_func) glGetShaderSource,
   (mapi_func) glGetShaderiv,
   (mapi_func) glGetString,
   (mapi_func) glGetStringi,
   (mapi_func) glGetSubroutineIndex,
   (mapi_func) glGetSubroutineUniformLocation,
   (mapi_func) glGetSynciv,
   (mapi_func) glGetTexEnvfv,
   (mapi_func) glGetTexEnviv,
   (mapi_func) glGetTexGendv,
   (mapi_func) glGetTexGenfv,
   (mapi_func) glGetTexGeniv,
   (mapi_func) glGetTexImage,
   (mapi_func) glGetTexLevelParameterfv,
   (mapi_func) glGetTexLevelParameteriv,
   (mapi_func) glGetTexParameterIiv,
   (mapi_func) glGetTexParameterIuiv,
   (mapi_func) glGetTexParameterfv,
   (mapi_func) glGetTexParameteriv,
   (mapi_func) glGetTextureImage,
   (mapi_func) glGetTextureLevelParameterfv,
   (mapi_func) glGetTextureLevelParameteriv,
   (mapi_func) glGetTextureParameterIiv,
   (mapi_func) glGetTextureParameterIuiv,
   (mapi_func) glGetTextureParameterfv,
   (mapi_func) glGetTextureParameteriv,
   (mapi_func) glGetTextureSubImage,
   (mapi_func) glGetTransformFeedbackVarying,
   (mapi_func) glGetTransformFeedbacki64_v,
   (mapi_func) glGetTransformFeedbacki_v,
   (mapi_func) glGetTransformFeedbackiv,
   (mapi_func) glGetUniformBlockIndex,
   (mapi_func) glGetUniformIndices,
   (mapi_func) glGetUniformLocation,
   (mapi_func) glGetUniformSubroutineuiv,
   (mapi_func) glGetUniformdv,
   (mapi_func) glGetUniformfv,
   (mapi_func) glGetUniformiv,
   (mapi_func) glGetUniformuiv,
   (mapi_func) glGetVertexArrayIndexed64iv,
   (mapi_func) glGetVertexArrayIndexediv,
   (mapi_func) glGetVertexArrayiv,
   (mapi_func) glGetVertexAttribIiv,
   (mapi_func) glGetVertexAttribIuiv,
   (mapi_func) glGetVertexAttribLdv,
   (mapi_func) glGetVertexAttribPointerv,
   (mapi_func) glGetVertexAttribdv,
   (mapi_func) glGetVertexAttribfv,
   (mapi_func) glGetVertexAttribiv,
   (mapi_func) glGetnColorTable,
   (mapi_func) glGetnCompressedTexImage,
   (mapi_func) glGetnConvolutionFilter,
   (mapi_func) glGetnHistogram,
   (mapi_func) glGetnMapdv,
   (mapi_func) glGetnMapfv,
   (mapi_func) glGetnMapiv,
   (mapi_func) glGetnMinmax,
   (mapi_func) glGetnPixelMapfv,
   (mapi_func) glGetnPixelMapuiv,
   (mapi_func) glGetnPixelMapusv,
   (mapi_func) glGetnPolygonStipple,
   (mapi_func) glGetnSeparableFilter,
   (mapi_func) glGetnTexImage,
   (mapi_func) glGetnUniformdv,
   (mapi_func) glGetnUniformfv,
   (mapi_func) glGetnUniformiv,
   (mapi_func) glGetnUniformuiv,
   (mapi_func) glHint,
   (mapi_func) glIndexMask,
   (mapi_func) glIndexPointer,
   (mapi_func) glIndexd,
   (mapi_func) glIndexdv,
   (mapi_func) glIndexf,
   (mapi_func) glIndexfv,
   (mapi_func) glIndexi,
   (mapi_func) glIndexiv,
   (mapi_func) glIndexs,
   (mapi_func) glIndexsv,
   (mapi_func) glIndexub,
   (mapi_func) glIndexubv,
   (mapi_func) glInitNames,
   (mapi_func) glInterleavedArrays,
   (mapi_func) glInvalidateBufferData,
   (mapi_func) glInvalidateBufferSubData,
   (mapi_func) glInvalidateFramebuffer,
   (mapi_func) glInvalidateNamedFramebufferData,
   (mapi_func) glInvalidateNamedFramebufferSubData,
   (mapi_func) glInvalidateSubFramebuffer,
   (mapi_func) glInvalidateTexImage,
   (mapi_func) glInvalidateTexSubImage,
   (mapi_func) glIsBuffer,
   (mapi_func) glIsEnabled,
   (mapi_func) glIsEnabledi,
   (mapi_func) glIsFramebuffer,
   (mapi_func) glIsList,
   (mapi_func) glIsProgram,
   (mapi_func) glIsProgramPipeline,
   (mapi_func) glIsQuery,
   (mapi_func) glIsRenderbuffer,
   (mapi_func) glIsSampler,
   (mapi_func) glIsShader,
   (mapi_func) glIsSync,
   (mapi_func) glIsTexture,
   (mapi_func) glIsTransformFeedback,
   (mapi_func) glIsVertexArray,
   (mapi_func) glLightModelf,
   (mapi_func) glLightModelfv,
   (mapi_func) glLightModeli,
   (mapi_func) glLightModeliv,
   (mapi_func) glLightf,
   (mapi_func) glLightfv,
   (mapi_func) glLighti,
   (mapi_func) glLightiv,
   (mapi_func) glLineStipple,
   (mapi_func) glLineWidth,
   (mapi_func) glLinkProgram,
   (mapi_func) glListBase,
   (mapi_func) glLoadIdentity,
   (mapi_func) glLoadMatrixd,
   (mapi_func) glLoadMatrixf,
   (mapi_func) glLoadName,
   (mapi_func) glLoadTransposeMatrixd,
   (mapi_func) glLoadTransposeMatrixf,
   (mapi_func) glLogicOp,
   (mapi_func) glMap1d,
   (mapi_func) glMap1f,
   (mapi_func) glMap2d,
   (mapi_func) glMap2f,
   (mapi_func) glMapBuffer,
   (mapi_func) glMapBufferRange,
   (mapi_func) glMapGrid1d,
   (mapi_func) glMapGrid1f,
   (mapi_func) glMapGrid2d,
   (mapi_func) glMapGrid2f,
   (mapi_func) glMapNamedBuffer,
   (mapi_func) glMapNamedBufferRange,
   (mapi_func) glMaterialf,
   (mapi_func) glMaterialfv,
   (mapi_func) glMateriali,
   (mapi_func) glMaterialiv,
   (mapi_func) glMatrixMode,
   (mapi_func) glMemoryBarrier,
   (mapi_func) glMemoryBarrierByRegion,
   (mapi_func) glMinSampleShading,
   (mapi_func) glMultMatrixd,
   (mapi_func) glMultMatrixf,
   (mapi_func) glMultTransposeMatrixd,
   (mapi_func) glMultTransposeMatrixf,
   (mapi_func) glMultiDrawArrays,
   (mapi_func) glMultiDrawArraysIndirect,
   (mapi_func) glMultiDrawElements,
   (mapi_func) glMultiDrawElementsBaseVertex,
   (mapi_func) glMultiDrawElementsIndirect,
   (mapi_func) glMultiTexCoord1d,
   (mapi_func) glMultiTexCoord1dv,
   (mapi_func) glMultiTexCoord1f,
   (mapi_func) glMultiTexCoord1fv,
   (mapi_func) glMultiTexCoord1i,
   (mapi_func) glMultiTexCoord1iv,
   (mapi_func) glMultiTexCoord1s,
   (mapi_func) glMultiTexCoord1sv,
   (mapi_func) glMultiTexCoord2d,
   (mapi_func) glMultiTexCoord2dv,
   (mapi_func) glMultiTexCoord2f,
   (mapi_func) glMultiTexCoord2fv,
   (mapi_func) glMultiTexCoord2i,
   (mapi_func) glMultiTexCoord2iv,
   (mapi_func) glMultiTexCoord2s,
   (mapi_func) glMultiTexCoord2sv,
   (mapi_func) glMultiTexCoord3d,
   (mapi_func) glMultiTexCoord3dv,
   (mapi_func) glMultiTexCoord3f,
   (mapi_func) glMultiTexCoord3fv,
   (mapi_func) glMultiTexCoord3i,
   (mapi_func) glMultiTexCoord3iv,
   (mapi_func) glMultiTexCoord3s,
   (mapi_func) glMultiTexCoord3sv,
   (mapi_func) glMultiTexCoord4d,
   (mapi_func) glMultiTexCoord4dv,
   (mapi_func) glMultiTexCoord4f,
   (mapi_func) glMultiTexCoord4fv,
   (mapi_func) glMultiTexCoord4i,
   (mapi_func) glMultiTexCoord4iv,
   (mapi_func) glMultiTexCoord4s,
   (mapi_func) glMultiTexCoord4sv,
   (mapi_func) glMultiTexCoordP1ui,
   (mapi_func) glMultiTexCoordP1uiv,
   (mapi_func) glMultiTexCoordP2ui,
   (mapi_func) glMultiTexCoordP2uiv,
   (mapi_func) glMultiTexCoordP3ui,
   (mapi_func) glMultiTexCoordP3uiv,
   (mapi_func) glMultiTexCoordP4ui,
   (mapi_func) glMultiTexCoordP4uiv,
   (mapi_func) glNamedBufferData,
   (mapi_func) glNamedBufferStorage,
   (mapi_func) glNamedBufferSubData,
   (mapi_func) glNamedFramebufferDrawBuffer,
   (mapi_func) glNamedFramebufferDrawBuffers,
   (mapi_func) glNamedFramebufferParameteri,
   (mapi_func) glNamedFramebufferReadBuffer,
   (mapi_func) glNamedFramebufferRenderbuffer,
   (mapi_func) glNamedFramebufferTexture,
   (mapi_func) glNamedFramebufferTextureLayer,
   (mapi_func) glNamedRenderbufferStorage,
   (mapi_func) glNamedRenderbufferStorageMultisample,
   (mapi_func) glNewList,
   (mapi_func) glNormal3b,
   (mapi_func) glNormal3bv,
   (mapi_func) glNormal3d,
   (mapi_func) glNormal3dv,
   (mapi_func) glNormal3f,
   (mapi_func) glNormal3fv,
   (mapi_func) glNormal3i,
   (mapi_func) glNormal3iv,
   (mapi_func) glNormal3s,
   (mapi_func) glNormal3sv,
   (mapi_func) glNormalP3ui,
   (mapi_func) glNormalP3uiv,
   (mapi_func) glNormalPointer,
   (mapi_func) glObjectLabel,
   (mapi_func) glObjectPtrLabel,
   (mapi_func) glOrtho,
   (mapi_func) glPassThrough,
   (mapi_func) glPatchParameterfv,
   (mapi_func) glPatchParameteri,
   (mapi_func) glPauseTransformFeedback,
   (mapi_func) glPixelMapfv,
   (mapi_func) glPixelMapuiv,
   (mapi_func) glPixelMapusv,
   (mapi_func) glPixelStoref,
   (mapi_func) glPixelStorei,
   (mapi_func) glPixelTransferf,
   (mapi_func) glPixelTransferi,
   (mapi_func) glPixelZoom,
   (mapi_func) glPointParameterf,
   (mapi_func) glPointParameterfv,
   (mapi_func) glPointParameteri,
   (mapi_func) glPointParameteriv,
   (mapi_func) glPointSize,
   (mapi_func) glPolygonMode,
   (mapi_func) glPolygonOffset,
   (mapi_func) glPolygonStipple,
   (mapi_func) glPopAttrib,
   (mapi_func) glPopClientAttrib,
   (mapi_func) glPopDebugGroup,
   (mapi_func) glPopMatrix,
   (mapi_func) glPopName,
   (mapi_func) glPrimitiveRestartIndex,
   (mapi_func) glPrioritizeTextures,
   (mapi_func) glProgramBinary,
   (mapi_func) glProgramParameteri,
   (mapi_func) glProgramUniform1d,
   (mapi_func) glProgramUniform1dv,
   (mapi_func) glProgramUniform1f,
   (mapi_func) glProgramUniform1fv,
   (mapi_func) glProgramUniform1i,
   (mapi_func) glProgramUniform1iv,
   (mapi_func) glProgramUniform1ui,
   (mapi_func) glProgramUniform1uiv,
   (mapi_func) glProgramUniform2d,
   (mapi_func) glProgramUniform2dv,
   (mapi_func) glProgramUniform2f,
   (mapi_func) glProgramUniform2fv,
   (mapi_func) glProgramUniform2i,
   (mapi_func) glProgramUniform2iv,
   (mapi_func) glProgramUniform2ui,
   (mapi_func) glProgramUniform2uiv,
   (mapi_func) glProgramUniform3d,
   (mapi_func) glProgramUniform3dv,
   (mapi_func) glProgramUniform3f,
   (mapi_func) glProgramUniform3fv,
   (mapi_func) glProgramUniform3i,
   (mapi_func) glProgramUniform3iv,
   (mapi_func) glProgramUniform3ui,
   (mapi_func) glProgramUniform3uiv,
   (mapi_func) glProgramUniform4d,
   (mapi_func) glProgramUniform4dv,
   (mapi_func) glProgramUniform4f,
   (mapi_func) glProgramUniform4fv,
   (mapi_func) glProgramUniform4i,
   (mapi_func) glProgramUniform4iv,
   (mapi_func) glProgramUniform4ui,
   (mapi_func) glProgramUniform4uiv,
   (mapi_func) glProgramUniformMatrix2dv,
   (mapi_func) glProgramUniformMatrix2fv,
   (mapi_func) glProgramUniformMatrix2x3dv,
   (mapi_func) glProgramUniformMatrix2x3fv,
   (mapi_func) glProgramUniformMatrix2x4dv,
   (mapi_func) glProgramUniformMatrix2x4fv,
   (mapi_func) glProgramUniformMatrix3dv,
   (mapi_func) glProgramUniformMatrix3fv,
   (mapi_func) glProgramUniformMatrix3x2dv,
   (mapi_func) glProgramUniformMatrix3x2fv,
   (mapi_func) glProgramUniformMatrix3x4dv,
   (mapi_func) glProgramUniformMatrix3x4fv,
   (mapi_func) glProgramUniformMatrix4dv,
   (mapi_func) glProgramUniformMatrix4fv,
   (mapi_func) glProgramUniformMatrix4x2dv,
   (mapi_func) glProgramUniformMatrix4x2fv,
   (mapi_func) glProgramUniformMatrix4x3dv,
   (mapi_func) glProgramUniformMatrix4x3fv,
   (mapi_func) glProvokingVertex,
   (mapi_func) glPushAttrib,
   (mapi_func) glPushClientAttrib,
   (mapi_func) glPushDebugGroup,
   (mapi_func) glPushMatrix,
   (mapi_func) glPushName,
   (mapi_func) glQueryCounter,
   (mapi_func) glRasterPos2d,
   (mapi_func) glRasterPos2dv,
   (mapi_func) glRasterPos2f,
   (mapi_func) glRasterPos2fv,
   (mapi_func) glRasterPos2i,
   (mapi_func) glRasterPos2iv,
   (mapi_func) glRasterPos2s,
   (mapi_func) glRasterPos2sv,
   (mapi_func) glRasterPos3d,
   (mapi_func) glRasterPos3dv,
   (mapi_func) glRasterPos3f,
   (mapi_func) glRasterPos3fv,
   (mapi_func) glRasterPos3i,
   (mapi_func) glRasterPos3iv,
   (mapi_func) glRasterPos3s,
   (mapi_func) glRasterPos3sv,
   (mapi_func) glRasterPos4d,
   (mapi_func) glRasterPos4dv,
   (mapi_func) glRasterPos4f,
   (mapi_func) glRasterPos4fv,
   (mapi_func) glRasterPos4i,
   (mapi_func) glRasterPos4iv,
   (mapi_func) glRasterPos4s,
   (mapi_func) glRasterPos4sv,
   (mapi_func) glReadBuffer,
   (mapi_func) glReadPixels,
   (mapi_func) glReadnPixels,
   (mapi_func) glRectd,
   (mapi_func) glRectdv,
   (mapi_func) glRectf,
   (mapi_func) glRectfv,
   (mapi_func) glRecti,
   (mapi_func) glRectiv,
   (mapi_func) glRects,
   (mapi_func) glRectsv,
   (mapi_func) glReleaseShaderCompiler,
   (mapi_func) glRenderMode,
   (mapi_func) glRenderbufferStorage,
   (mapi_func) glRenderbufferStorageMultisample,
   (mapi_func) glResumeTransformFeedback,
   (mapi_func) glRotated,
   (mapi_func) glRotatef,
   (mapi_func) glSampleCoverage,
   (mapi_func) glSampleMaski,
   (mapi_func) glSamplerParameterIiv,
   (mapi_func) glSamplerParameterIuiv,
   (mapi_func) glSamplerParameterf,
   (mapi_func) glSamplerParameterfv,
   (mapi_func) glSamplerParameteri,
   (mapi_func) glSamplerParameteriv,
   (mapi_func) glScaled,
   (mapi_func) glScalef,
   (mapi_func) glScissor,
   (mapi_func) glScissorArrayv,
   (mapi_func) glScissorIndexed,
   (mapi_func) glScissorIndexedv,
   (mapi_func) glSecondaryColor3b,
   (mapi_func) glSecondaryColor3bv,
   (mapi_func) glSecondaryColor3d,
   (mapi_func) glSecondaryColor3dv,
   (mapi_func) glSecondaryColor3f,
   (mapi_func) glSecondaryColor3fv,
   (mapi_func) glSecondaryColor3i,
   (mapi_func) glSecondaryColor3iv,
   (mapi_func) glSecondaryColor3s,
   (mapi_func) glSecondaryColor3sv,
   (mapi_func) glSecondaryColor3ub,
   (mapi_func) glSecondaryColor3ubv,
   (mapi_func) glSecondaryColor3ui,
   (mapi_func) glSecondaryColor3uiv,
   (mapi_func) glSecondaryColor3us,
   (mapi_func) glSecondaryColor3usv,
   (mapi_func) glSecondaryColorP3ui,
   (mapi_func) glSecondaryColorP3uiv,
   (mapi_func) glSecondaryColorPointer,
   (mapi_func) glSelectBuffer,
   (mapi_func) glShadeModel,
   (mapi_func) glShaderBinary,
   (mapi_func) glShaderSource,
   (mapi_func) glShaderStorageBlockBinding,
   (mapi_func) glStencilFunc,
   (mapi_func) glStencilFuncSeparate,
   (mapi_func) glStencilMask,
   (mapi_func) glStencilMaskSeparate,
   (mapi_func) glStencilOp,
   (mapi_func) glStencilOpSeparate,
   (mapi_func) glTexBuffer,
   (mapi_func) glTexBufferRange,
   (mapi_func) glTexCoord1d,
   (mapi_func) glTexCoord1dv,
   (mapi_func) glTexCoord1f,
   (mapi_func) glTexCoord1fv,
   (mapi_func) glTexCoord1i,
   (mapi_func) glTexCoord1iv,
   (mapi_func) glTexCoord1s,
   (mapi_func) glTexCoord1sv,
   (mapi_func) glTexCoord2d,
   (mapi_func) glTexCoord2dv,
   (mapi_func) glTexCoord2f,
   (mapi_func) glTexCoord2fv,
   (mapi_func) glTexCoord2i,
   (mapi_func) glTexCoord2iv,
   (mapi_func) glTexCoord2s,
   (mapi_func) glTexCoord2sv,
   (mapi_func) glTexCoord3d,
   (mapi_func) glTexCoord3dv,
   (mapi_func) glTexCoord3f,
   (mapi_func) glTexCoord3fv,
   (mapi_func) glTexCoord3i,
   (mapi_func) glTexCoord3iv,
   (mapi_func) glTexCoord3s,
   (mapi_func) glTexCoord3sv,
   (mapi_func) glTexCoord4d,
   (mapi_func) glTexCoord4dv,
   (mapi_func) glTexCoord4f,
   (mapi_func) glTexCoord4fv,
   (mapi_func) glTexCoord4i,
   (mapi_func) glTexCoord4iv,
   (mapi_func) glTexCoord4s,
   (mapi_func) glTexCoord4sv,
   (mapi_func) glTexCoordP1ui,
   (mapi_func) glTexCoordP1uiv,
   (mapi_func) glTexCoordP2ui,
   (mapi_func) glTexCoordP2uiv,
   (mapi_func) glTexCoordP3ui,
   (mapi_func) glTexCoordP3uiv,
   (mapi_func) glTexCoordP4ui,
   (mapi_func) glTexCoordP4uiv,
   (mapi_func) glTexCoordPointer,
   (mapi_func) glTexEnvf,
   (mapi_func) glTexEnvfv,
   (mapi_func) glTexEnvi,
   (mapi_func) glTexEnviv,
   (mapi_func) glTexGend,
   (mapi_func) glTexGendv,
   (mapi_func) glTexGenf,
   (mapi_func) glTexGenfv,
   (mapi_func) glTexGeni,
   (mapi_func) glTexGeniv,
   (mapi_func) glTexImage1D,
   (mapi_func) glTexImage2D,
   (mapi_func) glTexImage2DMultisample,
   (mapi_func) glTexImage3D,
   (mapi_func) glTexImage3DMultisample,
   (mapi_func) glTexParameterIiv,
   (mapi_func) glTexParameterIuiv,
   (mapi_func) glTexParameterf,
   (mapi_func) glTexParameterfv,
   (mapi_func) glTexParameteri,
   (mapi_func) glTexParameteriv,
   (mapi_func) glTexStorage1D,
   (mapi_func) glTexStorage2D,
   (mapi_func) glTexStorage2DMultisample,
   (mapi_func) glTexStorage3D,
   (mapi_func) glTexStorage3DMultisample,
   (mapi_func) glTexSubImage1D,
   (mapi_func) glTexSubImage2D,
   (mapi_func) glTexSubImage3D,
   (mapi_func) glTextureBarrier,
   (mapi_func) glTextureBuffer,
   (mapi_func) glTextureBufferRange,
   (mapi_func) glTextureParameterIiv,
   (mapi_func) glTextureParameterIuiv,
   (mapi_func) glTextureParameterf,
   (mapi_func) glTextureParameterfv,
   (mapi_func) glTextureParameteri,
   (mapi_func) glTextureParameteriv,
   (mapi_func) glTextureStorage1D,
   (mapi_func) glTextureStorage2D,
   (mapi_func) glTextureStorage2DMultisample,
   (mapi_func) glTextureStorage3D,
   (mapi_func) glTextureStorage3DMultisample,
   (mapi_func) glTextureSubImage1D,
   (mapi_func) glTextureSubImage2D,
   (mapi_func) glTextureSubImage3D,
   (mapi_func) glTextureView,
   (mapi_func) glTransformFeedbackBufferBase,
   (mapi_func) glTransformFeedbackBufferRange,
   (mapi_func) glTransformFeedbackVaryings,
   (mapi_func) glTranslated,
   (mapi_func) glTranslatef,
   (mapi_func) glUniform1d,
   (mapi_func) glUniform1dv,
   (mapi_func) glUniform1f,
   (mapi_func) glUniform1fv,
   (mapi_func) glUniform1i,
   (mapi_func) glUniform1iv,
   (mapi_func) glUniform1ui,
   (mapi_func) glUniform1uiv,
   (mapi_func) glUniform2d,
   (mapi_func) glUniform2dv,
   (mapi_func) glUniform2f,
   (mapi_func) glUniform2fv,
   (mapi_func) glUniform2i,
   (mapi_func) glUniform2iv,
   (mapi_func) glUniform2ui,
   (mapi_func) glUniform2uiv,
   (mapi_func) glUniform3d,
   (mapi_func) glUniform3dv,
   (mapi_func) glUniform3f,
   (mapi_func) glUniform3fv,
   (mapi_func) glUniform3i,
   (mapi_func) glUniform3iv,
   (mapi_func) glUniform3ui,
   (mapi_func) glUniform3uiv,
   (mapi_func) glUniform4d,
   (mapi_func) glUniform4dv,
   (mapi_func) glUniform4f,
   (mapi_func) glUniform4fv,
   (mapi_func) glUniform4i,
   (mapi_func) glUniform4iv,
   (mapi_func) glUniform4ui,
   (mapi_func) glUniform4uiv,
   (mapi_func) glUniformBlockBinding,
   (mapi_func) glUniformMatrix2dv,
   (mapi_func) glUniformMatrix2fv,
   (mapi_func) glUniformMatrix2x3dv,
   (mapi_func) glUniformMatrix2x3fv,
   (mapi_func) glUniformMatrix2x4dv,
   (mapi_func) glUniformMatrix2x4fv,
   (mapi_func) glUniformMatrix3dv,
   (mapi_func) glUniformMatrix3fv,
   (mapi_func) glUniformMatrix3x2dv,
   (mapi_func) glUniformMatrix3x2fv,
   (mapi_func) glUniformMatrix3x4dv,
   (mapi_func) glUniformMatrix3x4fv,
   (mapi_func) glUniformMatrix4dv,
   (mapi_func) glUniformMatrix4fv,
   (mapi_func) glUniformMatrix4x2dv,
   (mapi_func) glUniformMatrix4x2fv,
   (mapi_func) glUniformMatrix4x3dv,
   (mapi_func) glUniformMatrix4x3fv,
   (mapi_func) glUniformSubroutinesuiv,
   (mapi_func) glUnmapBuffer,
   (mapi_func) glUnmapNamedBuffer,
   (mapi_func) glUseProgram,
   (mapi_func) glUseProgramStages,
   (mapi_func) glValidateProgram,
   (mapi_func) glValidateProgramPipeline,
   (mapi_func) glVertex2d,
   (mapi_func) glVertex2dv,
   (mapi_func) glVertex2f,
   (mapi_func) glVertex2fv,
   (mapi_func) glVertex2i,
   (mapi_func) glVertex2iv,
   (mapi_func) glVertex2s,
   (mapi_func) glVertex2sv,
   (mapi_func) glVertex3d,
   (mapi_func) glVertex3dv,
   (mapi_func) glVertex3f,
   (mapi_func) glVertex3fv,
   (mapi_func) glVertex3i,
   (mapi_func) glVertex3iv,
   (mapi_func) glVertex3s,
   (mapi_func) glVertex3sv,
   (mapi_func) glVertex4d,
   (mapi_func) glVertex4dv,
   (mapi_func) glVertex4f,
   (mapi_func) glVertex4fv,
   (mapi_func) glVertex4i,
   (mapi_func) glVertex4iv,
   (mapi_func) glVertex4s,
   (mapi_func) glVertex4sv,
   (mapi_func) glVertexArrayAttribBinding,
   (mapi_func) glVertexArrayAttribFormat,
   (mapi_func) glVertexArrayAttribIFormat,
   (mapi_func) glVertexArrayAttribLFormat,
   (mapi_func) glVertexArrayBindingDivisor,
   (mapi_func) glVertexArrayElementBuffer,
   (mapi_func) glVertexArrayVertexBuffer,
   (mapi_func) glVertexArrayVertexBuffers,
   (mapi_func) glVertexAttrib1d,
   (mapi_func) glVertexAttrib1dv,
   (mapi_func) glVertexAttrib1f,
   (mapi_func) glVertexAttrib1fv,
   (mapi_func) glVertexAttrib1s,
   (mapi_func) glVertexAttrib1sv,
   (mapi_func) glVertexAttrib2d,
   (mapi_func) glVertexAttrib2dv,
   (mapi_func) glVertexAttrib2f,
   (mapi_func) glVertexAttrib2fv,
   (mapi_func) glVertexAttrib2s,
   (mapi_func) glVertexAttrib2sv,
   (mapi_func) glVertexAttrib3d,
   (mapi_func) glVertexAttrib3dv,
   (mapi_func) glVertexAttrib3f,
   (mapi_func) glVertexAttrib3fv,
   (mapi_func) glVertexAttrib3s,
   (mapi_func) glVertexAttrib3sv,
   (mapi_func) glVertexAttrib4Nbv,
   (mapi_func) glVertexAttrib4Niv,
   (mapi_func) glVertexAttrib4Nsv,
   (mapi_func) glVertexAttrib4Nub,
   (mapi_func) glVertexAttrib4Nubv,
   (mapi_func) glVertexAttrib4Nuiv,
   (mapi_func) glVertexAttrib4Nusv,
   (mapi_func) glVertexAttrib4bv,
   (mapi_func) glVertexAttrib4d,
   (mapi_func) glVertexAttrib4dv,
   (mapi_func) glVertexAttrib4f,
   (mapi_func) glVertexAttrib4fv,
   (mapi_func) glVertexAttrib4iv,
   (mapi_func) glVertexAttrib4s,
   (mapi_func) glVertexAttrib4sv,
   (mapi_func) glVertexAttrib4ubv,
   (mapi_func) glVertexAttrib4uiv,
   (mapi_func) glVertexAttrib4usv,
   (mapi_func) glVertexAttribBinding,
   (mapi_func) glVertexAttribDivisor,
   (mapi_func) glVertexAttribFormat,
   (mapi_func) glVertexAttribI1i,
   (mapi_func) glVertexAttribI1iv,
   (mapi_func) glVertexAttribI1ui,
   (mapi_func) glVertexAttribI1uiv,
   (mapi_func) glVertexAttribI2i,
   (mapi_func) glVertexAttribI2iv,
   (mapi_func) glVertexAttribI2ui,
   (mapi_func) glVertexAttribI2uiv,
   (mapi_func) glVertexAttribI3i,
   (mapi_func) glVertexAttribI3iv,
   (mapi_func) glVertexAttribI3ui,
   (mapi_func) glVertexAttribI3uiv,
   (mapi_func) glVertexAttribI4bv,
   (mapi_func) glVertexAttribI4i,
   (mapi_func) glVertexAttribI4iv,
   (mapi_func) glVertexAttribI4sv,
   (mapi_func) glVertexAttribI4ubv,
   (mapi_func) glVertexAttribI4ui,
   (mapi_func) glVertexAttribI4uiv,
   (mapi_func) glVertexAttribI4usv,
   (mapi_func) glVertexAttribIFormat,
   (mapi_func) glVertexAttribIPointer,
   (mapi_func) glVertexAttribL1d,
   (mapi_func) glVertexAttribL1dv,
   (mapi_func) glVertexAttribL2d,
   (mapi_func) glVertexAttribL2dv,
   (mapi_func) glVertexAttribL3d,
   (mapi_func) glVertexAttribL3dv,
   (mapi_func) glVertexAttribL4d,
   (mapi_func) glVertexAttribL4dv,
   (mapi_func) glVertexAttribLFormat,
   (mapi_func) glVertexAttribLPointer,
   (mapi_func) glVertexAttribP1ui,
   (mapi_func) glVertexAttribP1uiv,
   (mapi_func) glVertexAttribP2ui,
   (mapi_func) glVertexAttribP2uiv,
   (mapi_func) glVertexAttribP3ui,
   (mapi_func) glVertexAttribP3uiv,
   (mapi_func) glVertexAttribP4ui,
   (mapi_func) glVertexAttribP4uiv,
   (mapi_func) glVertexAttribPointer,
   (mapi_func) glVertexBindingDivisor,
   (mapi_func) glVertexP2ui,
   (mapi_func) glVertexP2uiv,
   (mapi_func) glVertexP3ui,
   (mapi_func) glVertexP3uiv,
   (mapi_func) glVertexP4ui,
   (mapi_func) glVertexP4uiv,
   (mapi_func) glVertexPointer,
   (mapi_func) glViewport,
   (mapi_func) glViewportArrayv,
   (mapi_func) glViewportIndexedf,
   (mapi_func) glViewportIndexedfv,
   (mapi_func) glWaitSync,
   (mapi_func) glWindowPos2d,
   (mapi_func) glWindowPos2dv,
   (mapi_func) glWindowPos2f,
   (mapi_func) glWindowPos2fv,
   (mapi_func) glWindowPos2i,
   (mapi_func) glWindowPos2iv,
   (mapi_func) glWindowPos2s,
   (mapi_func) glWindowPos2sv,
   (mapi_func) glWindowPos3d,
   (mapi_func) glWindowPos3dv,
   (mapi_func) glWindowPos3f,
   (mapi_func) glWindowPos3fv,
   (mapi_func) glWindowPos3i,
   (mapi_func) glWindowPos3iv,
   (mapi_func) glWindowPos3s,
   (mapi_func) glWindowPos3sv,
};
#undef MAPI_TMP_PUBLIC_ENTRIES
#endif /* MAPI_TMP_PUBLIC_ENTRIES */

#ifdef MAPI_TMP_STUB_ASM_GCC
__asm__(
STUB_ASM_ENTRY("glAccum")"\n"
"\t"STUB_ASM_CODE("0")"\n"

STUB_ASM_ENTRY("glActiveShaderProgram")"\n"
"\t"STUB_ASM_CODE("4")"\n"

STUB_ASM_ENTRY("glActiveTexture")"\n"
"\t"STUB_ASM_CODE("7")"\n"

STUB_ASM_ENTRY("glAlphaFunc")"\n"
"\t"STUB_ASM_CODE("13")"\n"

STUB_ASM_ENTRY("glAreTexturesResident")"\n"
"\t"STUB_ASM_CODE("21")"\n"

STUB_ASM_ENTRY("glArrayElement")"\n"
"\t"STUB_ASM_CODE("23")"\n"

STUB_ASM_ENTRY("glAttachShader")"\n"
"\t"STUB_ASM_CODE("30")"\n"

STUB_ASM_ENTRY("glBegin")"\n"
"\t"STUB_ASM_CODE("31")"\n"

STUB_ASM_ENTRY("glBeginConditionalRender")"\n"
"\t"STUB_ASM_CODE("32")"\n"

STUB_ASM_ENTRY("glBeginQuery")"\n"
"\t"STUB_ASM_CODE("39")"\n"

STUB_ASM_ENTRY("glBeginQueryIndexed")"\n"
"\t"STUB_ASM_CODE("42")"\n"

STUB_ASM_ENTRY("glBeginTransformFeedback")"\n"
"\t"STUB_ASM_CODE("43")"\n"

STUB_ASM_ENTRY("glBindAttribLocation")"\n"
"\t"STUB_ASM_CODE("49")"\n"

STUB_ASM_ENTRY("glBindBuffer")"\n"
"\t"STUB_ASM_CODE("51")"\n"

STUB_ASM_ENTRY("glBindBufferBase")"\n"
"\t"STUB_ASM_CODE("53")"\n"

STUB_ASM_ENTRY("glBindBufferRange")"\n"
"\t"STUB_ASM_CODE("58")"\n"

STUB_ASM_ENTRY("glBindBuffersBase")"\n"
"\t"STUB_ASM_CODE("61")"\n"

STUB_ASM_ENTRY("glBindBuffersRange")"\n"
"\t"STUB_ASM_CODE("62")"\n"

STUB_ASM_ENTRY("glBindFragDataLocation")"\n"
"\t"STUB_ASM_CODE("63")"\n"

STUB_ASM_ENTRY("glBindFragDataLocationIndexed")"\n"
"\t"STUB_ASM_CODE("65")"\n"

STUB_ASM_ENTRY("glBindFramebuffer")"\n"
"\t"STUB_ASM_CODE("68")"\n"

STUB_ASM_ENTRY("glBindImageTexture")"\n"
"\t"STUB_ASM_CODE("71")"\n"

STUB_ASM_ENTRY("glBindImageTextures")"\n"
"\t"STUB_ASM_CODE("73")"\n"

STUB_ASM_ENTRY("glBindProgramPipeline")"\n"
"\t"STUB_ASM_CODE("80")"\n"

STUB_ASM_ENTRY("glBindRenderbuffer")"\n"
"\t"STUB_ASM_CODE("82")"\n"

STUB_ASM_ENTRY("glBindSampler")"\n"
"\t"STUB_ASM_CODE("85")"\n"

STUB_ASM_ENTRY("glBindSamplers")"\n"
"\t"STUB_ASM_CODE("86")"\n"

STUB_ASM_ENTRY("glBindTexture")"\n"
"\t"STUB_ASM_CODE("89")"\n"

STUB_ASM_ENTRY("glBindTextureUnit")"\n"
"\t"STUB_ASM_CODE("91")"\n"

STUB_ASM_ENTRY("glBindTextures")"\n"
"\t"STUB_ASM_CODE("93")"\n"

STUB_ASM_ENTRY("glBindTransformFeedback")"\n"
"\t"STUB_ASM_CODE("94")"\n"

STUB_ASM_ENTRY("glBindVertexArray")"\n"
"\t"STUB_ASM_CODE("97")"\n"

STUB_ASM_ENTRY("glBindVertexBuffer")"\n"
"\t"STUB_ASM_CODE("100")"\n"

STUB_ASM_ENTRY("glBindVertexBuffers")"\n"
"\t"STUB_ASM_CODE("101")"\n"

STUB_ASM_ENTRY("glBitmap")"\n"
"\t"STUB_ASM_CODE("116")"\n"

STUB_ASM_ENTRY("glBlendColor")"\n"
"\t"STUB_ASM_CODE("121")"\n"

STUB_ASM_ENTRY("glBlendEquation")"\n"
"\t"STUB_ASM_CODE("124")"\n"

STUB_ASM_ENTRY("glBlendEquationSeparate")"\n"
"\t"STUB_ASM_CODE("128")"\n"

STUB_ASM_ENTRY("glBlendEquationSeparatei")"\n"
"\t"STUB_ASM_CODE("132")"\n"

STUB_ASM_ENTRY("glBlendEquationi")"\n"
"\t"STUB_ASM_CODE("136")"\n"

STUB_ASM_ENTRY("glBlendFunc")"\n"
"\t"STUB_ASM_CODE("140")"\n"

STUB_ASM_ENTRY("glBlendFuncSeparate")"\n"
"\t"STUB_ASM_CODE("142")"\n"

STUB_ASM_ENTRY("glBlendFuncSeparatei")"\n"
"\t"STUB_ASM_CODE("147")"\n"

STUB_ASM_ENTRY("glBlendFunci")"\n"
"\t"STUB_ASM_CODE("151")"\n"

STUB_ASM_ENTRY("glBlitFramebuffer")"\n"
"\t"STUB_ASM_CODE("156")"\n"

STUB_ASM_ENTRY("glBlitNamedFramebuffer")"\n"
"\t"STUB_ASM_CODE("160")"\n"

STUB_ASM_ENTRY("glBufferData")"\n"
"\t"STUB_ASM_CODE("163")"\n"

STUB_ASM_ENTRY("glBufferStorage")"\n"
"\t"STUB_ASM_CODE("169")"\n"

STUB_ASM_ENTRY("glBufferSubData")"\n"
"\t"STUB_ASM_CODE("173")"\n"

STUB_ASM_ENTRY("glCallList")"\n"
"\t"STUB_ASM_CODE("176")"\n"

STUB_ASM_ENTRY("glCallLists")"\n"
"\t"STUB_ASM_CODE("177")"\n"

STUB_ASM_ENTRY("glCheckFramebufferStatus")"\n"
"\t"STUB_ASM_CODE("178")"\n"

STUB_ASM_ENTRY("glCheckNamedFramebufferStatus")"\n"
"\t"STUB_ASM_CODE("181")"\n"

STUB_ASM_ENTRY("glClampColor")"\n"
"\t"STUB_ASM_CODE("183")"\n"

STUB_ASM_ENTRY("glClear")"\n"
"\t"STUB_ASM_CODE("185")"\n"

STUB_ASM_ENTRY("glClearAccum")"\n"
"\t"STUB_ASM_CODE("186")"\n"

STUB_ASM_ENTRY("glClearBufferData")"\n"
"\t"STUB_ASM_CODE("188")"\n"

STUB_ASM_ENTRY("glClearBufferSubData")"\n"
"\t"STUB_ASM_CODE("189")"\n"

STUB_ASM_ENTRY("glClearBufferfi")"\n"
"\t"STUB_ASM_CODE("190")"\n"

STUB_ASM_ENTRY("glClearBufferfv")"\n"
"\t"STUB_ASM_CODE("191")"\n"

STUB_ASM_ENTRY("glClearBufferiv")"\n"
"\t"STUB_ASM_CODE("192")"\n"

STUB_ASM_ENTRY("glClearBufferuiv")"\n"
"\t"STUB_ASM_CODE("193")"\n"

STUB_ASM_ENTRY("glClearColor")"\n"
"\t"STUB_ASM_CODE("194")"\n"

STUB_ASM_ENTRY("glClearDepth")"\n"
"\t"STUB_ASM_CODE("199")"\n"

STUB_ASM_ENTRY("glClearDepthf")"\n"
"\t"STUB_ASM_CODE("201")"\n"

STUB_ASM_ENTRY("glClearIndex")"\n"
"\t"STUB_ASM_CODE("205")"\n"

STUB_ASM_ENTRY("glClearNamedBufferData")"\n"
"\t"STUB_ASM_CODE("206")"\n"

STUB_ASM_ENTRY("glClearNamedBufferSubData")"\n"
"\t"STUB_ASM_CODE("208")"\n"

STUB_ASM_ENTRY("glClearNamedFramebufferfi")"\n"
"\t"STUB_ASM_CODE("210")"\n"

STUB_ASM_ENTRY("glClearNamedFramebufferfv")"\n"
"\t"STUB_ASM_CODE("211")"\n"

STUB_ASM_ENTRY("glClearNamedFramebufferiv")"\n"
"\t"STUB_ASM_CODE("212")"\n"

STUB_ASM_ENTRY("glClearNamedFramebufferuiv")"\n"
"\t"STUB_ASM_CODE("213")"\n"

STUB_ASM_ENTRY("glClearStencil")"\n"
"\t"STUB_ASM_CODE("215")"\n"

STUB_ASM_ENTRY("glClearTexImage")"\n"
"\t"STUB_ASM_CODE("216")"\n"

STUB_ASM_ENTRY("glClearTexSubImage")"\n"
"\t"STUB_ASM_CODE("218")"\n"

STUB_ASM_ENTRY("glClientActiveTexture")"\n"
"\t"STUB_ASM_CODE("220")"\n"

STUB_ASM_ENTRY("glClientWaitSync")"\n"
"\t"STUB_ASM_CODE("225")"\n"

STUB_ASM_ENTRY("glClipControl")"\n"
"\t"STUB_ASM_CODE("228")"\n"

STUB_ASM_ENTRY("glClipPlane")"\n"
"\t"STUB_ASM_CODE("230")"\n"

STUB_ASM_ENTRY("glColor3b")"\n"
"\t"STUB_ASM_CODE("237")"\n"

STUB_ASM_ENTRY("glColor3bv")"\n"
"\t"STUB_ASM_CODE("238")"\n"

STUB_ASM_ENTRY("glColor3d")"\n"
"\t"STUB_ASM_CODE("239")"\n"

STUB_ASM_ENTRY("glColor3dv")"\n"
"\t"STUB_ASM_CODE("240")"\n"

STUB_ASM_ENTRY("glColor3f")"\n"
"\t"STUB_ASM_CODE("241")"\n"

STUB_ASM_ENTRY("glColor3fv")"\n"
"\t"STUB_ASM_CODE("244")"\n"

STUB_ASM_ENTRY("glColor3i")"\n"
"\t"STUB_ASM_CODE("247")"\n"

STUB_ASM_ENTRY("glColor3iv")"\n"
"\t"STUB_ASM_CODE("248")"\n"

STUB_ASM_ENTRY("glColor3s")"\n"
"\t"STUB_ASM_CODE("249")"\n"

STUB_ASM_ENTRY("glColor3sv")"\n"
"\t"STUB_ASM_CODE("250")"\n"

STUB_ASM_ENTRY("glColor3ub")"\n"
"\t"STUB_ASM_CODE("251")"\n"

STUB_ASM_ENTRY("glColor3ubv")"\n"
"\t"STUB_ASM_CODE("252")"\n"

STUB_ASM_ENTRY("glColor3ui")"\n"
"\t"STUB_ASM_CODE("253")"\n"

STUB_ASM_ENTRY("glColor3uiv")"\n"
"\t"STUB_ASM_CODE("254")"\n"

STUB_ASM_ENTRY("glColor3us")"\n"
"\t"STUB_ASM_CODE("255")"\n"

STUB_ASM_ENTRY("glColor3usv")"\n"
"\t"STUB_ASM_CODE("256")"\n"

STUB_ASM_ENTRY("glColor4b")"\n"
"\t"STUB_ASM_CODE("260")"\n"

STUB_ASM_ENTRY("glColor4bv")"\n"
"\t"STUB_ASM_CODE("261")"\n"

STUB_ASM_ENTRY("glColor4d")"\n"
"\t"STUB_ASM_CODE("262")"\n"

STUB_ASM_ENTRY("glColor4dv")"\n"
"\t"STUB_ASM_CODE("263")"\n"

STUB_ASM_ENTRY("glColor4f")"\n"
"\t"STUB_ASM_CODE("264")"\n"

STUB_ASM_ENTRY("glColor4fv")"\n"
"\t"STUB_ASM_CODE("267")"\n"

STUB_ASM_ENTRY("glColor4i")"\n"
"\t"STUB_ASM_CODE("270")"\n"

STUB_ASM_ENTRY("glColor4iv")"\n"
"\t"STUB_ASM_CODE("271")"\n"

STUB_ASM_ENTRY("glColor4s")"\n"
"\t"STUB_ASM_CODE("272")"\n"

STUB_ASM_ENTRY("glColor4sv")"\n"
"\t"STUB_ASM_CODE("273")"\n"

STUB_ASM_ENTRY("glColor4ub")"\n"
"\t"STUB_ASM_CODE("274")"\n"

STUB_ASM_ENTRY("glColor4ubv")"\n"
"\t"STUB_ASM_CODE("279")"\n"

STUB_ASM_ENTRY("glColor4ui")"\n"
"\t"STUB_ASM_CODE("280")"\n"

STUB_ASM_ENTRY("glColor4uiv")"\n"
"\t"STUB_ASM_CODE("281")"\n"

STUB_ASM_ENTRY("glColor4us")"\n"
"\t"STUB_ASM_CODE("282")"\n"

STUB_ASM_ENTRY("glColor4usv")"\n"
"\t"STUB_ASM_CODE("283")"\n"

STUB_ASM_ENTRY("glColorMask")"\n"
"\t"STUB_ASM_CODE("291")"\n"

STUB_ASM_ENTRY("glColorMaski")"\n"
"\t"STUB_ASM_CODE("293")"\n"

STUB_ASM_ENTRY("glColorMaterial")"\n"
"\t"STUB_ASM_CODE("296")"\n"

STUB_ASM_ENTRY("glColorP3ui")"\n"
"\t"STUB_ASM_CODE("297")"\n"

STUB_ASM_ENTRY("glColorP3uiv")"\n"
"\t"STUB_ASM_CODE("298")"\n"

STUB_ASM_ENTRY("glColorP4ui")"\n"
"\t"STUB_ASM_CODE("299")"\n"

STUB_ASM_ENTRY("glColorP4uiv")"\n"
"\t"STUB_ASM_CODE("300")"\n"

STUB_ASM_ENTRY("glColorPointer")"\n"
"\t"STUB_ASM_CODE("301")"\n"

STUB_ASM_ENTRY("glCompileShader")"\n"
"\t"STUB_ASM_CODE("323")"\n"

STUB_ASM_ENTRY("glCompressedTexImage1D")"\n"
"\t"STUB_ASM_CODE("332")"\n"

STUB_ASM_ENTRY("glCompressedTexImage2D")"\n"
"\t"STUB_ASM_CODE("334")"\n"

STUB_ASM_ENTRY("glCompressedTexImage3D")"\n"
"\t"STUB_ASM_CODE("336")"\n"

STUB_ASM_ENTRY("glCompressedTexSubImage1D")"\n"
"\t"STUB_ASM_CODE("340")"\n"

STUB_ASM_ENTRY("glCompressedTexSubImage2D")"\n"
"\t"STUB_ASM_CODE("342")"\n"

STUB_ASM_ENTRY("glCompressedTexSubImage3D")"\n"
"\t"STUB_ASM_CODE("344")"\n"

STUB_ASM_ENTRY("glCompressedTextureSubImage1D")"\n"
"\t"STUB_ASM_CODE("351")"\n"

STUB_ASM_ENTRY("glCompressedTextureSubImage2D")"\n"
"\t"STUB_ASM_CODE("353")"\n"

STUB_ASM_ENTRY("glCompressedTextureSubImage3D")"\n"
"\t"STUB_ASM_CODE("355")"\n"

STUB_ASM_ENTRY("glCopyBufferSubData")"\n"
"\t"STUB_ASM_CODE("373")"\n"

STUB_ASM_ENTRY("glCopyImageSubData")"\n"
"\t"STUB_ASM_CODE("383")"\n"

STUB_ASM_ENTRY("glCopyNamedBufferSubData")"\n"
"\t"STUB_ASM_CODE("392")"\n"

STUB_ASM_ENTRY("glCopyPixels")"\n"
"\t"STUB_ASM_CODE("394")"\n"

STUB_ASM_ENTRY("glCopyTexImage1D")"\n"
"\t"STUB_ASM_CODE("395")"\n"

STUB_ASM_ENTRY("glCopyTexImage2D")"\n"
"\t"STUB_ASM_CODE("397")"\n"

STUB_ASM_ENTRY("glCopyTexSubImage1D")"\n"
"\t"STUB_ASM_CODE("399")"\n"

STUB_ASM_ENTRY("glCopyTexSubImage2D")"\n"
"\t"STUB_ASM_CODE("401")"\n"

STUB_ASM_ENTRY("glCopyTexSubImage3D")"\n"
"\t"STUB_ASM_CODE("403")"\n"

STUB_ASM_ENTRY("glCopyTextureSubImage1D")"\n"
"\t"STUB_ASM_CODE("410")"\n"

STUB_ASM_ENTRY("glCopyTextureSubImage2D")"\n"
"\t"STUB_ASM_CODE("412")"\n"

STUB_ASM_ENTRY("glCopyTextureSubImage3D")"\n"
"\t"STUB_ASM_CODE("414")"\n"

STUB_ASM_ENTRY("glCreateBuffers")"\n"
"\t"STUB_ASM_CODE("424")"\n"

STUB_ASM_ENTRY("glCreateFramebuffers")"\n"
"\t"STUB_ASM_CODE("426")"\n"

STUB_ASM_ENTRY("glCreateProgram")"\n"
"\t"STUB_ASM_CODE("429")"\n"

STUB_ASM_ENTRY("glCreateProgramPipelines")"\n"
"\t"STUB_ASM_CODE("431")"\n"

STUB_ASM_ENTRY("glCreateQueries")"\n"
"\t"STUB_ASM_CODE("433")"\n"

STUB_ASM_ENTRY("glCreateRenderbuffers")"\n"
"\t"STUB_ASM_CODE("434")"\n"

STUB_ASM_ENTRY("glCreateSamplers")"\n"
"\t"STUB_ASM_CODE("435")"\n"

STUB_ASM_ENTRY("glCreateShader")"\n"
"\t"STUB_ASM_CODE("437")"\n"

STUB_ASM_ENTRY("glCreateShaderProgramv")"\n"
"\t"STUB_ASM_CODE("440")"\n"

STUB_ASM_ENTRY("glCreateTextures")"\n"
"\t"STUB_ASM_CODE("444")"\n"

STUB_ASM_ENTRY("glCreateTransformFeedbacks")"\n"
"\t"STUB_ASM_CODE("445")"\n"

STUB_ASM_ENTRY("glCreateVertexArrays")"\n"
"\t"STUB_ASM_CODE("446")"\n"

STUB_ASM_ENTRY("glCullFace")"\n"
"\t"STUB_ASM_CODE("447")"\n"

STUB_ASM_ENTRY("glDebugMessageCallback")"\n"
"\t"STUB_ASM_CODE("452")"\n"

STUB_ASM_ENTRY("glDebugMessageControl")"\n"
"\t"STUB_ASM_CODE("457")"\n"

STUB_ASM_ENTRY("glDebugMessageInsert")"\n"
"\t"STUB_ASM_CODE("462")"\n"

STUB_ASM_ENTRY("glDeleteBuffers")"\n"
"\t"STUB_ASM_CODE("471")"\n"

STUB_ASM_ENTRY("glDeleteFramebuffers")"\n"
"\t"STUB_ASM_CODE("477")"\n"

STUB_ASM_ENTRY("glDeleteLists")"\n"
"\t"STUB_ASM_CODE("480")"\n"

STUB_ASM_ENTRY("glDeleteProgram")"\n"
"\t"STUB_ASM_CODE("489")"\n"

STUB_ASM_ENTRY("glDeleteProgramPipelines")"\n"
"\t"STUB_ASM_CODE("490")"\n"

STUB_ASM_ENTRY("glDeleteQueries")"\n"
"\t"STUB_ASM_CODE("494")"\n"

STUB_ASM_ENTRY("glDeleteRenderbuffers")"\n"
"\t"STUB_ASM_CODE("498")"\n"

STUB_ASM_ENTRY("glDeleteSamplers")"\n"
"\t"STUB_ASM_CODE("501")"\n"

STUB_ASM_ENTRY("glDeleteShader")"\n"
"\t"STUB_ASM_CODE("503")"\n"

STUB_ASM_ENTRY("glDeleteSync")"\n"
"\t"STUB_ASM_CODE("505")"\n"

STUB_ASM_ENTRY("glDeleteTextures")"\n"
"\t"STUB_ASM_CODE("507")"\n"

STUB_ASM_ENTRY("glDeleteTransformFeedbacks")"\n"
"\t"STUB_ASM_CODE("509")"\n"

STUB_ASM_ENTRY("glDeleteVertexArrays")"\n"
"\t"STUB_ASM_CODE("512")"\n"

STUB_ASM_ENTRY("glDepthFunc")"\n"
"\t"STUB_ASM_CODE("518")"\n"

STUB_ASM_ENTRY("glDepthMask")"\n"
"\t"STUB_ASM_CODE("519")"\n"

STUB_ASM_ENTRY("glDepthRange")"\n"
"\t"STUB_ASM_CODE("520")"\n"

STUB_ASM_ENTRY("glDepthRangeArrayv")"\n"
"\t"STUB_ASM_CODE("524")"\n"

STUB_ASM_ENTRY("glDepthRangeIndexed")"\n"
"\t"STUB_ASM_CODE("525")"\n"

STUB_ASM_ENTRY("glDepthRangef")"\n"
"\t"STUB_ASM_CODE("530")"\n"

STUB_ASM_ENTRY("glDetachShader")"\n"
"\t"STUB_ASM_CODE("535")"\n"

STUB_ASM_ENTRY("glDisable")"\n"
"\t"STUB_ASM_CODE("539")"\n"

STUB_ASM_ENTRY("glDisableClientState")"\n"
"\t"STUB_ASM_CODE("540")"\n"

STUB_ASM_ENTRY("glDisableVertexArrayAttrib")"\n"
"\t"STUB_ASM_CODE("546")"\n"

STUB_ASM_ENTRY("glDisableVertexAttribArray")"\n"
"\t"STUB_ASM_CODE("550")"\n"

STUB_ASM_ENTRY("glDisablei")"\n"
"\t"STUB_ASM_CODE("552")"\n"

STUB_ASM_ENTRY("glDispatchCompute")"\n"
"\t"STUB_ASM_CODE("557")"\n"

STUB_ASM_ENTRY("glDispatchComputeIndirect")"\n"
"\t"STUB_ASM_CODE("559")"\n"

STUB_ASM_ENTRY("glDrawArrays")"\n"
"\t"STUB_ASM_CODE("560")"\n"

STUB_ASM_ENTRY("glDrawArraysIndirect")"\n"
"\t"STUB_ASM_CODE("562")"\n"

STUB_ASM_ENTRY("glDrawArraysInstanced")"\n"
"\t"STUB_ASM_CODE("563")"\n"

STUB_ASM_ENTRY("glDrawArraysInstancedBaseInstance")"\n"
"\t"STUB_ASM_CODE("566")"\n"

STUB_ASM_ENTRY("glDrawBuffer")"\n"
"\t"STUB_ASM_CODE("570")"\n"

STUB_ASM_ENTRY("glDrawBuffers")"\n"
"\t"STUB_ASM_CODE("571")"\n"

STUB_ASM_ENTRY("glDrawElements")"\n"
"\t"STUB_ASM_CODE("583")"\n"

STUB_ASM_ENTRY("glDrawElementsBaseVertex")"\n"
"\t"STUB_ASM_CODE("584")"\n"

STUB_ASM_ENTRY("glDrawElementsIndirect")"\n"
"\t"STUB_ASM_CODE("587")"\n"

STUB_ASM_ENTRY("glDrawElementsInstanced")"\n"
"\t"STUB_ASM_CODE("588")"\n"

STUB_ASM_ENTRY("glDrawElementsInstancedBaseInstance")"\n"
"\t"STUB_ASM_CODE("591")"\n"

STUB_ASM_ENTRY("glDrawElementsInstancedBaseVertex")"\n"
"\t"STUB_ASM_CODE("593")"\n"

STUB_ASM_ENTRY("glDrawElementsInstancedBaseVertexBaseInstance")"\n"
"\t"STUB_ASM_CODE("594")"\n"

STUB_ASM_ENTRY("glDrawPixels")"\n"
"\t"STUB_ASM_CODE("604")"\n"

STUB_ASM_ENTRY("glDrawRangeElements")"\n"
"\t"STUB_ASM_CODE("607")"\n"

STUB_ASM_ENTRY("glDrawRangeElementsBaseVertex")"\n"
"\t"STUB_ASM_CODE("608")"\n"

STUB_ASM_ENTRY("glDrawTransformFeedback")"\n"
"\t"STUB_ASM_CODE("621")"\n"

STUB_ASM_ENTRY("glDrawTransformFeedbackInstanced")"\n"
"\t"STUB_ASM_CODE("623")"\n"

STUB_ASM_ENTRY("glDrawTransformFeedbackStream")"\n"
"\t"STUB_ASM_CODE("626")"\n"

STUB_ASM_ENTRY("glDrawTransformFeedbackStreamInstanced")"\n"
"\t"STUB_ASM_CODE("627")"\n"

STUB_ASM_ENTRY("glEdgeFlag")"\n"
"\t"STUB_ASM_CODE("633")"\n"

STUB_ASM_ENTRY("glEdgeFlagPointer")"\n"
"\t"STUB_ASM_CODE("635")"\n"

STUB_ASM_ENTRY("glEdgeFlagv")"\n"
"\t"STUB_ASM_CODE("638")"\n"

STUB_ASM_ENTRY("glEnable")"\n"
"\t"STUB_ASM_CODE("641")"\n"

STUB_ASM_ENTRY("glEnableClientState")"\n"
"\t"STUB_ASM_CODE("642")"\n"

STUB_ASM_ENTRY("glEnableVertexArrayAttrib")"\n"
"\t"STUB_ASM_CODE("648")"\n"

STUB_ASM_ENTRY("glEnableVertexAttribArray")"\n"
"\t"STUB_ASM_CODE("652")"\n"

STUB_ASM_ENTRY("glEnablei")"\n"
"\t"STUB_ASM_CODE("654")"\n"

STUB_ASM_ENTRY("glEnd")"\n"
"\t"STUB_ASM_CODE("658")"\n"

STUB_ASM_ENTRY("glEndConditionalRender")"\n"
"\t"STUB_ASM_CODE("659")"\n"

STUB_ASM_ENTRY("glEndList")"\n"
"\t"STUB_ASM_CODE("663")"\n"

STUB_ASM_ENTRY("glEndQuery")"\n"
"\t"STUB_ASM_CODE("667")"\n"

STUB_ASM_ENTRY("glEndQueryIndexed")"\n"
"\t"STUB_ASM_CODE("670")"\n"

STUB_ASM_ENTRY("glEndTransformFeedback")"\n"
"\t"STUB_ASM_CODE("672")"\n"

STUB_ASM_ENTRY("glEvalCoord1d")"\n"
"\t"STUB_ASM_CODE("677")"\n"

STUB_ASM_ENTRY("glEvalCoord1dv")"\n"
"\t"STUB_ASM_CODE("678")"\n"

STUB_ASM_ENTRY("glEvalCoord1f")"\n"
"\t"STUB_ASM_CODE("679")"\n"

STUB_ASM_ENTRY("glEvalCoord1fv")"\n"
"\t"STUB_ASM_CODE("680")"\n"

STUB_ASM_ENTRY("glEvalCoord2d")"\n"
"\t"STUB_ASM_CODE("683")"\n"

STUB_ASM_ENTRY("glEvalCoord2dv")"\n"
"\t"STUB_ASM_CODE("684")"\n"

STUB_ASM_ENTRY("glEvalCoord2f")"\n"
"\t"STUB_ASM_CODE("685")"\n"

STUB_ASM_ENTRY("glEvalCoord2fv")"\n"
"\t"STUB_ASM_CODE("686")"\n"

STUB_ASM_ENTRY("glEvalMesh1")"\n"
"\t"STUB_ASM_CODE("690")"\n"

STUB_ASM_ENTRY("glEvalMesh2")"\n"
"\t"STUB_ASM_CODE("691")"\n"

STUB_ASM_ENTRY("glEvalPoint1")"\n"
"\t"STUB_ASM_CODE("692")"\n"

STUB_ASM_ENTRY("glEvalPoint2")"\n"
"\t"STUB_ASM_CODE("693")"\n"

STUB_ASM_ENTRY("glFeedbackBuffer")"\n"
"\t"STUB_ASM_CODE("710")"\n"

STUB_ASM_ENTRY("glFenceSync")"\n"
"\t"STUB_ASM_CODE("712")"\n"

STUB_ASM_ENTRY("glFinish")"\n"
"\t"STUB_ASM_CODE("716")"\n"

STUB_ASM_ENTRY("glFlush")"\n"
"\t"STUB_ASM_CODE("722")"\n"

STUB_ASM_ENTRY("glFlushMappedBufferRange")"\n"
"\t"STUB_ASM_CODE("723")"\n"

STUB_ASM_ENTRY("glFlushMappedNamedBufferRange")"\n"
"\t"STUB_ASM_CODE("726")"\n"

STUB_ASM_ENTRY("glFogCoordPointer")"\n"
"\t"STUB_ASM_CODE("734")"\n"

STUB_ASM_ENTRY("glFogCoordd")"\n"
"\t"STUB_ASM_CODE("737")"\n"

STUB_ASM_ENTRY("glFogCoorddv")"\n"
"\t"STUB_ASM_CODE("739")"\n"

STUB_ASM_ENTRY("glFogCoordf")"\n"
"\t"STUB_ASM_CODE("741")"\n"

STUB_ASM_ENTRY("glFogCoordfv")"\n"
"\t"STUB_ASM_CODE("743")"\n"

STUB_ASM_ENTRY("glFogf")"\n"
"\t"STUB_ASM_CODE("748")"\n"

STUB_ASM_ENTRY("glFogfv")"\n"
"\t"STUB_ASM_CODE("749")"\n"

STUB_ASM_ENTRY("glFogi")"\n"
"\t"STUB_ASM_CODE("750")"\n"

STUB_ASM_ENTRY("glFogiv")"\n"
"\t"STUB_ASM_CODE("751")"\n"

STUB_ASM_ENTRY("glFramebufferParameteri")"\n"
"\t"STUB_ASM_CODE("778")"\n"

STUB_ASM_ENTRY("glFramebufferRenderbuffer")"\n"
"\t"STUB_ASM_CODE("782")"\n"

STUB_ASM_ENTRY("glFramebufferTexture")"\n"
"\t"STUB_ASM_CODE("789")"\n"

STUB_ASM_ENTRY("glFramebufferTexture1D")"\n"
"\t"STUB_ASM_CODE("790")"\n"

STUB_ASM_ENTRY("glFramebufferTexture2D")"\n"
"\t"STUB_ASM_CODE("792")"\n"

STUB_ASM_ENTRY("glFramebufferTexture3D")"\n"
"\t"STUB_ASM_CODE("798")"\n"

STUB_ASM_ENTRY("glFramebufferTextureLayer")"\n"
"\t"STUB_ASM_CODE("805")"\n"

STUB_ASM_ENTRY("glFrontFace")"\n"
"\t"STUB_ASM_CODE("814")"\n"

STUB_ASM_ENTRY("glFrustum")"\n"
"\t"STUB_ASM_CODE("815")"\n"

STUB_ASM_ENTRY("glGenBuffers")"\n"
"\t"STUB_ASM_CODE("821")"\n"

STUB_ASM_ENTRY("glGenFramebuffers")"\n"
"\t"STUB_ASM_CODE("826")"\n"

STUB_ASM_ENTRY("glGenLists")"\n"
"\t"STUB_ASM_CODE("829")"\n"

STUB_ASM_ENTRY("glGenProgramPipelines")"\n"
"\t"STUB_ASM_CODE("834")"\n"

STUB_ASM_ENTRY("glGenQueries")"\n"
"\t"STUB_ASM_CODE("838")"\n"

STUB_ASM_ENTRY("glGenRenderbuffers")"\n"
"\t"STUB_ASM_CODE("842")"\n"

STUB_ASM_ENTRY("glGenSamplers")"\n"
"\t"STUB_ASM_CODE("845")"\n"

STUB_ASM_ENTRY("glGenTextures")"\n"
"\t"STUB_ASM_CODE("848")"\n"

STUB_ASM_ENTRY("glGenTransformFeedbacks")"\n"
"\t"STUB_ASM_CODE("850")"\n"

STUB_ASM_ENTRY("glGenVertexArrays")"\n"
"\t"STUB_ASM_CODE("853")"\n"

STUB_ASM_ENTRY("glGenerateMipmap")"\n"
"\t"STUB_ASM_CODE("857")"\n"

STUB_ASM_ENTRY("glGenerateTextureMipmap")"\n"
"\t"STUB_ASM_CODE("861")"\n"

STUB_ASM_ENTRY("glGetActiveAtomicCounterBufferiv")"\n"
"\t"STUB_ASM_CODE("863")"\n"

STUB_ASM_ENTRY("glGetActiveAttrib")"\n"
"\t"STUB_ASM_CODE("864")"\n"

STUB_ASM_ENTRY("glGetActiveSubroutineName")"\n"
"\t"STUB_ASM_CODE("866")"\n"

STUB_ASM_ENTRY("glGetActiveSubroutineUniformName")"\n"
"\t"STUB_ASM_CODE("867")"\n"

STUB_ASM_ENTRY("glGetActiveSubroutineUniformiv")"\n"
"\t"STUB_ASM_CODE("868")"\n"

STUB_ASM_ENTRY("glGetActiveUniform")"\n"
"\t"STUB_ASM_CODE("869")"\n"

STUB_ASM_ENTRY("glGetActiveUniformBlockName")"\n"
"\t"STUB_ASM_CODE("871")"\n"

STUB_ASM_ENTRY("glGetActiveUniformBlockiv")"\n"
"\t"STUB_ASM_CODE("872")"\n"

STUB_ASM_ENTRY("glGetActiveUniformName")"\n"
"\t"STUB_ASM_CODE("873")"\n"

STUB_ASM_ENTRY("glGetActiveUniformsiv")"\n"
"\t"STUB_ASM_CODE("874")"\n"

STUB_ASM_ENTRY("glGetAttachedShaders")"\n"
"\t"STUB_ASM_CODE("879")"\n"

STUB_ASM_ENTRY("glGetAttribLocation")"\n"
"\t"STUB_ASM_CODE("880")"\n"

STUB_ASM_ENTRY("glGetBooleani_v")"\n"
"\t"STUB_ASM_CODE("883")"\n"

STUB_ASM_ENTRY("glGetBooleanv")"\n"
"\t"STUB_ASM_CODE("884")"\n"

STUB_ASM_ENTRY("glGetBufferParameteri64v")"\n"
"\t"STUB_ASM_CODE("885")"\n"

STUB_ASM_ENTRY("glGetBufferParameteriv")"\n"
"\t"STUB_ASM_CODE("886")"\n"

STUB_ASM_ENTRY("glGetBufferPointerv")"\n"
"\t"STUB_ASM_CODE("889")"\n"

STUB_ASM_ENTRY("glGetBufferSubData")"\n"
"\t"STUB_ASM_CODE("892")"\n"

STUB_ASM_ENTRY("glGetClipPlane")"\n"
"\t"STUB_ASM_CODE("894")"\n"

STUB_ASM_ENTRY("glGetCompressedTexImage")"\n"
"\t"STUB_ASM_CODE("915")"\n"

STUB_ASM_ENTRY("glGetCompressedTextureImage")"\n"
"\t"STUB_ASM_CODE("918")"\n"

STUB_ASM_ENTRY("glGetCompressedTextureSubImage")"\n"
"\t"STUB_ASM_CODE("920")"\n"

STUB_ASM_ENTRY("glGetDebugMessageLog")"\n"
"\t"STUB_ASM_CODE("929")"\n"

STUB_ASM_ENTRY("glGetDoublei_v")"\n"
"\t"STUB_ASM_CODE("936")"\n"

STUB_ASM_ENTRY("glGetDoublev")"\n"
"\t"STUB_ASM_CODE("938")"\n"

STUB_ASM_ENTRY("glGetError")"\n"
"\t"STUB_ASM_CODE("941")"\n"

STUB_ASM_ENTRY("glGetFloati_v")"\n"
"\t"STUB_ASM_CODE("949")"\n"

STUB_ASM_ENTRY("glGetFloatv")"\n"
"\t"STUB_ASM_CODE("953")"\n"

STUB_ASM_ENTRY("glGetFragDataIndex")"\n"
"\t"STUB_ASM_CODE("955")"\n"

STUB_ASM_ENTRY("glGetFragDataLocation")"\n"
"\t"STUB_ASM_CODE("957")"\n"

STUB_ASM_ENTRY("glGetFramebufferAttachmentParameteriv")"\n"
"\t"STUB_ASM_CODE("964")"\n"

STUB_ASM_ENTRY("glGetFramebufferParameteriv")"\n"
"\t"STUB_ASM_CODE("968")"\n"

STUB_ASM_ENTRY("glGetGraphicsResetStatus")"\n"
"\t"STUB_ASM_CODE("972")"\n"

STUB_ASM_ENTRY("glGetInteger64i_v")"\n"
"\t"STUB_ASM_CODE("990")"\n"

STUB_ASM_ENTRY("glGetInteger64v")"\n"
"\t"STUB_ASM_CODE("991")"\n"

STUB_ASM_ENTRY("glGetIntegeri_v")"\n"
"\t"STUB_ASM_CODE("995")"\n"

STUB_ASM_ENTRY("glGetIntegerv")"\n"
"\t"STUB_ASM_CODE("999")"\n"

STUB_ASM_ENTRY("glGetInternalformati64v")"\n"
"\t"STUB_ASM_CODE("1001")"\n"

STUB_ASM_ENTRY("glGetInternalformativ")"\n"
"\t"STUB_ASM_CODE("1002")"\n"

STUB_ASM_ENTRY("glGetLightfv")"\n"
"\t"STUB_ASM_CODE("1006")"\n"

STUB_ASM_ENTRY("glGetLightiv")"\n"
"\t"STUB_ASM_CODE("1007")"\n"

STUB_ASM_ENTRY("glGetMapdv")"\n"
"\t"STUB_ASM_CODE("1021")"\n"

STUB_ASM_ENTRY("glGetMapfv")"\n"
"\t"STUB_ASM_CODE("1022")"\n"

STUB_ASM_ENTRY("glGetMapiv")"\n"
"\t"STUB_ASM_CODE("1023")"\n"

STUB_ASM_ENTRY("glGetMaterialfv")"\n"
"\t"STUB_ASM_CODE("1025")"\n"

STUB_ASM_ENTRY("glGetMaterialiv")"\n"
"\t"STUB_ASM_CODE("1026")"\n"

STUB_ASM_ENTRY("glGetMultisamplefv")"\n"
"\t"STUB_ASM_CODE("1050")"\n"

STUB_ASM_ENTRY("glGetNamedBufferParameteri64v")"\n"
"\t"STUB_ASM_CODE("1052")"\n"

STUB_ASM_ENTRY("glGetNamedBufferParameteriv")"\n"
"\t"STUB_ASM_CODE("1054")"\n"

STUB_ASM_ENTRY("glGetNamedBufferPointerv")"\n"
"\t"STUB_ASM_CODE("1057")"\n"

STUB_ASM_ENTRY("glGetNamedBufferSubData")"\n"
"\t"STUB_ASM_CODE("1059")"\n"

STUB_ASM_ENTRY("glGetNamedFramebufferAttachmentParameteriv")"\n"
"\t"STUB_ASM_CODE("1061")"\n"

STUB_ASM_ENTRY("glGetNamedFramebufferParameteriv")"\n"
"\t"STUB_ASM_CODE("1064")"\n"

STUB_ASM_ENTRY("glGetNamedRenderbufferParameteriv")"\n"
"\t"STUB_ASM_CODE("1072")"\n"

STUB_ASM_ENTRY("glGetObjectLabel")"\n"
"\t"STUB_ASM_CODE("1079")"\n"

STUB_ASM_ENTRY("glGetObjectPtrLabel")"\n"
"\t"STUB_ASM_CODE("1086")"\n"

STUB_ASM_ENTRY("glGetPixelMapfv")"\n"
"\t"STUB_ASM_CODE("1114")"\n"

STUB_ASM_ENTRY("glGetPixelMapuiv")"\n"
"\t"STUB_ASM_CODE("1115")"\n"

STUB_ASM_ENTRY("glGetPixelMapusv")"\n"
"\t"STUB_ASM_CODE("1116")"\n"

STUB_ASM_ENTRY("glGetPointerv")"\n"
"\t"STUB_ASM_CODE("1124")"\n"

STUB_ASM_ENTRY("glGetPolygonStipple")"\n"
"\t"STUB_ASM_CODE("1128")"\n"

STUB_ASM_ENTRY("glGetProgramBinary")"\n"
"\t"STUB_ASM_CODE("1129")"\n"

STUB_ASM_ENTRY("glGetProgramInfoLog")"\n"
"\t"STUB_ASM_CODE("1135")"\n"

STUB_ASM_ENTRY("glGetProgramInterfaceiv")"\n"
"\t"STUB_ASM_CODE("1136")"\n"

STUB_ASM_ENTRY("glGetProgramPipelineInfoLog")"\n"
"\t"STUB_ASM_CODE("1145")"\n"

STUB_ASM_ENTRY("glGetProgramPipelineiv")"\n"
"\t"STUB_ASM_CODE("1147")"\n"

STUB_ASM_ENTRY("glGetProgramResourceIndex")"\n"
"\t"STUB_ASM_CODE("1149")"\n"

STUB_ASM_ENTRY("glGetProgramResourceLocation")"\n"
"\t"STUB_ASM_CODE("1150")"\n"

STUB_ASM_ENTRY("glGetProgramResourceLocationIndex")"\n"
"\t"STUB_ASM_CODE("1151")"\n"

STUB_ASM_ENTRY("glGetProgramResourceName")"\n"
"\t"STUB_ASM_CODE("1153")"\n"

STUB_ASM_ENTRY("glGetProgramResourceiv")"\n"
"\t"STUB_ASM_CODE("1155")"\n"

STUB_ASM_ENTRY("glGetProgramStageiv")"\n"
"\t"STUB_ASM_CODE("1156")"\n"

STUB_ASM_ENTRY("glGetProgramiv")"\n"
"\t"STUB_ASM_CODE("1160")"\n"

STUB_ASM_ENTRY("glGetQueryBufferObjecti64v")"\n"
"\t"STUB_ASM_CODE("1163")"\n"

STUB_ASM_ENTRY("glGetQueryBufferObjectiv")"\n"
"\t"STUB_ASM_CODE("1164")"\n"

STUB_ASM_ENTRY("glGetQueryBufferObjectui64v")"\n"
"\t"STUB_ASM_CODE("1165")"\n"

STUB_ASM_ENTRY("glGetQueryBufferObjectuiv")"\n"
"\t"STUB_ASM_CODE("1166")"\n"

STUB_ASM_ENTRY("glGetQueryIndexediv")"\n"
"\t"STUB_ASM_CODE("1167")"\n"

STUB_ASM_ENTRY("glGetQueryObjecti64v")"\n"
"\t"STUB_ASM_CODE("1168")"\n"

STUB_ASM_ENTRY("glGetQueryObjectiv")"\n"
"\t"STUB_ASM_CODE("1170")"\n"

STUB_ASM_ENTRY("glGetQueryObjectui64v")"\n"
"\t"STUB_ASM_CODE("1173")"\n"

STUB_ASM_ENTRY("glGetQueryObjectuiv")"\n"
"\t"STUB_ASM_CODE("1176")"\n"

STUB_ASM_ENTRY("glGetQueryiv")"\n"
"\t"STUB_ASM_CODE("1179")"\n"

STUB_ASM_ENTRY("glGetRenderbufferParameteriv")"\n"
"\t"STUB_ASM_CODE("1182")"\n"

STUB_ASM_ENTRY("glGetSamplerParameterIiv")"\n"
"\t"STUB_ASM_CODE("1185")"\n"

STUB_ASM_ENTRY("glGetSamplerParameterIuiv")"\n"
"\t"STUB_ASM_CODE("1188")"\n"

STUB_ASM_ENTRY("glGetSamplerParameterfv")"\n"
"\t"STUB_ASM_CODE("1191")"\n"

STUB_ASM_ENTRY("glGetSamplerParameteriv")"\n"
"\t"STUB_ASM_CODE("1192")"\n"

STUB_ASM_ENTRY("glGetShaderInfoLog")"\n"
"\t"STUB_ASM_CODE("1197")"\n"

STUB_ASM_ENTRY("glGetShaderPrecisionFormat")"\n"
"\t"STUB_ASM_CODE("1198")"\n"

STUB_ASM_ENTRY("glGetShaderSource")"\n"
"\t"STUB_ASM_CODE("1199")"\n"

STUB_ASM_ENTRY("glGetShaderiv")"\n"
"\t"STUB_ASM_CODE("1201")"\n"

STUB_ASM_ENTRY("glGetString")"\n"
"\t"STUB_ASM_CODE("1206")"\n"

STUB_ASM_ENTRY("glGetStringi")"\n"
"\t"STUB_ASM_CODE("1207")"\n"

STUB_ASM_ENTRY("glGetSubroutineIndex")"\n"
"\t"STUB_ASM_CODE("1208")"\n"

STUB_ASM_ENTRY("glGetSubroutineUniformLocation")"\n"
"\t"STUB_ASM_CODE("1209")"\n"

STUB_ASM_ENTRY("glGetSynciv")"\n"
"\t"STUB_ASM_CODE("1210")"\n"

STUB_ASM_ENTRY("glGetTexEnvfv")"\n"
"\t"STUB_ASM_CODE("1215")"\n"

STUB_ASM_ENTRY("glGetTexEnviv")"\n"
"\t"STUB_ASM_CODE("1216")"\n"

STUB_ASM_ENTRY("glGetTexGendv")"\n"
"\t"STUB_ASM_CODE("1220")"\n"

STUB_ASM_ENTRY("glGetTexGenfv")"\n"
"\t"STUB_ASM_CODE("1221")"\n"

STUB_ASM_ENTRY("glGetTexGeniv")"\n"
"\t"STUB_ASM_CODE("1223")"\n"

STUB_ASM_ENTRY("glGetTexImage")"\n"
"\t"STUB_ASM_CODE("1226")"\n"

STUB_ASM_ENTRY("glGetTexLevelParameterfv")"\n"
"\t"STUB_ASM_CODE("1228")"\n"

STUB_ASM_ENTRY("glGetTexLevelParameteriv")"\n"
"\t"STUB_ASM_CODE("1230")"\n"

STUB_ASM_ENTRY("glGetTexParameterIiv")"\n"
"\t"STUB_ASM_CODE("1233")"\n"

STUB_ASM_ENTRY("glGetTexParameterIuiv")"\n"
"\t"STUB_ASM_CODE("1236")"\n"

STUB_ASM_ENTRY("glGetTexParameterfv")"\n"
"\t"STUB_ASM_CODE("1240")"\n"

STUB_ASM_ENTRY("glGetTexParameteriv")"\n"
"\t"STUB_ASM_CODE("1241")"\n"

STUB_ASM_ENTRY("glGetTextureImage")"\n"
"\t"STUB_ASM_CODE("1247")"\n"

STUB_ASM_ENTRY("glGetTextureLevelParameterfv")"\n"
"\t"STUB_ASM_CODE("1249")"\n"

STUB_ASM_ENTRY("glGetTextureLevelParameteriv")"\n"
"\t"STUB_ASM_CODE("1251")"\n"

STUB_ASM_ENTRY("glGetTextureParameterIiv")"\n"
"\t"STUB_ASM_CODE("1253")"\n"

STUB_ASM_ENTRY("glGetTextureParameterIuiv")"\n"
"\t"STUB_ASM_CODE("1255")"\n"

STUB_ASM_ENTRY("glGetTextureParameterfv")"\n"
"\t"STUB_ASM_CODE("1257")"\n"

STUB_ASM_ENTRY("glGetTextureParameteriv")"\n"
"\t"STUB_ASM_CODE("1259")"\n"

STUB_ASM_ENTRY("glGetTextureSubImage")"\n"
"\t"STUB_ASM_CODE("1264")"\n"

STUB_ASM_ENTRY("glGetTransformFeedbackVarying")"\n"
"\t"STUB_ASM_CODE("1266")"\n"

STUB_ASM_ENTRY("glGetTransformFeedbacki64_v")"\n"
"\t"STUB_ASM_CODE("1269")"\n"

STUB_ASM_ENTRY("glGetTransformFeedbacki_v")"\n"
"\t"STUB_ASM_CODE("1270")"\n"

STUB_ASM_ENTRY("glGetTransformFeedbackiv")"\n"
"\t"STUB_ASM_CODE("1271")"\n"

STUB_ASM_ENTRY("glGetUniformBlockIndex")"\n"
"\t"STUB_ASM_CODE("1273")"\n"

STUB_ASM_ENTRY("glGetUniformIndices")"\n"
"\t"STUB_ASM_CODE("1275")"\n"

STUB_ASM_ENTRY("glGetUniformLocation")"\n"
"\t"STUB_ASM_CODE("1276")"\n"

STUB_ASM_ENTRY("glGetUniformSubroutineuiv")"\n"
"\t"STUB_ASM_CODE("1279")"\n"

STUB_ASM_ENTRY("glGetUniformdv")"\n"
"\t"STUB_ASM_CODE("1280")"\n"

STUB_ASM_ENTRY("glGetUniformfv")"\n"
"\t"STUB_ASM_CODE("1281")"\n"

STUB_ASM_ENTRY("glGetUniformiv")"\n"
"\t"STUB_ASM_CODE("1285")"\n"

STUB_ASM_ENTRY("glGetUniformuiv")"\n"
"\t"STUB_ASM_CODE("1289")"\n"

STUB_ASM_ENTRY("glGetVertexArrayIndexed64iv")"\n"
"\t"STUB_ASM_CODE("1300")"\n"

STUB_ASM_ENTRY("glGetVertexArrayIndexediv")"\n"
"\t"STUB_ASM_CODE("1301")"\n"

STUB_ASM_ENTRY("glGetVertexArrayiv")"\n"
"\t"STUB_ASM_CODE("1306")"\n"

STUB_ASM_ENTRY("glGetVertexAttribIiv")"\n"
"\t"STUB_ASM_CODE("1309")"\n"

STUB_ASM_ENTRY("glGetVertexAttribIuiv")"\n"
"\t"STUB_ASM_CODE("1311")"\n"

STUB_ASM_ENTRY("glGetVertexAttribLdv")"\n"
"\t"STUB_ASM_CODE("1313")"\n"

STUB_ASM_ENTRY("glGetVertexAttribPointerv")"\n"
"\t"STUB_ASM_CODE("1318")"\n"

STUB_ASM_ENTRY("glGetVertexAttribdv")"\n"
"\t"STUB_ASM_CODE("1321")"\n"

STUB_ASM_ENTRY("glGetVertexAttribfv")"\n"
"\t"STUB_ASM_CODE("1324")"\n"

STUB_ASM_ENTRY("glGetVertexAttribiv")"\n"
"\t"STUB_ASM_CODE("1327")"\n"

STUB_ASM_ENTRY("glGetnColorTable")"\n"
"\t"STUB_ASM_CODE("1340")"\n"

STUB_ASM_ENTRY("glGetnCompressedTexImage")"\n"
"\t"STUB_ASM_CODE("1342")"\n"

STUB_ASM_ENTRY("glGetnConvolutionFilter")"\n"
"\t"STUB_ASM_CODE("1344")"\n"

STUB_ASM_ENTRY("glGetnHistogram")"\n"
"\t"STUB_ASM_CODE("1346")"\n"

STUB_ASM_ENTRY("glGetnMapdv")"\n"
"\t"STUB_ASM_CODE("1348")"\n"

STUB_ASM_ENTRY("glGetnMapfv")"\n"
"\t"STUB_ASM_CODE("1350")"\n"

STUB_ASM_ENTRY("glGetnMapiv")"\n"
"\t"STUB_ASM_CODE("1352")"\n"

STUB_ASM_ENTRY("glGetnMinmax")"\n"
"\t"STUB_ASM_CODE("1354")"\n"

STUB_ASM_ENTRY("glGetnPixelMapfv")"\n"
"\t"STUB_ASM_CODE("1356")"\n"

STUB_ASM_ENTRY("glGetnPixelMapuiv")"\n"
"\t"STUB_ASM_CODE("1358")"\n"

STUB_ASM_ENTRY("glGetnPixelMapusv")"\n"
"\t"STUB_ASM_CODE("1360")"\n"

STUB_ASM_ENTRY("glGetnPolygonStipple")"\n"
"\t"STUB_ASM_CODE("1362")"\n"

STUB_ASM_ENTRY("glGetnSeparableFilter")"\n"
"\t"STUB_ASM_CODE("1364")"\n"

STUB_ASM_ENTRY("glGetnTexImage")"\n"
"\t"STUB_ASM_CODE("1366")"\n"

STUB_ASM_ENTRY("glGetnUniformdv")"\n"
"\t"STUB_ASM_CODE("1368")"\n"

STUB_ASM_ENTRY("glGetnUniformfv")"\n"
"\t"STUB_ASM_CODE("1370")"\n"

STUB_ASM_ENTRY("glGetnUniformiv")"\n"
"\t"STUB_ASM_CODE("1375")"\n"

STUB_ASM_ENTRY("glGetnUniformuiv")"\n"
"\t"STUB_ASM_CODE("1380")"\n"

STUB_ASM_ENTRY("glHint")"\n"
"\t"STUB_ASM_CODE("1395")"\n"

STUB_ASM_ENTRY("glIndexMask")"\n"
"\t"STUB_ASM_CODE("1413")"\n"

STUB_ASM_ENTRY("glIndexPointer")"\n"
"\t"STUB_ASM_CODE("1415")"\n"

STUB_ASM_ENTRY("glIndexd")"\n"
"\t"STUB_ASM_CODE("1418")"\n"

STUB_ASM_ENTRY("glIndexdv")"\n"
"\t"STUB_ASM_CODE("1419")"\n"

STUB_ASM_ENTRY("glIndexf")"\n"
"\t"STUB_ASM_CODE("1420")"\n"

STUB_ASM_ENTRY("glIndexfv")"\n"
"\t"STUB_ASM_CODE("1421")"\n"

STUB_ASM_ENTRY("glIndexi")"\n"
"\t"STUB_ASM_CODE("1422")"\n"

STUB_ASM_ENTRY("glIndexiv")"\n"
"\t"STUB_ASM_CODE("1423")"\n"

STUB_ASM_ENTRY("glIndexs")"\n"
"\t"STUB_ASM_CODE("1424")"\n"

STUB_ASM_ENTRY("glIndexsv")"\n"
"\t"STUB_ASM_CODE("1425")"\n"

STUB_ASM_ENTRY("glIndexub")"\n"
"\t"STUB_ASM_CODE("1426")"\n"

STUB_ASM_ENTRY("glIndexubv")"\n"
"\t"STUB_ASM_CODE("1427")"\n"

STUB_ASM_ENTRY("glInitNames")"\n"
"\t"STUB_ASM_CODE("1430")"\n"

STUB_ASM_ENTRY("glInterleavedArrays")"\n"
"\t"STUB_ASM_CODE("1434")"\n"

STUB_ASM_ENTRY("glInvalidateBufferData")"\n"
"\t"STUB_ASM_CODE("1436")"\n"

STUB_ASM_ENTRY("glInvalidateBufferSubData")"\n"
"\t"STUB_ASM_CODE("1437")"\n"

STUB_ASM_ENTRY("glInvalidateFramebuffer")"\n"
"\t"STUB_ASM_CODE("1438")"\n"

STUB_ASM_ENTRY("glInvalidateNamedFramebufferData")"\n"
"\t"STUB_ASM_CODE("1439")"\n"

STUB_ASM_ENTRY("glInvalidateNamedFramebufferSubData")"\n"
"\t"STUB_ASM_CODE("1440")"\n"

STUB_ASM_ENTRY("glInvalidateSubFramebuffer")"\n"
"\t"STUB_ASM_CODE("1441")"\n"

STUB_ASM_ENTRY("glInvalidateTexImage")"\n"
"\t"STUB_ASM_CODE("1442")"\n"

STUB_ASM_ENTRY("glInvalidateTexSubImage")"\n"
"\t"STUB_ASM_CODE("1443")"\n"

STUB_ASM_ENTRY("glIsBuffer")"\n"
"\t"STUB_ASM_CODE("1445")"\n"

STUB_ASM_ENTRY("glIsEnabled")"\n"
"\t"STUB_ASM_CODE("1449")"\n"

STUB_ASM_ENTRY("glIsEnabledi")"\n"
"\t"STUB_ASM_CODE("1451")"\n"

STUB_ASM_ENTRY("glIsFramebuffer")"\n"
"\t"STUB_ASM_CODE("1457")"\n"

STUB_ASM_ENTRY("glIsList")"\n"
"\t"STUB_ASM_CODE("1462")"\n"

STUB_ASM_ENTRY("glIsProgram")"\n"
"\t"STUB_ASM_CODE("1472")"\n"

STUB_ASM_ENTRY("glIsProgramPipeline")"\n"
"\t"STUB_ASM_CODE("1475")"\n"

STUB_ASM_ENTRY("glIsQuery")"\n"
"\t"STUB_ASM_CODE("1477")"\n"

STUB_ASM_ENTRY("glIsRenderbuffer")"\n"
"\t"STUB_ASM_CODE("1480")"\n"

STUB_ASM_ENTRY("glIsSampler")"\n"
"\t"STUB_ASM_CODE("1483")"\n"

STUB_ASM_ENTRY("glIsShader")"\n"
"\t"STUB_ASM_CODE("1485")"\n"

STUB_ASM_ENTRY("glIsSync")"\n"
"\t"STUB_ASM_CODE("1487")"\n"

STUB_ASM_ENTRY("glIsTexture")"\n"
"\t"STUB_ASM_CODE("1489")"\n"

STUB_ASM_ENTRY("glIsTransformFeedback")"\n"
"\t"STUB_ASM_CODE("1493")"\n"

STUB_ASM_ENTRY("glIsVertexArray")"\n"
"\t"STUB_ASM_CODE("1497")"\n"

STUB_ASM_ENTRY("glLightModelf")"\n"
"\t"STUB_ASM_CODE("1506")"\n"

STUB_ASM_ENTRY("glLightModelfv")"\n"
"\t"STUB_ASM_CODE("1507")"\n"

STUB_ASM_ENTRY("glLightModeli")"\n"
"\t"STUB_ASM_CODE("1508")"\n"

STUB_ASM_ENTRY("glLightModeliv")"\n"
"\t"STUB_ASM_CODE("1509")"\n"

STUB_ASM_ENTRY("glLightf")"\n"
"\t"STUB_ASM_CODE("1514")"\n"

STUB_ASM_ENTRY("glLightfv")"\n"
"\t"STUB_ASM_CODE("1515")"\n"

STUB_ASM_ENTRY("glLighti")"\n"
"\t"STUB_ASM_CODE("1516")"\n"

STUB_ASM_ENTRY("glLightiv")"\n"
"\t"STUB_ASM_CODE("1517")"\n"

STUB_ASM_ENTRY("glLineStipple")"\n"
"\t"STUB_ASM_CODE("1522")"\n"

STUB_ASM_ENTRY("glLineWidth")"\n"
"\t"STUB_ASM_CODE("1523")"\n"

STUB_ASM_ENTRY("glLinkProgram")"\n"
"\t"STUB_ASM_CODE("1526")"\n"

STUB_ASM_ENTRY("glListBase")"\n"
"\t"STUB_ASM_CODE("1528")"\n"

STUB_ASM_ENTRY("glLoadIdentity")"\n"
"\t"STUB_ASM_CODE("1534")"\n"

STUB_ASM_ENTRY("glLoadMatrixd")"\n"
"\t"STUB_ASM_CODE("1536")"\n"

STUB_ASM_ENTRY("glLoadMatrixf")"\n"
"\t"STUB_ASM_CODE("1537")"\n"

STUB_ASM_ENTRY("glLoadName")"\n"
"\t"STUB_ASM_CODE("1540")"\n"

STUB_ASM_ENTRY("glLoadTransposeMatrixd")"\n"
"\t"STUB_ASM_CODE("1544")"\n"

STUB_ASM_ENTRY("glLoadTransposeMatrixf")"\n"
"\t"STUB_ASM_CODE("1546")"\n"

STUB_ASM_ENTRY("glLogicOp")"\n"
"\t"STUB_ASM_CODE("1550")"\n"

STUB_ASM_ENTRY("glMap1d")"\n"
"\t"STUB_ASM_CODE("1563")"\n"

STUB_ASM_ENTRY("glMap1f")"\n"
"\t"STUB_ASM_CODE("1564")"\n"

STUB_ASM_ENTRY("glMap2d")"\n"
"\t"STUB_ASM_CODE("1566")"\n"

STUB_ASM_ENTRY("glMap2f")"\n"
"\t"STUB_ASM_CODE("1567")"\n"

STUB_ASM_ENTRY("glMapBuffer")"\n"
"\t"STUB_ASM_CODE("1569")"\n"

STUB_ASM_ENTRY("glMapBufferRange")"\n"
"\t"STUB_ASM_CODE("1572")"\n"

STUB_ASM_ENTRY("glMapGrid1d")"\n"
"\t"STUB_ASM_CODE("1575")"\n"

STUB_ASM_ENTRY("glMapGrid1f")"\n"
"\t"STUB_ASM_CODE("1576")"\n"

STUB_ASM_ENTRY("glMapGrid2d")"\n"
"\t"STUB_ASM_CODE("1578")"\n"

STUB_ASM_ENTRY("glMapGrid2f")"\n"
"\t"STUB_ASM_CODE("1579")"\n"

STUB_ASM_ENTRY("glMapNamedBuffer")"\n"
"\t"STUB_ASM_CODE("1581")"\n"

STUB_ASM_ENTRY("glMapNamedBufferRange")"\n"
"\t"STUB_ASM_CODE("1583")"\n"

STUB_ASM_ENTRY("glMaterialf")"\n"
"\t"STUB_ASM_CODE("1593")"\n"

STUB_ASM_ENTRY("glMaterialfv")"\n"
"\t"STUB_ASM_CODE("1594")"\n"

STUB_ASM_ENTRY("glMateriali")"\n"
"\t"STUB_ASM_CODE("1595")"\n"

STUB_ASM_ENTRY("glMaterialiv")"\n"
"\t"STUB_ASM_CODE("1596")"\n"

STUB_ASM_ENTRY("glMatrixMode")"\n"
"\t"STUB_ASM_CODE("1615")"\n"

STUB_ASM_ENTRY("glMemoryBarrier")"\n"
"\t"STUB_ASM_CODE("1634")"\n"

STUB_ASM_ENTRY("glMemoryBarrierByRegion")"\n"
"\t"STUB_ASM_CODE("1635")"\n"

STUB_ASM_ENTRY("glMinSampleShading")"\n"
"\t"STUB_ASM_CODE("1638")"\n"

STUB_ASM_ENTRY("glMultMatrixd")"\n"
"\t"STUB_ASM_CODE("1643")"\n"

STUB_ASM_ENTRY("glMultMatrixf")"\n"
"\t"STUB_ASM_CODE("1644")"\n"

STUB_ASM_ENTRY("glMultTransposeMatrixd")"\n"
"\t"STUB_ASM_CODE("1648")"\n"

STUB_ASM_ENTRY("glMultTransposeMatrixf")"\n"
"\t"STUB_ASM_CODE("1650")"\n"

STUB_ASM_ENTRY("glMultiDrawArrays")"\n"
"\t"STUB_ASM_CODE("1653")"\n"

STUB_ASM_ENTRY("glMultiDrawArraysIndirect")"\n"
"\t"STUB_ASM_CODE("1655")"\n"

STUB_ASM_ENTRY("glMultiDrawElements")"\n"
"\t"STUB_ASM_CODE("1663")"\n"

STUB_ASM_ENTRY("glMultiDrawElementsBaseVertex")"\n"
"\t"STUB_ASM_CODE("1664")"\n"

STUB_ASM_ENTRY("glMultiDrawElementsIndirect")"\n"
"\t"STUB_ASM_CODE("1667")"\n"

STUB_ASM_ENTRY("glMultiTexCoord1d")"\n"
"\t"STUB_ASM_CODE("1682")"\n"

STUB_ASM_ENTRY("glMultiTexCoord1dv")"\n"
"\t"STUB_ASM_CODE("1684")"\n"

STUB_ASM_ENTRY("glMultiTexCoord1f")"\n"
"\t"STUB_ASM_CODE("1686")"\n"

STUB_ASM_ENTRY("glMultiTexCoord1fv")"\n"
"\t"STUB_ASM_CODE("1688")"\n"

STUB_ASM_ENTRY("glMultiTexCoord1i")"\n"
"\t"STUB_ASM_CODE("1692")"\n"

STUB_ASM_ENTRY("glMultiTexCoord1iv")"\n"
"\t"STUB_ASM_CODE("1694")"\n"

STUB_ASM_ENTRY("glMultiTexCoord1s")"\n"
"\t"STUB_ASM_CODE("1696")"\n"

STUB_ASM_ENTRY("glMultiTexCoord1sv")"\n"
"\t"STUB_ASM_CODE("1698")"\n"

STUB_ASM_ENTRY("glMultiTexCoord2d")"\n"
"\t"STUB_ASM_CODE("1706")"\n"

STUB_ASM_ENTRY("glMultiTexCoord2dv")"\n"
"\t"STUB_ASM_CODE("1708")"\n"

STUB_ASM_ENTRY("glMultiTexCoord2f")"\n"
"\t"STUB_ASM_CODE("1710")"\n"

STUB_ASM_ENTRY("glMultiTexCoord2fv")"\n"
"\t"STUB_ASM_CODE("1712")"\n"

STUB_ASM_ENTRY("glMultiTexCoord2i")"\n"
"\t"STUB_ASM_CODE("1716")"\n"

STUB_ASM_ENTRY("glMultiTexCoord2iv")"\n"
"\t"STUB_ASM_CODE("1718")"\n"

STUB_ASM_ENTRY("glMultiTexCoord2s")"\n"
"\t"STUB_ASM_CODE("1720")"\n"

STUB_ASM_ENTRY("glMultiTexCoord2sv")"\n"
"\t"STUB_ASM_CODE("1722")"\n"

STUB_ASM_ENTRY("glMultiTexCoord3d")"\n"
"\t"STUB_ASM_CODE("1730")"\n"

STUB_ASM_ENTRY("glMultiTexCoord3dv")"\n"
"\t"STUB_ASM_CODE("1732")"\n"

STUB_ASM_ENTRY("glMultiTexCoord3f")"\n"
"\t"STUB_ASM_CODE("1734")"\n"

STUB_ASM_ENTRY("glMultiTexCoord3fv")"\n"
"\t"STUB_ASM_CODE("1736")"\n"

STUB_ASM_ENTRY("glMultiTexCoord3i")"\n"
"\t"STUB_ASM_CODE("1740")"\n"

STUB_ASM_ENTRY("glMultiTexCoord3iv")"\n"
"\t"STUB_ASM_CODE("1742")"\n"

STUB_ASM_ENTRY("glMultiTexCoord3s")"\n"
"\t"STUB_ASM_CODE("1744")"\n"

STUB_ASM_ENTRY("glMultiTexCoord3sv")"\n"
"\t"STUB_ASM_CODE("1746")"\n"

STUB_ASM_ENTRY("glMultiTexCoord4d")"\n"
"\t"STUB_ASM_CODE("1754")"\n"

STUB_ASM_ENTRY("glMultiTexCoord4dv")"\n"
"\t"STUB_ASM_CODE("1756")"\n"

STUB_ASM_ENTRY("glMultiTexCoord4f")"\n"
"\t"STUB_ASM_CODE("1758")"\n"

STUB_ASM_ENTRY("glMultiTexCoord4fv")"\n"
"\t"STUB_ASM_CODE("1760")"\n"

STUB_ASM_ENTRY("glMultiTexCoord4i")"\n"
"\t"STUB_ASM_CODE("1764")"\n"

STUB_ASM_ENTRY("glMultiTexCoord4iv")"\n"
"\t"STUB_ASM_CODE("1766")"\n"

STUB_ASM_ENTRY("glMultiTexCoord4s")"\n"
"\t"STUB_ASM_CODE("1768")"\n"

STUB_ASM_ENTRY("glMultiTexCoord4sv")"\n"
"\t"STUB_ASM_CODE("1770")"\n"

STUB_ASM_ENTRY("glMultiTexCoordP1ui")"\n"
"\t"STUB_ASM_CODE("1776")"\n"

STUB_ASM_ENTRY("glMultiTexCoordP1uiv")"\n"
"\t"STUB_ASM_CODE("1777")"\n"

STUB_ASM_ENTRY("glMultiTexCoordP2ui")"\n"
"\t"STUB_ASM_CODE("1778")"\n"

STUB_ASM_ENTRY("glMultiTexCoordP2uiv")"\n"
"\t"STUB_ASM_CODE("1779")"\n"

STUB_ASM_ENTRY("glMultiTexCoordP3ui")"\n"
"\t"STUB_ASM_CODE("1780")"\n"

STUB_ASM_ENTRY("glMultiTexCoordP3uiv")"\n"
"\t"STUB_ASM_CODE("1781")"\n"

STUB_ASM_ENTRY("glMultiTexCoordP4ui")"\n"
"\t"STUB_ASM_CODE("1782")"\n"

STUB_ASM_ENTRY("glMultiTexCoordP4uiv")"\n"
"\t"STUB_ASM_CODE("1783")"\n"

STUB_ASM_ENTRY("glNamedBufferData")"\n"
"\t"STUB_ASM_CODE("1824")"\n"

STUB_ASM_ENTRY("glNamedBufferStorage")"\n"
"\t"STUB_ASM_CODE("1829")"\n"

STUB_ASM_ENTRY("glNamedBufferSubData")"\n"
"\t"STUB_ASM_CODE("1833")"\n"

STUB_ASM_ENTRY("glNamedFramebufferDrawBuffer")"\n"
"\t"STUB_ASM_CODE("1836")"\n"

STUB_ASM_ENTRY("glNamedFramebufferDrawBuffers")"\n"
"\t"STUB_ASM_CODE("1837")"\n"

STUB_ASM_ENTRY("glNamedFramebufferParameteri")"\n"
"\t"STUB_ASM_CODE("1838")"\n"

STUB_ASM_ENTRY("glNamedFramebufferReadBuffer")"\n"
"\t"STUB_ASM_CODE("1840")"\n"

STUB_ASM_ENTRY("glNamedFramebufferRenderbuffer")"\n"
"\t"STUB_ASM_CODE("1841")"\n"

STUB_ASM_ENTRY("glNamedFramebufferTexture")"\n"
"\t"STUB_ASM_CODE("1846")"\n"

STUB_ASM_ENTRY("glNamedFramebufferTextureLayer")"\n"
"\t"STUB_ASM_CODE("1852")"\n"

STUB_ASM_ENTRY("glNamedRenderbufferStorage")"\n"
"\t"STUB_ASM_CODE("1866")"\n"

STUB_ASM_ENTRY("glNamedRenderbufferStorageMultisample")"\n"
"\t"STUB_ASM_CODE("1868")"\n"

STUB_ASM_ENTRY("glNewList")"\n"
"\t"STUB_ASM_CODE("1873")"\n"

STUB_ASM_ENTRY("glNormal3b")"\n"
"\t"STUB_ASM_CODE("1875")"\n"

STUB_ASM_ENTRY("glNormal3bv")"\n"
"\t"STUB_ASM_CODE("1876")"\n"

STUB_ASM_ENTRY("glNormal3d")"\n"
"\t"STUB_ASM_CODE("1877")"\n"

STUB_ASM_ENTRY("glNormal3dv")"\n"
"\t"STUB_ASM_CODE("1878")"\n"

STUB_ASM_ENTRY("glNormal3f")"\n"
"\t"STUB_ASM_CODE("1879")"\n"

STUB_ASM_ENTRY("glNormal3fv")"\n"
"\t"STUB_ASM_CODE("1882")"\n"

STUB_ASM_ENTRY("glNormal3i")"\n"
"\t"STUB_ASM_CODE("1885")"\n"

STUB_ASM_ENTRY("glNormal3iv")"\n"
"\t"STUB_ASM_CODE("1886")"\n"

STUB_ASM_ENTRY("glNormal3s")"\n"
"\t"STUB_ASM_CODE("1887")"\n"

STUB_ASM_ENTRY("glNormal3sv")"\n"
"\t"STUB_ASM_CODE("1888")"\n"

STUB_ASM_ENTRY("glNormalP3ui")"\n"
"\t"STUB_ASM_CODE("1893")"\n"

STUB_ASM_ENTRY("glNormalP3uiv")"\n"
"\t"STUB_ASM_CODE("1894")"\n"

STUB_ASM_ENTRY("glNormalPointer")"\n"
"\t"STUB_ASM_CODE("1895")"\n"

STUB_ASM_ENTRY("glObjectLabel")"\n"
"\t"STUB_ASM_CODE("1909")"\n"

STUB_ASM_ENTRY("glObjectPtrLabel")"\n"
"\t"STUB_ASM_CODE("1912")"\n"

STUB_ASM_ENTRY("glOrtho")"\n"
"\t"STUB_ASM_CODE("1917")"\n"

STUB_ASM_ENTRY("glPassThrough")"\n"
"\t"STUB_ASM_CODE("1925")"\n"

STUB_ASM_ENTRY("glPatchParameterfv")"\n"
"\t"STUB_ASM_CODE("1927")"\n"

STUB_ASM_ENTRY("glPatchParameteri")"\n"
"\t"STUB_ASM_CODE("1930")"\n"

STUB_ASM_ENTRY("glPauseTransformFeedback")"\n"
"\t"STUB_ASM_CODE("1955")"\n"

STUB_ASM_ENTRY("glPixelMapfv")"\n"
"\t"STUB_ASM_CODE("1959")"\n"

STUB_ASM_ENTRY("glPixelMapuiv")"\n"
"\t"STUB_ASM_CODE("1960")"\n"

STUB_ASM_ENTRY("glPixelMapusv")"\n"
"\t"STUB_ASM_CODE("1961")"\n"

STUB_ASM_ENTRY("glPixelStoref")"\n"
"\t"STUB_ASM_CODE("1963")"\n"

STUB_ASM_ENTRY("glPixelStorei")"\n"
"\t"STUB_ASM_CODE("1964")"\n"

STUB_ASM_ENTRY("glPixelTransferf")"\n"
"\t"STUB_ASM_CODE("1971")"\n"

STUB_ASM_ENTRY("glPixelTransferi")"\n"
"\t"STUB_ASM_CODE("1972")"\n"

STUB_ASM_ENTRY("glPixelZoom")"\n"
"\t"STUB_ASM_CODE("1978")"\n"

STUB_ASM_ENTRY("glPointParameterf")"\n"
"\t"STUB_ASM_CODE("1981")"\n"

STUB_ASM_ENTRY("glPointParameterfv")"\n"
"\t"STUB_ASM_CODE("1985")"\n"

STUB_ASM_ENTRY("glPointParameteri")"\n"
"\t"STUB_ASM_CODE("1989")"\n"

STUB_ASM_ENTRY("glPointParameteriv")"\n"
"\t"STUB_ASM_CODE("1991")"\n"

STUB_ASM_ENTRY("glPointSize")"\n"
"\t"STUB_ASM_CODE("1997")"\n"

STUB_ASM_ENTRY("glPolygonMode")"\n"
"\t"STUB_ASM_CODE("2003")"\n"

STUB_ASM_ENTRY("glPolygonOffset")"\n"
"\t"STUB_ASM_CODE("2005")"\n"

STUB_ASM_ENTRY("glPolygonStipple")"\n"
"\t"STUB_ASM_CODE("2011")"\n"

STUB_ASM_ENTRY("glPopAttrib")"\n"
"\t"STUB_ASM_CODE("2012")"\n"

STUB_ASM_ENTRY("glPopClientAttrib")"\n"
"\t"STUB_ASM_CODE("2013")"\n"

STUB_ASM_ENTRY("glPopDebugGroup")"\n"
"\t"STUB_ASM_CODE("2014")"\n"

STUB_ASM_ENTRY("glPopMatrix")"\n"
"\t"STUB_ASM_CODE("2018")"\n"

STUB_ASM_ENTRY("glPopName")"\n"
"\t"STUB_ASM_CODE("2019")"\n"

STUB_ASM_ENTRY("glPrimitiveRestartIndex")"\n"
"\t"STUB_ASM_CODE("2027")"\n"

STUB_ASM_ENTRY("glPrioritizeTextures")"\n"
"\t"STUB_ASM_CODE("2030")"\n"

STUB_ASM_ENTRY("glProgramBinary")"\n"
"\t"STUB_ASM_CODE("2033")"\n"

STUB_ASM_ENTRY("glProgramParameteri")"\n"
"\t"STUB_ASM_CODE("2068")"\n"

STUB_ASM_ENTRY("glProgramUniform1d")"\n"
"\t"STUB_ASM_CODE("2076")"\n"

STUB_ASM_ENTRY("glProgramUniform1dv")"\n"
"\t"STUB_ASM_CODE("2078")"\n"

STUB_ASM_ENTRY("glProgramUniform1f")"\n"
"\t"STUB_ASM_CODE("2080")"\n"

STUB_ASM_ENTRY("glProgramUniform1fv")"\n"
"\t"STUB_ASM_CODE("2082")"\n"

STUB_ASM_ENTRY("glProgramUniform1i")"\n"
"\t"STUB_ASM_CODE("2084")"\n"

STUB_ASM_ENTRY("glProgramUniform1iv")"\n"
"\t"STUB_ASM_CODE("2090")"\n"

STUB_ASM_ENTRY("glProgramUniform1ui")"\n"
"\t"STUB_ASM_CODE("2092")"\n"

STUB_ASM_ENTRY("glProgramUniform1uiv")"\n"
"\t"STUB_ASM_CODE("2098")"\n"

STUB_ASM_ENTRY("glProgramUniform2d")"\n"
"\t"STUB_ASM_CODE("2100")"\n"

STUB_ASM_ENTRY("glProgramUniform2dv")"\n"
"\t"STUB_ASM_CODE("2102")"\n"

STUB_ASM_ENTRY("glProgramUniform2f")"\n"
"\t"STUB_ASM_CODE("2104")"\n"

STUB_ASM_ENTRY("glProgramUniform2fv")"\n"
"\t"STUB_ASM_CODE("2106")"\n"

STUB_ASM_ENTRY("glProgramUniform2i")"\n"
"\t"STUB_ASM_CODE("2108")"\n"

STUB_ASM_ENTRY("glProgramUniform2iv")"\n"
"\t"STUB_ASM_CODE("2114")"\n"

STUB_ASM_ENTRY("glProgramUniform2ui")"\n"
"\t"STUB_ASM_CODE("2116")"\n"

STUB_ASM_ENTRY("glProgramUniform2uiv")"\n"
"\t"STUB_ASM_CODE("2122")"\n"

STUB_ASM_ENTRY("glProgramUniform3d")"\n"
"\t"STUB_ASM_CODE("2124")"\n"

STUB_ASM_ENTRY("glProgramUniform3dv")"\n"
"\t"STUB_ASM_CODE("2126")"\n"

STUB_ASM_ENTRY("glProgramUniform3f")"\n"
"\t"STUB_ASM_CODE("2128")"\n"

STUB_ASM_ENTRY("glProgramUniform3fv")"\n"
"\t"STUB_ASM_CODE("2130")"\n"

STUB_ASM_ENTRY("glProgramUniform3i")"\n"
"\t"STUB_ASM_CODE("2132")"\n"

STUB_ASM_ENTRY("glProgramUniform3iv")"\n"
"\t"STUB_ASM_CODE("2138")"\n"

STUB_ASM_ENTRY("glProgramUniform3ui")"\n"
"\t"STUB_ASM_CODE("2140")"\n"

STUB_ASM_ENTRY("glProgramUniform3uiv")"\n"
"\t"STUB_ASM_CODE("2146")"\n"

STUB_ASM_ENTRY("glProgramUniform4d")"\n"
"\t"STUB_ASM_CODE("2148")"\n"

STUB_ASM_ENTRY("glProgramUniform4dv")"\n"
"\t"STUB_ASM_CODE("2150")"\n"

STUB_ASM_ENTRY("glProgramUniform4f")"\n"
"\t"STUB_ASM_CODE("2152")"\n"

STUB_ASM_ENTRY("glProgramUniform4fv")"\n"
"\t"STUB_ASM_CODE("2154")"\n"

STUB_ASM_ENTRY("glProgramUniform4i")"\n"
"\t"STUB_ASM_CODE("2156")"\n"

STUB_ASM_ENTRY("glProgramUniform4iv")"\n"
"\t"STUB_ASM_CODE("2162")"\n"

STUB_ASM_ENTRY("glProgramUniform4ui")"\n"
"\t"STUB_ASM_CODE("2164")"\n"

STUB_ASM_ENTRY("glProgramUniform4uiv")"\n"
"\t"STUB_ASM_CODE("2170")"\n"

STUB_ASM_ENTRY("glProgramUniformMatrix2dv")"\n"
"\t"STUB_ASM_CODE("2178")"\n"

STUB_ASM_ENTRY("glProgramUniformMatrix2fv")"\n"
"\t"STUB_ASM_CODE("2180")"\n"

STUB_ASM_ENTRY("glProgramUniformMatrix2x3dv")"\n"
"\t"STUB_ASM_CODE("2182")"\n"

STUB_ASM_ENTRY("glProgramUniformMatrix2x3fv")"\n"
"\t"STUB_ASM_CODE("2184")"\n"

STUB_ASM_ENTRY("glProgramUniformMatrix2x4dv")"\n"
"\t"STUB_ASM_CODE("2186")"\n"

STUB_ASM_ENTRY("glProgramUniformMatrix2x4fv")"\n"
"\t"STUB_ASM_CODE("2188")"\n"

STUB_ASM_ENTRY("glProgramUniformMatrix3dv")"\n"
"\t"STUB_ASM_CODE("2190")"\n"

STUB_ASM_ENTRY("glProgramUniformMatrix3fv")"\n"
"\t"STUB_ASM_CODE("2192")"\n"

STUB_ASM_ENTRY("glProgramUniformMatrix3x2dv")"\n"
"\t"STUB_ASM_CODE("2194")"\n"

STUB_ASM_ENTRY("glProgramUniformMatrix3x2fv")"\n"
"\t"STUB_ASM_CODE("2196")"\n"

STUB_ASM_ENTRY("glProgramUniformMatrix3x4dv")"\n"
"\t"STUB_ASM_CODE("2198")"\n"

STUB_ASM_ENTRY("glProgramUniformMatrix3x4fv")"\n"
"\t"STUB_ASM_CODE("2200")"\n"

STUB_ASM_ENTRY("glProgramUniformMatrix4dv")"\n"
"\t"STUB_ASM_CODE("2202")"\n"

STUB_ASM_ENTRY("glProgramUniformMatrix4fv")"\n"
"\t"STUB_ASM_CODE("2204")"\n"

STUB_ASM_ENTRY("glProgramUniformMatrix4x2dv")"\n"
"\t"STUB_ASM_CODE("2206")"\n"

STUB_ASM_ENTRY("glProgramUniformMatrix4x2fv")"\n"
"\t"STUB_ASM_CODE("2208")"\n"

STUB_ASM_ENTRY("glProgramUniformMatrix4x3dv")"\n"
"\t"STUB_ASM_CODE("2210")"\n"

STUB_ASM_ENTRY("glProgramUniformMatrix4x3fv")"\n"
"\t"STUB_ASM_CODE("2212")"\n"

STUB_ASM_ENTRY("glProvokingVertex")"\n"
"\t"STUB_ASM_CODE("2217")"\n"

STUB_ASM_ENTRY("glPushAttrib")"\n"
"\t"STUB_ASM_CODE("2219")"\n"

STUB_ASM_ENTRY("glPushClientAttrib")"\n"
"\t"STUB_ASM_CODE("2220")"\n"

STUB_ASM_ENTRY("glPushDebugGroup")"\n"
"\t"STUB_ASM_CODE("2222")"\n"

STUB_ASM_ENTRY("glPushMatrix")"\n"
"\t"STUB_ASM_CODE("2226")"\n"

STUB_ASM_ENTRY("glPushName")"\n"
"\t"STUB_ASM_CODE("2227")"\n"

STUB_ASM_ENTRY("glQueryCounter")"\n"
"\t"STUB_ASM_CODE("2228")"\n"

STUB_ASM_ENTRY("glRasterPos2d")"\n"
"\t"STUB_ASM_CODE("2235")"\n"

STUB_ASM_ENTRY("glRasterPos2dv")"\n"
"\t"STUB_ASM_CODE("2236")"\n"

STUB_ASM_ENTRY("glRasterPos2f")"\n"
"\t"STUB_ASM_CODE("2237")"\n"

STUB_ASM_ENTRY("glRasterPos2fv")"\n"
"\t"STUB_ASM_CODE("2238")"\n"

STUB_ASM_ENTRY("glRasterPos2i")"\n"
"\t"STUB_ASM_CODE("2239")"\n"

STUB_ASM_ENTRY("glRasterPos2iv")"\n"
"\t"STUB_ASM_CODE("2240")"\n"

STUB_ASM_ENTRY("glRasterPos2s")"\n"
"\t"STUB_ASM_CODE("2241")"\n"

STUB_ASM_ENTRY("glRasterPos2sv")"\n"
"\t"STUB_ASM_CODE("2242")"\n"

STUB_ASM_ENTRY("glRasterPos3d")"\n"
"\t"STUB_ASM_CODE("2245")"\n"

STUB_ASM_ENTRY("glRasterPos3dv")"\n"
"\t"STUB_ASM_CODE("2246")"\n"

STUB_ASM_ENTRY("glRasterPos3f")"\n"
"\t"STUB_ASM_CODE("2247")"\n"

STUB_ASM_ENTRY("glRasterPos3fv")"\n"
"\t"STUB_ASM_CODE("2248")"\n"

STUB_ASM_ENTRY("glRasterPos3i")"\n"
"\t"STUB_ASM_CODE("2249")"\n"

STUB_ASM_ENTRY("glRasterPos3iv")"\n"
"\t"STUB_ASM_CODE("2250")"\n"

STUB_ASM_ENTRY("glRasterPos3s")"\n"
"\t"STUB_ASM_CODE("2251")"\n"

STUB_ASM_ENTRY("glRasterPos3sv")"\n"
"\t"STUB_ASM_CODE("2252")"\n"

STUB_ASM_ENTRY("glRasterPos4d")"\n"
"\t"STUB_ASM_CODE("2255")"\n"

STUB_ASM_ENTRY("glRasterPos4dv")"\n"
"\t"STUB_ASM_CODE("2256")"\n"

STUB_ASM_ENTRY("glRasterPos4f")"\n"
"\t"STUB_ASM_CODE("2257")"\n"

STUB_ASM_ENTRY("glRasterPos4fv")"\n"
"\t"STUB_ASM_CODE("2258")"\n"

STUB_ASM_ENTRY("glRasterPos4i")"\n"
"\t"STUB_ASM_CODE("2259")"\n"

STUB_ASM_ENTRY("glRasterPos4iv")"\n"
"\t"STUB_ASM_CODE("2260")"\n"

STUB_ASM_ENTRY("glRasterPos4s")"\n"
"\t"STUB_ASM_CODE("2261")"\n"

STUB_ASM_ENTRY("glRasterPos4sv")"\n"
"\t"STUB_ASM_CODE("2262")"\n"

STUB_ASM_ENTRY("glReadBuffer")"\n"
"\t"STUB_ASM_CODE("2266")"\n"

STUB_ASM_ENTRY("glReadPixels")"\n"
"\t"STUB_ASM_CODE("2270")"\n"

STUB_ASM_ENTRY("glReadnPixels")"\n"
"\t"STUB_ASM_CODE("2271")"\n"

STUB_ASM_ENTRY("glRectd")"\n"
"\t"STUB_ASM_CODE("2275")"\n"

STUB_ASM_ENTRY("glRectdv")"\n"
"\t"STUB_ASM_CODE("2276")"\n"

STUB_ASM_ENTRY("glRectf")"\n"
"\t"STUB_ASM_CODE("2277")"\n"

STUB_ASM_ENTRY("glRectfv")"\n"
"\t"STUB_ASM_CODE("2278")"\n"

STUB_ASM_ENTRY("glRecti")"\n"
"\t"STUB_ASM_CODE("2279")"\n"

STUB_ASM_ENTRY("glRectiv")"\n"
"\t"STUB_ASM_CODE("2280")"\n"

STUB_ASM_ENTRY("glRects")"\n"
"\t"STUB_ASM_CODE("2281")"\n"

STUB_ASM_ENTRY("glRectsv")"\n"
"\t"STUB_ASM_CODE("2282")"\n"

STUB_ASM_ENTRY("glReleaseShaderCompiler")"\n"
"\t"STUB_ASM_CODE("2287")"\n"

STUB_ASM_ENTRY("glRenderMode")"\n"
"\t"STUB_ASM_CODE("2289")"\n"

STUB_ASM_ENTRY("glRenderbufferStorage")"\n"
"\t"STUB_ASM_CODE("2290")"\n"

STUB_ASM_ENTRY("glRenderbufferStorageMultisample")"\n"
"\t"STUB_ASM_CODE("2292")"\n"

STUB_ASM_ENTRY("glResumeTransformFeedback")"\n"
"\t"STUB_ASM_CODE("2333")"\n"

STUB_ASM_ENTRY("glRotated")"\n"
"\t"STUB_ASM_CODE("2336")"\n"

STUB_ASM_ENTRY("glRotatef")"\n"
"\t"STUB_ASM_CODE("2337")"\n"

STUB_ASM_ENTRY("glSampleCoverage")"\n"
"\t"STUB_ASM_CODE("2340")"\n"

STUB_ASM_ENTRY("glSampleMaski")"\n"
"\t"STUB_ASM_CODE("2348")"\n"

STUB_ASM_ENTRY("glSamplerParameterIiv")"\n"
"\t"STUB_ASM_CODE("2351")"\n"

STUB_ASM_ENTRY("glSamplerParameterIuiv")"\n"
"\t"STUB_ASM_CODE("2354")"\n"

STUB_ASM_ENTRY("glSamplerParameterf")"\n"
"\t"STUB_ASM_CODE("2357")"\n"

STUB_ASM_ENTRY("glSamplerParameterfv")"\n"
"\t"STUB_ASM_CODE("2358")"\n"

STUB_ASM_ENTRY("glSamplerParameteri")"\n"
"\t"STUB_ASM_CODE("2359")"\n"

STUB_ASM_ENTRY("glSamplerParameteriv")"\n"
"\t"STUB_ASM_CODE("2360")"\n"

STUB_ASM_ENTRY("glScaled")"\n"
"\t"STUB_ASM_CODE("2361")"\n"

STUB_ASM_ENTRY("glScalef")"\n"
"\t"STUB_ASM_CODE("2362")"\n"

STUB_ASM_ENTRY("glScissor")"\n"
"\t"STUB_ASM_CODE("2365")"\n"

STUB_ASM_ENTRY("glScissorArrayv")"\n"
"\t"STUB_ASM_CODE("2366")"\n"

STUB_ASM_ENTRY("glScissorIndexed")"\n"
"\t"STUB_ASM_CODE("2371")"\n"

STUB_ASM_ENTRY("glScissorIndexedv")"\n"
"\t"STUB_ASM_CODE("2374")"\n"

STUB_ASM_ENTRY("glSecondaryColor3b")"\n"
"\t"STUB_ASM_CODE("2377")"\n"

STUB_ASM_ENTRY("glSecondaryColor3bv")"\n"
"\t"STUB_ASM_CODE("2379")"\n"

STUB_ASM_ENTRY("glSecondaryColor3d")"\n"
"\t"STUB_ASM_CODE("2381")"\n"

STUB_ASM_ENTRY("glSecondaryColor3dv")"\n"
"\t"STUB_ASM_CODE("2383")"\n"

STUB_ASM_ENTRY("glSecondaryColor3f")"\n"
"\t"STUB_ASM_CODE("2385")"\n"

STUB_ASM_ENTRY("glSecondaryColor3fv")"\n"
"\t"STUB_ASM_CODE("2387")"\n"

STUB_ASM_ENTRY("glSecondaryColor3i")"\n"
"\t"STUB_ASM_CODE("2391")"\n"

STUB_ASM_ENTRY("glSecondaryColor3iv")"\n"
"\t"STUB_ASM_CODE("2393")"\n"

STUB_ASM_ENTRY("glSecondaryColor3s")"\n"
"\t"STUB_ASM_CODE("2395")"\n"

STUB_ASM_ENTRY("glSecondaryColor3sv")"\n"
"\t"STUB_ASM_CODE("2397")"\n"

STUB_ASM_ENTRY("glSecondaryColor3ub")"\n"
"\t"STUB_ASM_CODE("2399")"\n"

STUB_ASM_ENTRY("glSecondaryColor3ubv")"\n"
"\t"STUB_ASM_CODE("2401")"\n"

STUB_ASM_ENTRY("glSecondaryColor3ui")"\n"
"\t"STUB_ASM_CODE("2403")"\n"

STUB_ASM_ENTRY("glSecondaryColor3uiv")"\n"
"\t"STUB_ASM_CODE("2405")"\n"

STUB_ASM_ENTRY("glSecondaryColor3us")"\n"
"\t"STUB_ASM_CODE("2407")"\n"

STUB_ASM_ENTRY("glSecondaryColor3usv")"\n"
"\t"STUB_ASM_CODE("2409")"\n"

STUB_ASM_ENTRY("glSecondaryColorP3ui")"\n"
"\t"STUB_ASM_CODE("2412")"\n"

STUB_ASM_ENTRY("glSecondaryColorP3uiv")"\n"
"\t"STUB_ASM_CODE("2413")"\n"

STUB_ASM_ENTRY("glSecondaryColorPointer")"\n"
"\t"STUB_ASM_CODE("2414")"\n"

STUB_ASM_ENTRY("glSelectBuffer")"\n"
"\t"STUB_ASM_CODE("2417")"\n"

STUB_ASM_ENTRY("glShadeModel")"\n"
"\t"STUB_ASM_CODE("2429")"\n"

STUB_ASM_ENTRY("glShaderBinary")"\n"
"\t"STUB_ASM_CODE("2430")"\n"

STUB_ASM_ENTRY("glShaderSource")"\n"
"\t"STUB_ASM_CODE("2434")"\n"

STUB_ASM_ENTRY("glShaderStorageBlockBinding")"\n"
"\t"STUB_ASM_CODE("2436")"\n"

STUB_ASM_ENTRY("glStencilFunc")"\n"
"\t"STUB_ASM_CODE("2461")"\n"

STUB_ASM_ENTRY("glStencilFuncSeparate")"\n"
"\t"STUB_ASM_CODE("2462")"\n"

STUB_ASM_ENTRY("glStencilMask")"\n"
"\t"STUB_ASM_CODE("2464")"\n"

STUB_ASM_ENTRY("glStencilMaskSeparate")"\n"
"\t"STUB_ASM_CODE("2465")"\n"

STUB_ASM_ENTRY("glStencilOp")"\n"
"\t"STUB_ASM_CODE("2466")"\n"

STUB_ASM_ENTRY("glStencilOpSeparate")"\n"
"\t"STUB_ASM_CODE("2467")"\n"

STUB_ASM_ENTRY("glTexBuffer")"\n"
"\t"STUB_ASM_CODE("2500")"\n"

STUB_ASM_ENTRY("glTexBufferRange")"\n"
"\t"STUB_ASM_CODE("2504")"\n"

STUB_ASM_ENTRY("glTexCoord1d")"\n"
"\t"STUB_ASM_CODE("2511")"\n"

STUB_ASM_ENTRY("glTexCoord1dv")"\n"
"\t"STUB_ASM_CODE("2512")"\n"

STUB_ASM_ENTRY("glTexCoord1f")"\n"
"\t"STUB_ASM_CODE("2513")"\n"

STUB_ASM_ENTRY("glTexCoord1fv")"\n"
"\t"STUB_ASM_CODE("2514")"\n"

STUB_ASM_ENTRY("glTexCoord1i")"\n"
"\t"STUB_ASM_CODE("2517")"\n"

STUB_ASM_ENTRY("glTexCoord1iv")"\n"
"\t"STUB_ASM_CODE("2518")"\n"

STUB_ASM_ENTRY("glTexCoord1s")"\n"
"\t"STUB_ASM_CODE("2519")"\n"

STUB_ASM_ENTRY("glTexCoord1sv")"\n"
"\t"STUB_ASM_CODE("2520")"\n"

STUB_ASM_ENTRY("glTexCoord2d")"\n"
"\t"STUB_ASM_CODE("2525")"\n"

STUB_ASM_ENTRY("glTexCoord2dv")"\n"
"\t"STUB_ASM_CODE("2526")"\n"

STUB_ASM_ENTRY("glTexCoord2f")"\n"
"\t"STUB_ASM_CODE("2527")"\n"

STUB_ASM_ENTRY("glTexCoord2fv")"\n"
"\t"STUB_ASM_CODE("2538")"\n"

STUB_ASM_ENTRY("glTexCoord2i")"\n"
"\t"STUB_ASM_CODE("2541")"\n"

STUB_ASM_ENTRY("glTexCoord2iv")"\n"
"\t"STUB_ASM_CODE("2542")"\n"

STUB_ASM_ENTRY("glTexCoord2s")"\n"
"\t"STUB_ASM_CODE("2543")"\n"

STUB_ASM_ENTRY("glTexCoord2sv")"\n"
"\t"STUB_ASM_CODE("2544")"\n"

STUB_ASM_ENTRY("glTexCoord3d")"\n"
"\t"STUB_ASM_CODE("2549")"\n"

STUB_ASM_ENTRY("glTexCoord3dv")"\n"
"\t"STUB_ASM_CODE("2550")"\n"

STUB_ASM_ENTRY("glTexCoord3f")"\n"
"\t"STUB_ASM_CODE("2551")"\n"

STUB_ASM_ENTRY("glTexCoord3fv")"\n"
"\t"STUB_ASM_CODE("2552")"\n"

STUB_ASM_ENTRY("glTexCoord3i")"\n"
"\t"STUB_ASM_CODE("2555")"\n"

STUB_ASM_ENTRY("glTexCoord3iv")"\n"
"\t"STUB_ASM_CODE("2556")"\n"

STUB_ASM_ENTRY("glTexCoord3s")"\n"
"\t"STUB_ASM_CODE("2557")"\n"

STUB_ASM_ENTRY("glTexCoord3sv")"\n"
"\t"STUB_ASM_CODE("2558")"\n"

STUB_ASM_ENTRY("glTexCoord4d")"\n"
"\t"STUB_ASM_CODE("2563")"\n"

STUB_ASM_ENTRY("glTexCoord4dv")"\n"
"\t"STUB_ASM_CODE("2564")"\n"

STUB_ASM_ENTRY("glTexCoord4f")"\n"
"\t"STUB_ASM_CODE("2565")"\n"

STUB_ASM_ENTRY("glTexCoord4fv")"\n"
"\t"STUB_ASM_CODE("2570")"\n"

STUB_ASM_ENTRY("glTexCoord4i")"\n"
"\t"STUB_ASM_CODE("2573")"\n"

STUB_ASM_ENTRY("glTexCoord4iv")"\n"
"\t"STUB_ASM_CODE("2574")"\n"

STUB_ASM_ENTRY("glTexCoord4s")"\n"
"\t"STUB_ASM_CODE("2575")"\n"

STUB_ASM_ENTRY("glTexCoord4sv")"\n"
"\t"STUB_ASM_CODE("2576")"\n"

STUB_ASM_ENTRY("glTexCoordP1ui")"\n"
"\t"STUB_ASM_CODE("2580")"\n"

STUB_ASM_ENTRY("glTexCoordP1uiv")"\n"
"\t"STUB_ASM_CODE("2581")"\n"

STUB_ASM_ENTRY("glTexCoordP2ui")"\n"
"\t"STUB_ASM_CODE("2582")"\n"

STUB_ASM_ENTRY("glTexCoordP2uiv")"\n"
"\t"STUB_ASM_CODE("2583")"\n"

STUB_ASM_ENTRY("glTexCoordP3ui")"\n"
"\t"STUB_ASM_CODE("2584")"\n"

STUB_ASM_ENTRY("glTexCoordP3uiv")"\n"
"\t"STUB_ASM_CODE("2585")"\n"

STUB_ASM_ENTRY("glTexCoordP4ui")"\n"
"\t"STUB_ASM_CODE("2586")"\n"

STUB_ASM_ENTRY("glTexCoordP4uiv")"\n"
"\t"STUB_ASM_CODE("2587")"\n"

STUB_ASM_ENTRY("glTexCoordPointer")"\n"
"\t"STUB_ASM_CODE("2588")"\n"

STUB_ASM_ENTRY("glTexEnvf")"\n"
"\t"STUB_ASM_CODE("2592")"\n"

STUB_ASM_ENTRY("glTexEnvfv")"\n"
"\t"STUB_ASM_CODE("2593")"\n"

STUB_ASM_ENTRY("glTexEnvi")"\n"
"\t"STUB_ASM_CODE("2594")"\n"

STUB_ASM_ENTRY("glTexEnviv")"\n"
"\t"STUB_ASM_CODE("2595")"\n"

STUB_ASM_ENTRY("glTexGend")"\n"
"\t"STUB_ASM_CODE("2603")"\n"

STUB_ASM_ENTRY("glTexGendv")"\n"
"\t"STUB_ASM_CODE("2604")"\n"

STUB_ASM_ENTRY("glTexGenf")"\n"
"\t"STUB_ASM_CODE("2605")"\n"

STUB_ASM_ENTRY("glTexGenfv")"\n"
"\t"STUB_ASM_CODE("2607")"\n"

STUB_ASM_ENTRY("glTexGeni")"\n"
"\t"STUB_ASM_CODE("2609")"\n"

STUB_ASM_ENTRY("glTexGeniv")"\n"
"\t"STUB_ASM_CODE("2611")"\n"

STUB_ASM_ENTRY("glTexImage1D")"\n"
"\t"STUB_ASM_CODE("2615")"\n"

STUB_ASM_ENTRY("glTexImage2D")"\n"
"\t"STUB_ASM_CODE("2616")"\n"

STUB_ASM_ENTRY("glTexImage2DMultisample")"\n"
"\t"STUB_ASM_CODE("2617")"\n"

STUB_ASM_ENTRY("glTexImage3D")"\n"
"\t"STUB_ASM_CODE("2619")"\n"

STUB_ASM_ENTRY("glTexImage3DMultisample")"\n"
"\t"STUB_ASM_CODE("2621")"\n"

STUB_ASM_ENTRY("glTexParameterIiv")"\n"
"\t"STUB_ASM_CODE("2629")"\n"

STUB_ASM_ENTRY("glTexParameterIuiv")"\n"
"\t"STUB_ASM_CODE("2632")"\n"

STUB_ASM_ENTRY("glTexParameterf")"\n"
"\t"STUB_ASM_CODE("2635")"\n"

STUB_ASM_ENTRY("glTexParameterfv")"\n"
"\t"STUB_ASM_CODE("2636")"\n"

STUB_ASM_ENTRY("glTexParameteri")"\n"
"\t"STUB_ASM_CODE("2637")"\n"

STUB_ASM_ENTRY("glTexParameteriv")"\n"
"\t"STUB_ASM_CODE("2638")"\n"

STUB_ASM_ENTRY("glTexStorage1D")"\n"
"\t"STUB_ASM_CODE("2644")"\n"

STUB_ASM_ENTRY("glTexStorage2D")"\n"
"\t"STUB_ASM_CODE("2646")"\n"

STUB_ASM_ENTRY("glTexStorage2DMultisample")"\n"
"\t"STUB_ASM_CODE("2648")"\n"

STUB_ASM_ENTRY("glTexStorage3D")"\n"
"\t"STUB_ASM_CODE("2649")"\n"

STUB_ASM_ENTRY("glTexStorage3DMultisample")"\n"
"\t"STUB_ASM_CODE("2651")"\n"

STUB_ASM_ENTRY("glTexSubImage1D")"\n"
"\t"STUB_ASM_CODE("2661")"\n"

STUB_ASM_ENTRY("glTexSubImage2D")"\n"
"\t"STUB_ASM_CODE("2663")"\n"

STUB_ASM_ENTRY("glTexSubImage3D")"\n"
"\t"STUB_ASM_CODE("2665")"\n"

STUB_ASM_ENTRY("glTextureBarrier")"\n"
"\t"STUB_ASM_CODE("2671")"\n"

STUB_ASM_ENTRY("glTextureBuffer")"\n"
"\t"STUB_ASM_CODE("2673")"\n"

STUB_ASM_ENTRY("glTextureBufferRange")"\n"
"\t"STUB_ASM_CODE("2675")"\n"

STUB_ASM_ENTRY("glTextureParameterIiv")"\n"
"\t"STUB_ASM_CODE("2691")"\n"

STUB_ASM_ENTRY("glTextureParameterIuiv")"\n"
"\t"STUB_ASM_CODE("2693")"\n"

STUB_ASM_ENTRY("glTextureParameterf")"\n"
"\t"STUB_ASM_CODE("2695")"\n"

STUB_ASM_ENTRY("glTextureParameterfv")"\n"
"\t"STUB_ASM_CODE("2697")"\n"

STUB_ASM_ENTRY("glTextureParameteri")"\n"
"\t"STUB_ASM_CODE("2699")"\n"

STUB_ASM_ENTRY("glTextureParameteriv")"\n"
"\t"STUB_ASM_CODE("2701")"\n"

STUB_ASM_ENTRY("glTextureStorage1D")"\n"
"\t"STUB_ASM_CODE("2705")"\n"

STUB_ASM_ENTRY("glTextureStorage2D")"\n"
"\t"STUB_ASM_CODE("2707")"\n"

STUB_ASM_ENTRY("glTextureStorage2DMultisample")"\n"
"\t"STUB_ASM_CODE("2709")"\n"

STUB_ASM_ENTRY("glTextureStorage3D")"\n"
"\t"STUB_ASM_CODE("2711")"\n"

STUB_ASM_ENTRY("glTextureStorage3DMultisample")"\n"
"\t"STUB_ASM_CODE("2713")"\n"

STUB_ASM_ENTRY("glTextureSubImage1D")"\n"
"\t"STUB_ASM_CODE("2721")"\n"

STUB_ASM_ENTRY("glTextureSubImage2D")"\n"
"\t"STUB_ASM_CODE("2723")"\n"

STUB_ASM_ENTRY("glTextureSubImage3D")"\n"
"\t"STUB_ASM_CODE("2725")"\n"

STUB_ASM_ENTRY("glTextureView")"\n"
"\t"STUB_ASM_CODE("2727")"\n"

STUB_ASM_ENTRY("glTransformFeedbackBufferBase")"\n"
"\t"STUB_ASM_CODE("2732")"\n"

STUB_ASM_ENTRY("glTransformFeedbackBufferRange")"\n"
"\t"STUB_ASM_CODE("2733")"\n"

STUB_ASM_ENTRY("glTransformFeedbackVaryings")"\n"
"\t"STUB_ASM_CODE("2735")"\n"

STUB_ASM_ENTRY("glTranslated")"\n"
"\t"STUB_ASM_CODE("2739")"\n"

STUB_ASM_ENTRY("glTranslatef")"\n"
"\t"STUB_ASM_CODE("2740")"\n"

STUB_ASM_ENTRY("glUniform1d")"\n"
"\t"STUB_ASM_CODE("2743")"\n"

STUB_ASM_ENTRY("glUniform1dv")"\n"
"\t"STUB_ASM_CODE("2744")"\n"

STUB_ASM_ENTRY("glUniform1f")"\n"
"\t"STUB_ASM_CODE("2745")"\n"

STUB_ASM_ENTRY("glUniform1fv")"\n"
"\t"STUB_ASM_CODE("2747")"\n"

STUB_ASM_ENTRY("glUniform1i")"\n"
"\t"STUB_ASM_CODE("2749")"\n"

STUB_ASM_ENTRY("glUniform1iv")"\n"
"\t"STUB_ASM_CODE("2755")"\n"

STUB_ASM_ENTRY("glUniform1ui")"\n"
"\t"STUB_ASM_CODE("2757")"\n"

STUB_ASM_ENTRY("glUniform1uiv")"\n"
"\t"STUB_ASM_CODE("2763")"\n"

STUB_ASM_ENTRY("glUniform2d")"\n"
"\t"STUB_ASM_CODE("2765")"\n"

STUB_ASM_ENTRY("glUniform2dv")"\n"
"\t"STUB_ASM_CODE("2766")"\n"

STUB_ASM_ENTRY("glUniform2f")"\n"
"\t"STUB_ASM_CODE("2767")"\n"

STUB_ASM_ENTRY("glUniform2fv")"\n"
"\t"STUB_ASM_CODE("2769")"\n"

STUB_ASM_ENTRY("glUniform2i")"\n"
"\t"STUB_ASM_CODE("2771")"\n"

STUB_ASM_ENTRY("glUniform2iv")"\n"
"\t"STUB_ASM_CODE("2777")"\n"

STUB_ASM_ENTRY("glUniform2ui")"\n"
"\t"STUB_ASM_CODE("2779")"\n"

STUB_ASM_ENTRY("glUniform2uiv")"\n"
"\t"STUB_ASM_CODE("2785")"\n"

STUB_ASM_ENTRY("glUniform3d")"\n"
"\t"STUB_ASM_CODE("2787")"\n"

STUB_ASM_ENTRY("glUniform3dv")"\n"
"\t"STUB_ASM_CODE("2788")"\n"

STUB_ASM_ENTRY("glUniform3f")"\n"
"\t"STUB_ASM_CODE("2789")"\n"

STUB_ASM_ENTRY("glUniform3fv")"\n"
"\t"STUB_ASM_CODE("2791")"\n"

STUB_ASM_ENTRY("glUniform3i")"\n"
"\t"STUB_ASM_CODE("2793")"\n"

STUB_ASM_ENTRY("glUniform3iv")"\n"
"\t"STUB_ASM_CODE("2799")"\n"

STUB_ASM_ENTRY("glUniform3ui")"\n"
"\t"STUB_ASM_CODE("2801")"\n"

STUB_ASM_ENTRY("glUniform3uiv")"\n"
"\t"STUB_ASM_CODE("2807")"\n"

STUB_ASM_ENTRY("glUniform4d")"\n"
"\t"STUB_ASM_CODE("2809")"\n"

STUB_ASM_ENTRY("glUniform4dv")"\n"
"\t"STUB_ASM_CODE("2810")"\n"

STUB_ASM_ENTRY("glUniform4f")"\n"
"\t"STUB_ASM_CODE("2811")"\n"

STUB_ASM_ENTRY("glUniform4fv")"\n"
"\t"STUB_ASM_CODE("2813")"\n"

STUB_ASM_ENTRY("glUniform4i")"\n"
"\t"STUB_ASM_CODE("2815")"\n"

STUB_ASM_ENTRY("glUniform4iv")"\n"
"\t"STUB_ASM_CODE("2821")"\n"

STUB_ASM_ENTRY("glUniform4ui")"\n"
"\t"STUB_ASM_CODE("2823")"\n"

STUB_ASM_ENTRY("glUniform4uiv")"\n"
"\t"STUB_ASM_CODE("2829")"\n"

STUB_ASM_ENTRY("glUniformBlockBinding")"\n"
"\t"STUB_ASM_CODE("2831")"\n"

STUB_ASM_ENTRY("glUniformMatrix2dv")"\n"
"\t"STUB_ASM_CODE("2839")"\n"

STUB_ASM_ENTRY("glUniformMatrix2fv")"\n"
"\t"STUB_ASM_CODE("2840")"\n"

STUB_ASM_ENTRY("glUniformMatrix2x3dv")"\n"
"\t"STUB_ASM_CODE("2842")"\n"

STUB_ASM_ENTRY("glUniformMatrix2x3fv")"\n"
"\t"STUB_ASM_CODE("2843")"\n"

STUB_ASM_ENTRY("glUniformMatrix2x4dv")"\n"
"\t"STUB_ASM_CODE("2845")"\n"

STUB_ASM_ENTRY("glUniformMatrix2x4fv")"\n"
"\t"STUB_ASM_CODE("2846")"\n"

STUB_ASM_ENTRY("glUniformMatrix3dv")"\n"
"\t"STUB_ASM_CODE("2848")"\n"

STUB_ASM_ENTRY("glUniformMatrix3fv")"\n"
"\t"STUB_ASM_CODE("2849")"\n"

STUB_ASM_ENTRY("glUniformMatrix3x2dv")"\n"
"\t"STUB_ASM_CODE("2851")"\n"

STUB_ASM_ENTRY("glUniformMatrix3x2fv")"\n"
"\t"STUB_ASM_CODE("2852")"\n"

STUB_ASM_ENTRY("glUniformMatrix3x4dv")"\n"
"\t"STUB_ASM_CODE("2854")"\n"

STUB_ASM_ENTRY("glUniformMatrix3x4fv")"\n"
"\t"STUB_ASM_CODE("2855")"\n"

STUB_ASM_ENTRY("glUniformMatrix4dv")"\n"
"\t"STUB_ASM_CODE("2857")"\n"

STUB_ASM_ENTRY("glUniformMatrix4fv")"\n"
"\t"STUB_ASM_CODE("2858")"\n"

STUB_ASM_ENTRY("glUniformMatrix4x2dv")"\n"
"\t"STUB_ASM_CODE("2860")"\n"

STUB_ASM_ENTRY("glUniformMatrix4x2fv")"\n"
"\t"STUB_ASM_CODE("2861")"\n"

STUB_ASM_ENTRY("glUniformMatrix4x3dv")"\n"
"\t"STUB_ASM_CODE("2863")"\n"

STUB_ASM_ENTRY("glUniformMatrix4x3fv")"\n"
"\t"STUB_ASM_CODE("2864")"\n"

STUB_ASM_ENTRY("glUniformSubroutinesuiv")"\n"
"\t"STUB_ASM_CODE("2866")"\n"

STUB_ASM_ENTRY("glUnmapBuffer")"\n"
"\t"STUB_ASM_CODE("2870")"\n"

STUB_ASM_ENTRY("glUnmapNamedBuffer")"\n"
"\t"STUB_ASM_CODE("2873")"\n"

STUB_ASM_ENTRY("glUseProgram")"\n"
"\t"STUB_ASM_CODE("2879")"\n"

STUB_ASM_ENTRY("glUseProgramStages")"\n"
"\t"STUB_ASM_CODE("2881")"\n"

STUB_ASM_ENTRY("glValidateProgram")"\n"
"\t"STUB_ASM_CODE("2896")"\n"

STUB_ASM_ENTRY("glValidateProgramPipeline")"\n"
"\t"STUB_ASM_CODE("2898")"\n"

STUB_ASM_ENTRY("glVertex2d")"\n"
"\t"STUB_ASM_CODE("2912")"\n"

STUB_ASM_ENTRY("glVertex2dv")"\n"
"\t"STUB_ASM_CODE("2913")"\n"

STUB_ASM_ENTRY("glVertex2f")"\n"
"\t"STUB_ASM_CODE("2914")"\n"

STUB_ASM_ENTRY("glVertex2fv")"\n"
"\t"STUB_ASM_CODE("2915")"\n"

STUB_ASM_ENTRY("glVertex2i")"\n"
"\t"STUB_ASM_CODE("2918")"\n"

STUB_ASM_ENTRY("glVertex2iv")"\n"
"\t"STUB_ASM_CODE("2919")"\n"

STUB_ASM_ENTRY("glVertex2s")"\n"
"\t"STUB_ASM_CODE("2920")"\n"

STUB_ASM_ENTRY("glVertex2sv")"\n"
"\t"STUB_ASM_CODE("2921")"\n"

STUB_ASM_ENTRY("glVertex3d")"\n"
"\t"STUB_ASM_CODE("2926")"\n"

STUB_ASM_ENTRY("glVertex3dv")"\n"
"\t"STUB_ASM_CODE("2927")"\n"

STUB_ASM_ENTRY("glVertex3f")"\n"
"\t"STUB_ASM_CODE("2928")"\n"

STUB_ASM_ENTRY("glVertex3fv")"\n"
"\t"STUB_ASM_CODE("2929")"\n"

STUB_ASM_ENTRY("glVertex3i")"\n"
"\t"STUB_ASM_CODE("2932")"\n"

STUB_ASM_ENTRY("glVertex3iv")"\n"
"\t"STUB_ASM_CODE("2933")"\n"

STUB_ASM_ENTRY("glVertex3s")"\n"
"\t"STUB_ASM_CODE("2934")"\n"

STUB_ASM_ENTRY("glVertex3sv")"\n"
"\t"STUB_ASM_CODE("2935")"\n"

STUB_ASM_ENTRY("glVertex4d")"\n"
"\t"STUB_ASM_CODE("2940")"\n"

STUB_ASM_ENTRY("glVertex4dv")"\n"
"\t"STUB_ASM_CODE("2941")"\n"

STUB_ASM_ENTRY("glVertex4f")"\n"
"\t"STUB_ASM_CODE("2942")"\n"

STUB_ASM_ENTRY("glVertex4fv")"\n"
"\t"STUB_ASM_CODE("2943")"\n"

STUB_ASM_ENTRY("glVertex4i")"\n"
"\t"STUB_ASM_CODE("2946")"\n"

STUB_ASM_ENTRY("glVertex4iv")"\n"
"\t"STUB_ASM_CODE("2947")"\n"

STUB_ASM_ENTRY("glVertex4s")"\n"
"\t"STUB_ASM_CODE("2948")"\n"

STUB_ASM_ENTRY("glVertex4sv")"\n"
"\t"STUB_ASM_CODE("2949")"\n"

STUB_ASM_ENTRY("glVertexArrayAttribBinding")"\n"
"\t"STUB_ASM_CODE("2952")"\n"

STUB_ASM_ENTRY("glVertexArrayAttribFormat")"\n"
"\t"STUB_ASM_CODE("2953")"\n"

STUB_ASM_ENTRY("glVertexArrayAttribIFormat")"\n"
"\t"STUB_ASM_CODE("2954")"\n"

STUB_ASM_ENTRY("glVertexArrayAttribLFormat")"\n"
"\t"STUB_ASM_CODE("2955")"\n"

STUB_ASM_ENTRY("glVertexArrayBindingDivisor")"\n"
"\t"STUB_ASM_CODE("2957")"\n"

STUB_ASM_ENTRY("glVertexArrayElementBuffer")"\n"
"\t"STUB_ASM_CODE("2960")"\n"

STUB_ASM_ENTRY("glVertexArrayVertexBuffer")"\n"
"\t"STUB_ASM_CODE("2979")"\n"

STUB_ASM_ENTRY("glVertexArrayVertexBuffers")"\n"
"\t"STUB_ASM_CODE("2980")"\n"

STUB_ASM_ENTRY("glVertexAttrib1d")"\n"
"\t"STUB_ASM_CODE("2982")"\n"

STUB_ASM_ENTRY("glVertexAttrib1dv")"\n"
"\t"STUB_ASM_CODE("2985")"\n"

STUB_ASM_ENTRY("glVertexAttrib1f")"\n"
"\t"STUB_ASM_CODE("2988")"\n"

STUB_ASM_ENTRY("glVertexAttrib1fv")"\n"
"\t"STUB_ASM_CODE("2991")"\n"

STUB_ASM_ENTRY("glVertexAttrib1s")"\n"
"\t"STUB_ASM_CODE("2996")"\n"

STUB_ASM_ENTRY("glVertexAttrib1sv")"\n"
"\t"STUB_ASM_CODE("2999")"\n"

STUB_ASM_ENTRY("glVertexAttrib2d")"\n"
"\t"STUB_ASM_CODE("3002")"\n"

STUB_ASM_ENTRY("glVertexAttrib2dv")"\n"
"\t"STUB_ASM_CODE("3005")"\n"

STUB_ASM_ENTRY("glVertexAttrib2f")"\n"
"\t"STUB_ASM_CODE("3008")"\n"

STUB_ASM_ENTRY("glVertexAttrib2fv")"\n"
"\t"STUB_ASM_CODE("3011")"\n"

STUB_ASM_ENTRY("glVertexAttrib2s")"\n"
"\t"STUB_ASM_CODE("3016")"\n"

STUB_ASM_ENTRY("glVertexAttrib2sv")"\n"
"\t"STUB_ASM_CODE("3019")"\n"

STUB_ASM_ENTRY("glVertexAttrib3d")"\n"
"\t"STUB_ASM_CODE("3022")"\n"

STUB_ASM_ENTRY("glVertexAttrib3dv")"\n"
"\t"STUB_ASM_CODE("3025")"\n"

STUB_ASM_ENTRY("glVertexAttrib3f")"\n"
"\t"STUB_ASM_CODE("3028")"\n"

STUB_ASM_ENTRY("glVertexAttrib3fv")"\n"
"\t"STUB_ASM_CODE("3031")"\n"

STUB_ASM_ENTRY("glVertexAttrib3s")"\n"
"\t"STUB_ASM_CODE("3036")"\n"

STUB_ASM_ENTRY("glVertexAttrib3sv")"\n"
"\t"STUB_ASM_CODE("3039")"\n"

STUB_ASM_ENTRY("glVertexAttrib4Nbv")"\n"
"\t"STUB_ASM_CODE("3042")"\n"

STUB_ASM_ENTRY("glVertexAttrib4Niv")"\n"
"\t"STUB_ASM_CODE("3044")"\n"

STUB_ASM_ENTRY("glVertexAttrib4Nsv")"\n"
"\t"STUB_ASM_CODE("3046")"\n"

STUB_ASM_ENTRY("glVertexAttrib4Nub")"\n"
"\t"STUB_ASM_CODE("3048")"\n"

STUB_ASM_ENTRY("glVertexAttrib4Nubv")"\n"
"\t"STUB_ASM_CODE("3050")"\n"

STUB_ASM_ENTRY("glVertexAttrib4Nuiv")"\n"
"\t"STUB_ASM_CODE("3052")"\n"

STUB_ASM_ENTRY("glVertexAttrib4Nusv")"\n"
"\t"STUB_ASM_CODE("3054")"\n"

STUB_ASM_ENTRY("glVertexAttrib4bv")"\n"
"\t"STUB_ASM_CODE("3056")"\n"

STUB_ASM_ENTRY("glVertexAttrib4d")"\n"
"\t"STUB_ASM_CODE("3058")"\n"

STUB_ASM_ENTRY("glVertexAttrib4dv")"\n"
"\t"STUB_ASM_CODE("3061")"\n"

STUB_ASM_ENTRY("glVertexAttrib4f")"\n"
"\t"STUB_ASM_CODE("3064")"\n"

STUB_ASM_ENTRY("glVertexAttrib4fv")"\n"
"\t"STUB_ASM_CODE("3067")"\n"

STUB_ASM_ENTRY("glVertexAttrib4iv")"\n"
"\t"STUB_ASM_CODE("3072")"\n"

STUB_ASM_ENTRY("glVertexAttrib4s")"\n"
"\t"STUB_ASM_CODE("3074")"\n"

STUB_ASM_ENTRY("glVertexAttrib4sv")"\n"
"\t"STUB_ASM_CODE("3077")"\n"

STUB_ASM_ENTRY("glVertexAttrib4ubv")"\n"
"\t"STUB_ASM_CODE("3081")"\n"

STUB_ASM_ENTRY("glVertexAttrib4uiv")"\n"
"\t"STUB_ASM_CODE("3084")"\n"

STUB_ASM_ENTRY("glVertexAttrib4usv")"\n"
"\t"STUB_ASM_CODE("3086")"\n"

STUB_ASM_ENTRY("glVertexAttribBinding")"\n"
"\t"STUB_ASM_CODE("3089")"\n"

STUB_ASM_ENTRY("glVertexAttribDivisor")"\n"
"\t"STUB_ASM_CODE("3090")"\n"

STUB_ASM_ENTRY("glVertexAttribFormat")"\n"
"\t"STUB_ASM_CODE("3095")"\n"

STUB_ASM_ENTRY("glVertexAttribI1i")"\n"
"\t"STUB_ASM_CODE("3097")"\n"

STUB_ASM_ENTRY("glVertexAttribI1iv")"\n"
"\t"STUB_ASM_CODE("3099")"\n"

STUB_ASM_ENTRY("glVertexAttribI1ui")"\n"
"\t"STUB_ASM_CODE("3101")"\n"

STUB_ASM_ENTRY("glVertexAttribI1uiv")"\n"
"\t"STUB_ASM_CODE("3103")"\n"

STUB_ASM_ENTRY("glVertexAttribI2i")"\n"
"\t"STUB_ASM_CODE("3105")"\n"

STUB_ASM_ENTRY("glVertexAttribI2iv")"\n"
"\t"STUB_ASM_CODE("3107")"\n"

STUB_ASM_ENTRY("glVertexAttribI2ui")"\n"
"\t"STUB_ASM_CODE("3109")"\n"

STUB_ASM_ENTRY("glVertexAttribI2uiv")"\n"
"\t"STUB_ASM_CODE("3111")"\n"

STUB_ASM_ENTRY("glVertexAttribI3i")"\n"
"\t"STUB_ASM_CODE("3113")"\n"

STUB_ASM_ENTRY("glVertexAttribI3iv")"\n"
"\t"STUB_ASM_CODE("3115")"\n"

STUB_ASM_ENTRY("glVertexAttribI3ui")"\n"
"\t"STUB_ASM_CODE("3117")"\n"

STUB_ASM_ENTRY("glVertexAttribI3uiv")"\n"
"\t"STUB_ASM_CODE("3119")"\n"

STUB_ASM_ENTRY("glVertexAttribI4bv")"\n"
"\t"STUB_ASM_CODE("3121")"\n"

STUB_ASM_ENTRY("glVertexAttribI4i")"\n"
"\t"STUB_ASM_CODE("3123")"\n"

STUB_ASM_ENTRY("glVertexAttribI4iv")"\n"
"\t"STUB_ASM_CODE("3125")"\n"

STUB_ASM_ENTRY("glVertexAttribI4sv")"\n"
"\t"STUB_ASM_CODE("3127")"\n"

STUB_ASM_ENTRY("glVertexAttribI4ubv")"\n"
"\t"STUB_ASM_CODE("3129")"\n"

STUB_ASM_ENTRY("glVertexAttribI4ui")"\n"
"\t"STUB_ASM_CODE("3131")"\n"

STUB_ASM_ENTRY("glVertexAttribI4uiv")"\n"
"\t"STUB_ASM_CODE("3133")"\n"

STUB_ASM_ENTRY("glVertexAttribI4usv")"\n"
"\t"STUB_ASM_CODE("3135")"\n"

STUB_ASM_ENTRY("glVertexAttribIFormat")"\n"
"\t"STUB_ASM_CODE("3137")"\n"

STUB_ASM_ENTRY("glVertexAttribIPointer")"\n"
"\t"STUB_ASM_CODE("3139")"\n"

STUB_ASM_ENTRY("glVertexAttribL1d")"\n"
"\t"STUB_ASM_CODE("3141")"\n"

STUB_ASM_ENTRY("glVertexAttribL1dv")"\n"
"\t"STUB_ASM_CODE("3143")"\n"

STUB_ASM_ENTRY("glVertexAttribL2d")"\n"
"\t"STUB_ASM_CODE("3151")"\n"

STUB_ASM_ENTRY("glVertexAttribL2dv")"\n"
"\t"STUB_ASM_CODE("3153")"\n"

STUB_ASM_ENTRY("glVertexAttribL3d")"\n"
"\t"STUB_ASM_CODE("3159")"\n"

STUB_ASM_ENTRY("glVertexAttribL3dv")"\n"
"\t"STUB_ASM_CODE("3161")"\n"

STUB_ASM_ENTRY("glVertexAttribL4d")"\n"
"\t"STUB_ASM_CODE("3167")"\n"

STUB_ASM_ENTRY("glVertexAttribL4dv")"\n"
"\t"STUB_ASM_CODE("3169")"\n"

STUB_ASM_ENTRY("glVertexAttribLFormat")"\n"
"\t"STUB_ASM_CODE("3175")"\n"

STUB_ASM_ENTRY("glVertexAttribLPointer")"\n"
"\t"STUB_ASM_CODE("3177")"\n"

STUB_ASM_ENTRY("glVertexAttribP1ui")"\n"
"\t"STUB_ASM_CODE("3179")"\n"

STUB_ASM_ENTRY("glVertexAttribP1uiv")"\n"
"\t"STUB_ASM_CODE("3180")"\n"

STUB_ASM_ENTRY("glVertexAttribP2ui")"\n"
"\t"STUB_ASM_CODE("3181")"\n"

STUB_ASM_ENTRY("glVertexAttribP2uiv")"\n"
"\t"STUB_ASM_CODE("3182")"\n"

STUB_ASM_ENTRY("glVertexAttribP3ui")"\n"
"\t"STUB_ASM_CODE("3183")"\n"

STUB_ASM_ENTRY("glVertexAttribP3uiv")"\n"
"\t"STUB_ASM_CODE("3184")"\n"

STUB_ASM_ENTRY("glVertexAttribP4ui")"\n"
"\t"STUB_ASM_CODE("3185")"\n"

STUB_ASM_ENTRY("glVertexAttribP4uiv")"\n"
"\t"STUB_ASM_CODE("3186")"\n"

STUB_ASM_ENTRY("glVertexAttribPointer")"\n"
"\t"STUB_ASM_CODE("3188")"\n"

STUB_ASM_ENTRY("glVertexBindingDivisor")"\n"
"\t"STUB_ASM_CODE("3208")"\n"

STUB_ASM_ENTRY("glVertexP2ui")"\n"
"\t"STUB_ASM_CODE("3213")"\n"

STUB_ASM_ENTRY("glVertexP2uiv")"\n"
"\t"STUB_ASM_CODE("3214")"\n"

STUB_ASM_ENTRY("glVertexP3ui")"\n"
"\t"STUB_ASM_CODE("3215")"\n"

STUB_ASM_ENTRY("glVertexP3uiv")"\n"
"\t"STUB_ASM_CODE("3216")"\n"

STUB_ASM_ENTRY("glVertexP4ui")"\n"
"\t"STUB_ASM_CODE("3217")"\n"

STUB_ASM_ENTRY("glVertexP4uiv")"\n"
"\t"STUB_ASM_CODE("3218")"\n"

STUB_ASM_ENTRY("glVertexPointer")"\n"
"\t"STUB_ASM_CODE("3219")"\n"

STUB_ASM_ENTRY("glViewport")"\n"
"\t"STUB_ASM_CODE("3264")"\n"

STUB_ASM_ENTRY("glViewportArrayv")"\n"
"\t"STUB_ASM_CODE("3265")"\n"

STUB_ASM_ENTRY("glViewportIndexedf")"\n"
"\t"STUB_ASM_CODE("3268")"\n"

STUB_ASM_ENTRY("glViewportIndexedfv")"\n"
"\t"STUB_ASM_CODE("3271")"\n"

STUB_ASM_ENTRY("glWaitSync")"\n"
"\t"STUB_ASM_CODE("3278")"\n"

STUB_ASM_ENTRY("glWindowPos2d")"\n"
"\t"STUB_ASM_CODE("3294")"\n"

STUB_ASM_ENTRY("glWindowPos2dv")"\n"
"\t"STUB_ASM_CODE("3297")"\n"

STUB_ASM_ENTRY("glWindowPos2f")"\n"
"\t"STUB_ASM_CODE("3300")"\n"

STUB_ASM_ENTRY("glWindowPos2fv")"\n"
"\t"STUB_ASM_CODE("3303")"\n"

STUB_ASM_ENTRY("glWindowPos2i")"\n"
"\t"STUB_ASM_CODE("3306")"\n"

STUB_ASM_ENTRY("glWindowPos2iv")"\n"
"\t"STUB_ASM_CODE("3309")"\n"

STUB_ASM_ENTRY("glWindowPos2s")"\n"
"\t"STUB_ASM_CODE("3312")"\n"

STUB_ASM_ENTRY("glWindowPos2sv")"\n"
"\t"STUB_ASM_CODE("3315")"\n"

STUB_ASM_ENTRY("glWindowPos3d")"\n"
"\t"STUB_ASM_CODE("3318")"\n"

STUB_ASM_ENTRY("glWindowPos3dv")"\n"
"\t"STUB_ASM_CODE("3321")"\n"

STUB_ASM_ENTRY("glWindowPos3f")"\n"
"\t"STUB_ASM_CODE("3324")"\n"

STUB_ASM_ENTRY("glWindowPos3fv")"\n"
"\t"STUB_ASM_CODE("3327")"\n"

STUB_ASM_ENTRY("glWindowPos3i")"\n"
"\t"STUB_ASM_CODE("3330")"\n"

STUB_ASM_ENTRY("glWindowPos3iv")"\n"
"\t"STUB_ASM_CODE("3333")"\n"

STUB_ASM_ENTRY("glWindowPos3s")"\n"
"\t"STUB_ASM_CODE("3336")"\n"

STUB_ASM_ENTRY("glWindowPos3sv")"\n"
"\t"STUB_ASM_CODE("3339")"\n"

);
#undef MAPI_TMP_STUB_ASM_GCC
#endif /* MAPI_TMP_STUB_ASM_GCC */

