/* This file is automatically generated by gen_gldispatch_mapi.py.  Do not modify. */

#ifndef _GLAPI_TMP_H_
#define _GLAPI_TMP_H_
typedef int GLclampx;
typedef void (APIENTRY  *GLDEBUGPROCKHR)(GLenum source,GLenum type,GLuint id,GLenum severity,GLsizei length,const GLchar *message,const void *userParam);
#endif /* _GLAPI_TMP_H_ */

#ifdef MAPI_TMP_DEFINES
#define GL_GLEXT_PROTOTYPES
#include "GL/gl.h"
#include "GL/glext.h"

GLAPI void APIENTRY glAccum(GLenum op, GLfloat value);
GLAPI void APIENTRY glAccumxOES(GLenum op, GLfixed value);
GLAPI GLboolean APIENTRY glAcquireKeyedMutexWin32EXT(GLuint memory, GLuint64 key, GLuint timeout);
GLAPI void APIENTRY glActiveProgramEXT(GLuint program);
GLAPI void APIENTRY glActiveShaderProgram(GLuint pipeline, GLuint program);
GLAPI void APIENTRY glActiveShaderProgramEXT(GLuint pipeline, GLuint program);
GLAPI void APIENTRY glActiveStencilFaceEXT(GLenum face);
GLAPI void APIENTRY glActiveTexture(GLenum texture);
GLAPI void APIENTRY glActiveTextureARB(GLenum texture);
GLAPI void APIENTRY glActiveVaryingNV(GLuint program, const GLchar *name);
GLAPI void APIENTRY glAlphaFragmentOp1ATI(GLenum op, GLuint dst, GLuint dstMod, GLuint arg1, GLuint arg1Rep, GLuint arg1Mod);
GLAPI void APIENTRY glAlphaFragmentOp2ATI(GLenum op, GLuint dst, GLuint dstMod, GLuint arg1, GLuint arg1Rep, GLuint arg1Mod, GLuint arg2, GLuint arg2Rep, GLuint arg2Mod);
GLAPI void APIENTRY glAlphaFragmentOp3ATI(GLenum op, GLuint dst, GLuint dstMod, GLuint arg1, GLuint arg1Rep, GLuint arg1Mod, GLuint arg2, GLuint arg2Rep, GLuint arg2Mod, GLuint arg3, GLuint arg3Rep, GLuint arg3Mod);
GLAPI void APIENTRY glAlphaFunc(GLenum func, GLfloat ref);
GLAPI void APIENTRY glAlphaFuncQCOM(GLenum func, GLclampf ref);
GLAPI void APIENTRY glAlphaFuncx(GLenum func, GLfixed ref);
GLAPI void APIENTRY glAlphaFuncxOES(GLenum func, GLfixed ref);
GLAPI void APIENTRY glAlphaToCoverageDitherControlNV(GLenum mode);
GLAPI void APIENTRY glApplyFramebufferAttachmentCMAAINTEL(void);
GLAPI void APIENTRY glApplyTextureEXT(GLenum mode);
GLAPI GLboolean APIENTRY glAreProgramsResidentNV(GLsizei n, const GLuint *programs, GLboolean *residences);
GLAPI GLboolean APIENTRY glAreTexturesResident(GLsizei n, const GLuint *textures, GLboolean *residences);
GLAPI GLboolean APIENTRY glAreTexturesResidentEXT(GLsizei n, const GLuint *textures, GLboolean *residences);
GLAPI void APIENTRY glArrayElement(GLint i);
GLAPI void APIENTRY glArrayElementEXT(GLint i);
GLAPI void APIENTRY glArrayObjectATI(GLenum array, GLint size, GLenum type, GLsizei stride, GLuint buffer, GLuint offset);
GLAPI GLuint APIENTRY glAsyncCopyBufferSubDataNVX(GLsizei waitSemaphoreCount, const GLuint *waitSemaphoreArray, const GLuint64 *fenceValueArray, GLuint readGpu, GLbitfield writeGpuMask, GLuint readBuffer, GLuint writeBuffer, GLintptr readOffset, GLintptr writeOffset, GLsizeiptr size, GLsizei signalSemaphoreCount, const GLuint *signalSemaphoreArray, const GLuint64 *signalValueArray);
GLAPI GLuint APIENTRY glAsyncCopyImageSubDataNVX(GLsizei waitSemaphoreCount, const GLuint *waitSemaphoreArray, const GLuint64 *waitValueArray, GLuint srcGpu, GLbitfield dstGpuMask, GLuint srcName, GLenum srcTarget, GLint srcLevel, GLint srcX, GLint srcY, GLint srcZ, GLuint dstName, GLenum dstTarget, GLint dstLevel, GLint dstX, GLint dstY, GLint dstZ, GLsizei srcWidth, GLsizei srcHeight, GLsizei srcDepth, GLsizei signalSemaphoreCount, const GLuint *signalSemaphoreArray, const GLuint64 *signalValueArray);
GLAPI void APIENTRY glAsyncMarkerSGIX(GLuint marker);
GLAPI void APIENTRY glAttachObjectARB(GLhandleARB containerObj, GLhandleARB obj);
GLAPI void APIENTRY glAttachShader(GLuint program, GLuint shader);
GLAPI void APIENTRY glBegin(GLenum mode);
GLAPI void APIENTRY glBeginConditionalRender(GLuint id, GLenum mode);
GLAPI void APIENTRY glBeginConditionalRenderNV(GLuint id, GLenum mode);
GLAPI void APIENTRY glBeginConditionalRenderNVX(GLuint id);
GLAPI void APIENTRY glBeginFragmentShaderATI(void);
GLAPI void APIENTRY glBeginOcclusionQueryNV(GLuint id);
GLAPI void APIENTRY glBeginPerfMonitorAMD(GLuint monitor);
GLAPI void APIENTRY glBeginPerfQueryINTEL(GLuint queryHandle);
GLAPI void APIENTRY glBeginQuery(GLenum target, GLuint id);
GLAPI void APIENTRY glBeginQueryARB(GLenum target, GLuint id);
GLAPI void APIENTRY glBeginQueryEXT(GLenum target, GLuint id);
GLAPI void APIENTRY glBeginQueryIndexed(GLenum target, GLuint index, GLuint id);
GLAPI void APIENTRY glBeginTransformFeedback(GLenum primitiveMode);
GLAPI void APIENTRY glBeginTransformFeedbackEXT(GLenum primitiveMode);
GLAPI void APIENTRY glBeginTransformFeedbackNV(GLenum primitiveMode);
GLAPI void APIENTRY glBeginVertexShaderEXT(void);
GLAPI void APIENTRY glBeginVideoCaptureNV(GLuint video_capture_slot);
GLAPI void APIENTRY glBindANCCaptureStreamBufferNVX(GLuint video_capture_slot, GLuint stream, GLuint link, GLenum frame_region, GLenum anc_region, GLintptr offset);
GLAPI void APIENTRY glBindAttribLocation(GLuint program, GLuint index, const GLchar *name);
GLAPI void APIENTRY glBindAttribLocationARB(GLhandleARB programObj, GLuint index, const GLcharARB *name);
GLAPI void APIENTRY glBindBuffer(GLenum target, GLuint buffer);
GLAPI void APIENTRY glBindBufferARB(GLenum target, GLuint buffer);
GLAPI void APIENTRY glBindBufferBase(GLenum target, GLuint index, GLuint buffer);
GLAPI void APIENTRY glBindBufferBaseEXT(GLenum target, GLuint index, GLuint buffer);
GLAPI void APIENTRY glBindBufferBaseNV(GLenum target, GLuint index, GLuint buffer);
GLAPI void APIENTRY glBindBufferOffsetEXT(GLenum target, GLuint index, GLuint buffer, GLintptr offset);
GLAPI void APIENTRY glBindBufferOffsetNV(GLenum target, GLuint index, GLuint buffer, GLintptr offset);
GLAPI void APIENTRY glBindBufferRange(GLenum target, GLuint index, GLuint buffer, GLintptr offset, GLsizeiptr size);
GLAPI void APIENTRY glBindBufferRangeEXT(GLenum target, GLuint index, GLuint buffer, GLintptr offset, GLsizeiptr size);
GLAPI void APIENTRY glBindBufferRangeNV(GLenum target, GLuint index, GLuint buffer, GLintptr offset, GLsizeiptr size);
GLAPI void APIENTRY glBindBuffersBase(GLenum target, GLuint first, GLsizei count, const GLuint *buffers);
GLAPI void APIENTRY glBindBuffersRange(GLenum target, GLuint first, GLsizei count, const GLuint *buffers, const GLintptr *offsets, const GLsizeiptr *sizes);
GLAPI void APIENTRY glBindFragDataLocation(GLuint program, GLuint color, const GLchar *name);
GLAPI void APIENTRY glBindFragDataLocationEXT(GLuint program, GLuint color, const GLchar *name);
GLAPI void APIENTRY glBindFragDataLocationIndexed(GLuint program, GLuint colorNumber, GLuint index, const GLchar *name);
GLAPI void APIENTRY glBindFragDataLocationIndexedEXT(GLuint program, GLuint colorNumber, GLuint index, const GLchar *name);
GLAPI void APIENTRY glBindFragmentShaderATI(GLuint id);
GLAPI void APIENTRY glBindFramebuffer(GLenum target, GLuint framebuffer);
GLAPI void APIENTRY glBindFramebufferEXT(GLenum target, GLuint framebuffer);
GLAPI void APIENTRY glBindFramebufferOES(GLenum target, GLuint framebuffer);
GLAPI void APIENTRY glBindImageTexture(GLuint unit, GLuint texture, GLint level, GLboolean layered, GLint layer, GLenum access, GLenum format);
GLAPI void APIENTRY glBindImageTextureEXT(GLuint index, GLuint texture, GLint level, GLboolean layered, GLint layer, GLenum access, GLint format);
GLAPI void APIENTRY glBindImageTextures(GLuint first, GLsizei count, const GLuint *textures);
GLAPI GLuint APIENTRY glBindLightParameterEXT(GLenum light, GLenum value);
GLAPI GLuint APIENTRY glBindMaterialParameterEXT(GLenum face, GLenum value);
GLAPI void APIENTRY glBindMultiTextureEXT(GLenum texunit, GLenum target, GLuint texture);
GLAPI GLuint APIENTRY glBindParameterEXT(GLenum value);
GLAPI void APIENTRY glBindProgramARB(GLenum target, GLuint program);
GLAPI void APIENTRY glBindProgramNV(GLenum target, GLuint id);
GLAPI void APIENTRY glBindProgramPipeline(GLuint pipeline);
GLAPI void APIENTRY glBindProgramPipelineEXT(GLuint pipeline);
GLAPI void APIENTRY glBindRenderbuffer(GLenum target, GLuint renderbuffer);
GLAPI void APIENTRY glBindRenderbufferEXT(GLenum target, GLuint renderbuffer);
GLAPI void APIENTRY glBindRenderbufferOES(GLenum target, GLuint renderbuffer);
GLAPI void APIENTRY glBindSampler(GLuint unit, GLuint sampler);
GLAPI void APIENTRY glBindSamplers(GLuint first, GLsizei count, const GLuint *samplers);
GLAPI void APIENTRY glBindShadingRateImageNV(GLuint texture);
GLAPI GLuint APIENTRY glBindTexGenParameterEXT(GLenum unit, GLenum coord, GLenum value);
GLAPI void APIENTRY glBindTexture(GLenum target, GLuint texture);
GLAPI void APIENTRY glBindTextureEXT(GLenum target, GLuint texture);
GLAPI void APIENTRY glBindTextureUnit(GLuint unit, GLuint texture);
GLAPI GLuint APIENTRY glBindTextureUnitParameterEXT(GLenum unit, GLenum value);
GLAPI void APIENTRY glBindTextures(GLuint first, GLsizei count, const GLuint *textures);
GLAPI void APIENTRY glBindTransformFeedback(GLenum target, GLuint id);
GLAPI void APIENTRY glBindTransformFeedbackEXT(GLenum target, GLuint id);
GLAPI void APIENTRY glBindTransformFeedbackNV(GLenum target, GLuint id);
GLAPI void APIENTRY glBindVertexArray(GLuint array);
GLAPI void APIENTRY glBindVertexArrayAPPLE(GLuint array);
GLAPI void APIENTRY glBindVertexArrayOES(GLuint array);
GLAPI void APIENTRY glBindVertexBuffer(GLuint bindingindex, GLuint buffer, GLintptr offset, GLsizei stride);
GLAPI void APIENTRY glBindVertexBuffers(GLuint first, GLsizei count, const GLuint *buffers, const GLintptr *offsets, const GLsizei *strides);
GLAPI void APIENTRY glBindVertexShaderEXT(GLuint id);
GLAPI void APIENTRY glBindVideoCaptureStreamBufferNV(GLuint video_capture_slot, GLuint stream, GLenum frame_region, GLintptr offset);
GLAPI void APIENTRY glBindVideoCaptureStreamTextureNV(GLuint video_capture_slot, GLuint stream, GLenum frame_region, GLenum target, GLuint texture);
GLAPI void APIENTRY glBinormal3bEXT(GLbyte bx, GLbyte by, GLbyte bz);
GLAPI void APIENTRY glBinormal3bvEXT(const GLbyte *v);
GLAPI void APIENTRY glBinormal3dEXT(GLdouble bx, GLdouble by, GLdouble bz);
GLAPI void APIENTRY glBinormal3dvEXT(const GLdouble *v);
GLAPI void APIENTRY glBinormal3fEXT(GLfloat bx, GLfloat by, GLfloat bz);
GLAPI void APIENTRY glBinormal3fvEXT(const GLfloat *v);
GLAPI void APIENTRY glBinormal3iEXT(GLint bx, GLint by, GLint bz);
GLAPI void APIENTRY glBinormal3ivEXT(const GLint *v);
GLAPI void APIENTRY glBinormal3sEXT(GLshort bx, GLshort by, GLshort bz);
GLAPI void APIENTRY glBinormal3svEXT(const GLshort *v);
GLAPI void APIENTRY glBinormalPointerEXT(GLenum type, GLsizei stride, const void *pointer);
GLAPI void APIENTRY glBitmap(GLsizei width, GLsizei height, GLfloat xorig, GLfloat yorig, GLfloat xmove, GLfloat ymove, const GLubyte *bitmap);
GLAPI void APIENTRY glBitmapxOES(GLsizei width, GLsizei height, GLfixed xorig, GLfixed yorig, GLfixed xmove, GLfixed ymove, const GLubyte *bitmap);
GLAPI void APIENTRY glBlendBarrier(void);
GLAPI void APIENTRY glBlendBarrierKHR(void);
GLAPI void APIENTRY glBlendBarrierNV(void);
GLAPI void APIENTRY glBlendColor(GLfloat red, GLfloat green, GLfloat blue, GLfloat alpha);
GLAPI void APIENTRY glBlendColorEXT(GLfloat red, GLfloat green, GLfloat blue, GLfloat alpha);
GLAPI void APIENTRY glBlendColorxOES(GLfixed red, GLfixed green, GLfixed blue, GLfixed alpha);
GLAPI void APIENTRY glBlendEquation(GLenum mode);
GLAPI void APIENTRY glBlendEquationEXT(GLenum mode);
GLAPI void APIENTRY glBlendEquationIndexedAMD(GLuint buf, GLenum mode);
GLAPI void APIENTRY glBlendEquationOES(GLenum mode);
GLAPI void APIENTRY glBlendEquationSeparate(GLenum modeRGB, GLenum modeAlpha);
GLAPI void APIENTRY glBlendEquationSeparateEXT(GLenum modeRGB, GLenum modeAlpha);
GLAPI void APIENTRY glBlendEquationSeparateIndexedAMD(GLuint buf, GLenum modeRGB, GLenum modeAlpha);
GLAPI void APIENTRY glBlendEquationSeparateOES(GLenum modeRGB, GLenum modeAlpha);
GLAPI void APIENTRY glBlendEquationSeparatei(GLuint buf, GLenum modeRGB, GLenum modeAlpha);
GLAPI void APIENTRY glBlendEquationSeparateiARB(GLuint buf, GLenum modeRGB, GLenum modeAlpha);
GLAPI void APIENTRY glBlendEquationSeparateiEXT(GLuint buf, GLenum modeRGB, GLenum modeAlpha);
GLAPI void APIENTRY glBlendEquationSeparateiOES(GLuint buf, GLenum modeRGB, GLenum modeAlpha);
GLAPI void APIENTRY glBlendEquationi(GLuint buf, GLenum mode);
GLAPI void APIENTRY glBlendEquationiARB(GLuint buf, GLenum mode);
GLAPI void APIENTRY glBlendEquationiEXT(GLuint buf, GLenum mode);
GLAPI void APIENTRY glBlendEquationiOES(GLuint buf, GLenum mode);
GLAPI void APIENTRY glBlendFunc(GLenum sfactor, GLenum dfactor);
GLAPI void APIENTRY glBlendFuncIndexedAMD(GLuint buf, GLenum src, GLenum dst);
GLAPI void APIENTRY glBlendFuncSeparate(GLenum sfactorRGB, GLenum dfactorRGB, GLenum sfactorAlpha, GLenum dfactorAlpha);
GLAPI void APIENTRY glBlendFuncSeparateEXT(GLenum sfactorRGB, GLenum dfactorRGB, GLenum sfactorAlpha, GLenum dfactorAlpha);
GLAPI void APIENTRY glBlendFuncSeparateINGR(GLenum sfactorRGB, GLenum dfactorRGB, GLenum sfactorAlpha, GLenum dfactorAlpha);
GLAPI void APIENTRY glBlendFuncSeparateIndexedAMD(GLuint buf, GLenum srcRGB, GLenum dstRGB, GLenum srcAlpha, GLenum dstAlpha);
GLAPI void APIENTRY glBlendFuncSeparateOES(GLenum srcRGB, GLenum dstRGB, GLenum srcAlpha, GLenum dstAlpha);
GLAPI void APIENTRY glBlendFuncSeparatei(GLuint buf, GLenum srcRGB, GLenum dstRGB, GLenum srcAlpha, GLenum dstAlpha);
GLAPI void APIENTRY glBlendFuncSeparateiARB(GLuint buf, GLenum srcRGB, GLenum dstRGB, GLenum srcAlpha, GLenum dstAlpha);
GLAPI void APIENTRY glBlendFuncSeparateiEXT(GLuint buf, GLenum srcRGB, GLenum dstRGB, GLenum srcAlpha, GLenum dstAlpha);
GLAPI void APIENTRY glBlendFuncSeparateiOES(GLuint buf, GLenum srcRGB, GLenum dstRGB, GLenum srcAlpha, GLenum dstAlpha);
GLAPI void APIENTRY glBlendFunci(GLuint buf, GLenum src, GLenum dst);
GLAPI void APIENTRY glBlendFunciARB(GLuint buf, GLenum src, GLenum dst);
GLAPI void APIENTRY glBlendFunciEXT(GLuint buf, GLenum src, GLenum dst);
GLAPI void APIENTRY glBlendFunciOES(GLuint buf, GLenum src, GLenum dst);
GLAPI void APIENTRY glBlendParameteriNV(GLenum pname, GLint value);
GLAPI void APIENTRY glBlitFramebuffer(GLint srcX0, GLint srcY0, GLint srcX1, GLint srcY1, GLint dstX0, GLint dstY0, GLint dstX1, GLint dstY1, GLbitfield mask, GLenum filter);
GLAPI void APIENTRY glBlitFramebufferANGLE(GLint srcX0, GLint srcY0, GLint srcX1, GLint srcY1, GLint dstX0, GLint dstY0, GLint dstX1, GLint dstY1, GLbitfield mask, GLenum filter);
GLAPI void APIENTRY glBlitFramebufferEXT(GLint srcX0, GLint srcY0, GLint srcX1, GLint srcY1, GLint dstX0, GLint dstY0, GLint dstX1, GLint dstY1, GLbitfield mask, GLenum filter);
GLAPI void APIENTRY glBlitFramebufferNV(GLint srcX0, GLint srcY0, GLint srcX1, GLint srcY1, GLint dstX0, GLint dstY0, GLint dstX1, GLint dstY1, GLbitfield mask, GLenum filter);
GLAPI void APIENTRY glBlitNamedFramebuffer(GLuint readFramebuffer, GLuint drawFramebuffer, GLint srcX0, GLint srcY0, GLint srcX1, GLint srcY1, GLint dstX0, GLint dstY0, GLint dstX1, GLint dstY1, GLbitfield mask, GLenum filter);
GLAPI void APIENTRY glBufferAddressRangeNV(GLenum pname, GLuint index, GLuint64 address, GLsizeiptr length);
GLAPI void APIENTRY glBufferAttachMemoryNV(GLenum target, GLuint memory, GLuint64 offset);
GLAPI void APIENTRY glBufferData(GLenum target, GLsizeiptr size, const void *data, GLenum usage);
GLAPI void APIENTRY glBufferDataARB(GLenum target, GLsizeiptr size, const void *data, GLenum usage);
GLAPI void APIENTRY glBufferDataSysmem(GLenum target, GLsizeiptr size, const void *data, GLenum usage);
GLAPI void APIENTRY glBufferPageCommitmentARB(GLenum target, GLintptr offset, GLsizeiptr size, GLboolean commit);
GLAPI void APIENTRY glBufferParameteriAPPLE(GLenum target, GLenum pname, GLint param);
GLAPI void APIENTRY glBufferStorage(GLenum target, GLsizeiptr size, const void *data, GLbitfield flags);
GLAPI void APIENTRY glBufferStorageEXT(GLenum target, GLsizeiptr size, const void *data, GLbitfield flags);
GLAPI void APIENTRY glBufferStorageExternalEXT(GLenum target, GLintptr offset, GLsizeiptr size, GLeglClientBufferEXT clientBuffer, GLbitfield flags);
GLAPI void APIENTRY glBufferStorageMemEXT(GLenum target, GLsizeiptr size, GLuint memory, GLuint64 offset);
GLAPI void APIENTRY glBufferSubData(GLenum target, GLintptr offset, GLsizeiptr size, const void *data);
GLAPI void APIENTRY glBufferSubDataARB(GLenum target, GLintptr offset, GLsizeiptr size, const void *data);
GLAPI void APIENTRY glCallCommandListNV(GLuint list);
GLAPI void APIENTRY glCallList(GLuint list);
GLAPI void APIENTRY glCallLists(GLsizei n, GLenum type, const void *lists);
GLAPI GLenum APIENTRY glCheckFramebufferStatus(GLenum target);
GLAPI GLenum APIENTRY glCheckFramebufferStatusEXT(GLenum target);
GLAPI GLenum APIENTRY glCheckFramebufferStatusOES(GLenum target);
GLAPI GLenum APIENTRY glCheckNamedFramebufferStatus(GLuint framebuffer, GLenum target);
GLAPI GLenum APIENTRY glCheckNamedFramebufferStatusEXT(GLuint framebuffer, GLenum target);
GLAPI void APIENTRY glClampColor(GLenum target, GLenum clamp);
GLAPI void APIENTRY glClampColorARB(GLenum target, GLenum clamp);
GLAPI void APIENTRY glClear(GLbitfield mask);
GLAPI void APIENTRY glClearAccum(GLfloat red, GLfloat green, GLfloat blue, GLfloat alpha);
GLAPI void APIENTRY glClearAccumxOES(GLfixed red, GLfixed green, GLfixed blue, GLfixed alpha);
GLAPI void APIENTRY glClearBufferData(GLenum target, GLenum internalformat, GLenum format, GLenum type, const void *data);
GLAPI void APIENTRY glClearBufferSubData(GLenum target, GLenum internalformat, GLintptr offset, GLsizeiptr size, GLenum format, GLenum type, const void *data);
GLAPI void APIENTRY glClearBufferfi(GLenum buffer, GLint drawbuffer, GLfloat depth, GLint stencil);
GLAPI void APIENTRY glClearBufferfv(GLenum buffer, GLint drawbuffer, const GLfloat *value);
GLAPI void APIENTRY glClearBufferiv(GLenum buffer, GLint drawbuffer, const GLint *value);
GLAPI void APIENTRY glClearBufferuiv(GLenum buffer, GLint drawbuffer, const GLuint *value);
GLAPI void APIENTRY glClearColor(GLfloat red, GLfloat green, GLfloat blue, GLfloat alpha);
GLAPI void APIENTRY glClearColorIiEXT(GLint red, GLint green, GLint blue, GLint alpha);
GLAPI void APIENTRY glClearColorIuiEXT(GLuint red, GLuint green, GLuint blue, GLuint alpha);
GLAPI void APIENTRY glClearColorx(GLfixed red, GLfixed green, GLfixed blue, GLfixed alpha);
GLAPI void APIENTRY glClearColorxOES(GLfixed red, GLfixed green, GLfixed blue, GLfixed alpha);
GLAPI void APIENTRY glClearDepth(GLdouble depth);
GLAPI void APIENTRY glClearDepthdNV(GLdouble depth);
GLAPI void APIENTRY glClearDepthf(GLfloat d);
GLAPI void APIENTRY glClearDepthfOES(GLclampf depth);
GLAPI void APIENTRY glClearDepthx(GLfixed depth);
GLAPI void APIENTRY glClearDepthxOES(GLfixed depth);
GLAPI void APIENTRY glClearIndex(GLfloat c);
GLAPI void APIENTRY glClearNamedBufferData(GLuint buffer, GLenum internalformat, GLenum format, GLenum type, const void *data);
GLAPI void APIENTRY glClearNamedBufferDataEXT(GLuint buffer, GLenum internalformat, GLenum format, GLenum type, const void *data);
GLAPI void APIENTRY glClearNamedBufferSubData(GLuint buffer, GLenum internalformat, GLintptr offset, GLsizeiptr size, GLenum format, GLenum type, const void *data);
GLAPI void APIENTRY glClearNamedBufferSubDataEXT(GLuint buffer, GLenum internalformat, GLsizeiptr offset, GLsizeiptr size, GLenum format, GLenum type, const void *data);
GLAPI void APIENTRY glClearNamedFramebufferfi(GLuint framebuffer, GLenum buffer, GLint drawbuffer, GLfloat depth, GLint stencil);
GLAPI void APIENTRY glClearNamedFramebufferfv(GLuint framebuffer, GLenum buffer, GLint drawbuffer, const GLfloat *value);
GLAPI void APIENTRY glClearNamedFramebufferiv(GLuint framebuffer, GLenum buffer, GLint drawbuffer, const GLint *value);
GLAPI void APIENTRY glClearNamedFramebufferuiv(GLuint framebuffer, GLenum buffer, GLint drawbuffer, const GLuint *value);
GLAPI void APIENTRY glClearPixelLocalStorageuiEXT(GLsizei offset, GLsizei n, const GLuint *values);
GLAPI void APIENTRY glClearStencil(GLint s);
GLAPI void APIENTRY glClearTexImage(GLuint texture, GLint level, GLenum format, GLenum type, const void *data);
GLAPI void APIENTRY glClearTexImageEXT(GLuint texture, GLint level, GLenum format, GLenum type, const void *data);
GLAPI void APIENTRY glClearTexSubImage(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void *data);
GLAPI void APIENTRY glClearTexSubImageEXT(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void *data);
GLAPI void APIENTRY glClientActiveTexture(GLenum texture);
GLAPI void APIENTRY glClientActiveTextureARB(GLenum texture);
GLAPI void APIENTRY glClientActiveVertexStreamATI(GLenum stream);
GLAPI void APIENTRY glClientAttribDefaultEXT(GLbitfield mask);
GLAPI void APIENTRY glClientWaitSemaphoreui64NVX(GLsizei fenceObjectCount, const GLuint *semaphoreArray, const GLuint64 *fenceValueArray);
GLAPI GLenum APIENTRY glClientWaitSync(GLsync sync, GLbitfield flags, GLuint64 timeout);
GLAPI GLenum APIENTRY glClientWaitSyncAPPLE(GLsync sync, GLbitfield flags, GLuint64 timeout);
GLAPI GLenum APIENTRY glClientWaitSyncValueuiNVX(GLsync sync, GLbitfield flags, GLuint64 timeout, GLuint value, GLboolean GEQ);
GLAPI void APIENTRY glClipControl(GLenum origin, GLenum depth);
GLAPI void APIENTRY glClipControlEXT(GLenum origin, GLenum depth);
GLAPI void APIENTRY glClipPlane(GLenum plane, const GLdouble *equation);
GLAPI void APIENTRY glClipPlanef(GLenum p, const GLfloat *eqn);
GLAPI void APIENTRY glClipPlanefIMG(GLenum p, const GLfloat *eqn);
GLAPI void APIENTRY glClipPlanefOES(GLenum plane, const GLfloat *equation);
GLAPI void APIENTRY glClipPlanex(GLenum plane, const GLfixed *equation);
GLAPI void APIENTRY glClipPlanexIMG(GLenum p, const GLfixed *eqn);
GLAPI void APIENTRY glClipPlanexOES(GLenum plane, const GLfixed *equation);
GLAPI void APIENTRY glColor3b(GLbyte red, GLbyte green, GLbyte blue);
GLAPI void APIENTRY glColor3bv(const GLbyte *v);
GLAPI void APIENTRY glColor3d(GLdouble red, GLdouble green, GLdouble blue);
GLAPI void APIENTRY glColor3dv(const GLdouble *v);
GLAPI void APIENTRY glColor3f(GLfloat red, GLfloat green, GLfloat blue);
GLAPI void APIENTRY glColor3fVertex3fSUN(GLfloat r, GLfloat g, GLfloat b, GLfloat x, GLfloat y, GLfloat z);
GLAPI void APIENTRY glColor3fVertex3fvSUN(const GLfloat *c, const GLfloat *v);
GLAPI void APIENTRY glColor3fv(const GLfloat *v);
GLAPI void APIENTRY glColor3hNV(GLhalf red, GLhalf green, GLhalf blue);
GLAPI void APIENTRY glColor3hvNV(const GLhalf *v);
GLAPI void APIENTRY glColor3i(GLint red, GLint green, GLint blue);
GLAPI void APIENTRY glColor3iv(const GLint *v);
GLAPI void APIENTRY glColor3s(GLshort red, GLshort green, GLshort blue);
GLAPI void APIENTRY glColor3sv(const GLshort *v);
GLAPI void APIENTRY glColor3ub(GLubyte red, GLubyte green, GLubyte blue);
GLAPI void APIENTRY glColor3ubv(const GLubyte *v);
GLAPI void APIENTRY glColor3ui(GLuint red, GLuint green, GLuint blue);
GLAPI void APIENTRY glColor3uiv(const GLuint *v);
GLAPI void APIENTRY glColor3us(GLushort red, GLushort green, GLushort blue);
GLAPI void APIENTRY glColor3usv(const GLushort *v);
GLAPI void APIENTRY glColor3x(GLfixed red, GLfixed green, GLfixed blue);
GLAPI void APIENTRY glColor3xOES(GLfixed red, GLfixed green, GLfixed blue);
GLAPI void APIENTRY glColor3xvOES(const GLfixed *components);
GLAPI void APIENTRY glColor4b(GLbyte red, GLbyte green, GLbyte blue, GLbyte alpha);
GLAPI void APIENTRY glColor4bv(const GLbyte *v);
GLAPI void APIENTRY glColor4d(GLdouble red, GLdouble green, GLdouble blue, GLdouble alpha);
GLAPI void APIENTRY glColor4dv(const GLdouble *v);
GLAPI void APIENTRY glColor4f(GLfloat red, GLfloat green, GLfloat blue, GLfloat alpha);
GLAPI void APIENTRY glColor4fNormal3fVertex3fSUN(GLfloat r, GLfloat g, GLfloat b, GLfloat a, GLfloat nx, GLfloat ny, GLfloat nz, GLfloat x, GLfloat y, GLfloat z);
GLAPI void APIENTRY glColor4fNormal3fVertex3fvSUN(const GLfloat *c, const GLfloat *n, const GLfloat *v);
GLAPI void APIENTRY glColor4fv(const GLfloat *v);
GLAPI void APIENTRY glColor4hNV(GLhalf red, GLhalf green, GLhalf blue, GLhalf alpha);
GLAPI void APIENTRY glColor4hvNV(const GLhalf *v);
GLAPI void APIENTRY glColor4i(GLint red, GLint green, GLint blue, GLint alpha);
GLAPI void APIENTRY glColor4iv(const GLint *v);
GLAPI void APIENTRY glColor4s(GLshort red, GLshort green, GLshort blue, GLshort alpha);
GLAPI void APIENTRY glColor4sv(const GLshort *v);
GLAPI void APIENTRY glColor4ub(GLubyte red, GLubyte green, GLubyte blue, GLubyte alpha);
GLAPI void APIENTRY glColor4ubVertex2fSUN(GLubyte r, GLubyte g, GLubyte b, GLubyte a, GLfloat x, GLfloat y);
GLAPI void APIENTRY glColor4ubVertex2fvSUN(const GLubyte *c, const GLfloat *v);
GLAPI void APIENTRY glColor4ubVertex3fSUN(GLubyte r, GLubyte g, GLubyte b, GLubyte a, GLfloat x, GLfloat y, GLfloat z);
GLAPI void APIENTRY glColor4ubVertex3fvSUN(const GLubyte *c, const GLfloat *v);
GLAPI void APIENTRY glColor4ubv(const GLubyte *v);
GLAPI void APIENTRY glColor4ui(GLuint red, GLuint green, GLuint blue, GLuint alpha);
GLAPI void APIENTRY glColor4uiv(const GLuint *v);
GLAPI void APIENTRY glColor4us(GLushort red, GLushort green, GLushort blue, GLushort alpha);
GLAPI void APIENTRY glColor4usv(const GLushort *v);
GLAPI void APIENTRY glColor4x(GLfixed red, GLfixed green, GLfixed blue, GLfixed alpha);
GLAPI void APIENTRY glColor4xOES(GLfixed red, GLfixed green, GLfixed blue, GLfixed alpha);
GLAPI void APIENTRY glColor4xvOES(const GLfixed *components);
GLAPI void APIENTRY glColorFormatNV(GLint size, GLenum type, GLsizei stride);
GLAPI void APIENTRY glColorFragmentOp1ATI(GLenum op, GLuint dst, GLuint dstMask, GLuint dstMod, GLuint arg1, GLuint arg1Rep, GLuint arg1Mod);
GLAPI void APIENTRY glColorFragmentOp2ATI(GLenum op, GLuint dst, GLuint dstMask, GLuint dstMod, GLuint arg1, GLuint arg1Rep, GLuint arg1Mod, GLuint arg2, GLuint arg2Rep, GLuint arg2Mod);
GLAPI void APIENTRY glColorFragmentOp3ATI(GLenum op, GLuint dst, GLuint dstMask, GLuint dstMod, GLuint arg1, GLuint arg1Rep, GLuint arg1Mod, GLuint arg2, GLuint arg2Rep, GLuint arg2Mod, GLuint arg3, GLuint arg3Rep, GLuint arg3Mod);
GLAPI void APIENTRY glColorMask(GLboolean red, GLboolean green, GLboolean blue, GLboolean alpha);
GLAPI void APIENTRY glColorMaskIndexedEXT(GLuint index, GLboolean r, GLboolean g, GLboolean b, GLboolean a);
GLAPI void APIENTRY glColorMaski(GLuint index, GLboolean r, GLboolean g, GLboolean b, GLboolean a);
GLAPI void APIENTRY glColorMaskiEXT(GLuint index, GLboolean r, GLboolean g, GLboolean b, GLboolean a);
GLAPI void APIENTRY glColorMaskiOES(GLuint index, GLboolean r, GLboolean g, GLboolean b, GLboolean a);
GLAPI void APIENTRY glColorMaterial(GLenum face, GLenum mode);
GLAPI void APIENTRY glColorP3ui(GLenum type, GLuint color);
GLAPI void APIENTRY glColorP3uiv(GLenum type, const GLuint *color);
GLAPI void APIENTRY glColorP4ui(GLenum type, GLuint color);
GLAPI void APIENTRY glColorP4uiv(GLenum type, const GLuint *color);
GLAPI void APIENTRY glColorPointer(GLint size, GLenum type, GLsizei stride, const void *pointer);
GLAPI void APIENTRY glColorPointerEXT(GLint size, GLenum type, GLsizei stride, GLsizei count, const void *pointer);
GLAPI void APIENTRY glColorPointerListIBM(GLint size, GLenum type, GLint stride, const void **pointer, GLint ptrstride);
GLAPI void APIENTRY glColorPointervINTEL(GLint size, GLenum type, const void **pointer);
GLAPI void APIENTRY glColorSubTable(GLenum target, GLsizei start, GLsizei count, GLenum format, GLenum type, const void *data);
GLAPI void APIENTRY glColorSubTableEXT(GLenum target, GLsizei start, GLsizei count, GLenum format, GLenum type, const void *data);
GLAPI void APIENTRY glColorTable(GLenum target, GLenum internalformat, GLsizei width, GLenum format, GLenum type, const void *table);
GLAPI void APIENTRY glColorTableEXT(GLenum target, GLenum internalFormat, GLsizei width, GLenum format, GLenum type, const void *table);
GLAPI void APIENTRY glColorTableParameterfv(GLenum target, GLenum pname, const GLfloat *params);
GLAPI void APIENTRY glColorTableParameterfvSGI(GLenum target, GLenum pname, const GLfloat *params);
GLAPI void APIENTRY glColorTableParameteriv(GLenum target, GLenum pname, const GLint *params);
GLAPI void APIENTRY glColorTableParameterivSGI(GLenum target, GLenum pname, const GLint *params);
GLAPI void APIENTRY glColorTableSGI(GLenum target, GLenum internalformat, GLsizei width, GLenum format, GLenum type, const void *table);
GLAPI void APIENTRY glCombinerInputNV(GLenum stage, GLenum portion, GLenum variable, GLenum input, GLenum mapping, GLenum componentUsage);
GLAPI void APIENTRY glCombinerOutputNV(GLenum stage, GLenum portion, GLenum abOutput, GLenum cdOutput, GLenum sumOutput, GLenum scale, GLenum bias, GLboolean abDotProduct, GLboolean cdDotProduct, GLboolean muxSum);
GLAPI void APIENTRY glCombinerParameterfNV(GLenum pname, GLfloat param);
GLAPI void APIENTRY glCombinerParameterfvNV(GLenum pname, const GLfloat *params);
GLAPI void APIENTRY glCombinerParameteriNV(GLenum pname, GLint param);
GLAPI void APIENTRY glCombinerParameterivNV(GLenum pname, const GLint *params);
GLAPI void APIENTRY glCombinerStageParameterfvNV(GLenum stage, GLenum pname, const GLfloat *params);
GLAPI void APIENTRY glCommandListSegmentsNV(GLuint list, GLuint segments);
GLAPI void APIENTRY glCompileCommandListNV(GLuint list);
GLAPI void APIENTRY glCompileShader(GLuint shader);
GLAPI void APIENTRY glCompileShaderARB(GLhandleARB shaderObj);
GLAPI void APIENTRY glCompileShaderIncludeARB(GLuint shader, GLsizei count, const GLchar *const *path, const GLint *length);
GLAPI void APIENTRY glCompressedMultiTexImage1DEXT(GLenum texunit, GLenum target, GLint level, GLenum internalformat, GLsizei width, GLint border, GLsizei imageSize, const void *bits);
GLAPI void APIENTRY glCompressedMultiTexImage2DEXT(GLenum texunit, GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLint border, GLsizei imageSize, const void *bits);
GLAPI void APIENTRY glCompressedMultiTexImage3DEXT(GLenum texunit, GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLsizei imageSize, const void *bits);
GLAPI void APIENTRY glCompressedMultiTexSubImage1DEXT(GLenum texunit, GLenum target, GLint level, GLint xoffset, GLsizei width, GLenum format, GLsizei imageSize, const void *bits);
GLAPI void APIENTRY glCompressedMultiTexSubImage2DEXT(GLenum texunit, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLsizei imageSize, const void *bits);
GLAPI void APIENTRY glCompressedMultiTexSubImage3DEXT(GLenum texunit, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLsizei imageSize, const void *bits);
GLAPI void APIENTRY glCompressedTexImage1D(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLint border, GLsizei imageSize, const void *data);
GLAPI void APIENTRY glCompressedTexImage1DARB(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLint border, GLsizei imageSize, const void *data);
GLAPI void APIENTRY glCompressedTexImage2D(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLint border, GLsizei imageSize, const void *data);
GLAPI void APIENTRY glCompressedTexImage2DARB(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLint border, GLsizei imageSize, const void *data);
GLAPI void APIENTRY glCompressedTexImage3D(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLsizei imageSize, const void *data);
GLAPI void APIENTRY glCompressedTexImage3DARB(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLsizei imageSize, const void *data);
GLAPI void APIENTRY glCompressedTexImage3DNV(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLsizei imageSize, const void *data);
GLAPI void APIENTRY glCompressedTexImage3DOES(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLsizei imageSize, const void *data);
GLAPI void APIENTRY glCompressedTexSubImage1D(GLenum target, GLint level, GLint xoffset, GLsizei width, GLenum format, GLsizei imageSize, const void *data);
GLAPI void APIENTRY glCompressedTexSubImage1DARB(GLenum target, GLint level, GLint xoffset, GLsizei width, GLenum format, GLsizei imageSize, const void *data);
GLAPI void APIENTRY glCompressedTexSubImage2D(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLsizei imageSize, const void *data);
GLAPI void APIENTRY glCompressedTexSubImage2DARB(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLsizei imageSize, const void *data);
GLAPI void APIENTRY glCompressedTexSubImage3D(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLsizei imageSize, const void *data);
GLAPI void APIENTRY glCompressedTexSubImage3DARB(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLsizei imageSize, const void *data);
GLAPI void APIENTRY glCompressedTexSubImage3DNV(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLsizei imageSize, const void *data);
GLAPI void APIENTRY glCompressedTexSubImage3DOES(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLsizei imageSize, const void *data);
GLAPI void APIENTRY glCompressedTextureImage1DEXT(GLuint texture, GLenum target, GLint level, GLenum internalformat, GLsizei width, GLint border, GLsizei imageSize, const void *bits);
GLAPI void APIENTRY glCompressedTextureImage2DEXT(GLuint texture, GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLint border, GLsizei imageSize, const void *bits);
GLAPI void APIENTRY glCompressedTextureImage3DEXT(GLuint texture, GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLsizei imageSize, const void *bits);
GLAPI void APIENTRY glCompressedTextureSubImage1D(GLuint texture, GLint level, GLint xoffset, GLsizei width, GLenum format, GLsizei imageSize, const void *data);
GLAPI void APIENTRY glCompressedTextureSubImage1DEXT(GLuint texture, GLenum target, GLint level, GLint xoffset, GLsizei width, GLenum format, GLsizei imageSize, const void *bits);
GLAPI void APIENTRY glCompressedTextureSubImage2D(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLsizei imageSize, const void *data);
GLAPI void APIENTRY glCompressedTextureSubImage2DEXT(GLuint texture, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLsizei imageSize, const void *bits);
GLAPI void APIENTRY glCompressedTextureSubImage3D(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLsizei imageSize, const void *data);
GLAPI void APIENTRY glCompressedTextureSubImage3DEXT(GLuint texture, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLsizei imageSize, const void *bits);
GLAPI void APIENTRY glConservativeRasterParameterfNV(GLenum pname, GLfloat value);
GLAPI void APIENTRY glConservativeRasterParameteriNV(GLenum pname, GLint param);
GLAPI void APIENTRY glConvolutionFilter1D(GLenum target, GLenum internalformat, GLsizei width, GLenum format, GLenum type, const void *image);
GLAPI void APIENTRY glConvolutionFilter1DEXT(GLenum target, GLenum internalformat, GLsizei width, GLenum format, GLenum type, const void *image);
GLAPI void APIENTRY glConvolutionFilter2D(GLenum target, GLenum internalformat, GLsizei width, GLsizei height, GLenum format, GLenum type, const void *image);
GLAPI void APIENTRY glConvolutionFilter2DEXT(GLenum target, GLenum internalformat, GLsizei width, GLsizei height, GLenum format, GLenum type, const void *image);
GLAPI void APIENTRY glConvolutionParameterf(GLenum target, GLenum pname, GLfloat params);
GLAPI void APIENTRY glConvolutionParameterfEXT(GLenum target, GLenum pname, GLfloat params);
GLAPI void APIENTRY glConvolutionParameterfv(GLenum target, GLenum pname, const GLfloat *params);
GLAPI void APIENTRY glConvolutionParameterfvEXT(GLenum target, GLenum pname, const GLfloat *params);
GLAPI void APIENTRY glConvolutionParameteri(GLenum target, GLenum pname, GLint params);
GLAPI void APIENTRY glConvolutionParameteriEXT(GLenum target, GLenum pname, GLint params);
GLAPI void APIENTRY glConvolutionParameteriv(GLenum target, GLenum pname, const GLint *params);
GLAPI void APIENTRY glConvolutionParameterivEXT(GLenum target, GLenum pname, const GLint *params);
GLAPI void APIENTRY glConvolutionParameterxOES(GLenum target, GLenum pname, GLfixed param);
GLAPI void APIENTRY glConvolutionParameterxvOES(GLenum target, GLenum pname, const GLfixed *params);
GLAPI void APIENTRY glCopyBufferSubData(GLenum readTarget, GLenum writeTarget, GLintptr readOffset, GLintptr writeOffset, GLsizeiptr size);
GLAPI void APIENTRY glCopyBufferSubDataNV(GLenum readTarget, GLenum writeTarget, GLintptr readOffset, GLintptr writeOffset, GLsizeiptr size);
GLAPI void APIENTRY glCopyColorSubTable(GLenum target, GLsizei start, GLint x, GLint y, GLsizei width);
GLAPI void APIENTRY glCopyColorSubTableEXT(GLenum target, GLsizei start, GLint x, GLint y, GLsizei width);
GLAPI void APIENTRY glCopyColorTable(GLenum target, GLenum internalformat, GLint x, GLint y, GLsizei width);
GLAPI void APIENTRY glCopyColorTableSGI(GLenum target, GLenum internalformat, GLint x, GLint y, GLsizei width);
GLAPI void APIENTRY glCopyConvolutionFilter1D(GLenum target, GLenum internalformat, GLint x, GLint y, GLsizei width);
GLAPI void APIENTRY glCopyConvolutionFilter1DEXT(GLenum target, GLenum internalformat, GLint x, GLint y, GLsizei width);
GLAPI void APIENTRY glCopyConvolutionFilter2D(GLenum target, GLenum internalformat, GLint x, GLint y, GLsizei width, GLsizei height);
GLAPI void APIENTRY glCopyConvolutionFilter2DEXT(GLenum target, GLenum internalformat, GLint x, GLint y, GLsizei width, GLsizei height);
GLAPI void APIENTRY glCopyImageSubData(GLuint srcName, GLenum srcTarget, GLint srcLevel, GLint srcX, GLint srcY, GLint srcZ, GLuint dstName, GLenum dstTarget, GLint dstLevel, GLint dstX, GLint dstY, GLint dstZ, GLsizei srcWidth, GLsizei srcHeight, GLsizei srcDepth);
GLAPI void APIENTRY glCopyImageSubDataEXT(GLuint srcName, GLenum srcTarget, GLint srcLevel, GLint srcX, GLint srcY, GLint srcZ, GLuint dstName, GLenum dstTarget, GLint dstLevel, GLint dstX, GLint dstY, GLint dstZ, GLsizei srcWidth, GLsizei srcHeight, GLsizei srcDepth);
GLAPI void APIENTRY glCopyImageSubDataNV(GLuint srcName, GLenum srcTarget, GLint srcLevel, GLint srcX, GLint srcY, GLint srcZ, GLuint dstName, GLenum dstTarget, GLint dstLevel, GLint dstX, GLint dstY, GLint dstZ, GLsizei width, GLsizei height, GLsizei depth);
GLAPI void APIENTRY glCopyImageSubDataOES(GLuint srcName, GLenum srcTarget, GLint srcLevel, GLint srcX, GLint srcY, GLint srcZ, GLuint dstName, GLenum dstTarget, GLint dstLevel, GLint dstX, GLint dstY, GLint dstZ, GLsizei srcWidth, GLsizei srcHeight, GLsizei srcDepth);
GLAPI void APIENTRY glCopyMultiTexImage1DEXT(GLenum texunit, GLenum target, GLint level, GLenum internalformat, GLint x, GLint y, GLsizei width, GLint border);
GLAPI void APIENTRY glCopyMultiTexImage2DEXT(GLenum texunit, GLenum target, GLint level, GLenum internalformat, GLint x, GLint y, GLsizei width, GLsizei height, GLint border);
GLAPI void APIENTRY glCopyMultiTexSubImage1DEXT(GLenum texunit, GLenum target, GLint level, GLint xoffset, GLint x, GLint y, GLsizei width);
GLAPI void APIENTRY glCopyMultiTexSubImage2DEXT(GLenum texunit, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint x, GLint y, GLsizei width, GLsizei height);
GLAPI void APIENTRY glCopyMultiTexSubImage3DEXT(GLenum texunit, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLint x, GLint y, GLsizei width, GLsizei height);
GLAPI void APIENTRY glCopyNamedBufferSubData(GLuint readBuffer, GLuint writeBuffer, GLintptr readOffset, GLintptr writeOffset, GLsizeiptr size);
GLAPI void APIENTRY glCopyPathNV(GLuint resultPath, GLuint srcPath);
GLAPI void APIENTRY glCopyPixels(GLint x, GLint y, GLsizei width, GLsizei height, GLenum type);
GLAPI void APIENTRY glCopyTexImage1D(GLenum target, GLint level, GLenum internalformat, GLint x, GLint y, GLsizei width, GLint border);
GLAPI void APIENTRY glCopyTexImage1DEXT(GLenum target, GLint level, GLenum internalformat, GLint x, GLint y, GLsizei width, GLint border);
GLAPI void APIENTRY glCopyTexImage2D(GLenum target, GLint level, GLenum internalformat, GLint x, GLint y, GLsizei width, GLsizei height, GLint border);
GLAPI void APIENTRY glCopyTexImage2DEXT(GLenum target, GLint level, GLenum internalformat, GLint x, GLint y, GLsizei width, GLsizei height, GLint border);
GLAPI void APIENTRY glCopyTexSubImage1D(GLenum target, GLint level, GLint xoffset, GLint x, GLint y, GLsizei width);
GLAPI void APIENTRY glCopyTexSubImage1DEXT(GLenum target, GLint level, GLint xoffset, GLint x, GLint y, GLsizei width);
GLAPI void APIENTRY glCopyTexSubImage2D(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint x, GLint y, GLsizei width, GLsizei height);
GLAPI void APIENTRY glCopyTexSubImage2DEXT(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint x, GLint y, GLsizei width, GLsizei height);
GLAPI void APIENTRY glCopyTexSubImage3D(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLint x, GLint y, GLsizei width, GLsizei height);
GLAPI void APIENTRY glCopyTexSubImage3DEXT(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLint x, GLint y, GLsizei width, GLsizei height);
GLAPI void APIENTRY glCopyTexSubImage3DNV(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLint x, GLint y, GLsizei width, GLsizei height);
GLAPI void APIENTRY glCopyTexSubImage3DOES(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLint x, GLint y, GLsizei width, GLsizei height);
GLAPI void APIENTRY glCopyTextureImage1DEXT(GLuint texture, GLenum target, GLint level, GLenum internalformat, GLint x, GLint y, GLsizei width, GLint border);
GLAPI void APIENTRY glCopyTextureImage2DEXT(GLuint texture, GLenum target, GLint level, GLenum internalformat, GLint x, GLint y, GLsizei width, GLsizei height, GLint border);
GLAPI void APIENTRY glCopyTextureLevelsAPPLE(GLuint destinationTexture, GLuint sourceTexture, GLint sourceBaseLevel, GLsizei sourceLevelCount);
GLAPI void APIENTRY glCopyTextureSubImage1D(GLuint texture, GLint level, GLint xoffset, GLint x, GLint y, GLsizei width);
GLAPI void APIENTRY glCopyTextureSubImage1DEXT(GLuint texture, GLenum target, GLint level, GLint xoffset, GLint x, GLint y, GLsizei width);
GLAPI void APIENTRY glCopyTextureSubImage2D(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint x, GLint y, GLsizei width, GLsizei height);
GLAPI void APIENTRY glCopyTextureSubImage2DEXT(GLuint texture, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint x, GLint y, GLsizei width, GLsizei height);
GLAPI void APIENTRY glCopyTextureSubImage3D(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLint x, GLint y, GLsizei width, GLsizei height);
GLAPI void APIENTRY glCopyTextureSubImage3DEXT(GLuint texture, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLint x, GLint y, GLsizei width, GLsizei height);
GLAPI void APIENTRY glCoverFillPathInstancedNV(GLsizei numPaths, GLenum pathNameType, const void *paths, GLuint pathBase, GLenum coverMode, GLenum transformType, const GLfloat *transformValues);
GLAPI void APIENTRY glCoverFillPathNV(GLuint path, GLenum coverMode);
GLAPI void APIENTRY glCoverStrokePathInstancedNV(GLsizei numPaths, GLenum pathNameType, const void *paths, GLuint pathBase, GLenum coverMode, GLenum transformType, const GLfloat *transformValues);
GLAPI void APIENTRY glCoverStrokePathNV(GLuint path, GLenum coverMode);
GLAPI void APIENTRY glCoverageMaskNV(GLboolean mask);
GLAPI void APIENTRY glCoverageModulationNV(GLenum components);
GLAPI void APIENTRY glCoverageModulationTableNV(GLsizei n, const GLfloat *v);
GLAPI void APIENTRY glCoverageOperationNV(GLenum operation);
GLAPI void APIENTRY glCreateBuffers(GLsizei n, GLuint *buffers);
GLAPI void APIENTRY glCreateCommandListsNV(GLsizei n, GLuint *lists);
GLAPI void APIENTRY glCreateFramebuffers(GLsizei n, GLuint *framebuffers);
GLAPI void APIENTRY glCreateMemoryObjectsEXT(GLsizei n, GLuint *memoryObjects);
GLAPI void APIENTRY glCreatePerfQueryINTEL(GLuint queryId, GLuint *queryHandle);
GLAPI GLuint APIENTRY glCreateProgram(void);
GLAPI GLhandleARB APIENTRY glCreateProgramObjectARB(void);
GLAPI void APIENTRY glCreateProgramPipelines(GLsizei n, GLuint *pipelines);
GLAPI GLuint APIENTRY glCreateProgressFenceNVX(void);
GLAPI void APIENTRY glCreateQueries(GLenum target, GLsizei n, GLuint *ids);
GLAPI void APIENTRY glCreateRenderbuffers(GLsizei n, GLuint *renderbuffers);
GLAPI void APIENTRY glCreateSamplers(GLsizei n, GLuint *samplers);
GLAPI GLuint APIENTRY glCreateShader(GLenum type);
GLAPI GLhandleARB APIENTRY glCreateShaderObjectARB(GLenum shaderType);
GLAPI GLuint APIENTRY glCreateShaderProgramEXT(GLenum type, const GLchar *string);
GLAPI GLuint APIENTRY glCreateShaderProgramv(GLenum type, GLsizei count, const GLchar *const *strings);
GLAPI GLuint APIENTRY glCreateShaderProgramvEXT(GLenum type, GLsizei count, const GLchar **strings);
GLAPI void APIENTRY glCreateStatesNV(GLsizei n, GLuint *states);
GLAPI GLsync APIENTRY glCreateSyncFromCLeventARB(struct _cl_context *context, struct _cl_event *event, GLbitfield flags);
GLAPI void APIENTRY glCreateTextures(GLenum target, GLsizei n, GLuint *textures);
GLAPI void APIENTRY glCreateTransformFeedbacks(GLsizei n, GLuint *ids);
GLAPI void APIENTRY glCreateVertexArrays(GLsizei n, GLuint *arrays);
GLAPI void APIENTRY glCullFace(GLenum mode);
GLAPI void APIENTRY glCullParameterdvEXT(GLenum pname, GLdouble *params);
GLAPI void APIENTRY glCullParameterfvEXT(GLenum pname, GLfloat *params);
GLAPI void APIENTRY glCurrentPaletteMatrixARB(GLint index);
GLAPI void APIENTRY glCurrentPaletteMatrixOES(GLuint matrixpaletteindex);
GLAPI void APIENTRY glDebugMessageCallback(GLDEBUGPROC callback, const void *userParam);
GLAPI void APIENTRY glDebugMessageCallbackAMD(GLDEBUGPROCAMD callback, void *userParam);
GLAPI void APIENTRY glDebugMessageCallbackARB(GLDEBUGPROCARB callback, const void *userParam);
GLAPI void APIENTRY glDebugMessageCallbackKHR(GLDEBUGPROCKHR callback, const void *userParam);
GLAPI void APIENTRY glDebugMessageCallbackOES(GLDEBUGPROC callback, const void *userParam);
GLAPI void APIENTRY glDebugMessageControl(GLenum source, GLenum type, GLenum severity, GLsizei count, const GLuint *ids, GLboolean enabled);
GLAPI void APIENTRY glDebugMessageControlARB(GLenum source, GLenum type, GLenum severity, GLsizei count, const GLuint *ids, GLboolean enabled);
GLAPI void APIENTRY glDebugMessageControlKHR(GLenum source, GLenum type, GLenum severity, GLsizei count, const GLuint *ids, GLboolean enabled);
GLAPI void APIENTRY glDebugMessageControlOES(GLenum source, GLenum type, GLenum severity, GLsizei count, const GLuint *ids, GLboolean enabled);
GLAPI void APIENTRY glDebugMessageEnableAMD(GLenum category, GLenum severity, GLsizei count, const GLuint *ids, GLboolean enabled);
GLAPI void APIENTRY glDebugMessageInsert(GLenum source, GLenum type, GLuint id, GLenum severity, GLsizei length, const GLchar *buf);
GLAPI void APIENTRY glDebugMessageInsertAMD(GLenum category, GLenum severity, GLuint id, GLsizei length, const GLchar *buf);
GLAPI void APIENTRY glDebugMessageInsertARB(GLenum source, GLenum type, GLuint id, GLenum severity, GLsizei length, const GLchar *buf);
GLAPI void APIENTRY glDebugMessageInsertKHR(GLenum source, GLenum type, GLuint id, GLenum severity, GLsizei length, const GLchar *buf);
GLAPI void APIENTRY glDebugMessageInsertOES(GLenum source, GLenum type, GLuint id, GLenum severity, GLsizei length, const GLchar *buf);
GLAPI void APIENTRY glDeformSGIX(GLbitfield mask);
GLAPI void APIENTRY glDeformationMap3dSGIX(GLenum target, GLdouble u1, GLdouble u2, GLint ustride, GLint uorder, GLdouble v1, GLdouble v2, GLint vstride, GLint vorder, GLdouble w1, GLdouble w2, GLint wstride, GLint worder, const GLdouble *points);
GLAPI void APIENTRY glDeformationMap3fSGIX(GLenum target, GLfloat u1, GLfloat u2, GLint ustride, GLint uorder, GLfloat v1, GLfloat v2, GLint vstride, GLint vorder, GLfloat w1, GLfloat w2, GLint wstride, GLint worder, const GLfloat *points);
GLAPI void APIENTRY glDeleteAsyncMarkersSGIX(GLuint marker, GLsizei range);
GLAPI void APIENTRY glDeleteBuffers(GLsizei n, const GLuint *buffers);
GLAPI void APIENTRY glDeleteBuffersARB(GLsizei n, const GLuint *buffers);
GLAPI void APIENTRY glDeleteCommandListsNV(GLsizei n, const GLuint *lists);
GLAPI void APIENTRY glDeleteFencesAPPLE(GLsizei n, const GLuint *fences);
GLAPI void APIENTRY glDeleteFencesNV(GLsizei n, const GLuint *fences);
GLAPI void APIENTRY glDeleteFragmentShaderATI(GLuint id);
GLAPI void APIENTRY glDeleteFramebuffers(GLsizei n, const GLuint *framebuffers);
GLAPI void APIENTRY glDeleteFramebuffersEXT(GLsizei n, const GLuint *framebuffers);
GLAPI void APIENTRY glDeleteFramebuffersOES(GLsizei n, const GLuint *framebuffers);
GLAPI void APIENTRY glDeleteLists(GLuint list, GLsizei range);
GLAPI void APIENTRY glDeleteMemoryObjectsEXT(GLsizei n, const GLuint *memoryObjects);
GLAPI void APIENTRY glDeleteNamedStringARB(GLint namelen, const GLchar *name);
GLAPI void APIENTRY glDeleteNamesAMD(GLenum identifier, GLuint num, const GLuint *names);
GLAPI void APIENTRY glDeleteObjectARB(GLhandleARB obj);
GLAPI void APIENTRY glDeleteOcclusionQueriesNV(GLsizei n, const GLuint *ids);
GLAPI void APIENTRY glDeletePathsNV(GLuint path, GLsizei range);
GLAPI void APIENTRY glDeletePerfMonitorsAMD(GLsizei n, GLuint *monitors);
GLAPI void APIENTRY glDeletePerfQueryINTEL(GLuint queryHandle);
GLAPI void APIENTRY glDeleteProgram(GLuint program);
GLAPI void APIENTRY glDeleteProgramPipelines(GLsizei n, const GLuint *pipelines);
GLAPI void APIENTRY glDeleteProgramPipelinesEXT(GLsizei n, const GLuint *pipelines);
GLAPI void APIENTRY glDeleteProgramsARB(GLsizei n, const GLuint *programs);
GLAPI void APIENTRY glDeleteProgramsNV(GLsizei n, const GLuint *programs);
GLAPI void APIENTRY glDeleteQueries(GLsizei n, const GLuint *ids);
GLAPI void APIENTRY glDeleteQueriesARB(GLsizei n, const GLuint *ids);
GLAPI void APIENTRY glDeleteQueriesEXT(GLsizei n, const GLuint *ids);
GLAPI void APIENTRY glDeleteQueryResourceTagNV(GLsizei n, const GLint *tagIds);
GLAPI void APIENTRY glDeleteRenderbuffers(GLsizei n, const GLuint *renderbuffers);
GLAPI void APIENTRY glDeleteRenderbuffersEXT(GLsizei n, const GLuint *renderbuffers);
GLAPI void APIENTRY glDeleteRenderbuffersOES(GLsizei n, const GLuint *renderbuffers);
GLAPI void APIENTRY glDeleteSamplers(GLsizei count, const GLuint *samplers);
GLAPI void APIENTRY glDeleteSemaphoresEXT(GLsizei n, const GLuint *semaphores);
GLAPI void APIENTRY glDeleteShader(GLuint shader);
GLAPI void APIENTRY glDeleteStatesNV(GLsizei n, const GLuint *states);
GLAPI void APIENTRY glDeleteSync(GLsync sync);
GLAPI void APIENTRY glDeleteSyncAPPLE(GLsync sync);
GLAPI void APIENTRY glDeleteTextures(GLsizei n, const GLuint *textures);
GLAPI void APIENTRY glDeleteTexturesEXT(GLsizei n, const GLuint *textures);
GLAPI void APIENTRY glDeleteTransformFeedbacks(GLsizei n, const GLuint *ids);
GLAPI void APIENTRY glDeleteTransformFeedbacksEXT(GLsizei n, const GLuint *ids);
GLAPI void APIENTRY glDeleteTransformFeedbacksNV(GLsizei n, const GLuint *ids);
GLAPI void APIENTRY glDeleteVertexArrays(GLsizei n, const GLuint *arrays);
GLAPI void APIENTRY glDeleteVertexArraysAPPLE(GLsizei n, const GLuint *arrays);
GLAPI void APIENTRY glDeleteVertexArraysOES(GLsizei n, const GLuint *arrays);
GLAPI void APIENTRY glDeleteVertexShaderEXT(GLuint id);
GLAPI void APIENTRY glDepthBoundsEXT(GLclampd zmin, GLclampd zmax);
GLAPI void APIENTRY glDepthBoundsdNV(GLdouble zmin, GLdouble zmax);
GLAPI void APIENTRY glDepthFunc(GLenum func);
GLAPI void APIENTRY glDepthMask(GLboolean flag);
GLAPI void APIENTRY glDepthRange(GLdouble n, GLdouble f);
GLAPI void APIENTRY glDepthRangeArraydvNV(GLuint first, GLsizei count, const GLdouble *v);
GLAPI void APIENTRY glDepthRangeArrayfvNV(GLuint first, GLsizei count, const GLfloat *v);
GLAPI void APIENTRY glDepthRangeArrayfvOES(GLuint first, GLsizei count, const GLfloat *v);
GLAPI void APIENTRY glDepthRangeArrayv(GLuint first, GLsizei count, const GLdouble *v);
GLAPI void APIENTRY glDepthRangeIndexed(GLuint index, GLdouble n, GLdouble f);
GLAPI void APIENTRY glDepthRangeIndexeddNV(GLuint index, GLdouble n, GLdouble f);
GLAPI void APIENTRY glDepthRangeIndexedfNV(GLuint index, GLfloat n, GLfloat f);
GLAPI void APIENTRY glDepthRangeIndexedfOES(GLuint index, GLfloat n, GLfloat f);
GLAPI void APIENTRY glDepthRangedNV(GLdouble zNear, GLdouble zFar);
GLAPI void APIENTRY glDepthRangef(GLfloat n, GLfloat f);
GLAPI void APIENTRY glDepthRangefOES(GLclampf n, GLclampf f);
GLAPI void APIENTRY glDepthRangex(GLfixed n, GLfixed f);
GLAPI void APIENTRY glDepthRangexOES(GLfixed n, GLfixed f);
GLAPI void APIENTRY glDetachObjectARB(GLhandleARB containerObj, GLhandleARB attachedObj);
GLAPI void APIENTRY glDetachShader(GLuint program, GLuint shader);
GLAPI void APIENTRY glDetailTexFuncSGIS(GLenum target, GLsizei n, const GLfloat *points);
GLAPI void APIENTRY glDevtoolsCorrelationIdNVX(GLuint64 id);
GLAPI void APIENTRY glDevtoolsInvokeStreamedCallbackNVX(void *fnptr, void *userdata);
GLAPI void APIENTRY glDisable(GLenum cap);
GLAPI void APIENTRY glDisableClientState(GLenum array);
GLAPI void APIENTRY glDisableClientStateIndexedEXT(GLenum array, GLuint index);
GLAPI void APIENTRY glDisableClientStateiEXT(GLenum array, GLuint index);
GLAPI void APIENTRY glDisableDriverControlQCOM(GLuint driverControl);
GLAPI void APIENTRY glDisableIndexedEXT(GLenum target, GLuint index);
GLAPI void APIENTRY glDisableVariantClientStateEXT(GLuint id);
GLAPI void APIENTRY glDisableVertexArrayAttrib(GLuint vaobj, GLuint index);
GLAPI void APIENTRY glDisableVertexArrayAttribEXT(GLuint vaobj, GLuint index);
GLAPI void APIENTRY glDisableVertexArrayEXT(GLuint vaobj, GLenum array);
GLAPI void APIENTRY glDisableVertexAttribAPPLE(GLuint index, GLenum pname);
GLAPI void APIENTRY glDisableVertexAttribArray(GLuint index);
GLAPI void APIENTRY glDisableVertexAttribArrayARB(GLuint index);
GLAPI void APIENTRY glDisablei(GLenum target, GLuint index);
GLAPI void APIENTRY glDisableiEXT(GLenum target, GLuint index);
GLAPI void APIENTRY glDisableiNV(GLenum target, GLuint index);
GLAPI void APIENTRY glDisableiOES(GLenum target, GLuint index);
GLAPI void APIENTRY glDiscardFramebufferEXT(GLenum target, GLsizei numAttachments, const GLenum *attachments);
GLAPI void APIENTRY glDispatchCompute(GLuint num_groups_x, GLuint num_groups_y, GLuint num_groups_z);
GLAPI void APIENTRY glDispatchComputeGroupSizeARB(GLuint num_groups_x, GLuint num_groups_y, GLuint num_groups_z, GLuint group_size_x, GLuint group_size_y, GLuint group_size_z);
GLAPI void APIENTRY glDispatchComputeIndirect(GLintptr indirect);
GLAPI void APIENTRY glDrawArrays(GLenum mode, GLint first, GLsizei count);
GLAPI void APIENTRY glDrawArraysEXT(GLenum mode, GLint first, GLsizei count);
GLAPI void APIENTRY glDrawArraysIndirect(GLenum mode, const void *indirect);
GLAPI void APIENTRY glDrawArraysInstanced(GLenum mode, GLint first, GLsizei count, GLsizei instancecount);
GLAPI void APIENTRY glDrawArraysInstancedANGLE(GLenum mode, GLint first, GLsizei count, GLsizei primcount);
GLAPI void APIENTRY glDrawArraysInstancedARB(GLenum mode, GLint first, GLsizei count, GLsizei primcount);
GLAPI void APIENTRY glDrawArraysInstancedBaseInstance(GLenum mode, GLint first, GLsizei count, GLsizei instancecount, GLuint baseinstance);
GLAPI void APIENTRY glDrawArraysInstancedBaseInstanceEXT(GLenum mode, GLint first, GLsizei count, GLsizei instancecount, GLuint baseinstance);
GLAPI void APIENTRY glDrawArraysInstancedEXT(GLenum mode, GLint start, GLsizei count, GLsizei primcount);
GLAPI void APIENTRY glDrawArraysInstancedNV(GLenum mode, GLint first, GLsizei count, GLsizei primcount);
GLAPI void APIENTRY glDrawBuffer(GLenum buf);
GLAPI void APIENTRY glDrawBuffers(GLsizei n, const GLenum *bufs);
GLAPI void APIENTRY glDrawBuffersARB(GLsizei n, const GLenum *bufs);
GLAPI void APIENTRY glDrawBuffersATI(GLsizei n, const GLenum *bufs);
GLAPI void APIENTRY glDrawBuffersEXT(GLsizei n, const GLenum *bufs);
GLAPI void APIENTRY glDrawBuffersIndexedEXT(GLint n, const GLenum *location, const GLint *indices);
GLAPI void APIENTRY glDrawBuffersNV(GLsizei n, const GLenum *bufs);
GLAPI void APIENTRY glDrawCommandsAddressNV(GLenum primitiveMode, const GLuint64 *indirects, const GLsizei *sizes, GLuint count);
GLAPI void APIENTRY glDrawCommandsNV(GLenum primitiveMode, GLuint buffer, const GLintptr *indirects, const GLsizei *sizes, GLuint count);
GLAPI void APIENTRY glDrawCommandsStatesAddressNV(const GLuint64 *indirects, const GLsizei *sizes, const GLuint *states, const GLuint *fbos, GLuint count);
GLAPI void APIENTRY glDrawCommandsStatesNV(GLuint buffer, const GLintptr *indirects, const GLsizei *sizes, const GLuint *states, const GLuint *fbos, GLuint count);
GLAPI void APIENTRY glDrawElementArrayAPPLE(GLenum mode, GLint first, GLsizei count);
GLAPI void APIENTRY glDrawElementArrayATI(GLenum mode, GLsizei count);
GLAPI void APIENTRY glDrawElements(GLenum mode, GLsizei count, GLenum type, const void *indices);
GLAPI void APIENTRY glDrawElementsBaseVertex(GLenum mode, GLsizei count, GLenum type, const void *indices, GLint basevertex);
GLAPI void APIENTRY glDrawElementsBaseVertexEXT(GLenum mode, GLsizei count, GLenum type, const void *indices, GLint basevertex);
GLAPI void APIENTRY glDrawElementsBaseVertexOES(GLenum mode, GLsizei count, GLenum type, const void *indices, GLint basevertex);
GLAPI void APIENTRY glDrawElementsIndirect(GLenum mode, GLenum type, const void *indirect);
GLAPI void APIENTRY glDrawElementsInstanced(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei instancecount);
GLAPI void APIENTRY glDrawElementsInstancedANGLE(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei primcount);
GLAPI void APIENTRY glDrawElementsInstancedARB(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei primcount);
GLAPI void APIENTRY glDrawElementsInstancedBaseInstance(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei instancecount, GLuint baseinstance);
GLAPI void APIENTRY glDrawElementsInstancedBaseInstanceEXT(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei instancecount, GLuint baseinstance);
GLAPI void APIENTRY glDrawElementsInstancedBaseVertex(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei instancecount, GLint basevertex);
GLAPI void APIENTRY glDrawElementsInstancedBaseVertexBaseInstance(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei instancecount, GLint basevertex, GLuint baseinstance);
GLAPI void APIENTRY glDrawElementsInstancedBaseVertexBaseInstanceEXT(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei instancecount, GLint basevertex, GLuint baseinstance);
GLAPI void APIENTRY glDrawElementsInstancedBaseVertexEXT(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei instancecount, GLint basevertex);
GLAPI void APIENTRY glDrawElementsInstancedBaseVertexOES(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei instancecount, GLint basevertex);
GLAPI void APIENTRY glDrawElementsInstancedEXT(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei primcount);
GLAPI void APIENTRY glDrawElementsInstancedNV(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei primcount);
GLAPI void APIENTRY glDrawMeshArraysSUN(GLenum mode, GLint first, GLsizei count, GLsizei width);
GLAPI void APIENTRY glDrawMeshNV(GLenum mode, GLsizei count, GLenum type, GLsizei stride, const void *indicesTexCoord, const void *indicesNormal, const void *indicesVertex);
GLAPI void APIENTRY glDrawMeshTasksIndirectNV(GLintptr indirect);
GLAPI void APIENTRY glDrawMeshTasksNV(GLuint first, GLuint count);
GLAPI void APIENTRY glDrawPixels(GLsizei width, GLsizei height, GLenum format, GLenum type, const void *pixels);
GLAPI void APIENTRY glDrawRangeElementArrayAPPLE(GLenum mode, GLuint start, GLuint end, GLint first, GLsizei count);
GLAPI void APIENTRY glDrawRangeElementArrayATI(GLenum mode, GLuint start, GLuint end, GLsizei count);
GLAPI void APIENTRY glDrawRangeElements(GLenum mode, GLuint start, GLuint end, GLsizei count, GLenum type, const void *indices);
GLAPI void APIENTRY glDrawRangeElementsBaseVertex(GLenum mode, GLuint start, GLuint end, GLsizei count, GLenum type, const void *indices, GLint basevertex);
GLAPI void APIENTRY glDrawRangeElementsBaseVertexEXT(GLenum mode, GLuint start, GLuint end, GLsizei count, GLenum type, const void *indices, GLint basevertex);
GLAPI void APIENTRY glDrawRangeElementsBaseVertexOES(GLenum mode, GLuint start, GLuint end, GLsizei count, GLenum type, const void *indices, GLint basevertex);
GLAPI void APIENTRY glDrawRangeElementsEXT(GLenum mode, GLuint start, GLuint end, GLsizei count, GLenum type, const void *indices);
GLAPI void APIENTRY glDrawTexfOES(GLfloat x, GLfloat y, GLfloat z, GLfloat width, GLfloat height);
GLAPI void APIENTRY glDrawTexfvOES(const GLfloat *coords);
GLAPI void APIENTRY glDrawTexiOES(GLint x, GLint y, GLint z, GLint width, GLint height);
GLAPI void APIENTRY glDrawTexivOES(const GLint *coords);
GLAPI void APIENTRY glDrawTexsOES(GLshort x, GLshort y, GLshort z, GLshort width, GLshort height);
GLAPI void APIENTRY glDrawTexsvOES(const GLshort *coords);
GLAPI void APIENTRY glDrawTextureNV(GLuint texture, GLuint sampler, GLfloat x0, GLfloat y0, GLfloat x1, GLfloat y1, GLfloat z, GLfloat s0, GLfloat t0, GLfloat s1, GLfloat t1);
GLAPI void APIENTRY glDrawTexxOES(GLfixed x, GLfixed y, GLfixed z, GLfixed width, GLfixed height);
GLAPI void APIENTRY glDrawTexxvOES(const GLfixed *coords);
GLAPI void APIENTRY glDrawTransformFeedback(GLenum mode, GLuint id);
GLAPI void APIENTRY glDrawTransformFeedbackEXT(GLenum mode, GLuint id);
GLAPI void APIENTRY glDrawTransformFeedbackInstanced(GLenum mode, GLuint id, GLsizei instancecount);
GLAPI void APIENTRY glDrawTransformFeedbackInstancedEXT(GLenum mode, GLuint id, GLsizei instancecount);
GLAPI void APIENTRY glDrawTransformFeedbackNV(GLenum mode, GLuint id);
GLAPI void APIENTRY glDrawTransformFeedbackStream(GLenum mode, GLuint id, GLuint stream);
GLAPI void APIENTRY glDrawTransformFeedbackStreamInstanced(GLenum mode, GLuint id, GLuint stream, GLsizei instancecount);
GLAPI void APIENTRY glDrawVkImageNV(GLuint64 vkImage, GLuint sampler, GLfloat x0, GLfloat y0, GLfloat x1, GLfloat y1, GLfloat z, GLfloat s0, GLfloat t0, GLfloat s1, GLfloat t1);
GLAPI void APIENTRY glEGLImageTargetRenderbufferStorageOES(GLenum target, GLeglImageOES image);
GLAPI void APIENTRY glEGLImageTargetTexStorageEXT(GLenum target, GLeglImageOES image, const GLint *attrib_list);
GLAPI void APIENTRY glEGLImageTargetTexture2DOES(GLenum target, GLeglImageOES image);
GLAPI void APIENTRY glEGLImageTargetTextureStorageEXT(GLuint texture, GLeglImageOES image, const GLint *attrib_list);
GLAPI void APIENTRY glEdgeFlag(GLboolean flag);
GLAPI void APIENTRY glEdgeFlagFormatNV(GLsizei stride);
GLAPI void APIENTRY glEdgeFlagPointer(GLsizei stride, const void *pointer);
GLAPI void APIENTRY glEdgeFlagPointerEXT(GLsizei stride, GLsizei count, const GLboolean *pointer);
GLAPI void APIENTRY glEdgeFlagPointerListIBM(GLint stride, const GLboolean **pointer, GLint ptrstride);
GLAPI void APIENTRY glEdgeFlagv(const GLboolean *flag);
GLAPI void APIENTRY glElementPointerAPPLE(GLenum type, const void *pointer);
GLAPI void APIENTRY glElementPointerATI(GLenum type, const void *pointer);
GLAPI void APIENTRY glEnable(GLenum cap);
GLAPI void APIENTRY glEnableClientState(GLenum array);
GLAPI void APIENTRY glEnableClientStateIndexedEXT(GLenum array, GLuint index);
GLAPI void APIENTRY glEnableClientStateiEXT(GLenum array, GLuint index);
GLAPI void APIENTRY glEnableDriverControlQCOM(GLuint driverControl);
GLAPI void APIENTRY glEnableIndexedEXT(GLenum target, GLuint index);
GLAPI void APIENTRY glEnableVariantClientStateEXT(GLuint id);
GLAPI void APIENTRY glEnableVertexArrayAttrib(GLuint vaobj, GLuint index);
GLAPI void APIENTRY glEnableVertexArrayAttribEXT(GLuint vaobj, GLuint index);
GLAPI void APIENTRY glEnableVertexArrayEXT(GLuint vaobj, GLenum array);
GLAPI void APIENTRY glEnableVertexAttribAPPLE(GLuint index, GLenum pname);
GLAPI void APIENTRY glEnableVertexAttribArray(GLuint index);
GLAPI void APIENTRY glEnableVertexAttribArrayARB(GLuint index);
GLAPI void APIENTRY glEnablei(GLenum target, GLuint index);
GLAPI void APIENTRY glEnableiEXT(GLenum target, GLuint index);
GLAPI void APIENTRY glEnableiNV(GLenum target, GLuint index);
GLAPI void APIENTRY glEnableiOES(GLenum target, GLuint index);
GLAPI void APIENTRY glEnd(void);
GLAPI void APIENTRY glEndConditionalRender(void);
GLAPI void APIENTRY glEndConditionalRenderNV(void);
GLAPI void APIENTRY glEndConditionalRenderNVX(void);
GLAPI void APIENTRY glEndFragmentShaderATI(void);
GLAPI void APIENTRY glEndList(void);
GLAPI void APIENTRY glEndOcclusionQueryNV(void);
GLAPI void APIENTRY glEndPerfMonitorAMD(GLuint monitor);
GLAPI void APIENTRY glEndPerfQueryINTEL(GLuint queryHandle);
GLAPI void APIENTRY glEndQuery(GLenum target);
GLAPI void APIENTRY glEndQueryARB(GLenum target);
GLAPI void APIENTRY glEndQueryEXT(GLenum target);
GLAPI void APIENTRY glEndQueryIndexed(GLenum target, GLuint index);
GLAPI void APIENTRY glEndTilingQCOM(GLbitfield preserveMask);
GLAPI void APIENTRY glEndTransformFeedback(void);
GLAPI void APIENTRY glEndTransformFeedbackEXT(void);
GLAPI void APIENTRY glEndTransformFeedbackNV(void);
GLAPI void APIENTRY glEndVertexShaderEXT(void);
GLAPI void APIENTRY glEndVideoCaptureNV(GLuint video_capture_slot);
GLAPI void APIENTRY glEvalCoord1d(GLdouble u);
GLAPI void APIENTRY glEvalCoord1dv(const GLdouble *u);
GLAPI void APIENTRY glEvalCoord1f(GLfloat u);
GLAPI void APIENTRY glEvalCoord1fv(const GLfloat *u);
GLAPI void APIENTRY glEvalCoord1xOES(GLfixed u);
GLAPI void APIENTRY glEvalCoord1xvOES(const GLfixed *coords);
GLAPI void APIENTRY glEvalCoord2d(GLdouble u, GLdouble v);
GLAPI void APIENTRY glEvalCoord2dv(const GLdouble *u);
GLAPI void APIENTRY glEvalCoord2f(GLfloat u, GLfloat v);
GLAPI void APIENTRY glEvalCoord2fv(const GLfloat *u);
GLAPI void APIENTRY glEvalCoord2xOES(GLfixed u, GLfixed v);
GLAPI void APIENTRY glEvalCoord2xvOES(const GLfixed *coords);
GLAPI void APIENTRY glEvalMapsNV(GLenum target, GLenum mode);
GLAPI void APIENTRY glEvalMesh1(GLenum mode, GLint i1, GLint i2);
GLAPI void APIENTRY glEvalMesh2(GLenum mode, GLint i1, GLint i2, GLint j1, GLint j2);
GLAPI void APIENTRY glEvalPoint1(GLint i);
GLAPI void APIENTRY glEvalPoint2(GLint i, GLint j);
GLAPI void APIENTRY glEvaluateDepthValuesARB(void);
GLAPI void APIENTRY glExecuteProgramNV(GLenum target, GLuint id, const GLfloat *params);
GLAPI void APIENTRY glExtGetBufferPointervQCOM(GLenum target, void **params);
GLAPI void APIENTRY glExtGetBuffersQCOM(GLuint *buffers, GLint maxBuffers, GLint *numBuffers);
GLAPI void APIENTRY glExtGetFramebuffersQCOM(GLuint *framebuffers, GLint maxFramebuffers, GLint *numFramebuffers);
GLAPI void APIENTRY glExtGetProgramBinarySourceQCOM(GLuint program, GLenum shadertype, GLchar *source, GLint *length);
GLAPI void APIENTRY glExtGetProgramsQCOM(GLuint *programs, GLint maxPrograms, GLint *numPrograms);
GLAPI void APIENTRY glExtGetRenderbuffersQCOM(GLuint *renderbuffers, GLint maxRenderbuffers, GLint *numRenderbuffers);
GLAPI void APIENTRY glExtGetShadersQCOM(GLuint *shaders, GLint maxShaders, GLint *numShaders);
GLAPI void APIENTRY glExtGetTexLevelParameterivQCOM(GLuint texture, GLenum face, GLint level, GLenum pname, GLint *params);
GLAPI void APIENTRY glExtGetTexSubImageQCOM(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, void *texels);
GLAPI void APIENTRY glExtGetTexturesQCOM(GLuint *textures, GLint maxTextures, GLint *numTextures);
GLAPI GLboolean APIENTRY glExtIsProgramBinaryQCOM(GLuint program);
GLAPI void APIENTRY glExtTexObjectStateOverrideiQCOM(GLenum target, GLenum pname, GLint param);
GLAPI void APIENTRY glExtractComponentEXT(GLuint res, GLuint src, GLuint num);
GLAPI void APIENTRY glFeedbackBuffer(GLsizei size, GLenum type, GLfloat *buffer);
GLAPI void APIENTRY glFeedbackBufferxOES(GLsizei n, GLenum type, const GLfixed *buffer);
GLAPI GLsync APIENTRY glFenceSync(GLenum condition, GLbitfield flags);
GLAPI GLsync APIENTRY glFenceSyncAPPLE(GLenum condition, GLbitfield flags);
GLAPI void APIENTRY glFenceValueuiNVX(GLsync sync, GLenum condition, GLbitfield flags, GLuint value);
GLAPI void APIENTRY glFinalCombinerInputNV(GLenum variable, GLenum input, GLenum mapping, GLenum componentUsage);
GLAPI void APIENTRY glFinish(void);
GLAPI GLint APIENTRY glFinishAsyncSGIX(GLuint *markerp);
GLAPI void APIENTRY glFinishFenceAPPLE(GLuint fence);
GLAPI void APIENTRY glFinishFenceNV(GLuint fence);
GLAPI void APIENTRY glFinishObjectAPPLE(GLenum object, GLint name);
GLAPI void APIENTRY glFinishTextureSUNX(void);
GLAPI void APIENTRY glFlush(void);
GLAPI void APIENTRY glFlushMappedBufferRange(GLenum target, GLintptr offset, GLsizeiptr length);
GLAPI void APIENTRY glFlushMappedBufferRangeAPPLE(GLenum target, GLintptr offset, GLsizeiptr size);
GLAPI void APIENTRY glFlushMappedBufferRangeEXT(GLenum target, GLintptr offset, GLsizeiptr length);
GLAPI void APIENTRY glFlushMappedNamedBufferRange(GLuint buffer, GLintptr offset, GLsizeiptr length);
GLAPI void APIENTRY glFlushMappedNamedBufferRangeEXT(GLuint buffer, GLintptr offset, GLsizeiptr length);
GLAPI void APIENTRY glFlushPixelDataRangeNV(GLenum target);
GLAPI void APIENTRY glFlushRasterSGIX(void);
GLAPI void APIENTRY glFlushStaticDataIBM(GLenum target);
GLAPI void APIENTRY glFlushVertexArrayRangeAPPLE(GLsizei length, void *pointer);
GLAPI void APIENTRY glFlushVertexArrayRangeNV(void);
GLAPI void APIENTRY glFogCoordFormatNV(GLenum type, GLsizei stride);
GLAPI void APIENTRY glFogCoordPointer(GLenum type, GLsizei stride, const void *pointer);
GLAPI void APIENTRY glFogCoordPointerEXT(GLenum type, GLsizei stride, const void *pointer);
GLAPI void APIENTRY glFogCoordPointerListIBM(GLenum type, GLint stride, const void **pointer, GLint ptrstride);
GLAPI void APIENTRY glFogCoordd(GLdouble coord);
GLAPI void APIENTRY glFogCoorddEXT(GLdouble coord);
GLAPI void APIENTRY glFogCoorddv(const GLdouble *coord);
GLAPI void APIENTRY glFogCoorddvEXT(const GLdouble *coord);
GLAPI void APIENTRY glFogCoordf(GLfloat coord);
GLAPI void APIENTRY glFogCoordfEXT(GLfloat coord);
GLAPI void APIENTRY glFogCoordfv(const GLfloat *coord);
GLAPI void APIENTRY glFogCoordfvEXT(const GLfloat *coord);
GLAPI void APIENTRY glFogCoordhNV(GLhalf fog);
GLAPI void APIENTRY glFogCoordhvNV(const GLhalf *fog);
GLAPI void APIENTRY glFogFuncSGIS(GLsizei n, const GLfloat *points);
GLAPI void APIENTRY glFogf(GLenum pname, GLfloat param);
GLAPI void APIENTRY glFogfv(GLenum pname, const GLfloat *params);
GLAPI void APIENTRY glFogi(GLenum pname, GLint param);
GLAPI void APIENTRY glFogiv(GLenum pname, const GLint *params);
GLAPI void APIENTRY glFogx(GLenum pname, GLfixed param);
GLAPI void APIENTRY glFogxOES(GLenum pname, GLfixed param);
GLAPI void APIENTRY glFogxv(GLenum pname, const GLfixed *param);
GLAPI void APIENTRY glFogxvOES(GLenum pname, const GLfixed *param);
GLAPI void APIENTRY glFragmentColorMaterialSGIX(GLenum face, GLenum mode);
GLAPI void APIENTRY glFragmentCoverageColorNV(GLuint color);
GLAPI void APIENTRY glFragmentLightModelfSGIX(GLenum pname, GLfloat param);
GLAPI void APIENTRY glFragmentLightModelfvSGIX(GLenum pname, const GLfloat *params);
GLAPI void APIENTRY glFragmentLightModeliSGIX(GLenum pname, GLint param);
GLAPI void APIENTRY glFragmentLightModelivSGIX(GLenum pname, const GLint *params);
GLAPI void APIENTRY glFragmentLightfSGIX(GLenum light, GLenum pname, GLfloat param);
GLAPI void APIENTRY glFragmentLightfvSGIX(GLenum light, GLenum pname, const GLfloat *params);
GLAPI void APIENTRY glFragmentLightiSGIX(GLenum light, GLenum pname, GLint param);
GLAPI void APIENTRY glFragmentLightivSGIX(GLenum light, GLenum pname, const GLint *params);
GLAPI void APIENTRY glFragmentMaterialfSGIX(GLenum face, GLenum pname, GLfloat param);
GLAPI void APIENTRY glFragmentMaterialfvSGIX(GLenum face, GLenum pname, const GLfloat *params);
GLAPI void APIENTRY glFragmentMaterialiSGIX(GLenum face, GLenum pname, GLint param);
GLAPI void APIENTRY glFragmentMaterialivSGIX(GLenum face, GLenum pname, const GLint *params);
GLAPI void APIENTRY glFrameTerminatorGREMEDY(void);
GLAPI void APIENTRY glFrameZoomSGIX(GLint factor);
GLAPI void APIENTRY glFramebufferDrawBufferEXT(GLuint framebuffer, GLenum mode);
GLAPI void APIENTRY glFramebufferDrawBuffersEXT(GLuint framebuffer, GLsizei n, const GLenum *bufs);
GLAPI void APIENTRY glFramebufferFetchBarrierEXT(void);
GLAPI void APIENTRY glFramebufferFetchBarrierQCOM(void);
GLAPI void APIENTRY glFramebufferFoveationConfigQCOM(GLuint framebuffer, GLuint numLayers, GLuint focalPointsPerLayer, GLuint requestedFeatures, GLuint *providedFeatures);
GLAPI void APIENTRY glFramebufferFoveationParametersQCOM(GLuint framebuffer, GLuint layer, GLuint focalPoint, GLfloat focalX, GLfloat focalY, GLfloat gainX, GLfloat gainY, GLfloat foveaArea);
GLAPI void APIENTRY glFramebufferParameteri(GLenum target, GLenum pname, GLint param);
GLAPI void APIENTRY glFramebufferParameteriMESA(GLenum target, GLenum pname, GLint param);
GLAPI void APIENTRY glFramebufferPixelLocalStorageSizeEXT(GLuint target, GLsizei size);
GLAPI void APIENTRY glFramebufferReadBufferEXT(GLuint framebuffer, GLenum mode);
GLAPI void APIENTRY glFramebufferRenderbuffer(GLenum target, GLenum attachment, GLenum renderbuffertarget, GLuint renderbuffer);
GLAPI void APIENTRY glFramebufferRenderbufferEXT(GLenum target, GLenum attachment, GLenum renderbuffertarget, GLuint renderbuffer);
GLAPI void APIENTRY glFramebufferRenderbufferOES(GLenum target, GLenum attachment, GLenum renderbuffertarget, GLuint renderbuffer);
GLAPI void APIENTRY glFramebufferSampleLocationsfvARB(GLenum target, GLuint start, GLsizei count, const GLfloat *v);
GLAPI void APIENTRY glFramebufferSampleLocationsfvNV(GLenum target, GLuint start, GLsizei count, const GLfloat *v);
GLAPI void APIENTRY glFramebufferSamplePositionsfvAMD(GLenum target, GLuint numsamples, GLuint pixelindex, const GLfloat *values);
GLAPI void APIENTRY glFramebufferTexture(GLenum target, GLenum attachment, GLuint texture, GLint level);
GLAPI void APIENTRY glFramebufferTexture1D(GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level);
GLAPI void APIENTRY glFramebufferTexture1DEXT(GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level);
GLAPI void APIENTRY glFramebufferTexture2D(GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level);
GLAPI void APIENTRY glFramebufferTexture2DDownsampleIMG(GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level, GLint xscale, GLint yscale);
GLAPI void APIENTRY glFramebufferTexture2DEXT(GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level);
GLAPI void APIENTRY glFramebufferTexture2DMultisampleEXT(GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level, GLsizei samples);
GLAPI void APIENTRY glFramebufferTexture2DMultisampleIMG(GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level, GLsizei samples);
GLAPI void APIENTRY glFramebufferTexture2DOES(GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level);
GLAPI void APIENTRY glFramebufferTexture3D(GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level, GLint zoffset);
GLAPI void APIENTRY glFramebufferTexture3DEXT(GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level, GLint zoffset);
GLAPI void APIENTRY glFramebufferTexture3DOES(GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level, GLint zoffset);
GLAPI void APIENTRY glFramebufferTextureARB(GLenum target, GLenum attachment, GLuint texture, GLint level);
GLAPI void APIENTRY glFramebufferTextureEXT(GLenum target, GLenum attachment, GLuint texture, GLint level);
GLAPI void APIENTRY glFramebufferTextureFaceARB(GLenum target, GLenum attachment, GLuint texture, GLint level, GLenum face);
GLAPI void APIENTRY glFramebufferTextureFaceEXT(GLenum target, GLenum attachment, GLuint texture, GLint level, GLenum face);
GLAPI void APIENTRY glFramebufferTextureLayer(GLenum target, GLenum attachment, GLuint texture, GLint level, GLint layer);
GLAPI void APIENTRY glFramebufferTextureLayerARB(GLenum target, GLenum attachment, GLuint texture, GLint level, GLint layer);
GLAPI void APIENTRY glFramebufferTextureLayerDownsampleIMG(GLenum target, GLenum attachment, GLuint texture, GLint level, GLint layer, GLint xscale, GLint yscale);
GLAPI void APIENTRY glFramebufferTextureLayerEXT(GLenum target, GLenum attachment, GLuint texture, GLint level, GLint layer);
GLAPI void APIENTRY glFramebufferTextureLayerNV(GLenum target, GLenum attachment, GLuint texture, GLint level, GLint layer);
GLAPI void APIENTRY glFramebufferTextureMultisampleMultiviewOVR(GLenum target, GLenum attachment, GLuint texture, GLint level, GLsizei samples, GLint baseViewIndex, GLsizei numViews);
GLAPI void APIENTRY glFramebufferTextureMultiviewOVR(GLenum target, GLenum attachment, GLuint texture, GLint level, GLint baseViewIndex, GLsizei numViews);
GLAPI void APIENTRY glFramebufferTextureOES(GLenum target, GLenum attachment, GLuint texture, GLint level);
GLAPI void APIENTRY glFreeObjectBufferATI(GLuint buffer);
GLAPI void APIENTRY glFrontFace(GLenum mode);
GLAPI void APIENTRY glFrustum(GLdouble left, GLdouble right, GLdouble bottom, GLdouble top, GLdouble zNear, GLdouble zFar);
GLAPI void APIENTRY glFrustumf(GLfloat l, GLfloat r, GLfloat b, GLfloat t, GLfloat n, GLfloat f);
GLAPI void APIENTRY glFrustumfOES(GLfloat l, GLfloat r, GLfloat b, GLfloat t, GLfloat n, GLfloat f);
GLAPI void APIENTRY glFrustumx(GLfixed l, GLfixed r, GLfixed b, GLfixed t, GLfixed n, GLfixed f);
GLAPI void APIENTRY glFrustumxOES(GLfixed l, GLfixed r, GLfixed b, GLfixed t, GLfixed n, GLfixed f);
GLAPI GLuint APIENTRY glGenAsyncMarkersSGIX(GLsizei range);
GLAPI void APIENTRY glGenBuffers(GLsizei n, GLuint *buffers);
GLAPI void APIENTRY glGenBuffersARB(GLsizei n, GLuint *buffers);
GLAPI void APIENTRY glGenFencesAPPLE(GLsizei n, GLuint *fences);
GLAPI void APIENTRY glGenFencesNV(GLsizei n, GLuint *fences);
GLAPI GLuint APIENTRY glGenFragmentShadersATI(GLuint range);
GLAPI void APIENTRY glGenFramebuffers(GLsizei n, GLuint *framebuffers);
GLAPI void APIENTRY glGenFramebuffersEXT(GLsizei n, GLuint *framebuffers);
GLAPI void APIENTRY glGenFramebuffersOES(GLsizei n, GLuint *framebuffers);
GLAPI GLuint APIENTRY glGenLists(GLsizei range);
GLAPI void APIENTRY glGenNamesAMD(GLenum identifier, GLuint num, GLuint *names);
GLAPI void APIENTRY glGenOcclusionQueriesNV(GLsizei n, GLuint *ids);
GLAPI GLuint APIENTRY glGenPathsNV(GLsizei range);
GLAPI void APIENTRY glGenPerfMonitorsAMD(GLsizei n, GLuint *monitors);
GLAPI void APIENTRY glGenProgramPipelines(GLsizei n, GLuint *pipelines);
GLAPI void APIENTRY glGenProgramPipelinesEXT(GLsizei n, GLuint *pipelines);
GLAPI void APIENTRY glGenProgramsARB(GLsizei n, GLuint *programs);
GLAPI void APIENTRY glGenProgramsNV(GLsizei n, GLuint *programs);
GLAPI void APIENTRY glGenQueries(GLsizei n, GLuint *ids);
GLAPI void APIENTRY glGenQueriesARB(GLsizei n, GLuint *ids);
GLAPI void APIENTRY glGenQueriesEXT(GLsizei n, GLuint *ids);
GLAPI void APIENTRY glGenQueryResourceTagNV(GLsizei n, GLint *tagIds);
GLAPI void APIENTRY glGenRenderbuffers(GLsizei n, GLuint *renderbuffers);
GLAPI void APIENTRY glGenRenderbuffersEXT(GLsizei n, GLuint *renderbuffers);
GLAPI void APIENTRY glGenRenderbuffersOES(GLsizei n, GLuint *renderbuffers);
GLAPI void APIENTRY glGenSamplers(GLsizei count, GLuint *samplers);
GLAPI void APIENTRY glGenSemaphoresEXT(GLsizei n, GLuint *semaphores);
GLAPI GLuint APIENTRY glGenSymbolsEXT(GLenum datatype, GLenum storagetype, GLenum range, GLuint components);
GLAPI void APIENTRY glGenTextures(GLsizei n, GLuint *textures);
GLAPI void APIENTRY glGenTexturesEXT(GLsizei n, GLuint *textures);
GLAPI void APIENTRY glGenTransformFeedbacks(GLsizei n, GLuint *ids);
GLAPI void APIENTRY glGenTransformFeedbacksEXT(GLsizei n, GLuint *ids);
GLAPI void APIENTRY glGenTransformFeedbacksNV(GLsizei n, GLuint *ids);
GLAPI void APIENTRY glGenVertexArrays(GLsizei n, GLuint *arrays);
GLAPI void APIENTRY glGenVertexArraysAPPLE(GLsizei n, GLuint *arrays);
GLAPI void APIENTRY glGenVertexArraysOES(GLsizei n, GLuint *arrays);
GLAPI GLuint APIENTRY glGenVertexShadersEXT(GLuint range);
GLAPI void APIENTRY glGenerateMipmap(GLenum target);
GLAPI void APIENTRY glGenerateMipmapEXT(GLenum target);
GLAPI void APIENTRY glGenerateMipmapOES(GLenum target);
GLAPI void APIENTRY glGenerateMultiTexMipmapEXT(GLenum texunit, GLenum target);
GLAPI void APIENTRY glGenerateTextureMipmap(GLuint texture);
GLAPI void APIENTRY glGenerateTextureMipmapEXT(GLuint texture, GLenum target);
GLAPI void APIENTRY glGetActiveAtomicCounterBufferiv(GLuint program, GLuint bufferIndex, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetActiveAttrib(GLuint program, GLuint index, GLsizei bufSize, GLsizei *length, GLint *size, GLenum *type, GLchar *name);
GLAPI void APIENTRY glGetActiveAttribARB(GLhandleARB programObj, GLuint index, GLsizei maxLength, GLsizei *length, GLint *size, GLenum *type, GLcharARB *name);
GLAPI void APIENTRY glGetActiveSubroutineName(GLuint program, GLenum shadertype, GLuint index, GLsizei bufSize, GLsizei *length, GLchar *name);
GLAPI void APIENTRY glGetActiveSubroutineUniformName(GLuint program, GLenum shadertype, GLuint index, GLsizei bufSize, GLsizei *length, GLchar *name);
GLAPI void APIENTRY glGetActiveSubroutineUniformiv(GLuint program, GLenum shadertype, GLuint index, GLenum pname, GLint *values);
GLAPI void APIENTRY glGetActiveUniform(GLuint program, GLuint index, GLsizei bufSize, GLsizei *length, GLint *size, GLenum *type, GLchar *name);
GLAPI void APIENTRY glGetActiveUniformARB(GLhandleARB programObj, GLuint index, GLsizei maxLength, GLsizei *length, GLint *size, GLenum *type, GLcharARB *name);
GLAPI void APIENTRY glGetActiveUniformBlockName(GLuint program, GLuint uniformBlockIndex, GLsizei bufSize, GLsizei *length, GLchar *uniformBlockName);
GLAPI void APIENTRY glGetActiveUniformBlockiv(GLuint program, GLuint uniformBlockIndex, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetActiveUniformName(GLuint program, GLuint uniformIndex, GLsizei bufSize, GLsizei *length, GLchar *uniformName);
GLAPI void APIENTRY glGetActiveUniformsiv(GLuint program, GLsizei uniformCount, const GLuint *uniformIndices, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetActiveVaryingNV(GLuint program, GLuint index, GLsizei bufSize, GLsizei *length, GLsizei *size, GLenum *type, GLchar *name);
GLAPI void APIENTRY glGetArrayObjectfvATI(GLenum array, GLenum pname, GLfloat *params);
GLAPI void APIENTRY glGetArrayObjectivATI(GLenum array, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetAttachedObjectsARB(GLhandleARB containerObj, GLsizei maxCount, GLsizei *count, GLhandleARB *obj);
GLAPI void APIENTRY glGetAttachedShaders(GLuint program, GLsizei maxCount, GLsizei *count, GLuint *shaders);
GLAPI GLint APIENTRY glGetAttribLocation(GLuint program, const GLchar *name);
GLAPI GLint APIENTRY glGetAttribLocationARB(GLhandleARB programObj, const GLcharARB *name);
GLAPI void APIENTRY glGetBooleanIndexedvEXT(GLenum target, GLuint index, GLboolean *data);
GLAPI void APIENTRY glGetBooleani_v(GLenum target, GLuint index, GLboolean *data);
GLAPI void APIENTRY glGetBooleanv(GLenum pname, GLboolean *data);
GLAPI void APIENTRY glGetBufferParameteri64v(GLenum target, GLenum pname, GLint64 *params);
GLAPI void APIENTRY glGetBufferParameteriv(GLenum target, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetBufferParameterivARB(GLenum target, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetBufferParameterui64vNV(GLenum target, GLenum pname, GLuint64 *params);
GLAPI void APIENTRY glGetBufferPointerv(GLenum target, GLenum pname, void **params);
GLAPI void APIENTRY glGetBufferPointervARB(GLenum target, GLenum pname, void **params);
GLAPI void APIENTRY glGetBufferPointervOES(GLenum target, GLenum pname, void **params);
GLAPI void APIENTRY glGetBufferSubData(GLenum target, GLintptr offset, GLsizeiptr size, void *data);
GLAPI void APIENTRY glGetBufferSubDataARB(GLenum target, GLintptr offset, GLsizeiptr size, void *data);
GLAPI void APIENTRY glGetClipPlane(GLenum plane, GLdouble *equation);
GLAPI void APIENTRY glGetClipPlanef(GLenum plane, GLfloat *equation);
GLAPI void APIENTRY glGetClipPlanefOES(GLenum plane, GLfloat *equation);
GLAPI void APIENTRY glGetClipPlanex(GLenum plane, GLfixed *equation);
GLAPI void APIENTRY glGetClipPlanexOES(GLenum plane, GLfixed *equation);
GLAPI void APIENTRY glGetColorTable(GLenum target, GLenum format, GLenum type, void *table);
GLAPI void APIENTRY glGetColorTableEXT(GLenum target, GLenum format, GLenum type, void *data);
GLAPI void APIENTRY glGetColorTableParameterfv(GLenum target, GLenum pname, GLfloat *params);
GLAPI void APIENTRY glGetColorTableParameterfvEXT(GLenum target, GLenum pname, GLfloat *params);
GLAPI void APIENTRY glGetColorTableParameterfvSGI(GLenum target, GLenum pname, GLfloat *params);
GLAPI void APIENTRY glGetColorTableParameteriv(GLenum target, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetColorTableParameterivEXT(GLenum target, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetColorTableParameterivSGI(GLenum target, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetColorTableSGI(GLenum target, GLenum format, GLenum type, void *table);
GLAPI void APIENTRY glGetCombinerInputParameterfvNV(GLenum stage, GLenum portion, GLenum variable, GLenum pname, GLfloat *params);
GLAPI void APIENTRY glGetCombinerInputParameterivNV(GLenum stage, GLenum portion, GLenum variable, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetCombinerOutputParameterfvNV(GLenum stage, GLenum portion, GLenum pname, GLfloat *params);
GLAPI void APIENTRY glGetCombinerOutputParameterivNV(GLenum stage, GLenum portion, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetCombinerStageParameterfvNV(GLenum stage, GLenum pname, GLfloat *params);
GLAPI GLuint APIENTRY glGetCommandHeaderNV(GLenum tokenID, GLuint size);
GLAPI void APIENTRY glGetCompressedMultiTexImageEXT(GLenum texunit, GLenum target, GLint lod, void *img);
GLAPI void APIENTRY glGetCompressedTexImage(GLenum target, GLint level, void *img);
GLAPI void APIENTRY glGetCompressedTexImageARB(GLenum target, GLint level, void *img);
GLAPI void APIENTRY glGetCompressedTexImageNV(GLenum target, GLint lod, void *img);
GLAPI void APIENTRY glGetCompressedTextureImage(GLuint texture, GLint level, GLsizei bufSize, void *pixels);
GLAPI void APIENTRY glGetCompressedTextureImageEXT(GLuint texture, GLenum target, GLint lod, void *img);
GLAPI void APIENTRY glGetCompressedTextureSubImage(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLsizei bufSize, void *pixels);
GLAPI void APIENTRY glGetConvolutionFilter(GLenum target, GLenum format, GLenum type, void *image);
GLAPI void APIENTRY glGetConvolutionFilterEXT(GLenum target, GLenum format, GLenum type, void *image);
GLAPI void APIENTRY glGetConvolutionParameterfv(GLenum target, GLenum pname, GLfloat *params);
GLAPI void APIENTRY glGetConvolutionParameterfvEXT(GLenum target, GLenum pname, GLfloat *params);
GLAPI void APIENTRY glGetConvolutionParameteriv(GLenum target, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetConvolutionParameterivEXT(GLenum target, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetConvolutionParameterxvOES(GLenum target, GLenum pname, GLfixed *params);
GLAPI void APIENTRY glGetCoverageModulationTableNV(GLsizei bufSize, GLfloat *v);
GLAPI GLuint APIENTRY glGetDebugMessageLog(GLuint count, GLsizei bufSize, GLenum *sources, GLenum *types, GLuint *ids, GLenum *severities, GLsizei *lengths, GLchar *messageLog);
GLAPI GLuint APIENTRY glGetDebugMessageLogAMD(GLuint count, GLsizei bufSize, GLenum *categories, GLenum *severities, GLuint *ids, GLsizei *lengths, GLchar *message);
GLAPI GLuint APIENTRY glGetDebugMessageLogARB(GLuint count, GLsizei bufSize, GLenum *sources, GLenum *types, GLuint *ids, GLenum *severities, GLsizei *lengths, GLchar *messageLog);
GLAPI GLuint APIENTRY glGetDebugMessageLogKHR(GLuint count, GLsizei bufSize, GLenum *sources, GLenum *types, GLuint *ids, GLenum *severities, GLsizei *lengths, GLchar *messageLog);
GLAPI GLuint APIENTRY glGetDebugMessageLogOES(GLuint count, GLsizei bufsize, GLenum *sources, GLenum *types, GLuint *ids, GLenum *severities, GLsizei *lengths, GLchar *messageLog);
GLAPI void APIENTRY glGetDetailTexFuncSGIS(GLenum target, GLfloat *points);
GLAPI void APIENTRY glGetDoubleIndexedvEXT(GLenum target, GLuint index, GLdouble *data);
GLAPI void APIENTRY glGetDoublei_v(GLenum target, GLuint index, GLdouble *data);
GLAPI void APIENTRY glGetDoublei_vEXT(GLenum pname, GLuint index, GLdouble *params);
GLAPI void APIENTRY glGetDoublev(GLenum pname, GLdouble *data);
GLAPI void APIENTRY glGetDriverControlStringQCOM(GLuint driverControl, GLsizei bufSize, GLsizei *length, GLchar *driverControlString);
GLAPI void APIENTRY glGetDriverControlsQCOM(GLint *num, GLsizei size, GLuint *driverControls);
GLAPI GLenum APIENTRY glGetError(void);
GLAPI void APIENTRY glGetFenceivNV(GLuint fence, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetFinalCombinerInputParameterfvNV(GLenum variable, GLenum pname, GLfloat *params);
GLAPI void APIENTRY glGetFinalCombinerInputParameterivNV(GLenum variable, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetFirstPerfQueryIdINTEL(GLuint *queryId);
GLAPI void APIENTRY glGetFixedv(GLenum pname, GLfixed *params);
GLAPI void APIENTRY glGetFixedvOES(GLenum pname, GLfixed *params);
GLAPI void APIENTRY glGetFloatIndexedvEXT(GLenum target, GLuint index, GLfloat *data);
GLAPI void APIENTRY glGetFloati_v(GLenum target, GLuint index, GLfloat *data);
GLAPI void APIENTRY glGetFloati_vEXT(GLenum pname, GLuint index, GLfloat *params);
GLAPI void APIENTRY glGetFloati_vNV(GLenum target, GLuint index, GLfloat *data);
GLAPI void APIENTRY glGetFloati_vOES(GLenum target, GLuint index, GLfloat *data);
GLAPI void APIENTRY glGetFloatv(GLenum pname, GLfloat *data);
GLAPI void APIENTRY glGetFogFuncSGIS(GLfloat *points);
GLAPI GLint APIENTRY glGetFragDataIndex(GLuint program, const GLchar *name);
GLAPI GLint APIENTRY glGetFragDataIndexEXT(GLuint program, const GLchar *name);
GLAPI GLint APIENTRY glGetFragDataLocation(GLuint program, const GLchar *name);
GLAPI GLint APIENTRY glGetFragDataLocationEXT(GLuint program, const GLchar *name);
GLAPI void APIENTRY glGetFragmentLightfvSGIX(GLenum light, GLenum pname, GLfloat *params);
GLAPI void APIENTRY glGetFragmentLightivSGIX(GLenum light, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetFragmentMaterialfvSGIX(GLenum face, GLenum pname, GLfloat *params);
GLAPI void APIENTRY glGetFragmentMaterialivSGIX(GLenum face, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetFramebufferAttachmentParameteriv(GLenum target, GLenum attachment, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetFramebufferAttachmentParameterivEXT(GLenum target, GLenum attachment, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetFramebufferAttachmentParameterivOES(GLenum target, GLenum attachment, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetFramebufferParameterfvAMD(GLenum target, GLenum pname, GLuint numsamples, GLuint pixelindex, GLsizei size, GLfloat *values);
GLAPI void APIENTRY glGetFramebufferParameteriv(GLenum target, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetFramebufferParameterivEXT(GLuint framebuffer, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetFramebufferParameterivMESA(GLenum target, GLenum pname, GLint *params);
GLAPI GLsizei APIENTRY glGetFramebufferPixelLocalStorageSizeEXT(GLuint target);
GLAPI GLenum APIENTRY glGetGraphicsResetStatus(void);
GLAPI GLenum APIENTRY glGetGraphicsResetStatusARB(void);
GLAPI GLenum APIENTRY glGetGraphicsResetStatusEXT(void);
GLAPI GLenum APIENTRY glGetGraphicsResetStatusKHR(void);
GLAPI GLhandleARB APIENTRY glGetHandleARB(GLenum pname);
GLAPI void APIENTRY glGetHistogram(GLenum target, GLboolean reset, GLenum format, GLenum type, void *values);
GLAPI void APIENTRY glGetHistogramEXT(GLenum target, GLboolean reset, GLenum format, GLenum type, void *values);
GLAPI void APIENTRY glGetHistogramParameterfv(GLenum target, GLenum pname, GLfloat *params);
GLAPI void APIENTRY glGetHistogramParameterfvEXT(GLenum target, GLenum pname, GLfloat *params);
GLAPI void APIENTRY glGetHistogramParameteriv(GLenum target, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetHistogramParameterivEXT(GLenum target, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetHistogramParameterxvOES(GLenum target, GLenum pname, GLfixed *params);
GLAPI GLuint64 APIENTRY glGetImageHandleARB(GLuint texture, GLint level, GLboolean layered, GLint layer, GLenum format);
GLAPI GLuint64 APIENTRY glGetImageHandleNV(GLuint texture, GLint level, GLboolean layered, GLint layer, GLenum format);
GLAPI void APIENTRY glGetImageTransformParameterfvHP(GLenum target, GLenum pname, GLfloat *params);
GLAPI void APIENTRY glGetImageTransformParameterivHP(GLenum target, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetInfoLogARB(GLhandleARB obj, GLsizei maxLength, GLsizei *length, GLcharARB *infoLog);
GLAPI GLint APIENTRY glGetInstrumentsSGIX(void);
GLAPI void APIENTRY glGetInteger64i_v(GLenum target, GLuint index, GLint64 *data);
GLAPI void APIENTRY glGetInteger64v(GLenum pname, GLint64 *data);
GLAPI void APIENTRY glGetInteger64vAPPLE(GLenum pname, GLint64 *params);
GLAPI void APIENTRY glGetIntegerIndexedvEXT(GLenum target, GLuint index, GLint *data);
GLAPI void APIENTRY glGetIntegeri_v(GLenum target, GLuint index, GLint *data);
GLAPI void APIENTRY glGetIntegeri_vEXT(GLenum target, GLuint index, GLint *data);
GLAPI void APIENTRY glGetIntegerui64i_vNV(GLenum value, GLuint index, GLuint64 *result);
GLAPI void APIENTRY glGetIntegerui64vNV(GLenum value, GLuint64 *result);
GLAPI void APIENTRY glGetIntegerv(GLenum pname, GLint *data);
GLAPI void APIENTRY glGetInternalformatSampleivNV(GLenum target, GLenum internalformat, GLsizei samples, GLenum pname, GLsizei count, GLint *params);
GLAPI void APIENTRY glGetInternalformati64v(GLenum target, GLenum internalformat, GLenum pname, GLsizei count, GLint64 *params);
GLAPI void APIENTRY glGetInternalformativ(GLenum target, GLenum internalformat, GLenum pname, GLsizei count, GLint *params);
GLAPI void APIENTRY glGetInvariantBooleanvEXT(GLuint id, GLenum value, GLboolean *data);
GLAPI void APIENTRY glGetInvariantFloatvEXT(GLuint id, GLenum value, GLfloat *data);
GLAPI void APIENTRY glGetInvariantIntegervEXT(GLuint id, GLenum value, GLint *data);
GLAPI void APIENTRY glGetLightfv(GLenum light, GLenum pname, GLfloat *params);
GLAPI void APIENTRY glGetLightiv(GLenum light, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetLightxOES(GLenum light, GLenum pname, GLfixed *params);
GLAPI void APIENTRY glGetLightxv(GLenum light, GLenum pname, GLfixed *params);
GLAPI void APIENTRY glGetLightxvOES(GLenum light, GLenum pname, GLfixed *params);
GLAPI void APIENTRY glGetListParameterfvSGIX(GLuint list, GLenum pname, GLfloat *params);
GLAPI void APIENTRY glGetListParameterivSGIX(GLuint list, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetLocalConstantBooleanvEXT(GLuint id, GLenum value, GLboolean *data);
GLAPI void APIENTRY glGetLocalConstantFloatvEXT(GLuint id, GLenum value, GLfloat *data);
GLAPI void APIENTRY glGetLocalConstantIntegervEXT(GLuint id, GLenum value, GLint *data);
GLAPI void APIENTRY glGetMapAttribParameterfvNV(GLenum target, GLuint index, GLenum pname, GLfloat *params);
GLAPI void APIENTRY glGetMapAttribParameterivNV(GLenum target, GLuint index, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetMapControlPointsNV(GLenum target, GLuint index, GLenum type, GLsizei ustride, GLsizei vstride, GLboolean packed, void *points);
GLAPI void APIENTRY glGetMapParameterfvNV(GLenum target, GLenum pname, GLfloat *params);
GLAPI void APIENTRY glGetMapParameterivNV(GLenum target, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetMapdv(GLenum target, GLenum query, GLdouble *v);
GLAPI void APIENTRY glGetMapfv(GLenum target, GLenum query, GLfloat *v);
GLAPI void APIENTRY glGetMapiv(GLenum target, GLenum query, GLint *v);
GLAPI void APIENTRY glGetMapxvOES(GLenum target, GLenum query, GLfixed *v);
GLAPI void APIENTRY glGetMaterialfv(GLenum face, GLenum pname, GLfloat *params);
GLAPI void APIENTRY glGetMaterialiv(GLenum face, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetMaterialxOES(GLenum face, GLenum pname, GLfixed param);
GLAPI void APIENTRY glGetMaterialxv(GLenum face, GLenum pname, GLfixed *params);
GLAPI void APIENTRY glGetMaterialxvOES(GLenum face, GLenum pname, GLfixed *params);
GLAPI void APIENTRY glGetMemoryObjectDetachedResourcesuivNV(GLuint memory, GLenum pname, GLint first, GLsizei count, GLuint *params);
GLAPI void APIENTRY glGetMemoryObjectParameterivEXT(GLuint memoryObject, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetMinmax(GLenum target, GLboolean reset, GLenum format, GLenum type, void *values);
GLAPI void APIENTRY glGetMinmaxEXT(GLenum target, GLboolean reset, GLenum format, GLenum type, void *values);
GLAPI void APIENTRY glGetMinmaxParameterfv(GLenum target, GLenum pname, GLfloat *params);
GLAPI void APIENTRY glGetMinmaxParameterfvEXT(GLenum target, GLenum pname, GLfloat *params);
GLAPI void APIENTRY glGetMinmaxParameteriv(GLenum target, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetMinmaxParameterivEXT(GLenum target, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetMultiTexEnvfvEXT(GLenum texunit, GLenum target, GLenum pname, GLfloat *params);
GLAPI void APIENTRY glGetMultiTexEnvivEXT(GLenum texunit, GLenum target, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetMultiTexGendvEXT(GLenum texunit, GLenum coord, GLenum pname, GLdouble *params);
GLAPI void APIENTRY glGetMultiTexGenfvEXT(GLenum texunit, GLenum coord, GLenum pname, GLfloat *params);
GLAPI void APIENTRY glGetMultiTexGenivEXT(GLenum texunit, GLenum coord, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetMultiTexImageEXT(GLenum texunit, GLenum target, GLint level, GLenum format, GLenum type, void *pixels);
GLAPI void APIENTRY glGetMultiTexLevelParameterfvEXT(GLenum texunit, GLenum target, GLint level, GLenum pname, GLfloat *params);
GLAPI void APIENTRY glGetMultiTexLevelParameterivEXT(GLenum texunit, GLenum target, GLint level, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetMultiTexParameterIivEXT(GLenum texunit, GLenum target, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetMultiTexParameterIuivEXT(GLenum texunit, GLenum target, GLenum pname, GLuint *params);
GLAPI void APIENTRY glGetMultiTexParameterfvEXT(GLenum texunit, GLenum target, GLenum pname, GLfloat *params);
GLAPI void APIENTRY glGetMultiTexParameterivEXT(GLenum texunit, GLenum target, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetMultisamplefv(GLenum pname, GLuint index, GLfloat *val);
GLAPI void APIENTRY glGetMultisamplefvNV(GLenum pname, GLuint index, GLfloat *val);
GLAPI void APIENTRY glGetNamedBufferParameteri64v(GLuint buffer, GLenum pname, GLint64 *params);
GLAPI void APIENTRY glGetNamedBufferParameteri64vEXT(GLuint buffer, GLenum pname, GLint64 *params);
GLAPI void APIENTRY glGetNamedBufferParameteriv(GLuint buffer, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetNamedBufferParameterivEXT(GLuint buffer, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetNamedBufferParameterui64vNV(GLuint buffer, GLenum pname, GLuint64 *params);
GLAPI void APIENTRY glGetNamedBufferPointerv(GLuint buffer, GLenum pname, void **params);
GLAPI void APIENTRY glGetNamedBufferPointervEXT(GLuint buffer, GLenum pname, void **params);
GLAPI void APIENTRY glGetNamedBufferSubData(GLuint buffer, GLintptr offset, GLsizeiptr size, void *data);
GLAPI void APIENTRY glGetNamedBufferSubDataEXT(GLuint buffer, GLintptr offset, GLsizeiptr size, void *data);
GLAPI void APIENTRY glGetNamedFramebufferAttachmentParameteriv(GLuint framebuffer, GLenum attachment, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetNamedFramebufferAttachmentParameterivEXT(GLuint framebuffer, GLenum attachment, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetNamedFramebufferParameterfvAMD(GLuint framebuffer, GLenum pname, GLuint numsamples, GLuint pixelindex, GLsizei size, GLfloat *values);
GLAPI void APIENTRY glGetNamedFramebufferParameteriv(GLuint framebuffer, GLenum pname, GLint *param);
GLAPI void APIENTRY glGetNamedFramebufferParameterivEXT(GLuint framebuffer, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetNamedProgramLocalParameterIivEXT(GLuint program, GLenum target, GLuint index, GLint *params);
GLAPI void APIENTRY glGetNamedProgramLocalParameterIuivEXT(GLuint program, GLenum target, GLuint index, GLuint *params);
GLAPI void APIENTRY glGetNamedProgramLocalParameterdvEXT(GLuint program, GLenum target, GLuint index, GLdouble *params);
GLAPI void APIENTRY glGetNamedProgramLocalParameterfvEXT(GLuint program, GLenum target, GLuint index, GLfloat *params);
GLAPI void APIENTRY glGetNamedProgramStringEXT(GLuint program, GLenum target, GLenum pname, void *string);
GLAPI void APIENTRY glGetNamedProgramivEXT(GLuint program, GLenum target, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetNamedRenderbufferParameteriv(GLuint renderbuffer, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetNamedRenderbufferParameterivEXT(GLuint renderbuffer, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetNamedStringARB(GLint namelen, const GLchar *name, GLsizei bufSize, GLint *stringlen, GLchar *string);
GLAPI void APIENTRY glGetNamedStringivARB(GLint namelen, const GLchar *name, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetNextPerfQueryIdINTEL(GLuint queryId, GLuint *nextQueryId);
GLAPI void APIENTRY glGetObjectBufferfvATI(GLuint buffer, GLenum pname, GLfloat *params);
GLAPI void APIENTRY glGetObjectBufferivATI(GLuint buffer, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetObjectLabel(GLenum identifier, GLuint name, GLsizei bufSize, GLsizei *length, GLchar *label);
GLAPI void APIENTRY glGetObjectLabelEXT(GLenum type, GLuint object, GLsizei bufSize, GLsizei *length, GLchar *label);
GLAPI void APIENTRY glGetObjectLabelKHR(GLenum identifier, GLuint name, GLsizei bufSize, GLsizei *length, GLchar *label);
GLAPI void APIENTRY glGetObjectLabelOES(GLenum identifier, GLuint name, GLsizei bufSize, GLsizei *length, GLchar *label);
GLAPI void APIENTRY glGetObjectParameterfvARB(GLhandleARB obj, GLenum pname, GLfloat *params);
GLAPI void APIENTRY glGetObjectParameterivAPPLE(GLenum objectType, GLuint name, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetObjectParameterivARB(GLhandleARB obj, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetObjectPtrLabel(const void *ptr, GLsizei bufSize, GLsizei *length, GLchar *label);
GLAPI void APIENTRY glGetObjectPtrLabelKHR(const void *ptr, GLsizei bufSize, GLsizei *length, GLchar *label);
GLAPI void APIENTRY glGetObjectPtrLabelOES(void *ptr, GLsizei bufSize, GLsizei *length, GLchar *label);
GLAPI void APIENTRY glGetOcclusionQueryivNV(GLuint id, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetOcclusionQueryuivNV(GLuint id, GLenum pname, GLuint *params);
GLAPI void APIENTRY glGetPathColorGenfvNV(GLenum color, GLenum pname, GLfloat *value);
GLAPI void APIENTRY glGetPathColorGenivNV(GLenum color, GLenum pname, GLint *value);
GLAPI void APIENTRY glGetPathCommandsNV(GLuint path, GLubyte *commands);
GLAPI void APIENTRY glGetPathCoordsNV(GLuint path, GLfloat *coords);
GLAPI void APIENTRY glGetPathDashArrayNV(GLuint path, GLfloat *dashArray);
GLAPI GLfloat APIENTRY glGetPathLengthNV(GLuint path, GLsizei startSegment, GLsizei numSegments);
GLAPI void APIENTRY glGetPathMetricRangeNV(GLbitfield metricQueryMask, GLuint firstPathName, GLsizei numPaths, GLsizei stride, GLfloat *metrics);
GLAPI void APIENTRY glGetPathMetricsNV(GLbitfield metricQueryMask, GLsizei numPaths, GLenum pathNameType, const void *paths, GLuint pathBase, GLsizei stride, GLfloat *metrics);
GLAPI void APIENTRY glGetPathParameterfvNV(GLuint path, GLenum pname, GLfloat *value);
GLAPI void APIENTRY glGetPathParameterivNV(GLuint path, GLenum pname, GLint *value);
GLAPI void APIENTRY glGetPathSpacingNV(GLenum pathListMode, GLsizei numPaths, GLenum pathNameType, const void *paths, GLuint pathBase, GLfloat advanceScale, GLfloat kerningScale, GLenum transformType, GLfloat *returnedSpacing);
GLAPI void APIENTRY glGetPathTexGenfvNV(GLenum texCoordSet, GLenum pname, GLfloat *value);
GLAPI void APIENTRY glGetPathTexGenivNV(GLenum texCoordSet, GLenum pname, GLint *value);
GLAPI void APIENTRY glGetPerfCounterInfoINTEL(GLuint queryId, GLuint counterId, GLuint counterNameLength, GLchar *counterName, GLuint counterDescLength, GLchar *counterDesc, GLuint *counterOffset, GLuint *counterDataSize, GLuint *counterTypeEnum, GLuint *counterDataTypeEnum, GLuint64 *rawCounterMaxValue);
GLAPI void APIENTRY glGetPerfMonitorCounterDataAMD(GLuint monitor, GLenum pname, GLsizei dataSize, GLuint *data, GLint *bytesWritten);
GLAPI void APIENTRY glGetPerfMonitorCounterInfoAMD(GLuint group, GLuint counter, GLenum pname, void *data);
GLAPI void APIENTRY glGetPerfMonitorCounterStringAMD(GLuint group, GLuint counter, GLsizei bufSize, GLsizei *length, GLchar *counterString);
GLAPI void APIENTRY glGetPerfMonitorCountersAMD(GLuint group, GLint *numCounters, GLint *maxActiveCounters, GLsizei counterSize, GLuint *counters);
GLAPI void APIENTRY glGetPerfMonitorGroupStringAMD(GLuint group, GLsizei bufSize, GLsizei *length, GLchar *groupString);
GLAPI void APIENTRY glGetPerfMonitorGroupsAMD(GLint *numGroups, GLsizei groupsSize, GLuint *groups);
GLAPI void APIENTRY glGetPerfQueryDataINTEL(GLuint queryHandle, GLuint flags, GLsizei dataSize, void *data, GLuint *bytesWritten);
GLAPI void APIENTRY glGetPerfQueryIdByNameINTEL(GLchar *queryName, GLuint *queryId);
GLAPI void APIENTRY glGetPerfQueryInfoINTEL(GLuint queryId, GLuint queryNameLength, GLchar *queryName, GLuint *dataSize, GLuint *noCounters, GLuint *noInstances, GLuint *capsMask);
GLAPI void APIENTRY glGetPixelMapfv(GLenum map, GLfloat *values);
GLAPI void APIENTRY glGetPixelMapuiv(GLenum map, GLuint *values);
GLAPI void APIENTRY glGetPixelMapusv(GLenum map, GLushort *values);
GLAPI void APIENTRY glGetPixelMapxv(GLenum map, GLint size, GLfixed *values);
GLAPI void APIENTRY glGetPixelTexGenParameterfvSGIS(GLenum pname, GLfloat *params);
GLAPI void APIENTRY glGetPixelTexGenParameterivSGIS(GLenum pname, GLint *params);
GLAPI void APIENTRY glGetPixelTransformParameterfvEXT(GLenum target, GLenum pname, GLfloat *params);
GLAPI void APIENTRY glGetPixelTransformParameterivEXT(GLenum target, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetPointerIndexedvEXT(GLenum target, GLuint index, void **data);
GLAPI void APIENTRY glGetPointeri_vEXT(GLenum pname, GLuint index, void **params);
GLAPI void APIENTRY glGetPointerv(GLenum pname, void **params);
GLAPI void APIENTRY glGetPointervEXT(GLenum pname, void **params);
GLAPI void APIENTRY glGetPointervKHR(GLenum pname, void **params);
GLAPI void APIENTRY glGetPointervOES(GLenum pname, void **params);
GLAPI void APIENTRY glGetPolygonStipple(GLubyte *mask);
GLAPI void APIENTRY glGetProgramBinary(GLuint program, GLsizei bufSize, GLsizei *length, GLenum *binaryFormat, void *binary);
GLAPI void APIENTRY glGetProgramBinaryOES(GLuint program, GLsizei bufSize, GLsizei *length, GLenum *binaryFormat, void *binary);
GLAPI void APIENTRY glGetProgramEnvParameterIivNV(GLenum target, GLuint index, GLint *params);
GLAPI void APIENTRY glGetProgramEnvParameterIuivNV(GLenum target, GLuint index, GLuint *params);
GLAPI void APIENTRY glGetProgramEnvParameterdvARB(GLenum target, GLuint index, GLdouble *params);
GLAPI void APIENTRY glGetProgramEnvParameterfvARB(GLenum target, GLuint index, GLfloat *params);
GLAPI void APIENTRY glGetProgramInfoLog(GLuint program, GLsizei bufSize, GLsizei *length, GLchar *infoLog);
GLAPI void APIENTRY glGetProgramInterfaceiv(GLuint program, GLenum programInterface, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetProgramLocalParameterIivNV(GLenum target, GLuint index, GLint *params);
GLAPI void APIENTRY glGetProgramLocalParameterIuivNV(GLenum target, GLuint index, GLuint *params);
GLAPI void APIENTRY glGetProgramLocalParameterdvARB(GLenum target, GLuint index, GLdouble *params);
GLAPI void APIENTRY glGetProgramLocalParameterfvARB(GLenum target, GLuint index, GLfloat *params);
GLAPI void APIENTRY glGetProgramNamedParameterdvNV(GLuint id, GLsizei len, const GLubyte *name, GLdouble *params);
GLAPI void APIENTRY glGetProgramNamedParameterfvNV(GLuint id, GLsizei len, const GLubyte *name, GLfloat *params);
GLAPI void APIENTRY glGetProgramParameterdvNV(GLenum target, GLuint index, GLenum pname, GLdouble *params);
GLAPI void APIENTRY glGetProgramParameterfvNV(GLenum target, GLuint index, GLenum pname, GLfloat *params);
GLAPI void APIENTRY glGetProgramPipelineInfoLog(GLuint pipeline, GLsizei bufSize, GLsizei *length, GLchar *infoLog);
GLAPI void APIENTRY glGetProgramPipelineInfoLogEXT(GLuint pipeline, GLsizei bufSize, GLsizei *length, GLchar *infoLog);
GLAPI void APIENTRY glGetProgramPipelineiv(GLuint pipeline, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetProgramPipelineivEXT(GLuint pipeline, GLenum pname, GLint *params);
GLAPI GLuint APIENTRY glGetProgramResourceIndex(GLuint program, GLenum programInterface, const GLchar *name);
GLAPI GLint APIENTRY glGetProgramResourceLocation(GLuint program, GLenum programInterface, const GLchar *name);
GLAPI GLint APIENTRY glGetProgramResourceLocationIndex(GLuint program, GLenum programInterface, const GLchar *name);
GLAPI GLint APIENTRY glGetProgramResourceLocationIndexEXT(GLuint program, GLenum programInterface, const GLchar *name);
GLAPI void APIENTRY glGetProgramResourceName(GLuint program, GLenum programInterface, GLuint index, GLsizei bufSize, GLsizei *length, GLchar *name);
GLAPI void APIENTRY glGetProgramResourcefvNV(GLuint program, GLenum programInterface, GLuint index, GLsizei propCount, const GLenum *props, GLsizei count, GLsizei *length, GLfloat *params);
GLAPI void APIENTRY glGetProgramResourceiv(GLuint program, GLenum programInterface, GLuint index, GLsizei propCount, const GLenum *props, GLsizei count, GLsizei *length, GLint *params);
GLAPI void APIENTRY glGetProgramStageiv(GLuint program, GLenum shadertype, GLenum pname, GLint *values);
GLAPI void APIENTRY glGetProgramStringARB(GLenum target, GLenum pname, void *string);
GLAPI void APIENTRY glGetProgramStringNV(GLuint id, GLenum pname, GLubyte *program);
GLAPI void APIENTRY glGetProgramSubroutineParameteruivNV(GLenum target, GLuint index, GLuint *param);
GLAPI void APIENTRY glGetProgramiv(GLuint program, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetProgramivARB(GLenum target, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetProgramivNV(GLuint id, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetQueryBufferObjecti64v(GLuint id, GLuint buffer, GLenum pname, GLintptr offset);
GLAPI void APIENTRY glGetQueryBufferObjectiv(GLuint id, GLuint buffer, GLenum pname, GLintptr offset);
GLAPI void APIENTRY glGetQueryBufferObjectui64v(GLuint id, GLuint buffer, GLenum pname, GLintptr offset);
GLAPI void APIENTRY glGetQueryBufferObjectuiv(GLuint id, GLuint buffer, GLenum pname, GLintptr offset);
GLAPI void APIENTRY glGetQueryIndexediv(GLenum target, GLuint index, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetQueryObjecti64v(GLuint id, GLenum pname, GLint64 *params);
GLAPI void APIENTRY glGetQueryObjecti64vEXT(GLuint id, GLenum pname, GLint64 *params);
GLAPI void APIENTRY glGetQueryObjectiv(GLuint id, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetQueryObjectivARB(GLuint id, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetQueryObjectivEXT(GLuint id, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetQueryObjectui64v(GLuint id, GLenum pname, GLuint64 *params);
GLAPI void APIENTRY glGetQueryObjectui64vEXT(GLuint id, GLenum pname, GLuint64 *params);
GLAPI void APIENTRY glGetQueryObjectui64vNV(GLuint id, GLenum pname, GLuint64 *params);
GLAPI void APIENTRY glGetQueryObjectuiv(GLuint id, GLenum pname, GLuint *params);
GLAPI void APIENTRY glGetQueryObjectuivARB(GLuint id, GLenum pname, GLuint *params);
GLAPI void APIENTRY glGetQueryObjectuivEXT(GLuint id, GLenum pname, GLuint *params);
GLAPI void APIENTRY glGetQueryiv(GLenum target, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetQueryivARB(GLenum target, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetQueryivEXT(GLenum target, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetRenderbufferParameteriv(GLenum target, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetRenderbufferParameterivEXT(GLenum target, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetRenderbufferParameterivOES(GLenum target, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetSamplerParameterIiv(GLuint sampler, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetSamplerParameterIivEXT(GLuint sampler, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetSamplerParameterIivOES(GLuint sampler, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetSamplerParameterIuiv(GLuint sampler, GLenum pname, GLuint *params);
GLAPI void APIENTRY glGetSamplerParameterIuivEXT(GLuint sampler, GLenum pname, GLuint *params);
GLAPI void APIENTRY glGetSamplerParameterIuivOES(GLuint sampler, GLenum pname, GLuint *params);
GLAPI void APIENTRY glGetSamplerParameterfv(GLuint sampler, GLenum pname, GLfloat *params);
GLAPI void APIENTRY glGetSamplerParameteriv(GLuint sampler, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetSemaphoreParameterui64vEXT(GLuint semaphore, GLenum pname, GLuint64 *params);
GLAPI void APIENTRY glGetSeparableFilter(GLenum target, GLenum format, GLenum type, void *row, void *column, void *span);
GLAPI void APIENTRY glGetSeparableFilterEXT(GLenum target, GLenum format, GLenum type, void *row, void *column, void *span);
GLAPI void APIENTRY glGetShaderInfoLog(GLuint shader, GLsizei bufSize, GLsizei *length, GLchar *infoLog);
GLAPI void APIENTRY glGetShaderPrecisionFormat(GLenum shadertype, GLenum precisiontype, GLint *range, GLint *precision);
GLAPI void APIENTRY glGetShaderSource(GLuint shader, GLsizei bufSize, GLsizei *length, GLchar *source);
GLAPI void APIENTRY glGetShaderSourceARB(GLhandleARB obj, GLsizei maxLength, GLsizei *length, GLcharARB *source);
GLAPI void APIENTRY glGetShaderiv(GLuint shader, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetShadingRateImagePaletteNV(GLuint viewport, GLuint entry, GLenum *rate);
GLAPI void APIENTRY glGetShadingRateSampleLocationivNV(GLenum rate, GLuint samples, GLuint index, GLint *location);
GLAPI void APIENTRY glGetSharpenTexFuncSGIS(GLenum target, GLfloat *points);
GLAPI GLushort APIENTRY glGetStageIndexNV(GLenum shadertype);
GLAPI const GLubyte * APIENTRY glGetString(GLenum name);
GLAPI const GLubyte * APIENTRY glGetStringi(GLenum name, GLuint index);
GLAPI GLuint APIENTRY glGetSubroutineIndex(GLuint program, GLenum shadertype, const GLchar *name);
GLAPI GLint APIENTRY glGetSubroutineUniformLocation(GLuint program, GLenum shadertype, const GLchar *name);
GLAPI void APIENTRY glGetSynciv(GLsync sync, GLenum pname, GLsizei count, GLsizei *length, GLint *values);
GLAPI void APIENTRY glGetSyncivAPPLE(GLsync sync, GLenum pname, GLsizei count, GLsizei *length, GLint *values);
GLAPI void APIENTRY glGetSyncv64NVX(GLsync sync, GLenum pname, GLuint64 *value);
GLAPI void APIENTRY glGetTexBumpParameterfvATI(GLenum pname, GLfloat *param);
GLAPI void APIENTRY glGetTexBumpParameterivATI(GLenum pname, GLint *param);
GLAPI void APIENTRY glGetTexEnvfv(GLenum target, GLenum pname, GLfloat *params);
GLAPI void APIENTRY glGetTexEnviv(GLenum target, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetTexEnvxv(GLenum target, GLenum pname, GLfixed *params);
GLAPI void APIENTRY glGetTexEnvxvOES(GLenum target, GLenum pname, GLfixed *params);
GLAPI void APIENTRY glGetTexFilterFuncSGIS(GLenum target, GLenum filter, GLfloat *weights);
GLAPI void APIENTRY glGetTexGendv(GLenum coord, GLenum pname, GLdouble *params);
GLAPI void APIENTRY glGetTexGenfv(GLenum coord, GLenum pname, GLfloat *params);
GLAPI void APIENTRY glGetTexGenfvOES(GLenum coord, GLenum pname, GLfloat *params);
GLAPI void APIENTRY glGetTexGeniv(GLenum coord, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetTexGenivOES(GLenum coord, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetTexGenxvOES(GLenum coord, GLenum pname, GLfixed *params);
GLAPI void APIENTRY glGetTexImage(GLenum target, GLint level, GLenum format, GLenum type, void *pixels);
GLAPI void APIENTRY glGetTexImageNV(GLenum target, GLint level, GLenum format, GLenum type, void *pixels);
GLAPI void APIENTRY glGetTexLevelParameterfv(GLenum target, GLint level, GLenum pname, GLfloat *params);
GLAPI void APIENTRY glGetTexLevelParameterfvNV(GLenum target, GLint level, GLenum pname, GLfloat *params);
GLAPI void APIENTRY glGetTexLevelParameteriv(GLenum target, GLint level, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetTexLevelParameterivNV(GLenum target, GLint level, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetTexLevelParameterxvOES(GLenum target, GLint level, GLenum pname, GLfixed *params);
GLAPI void APIENTRY glGetTexParameterIiv(GLenum target, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetTexParameterIivEXT(GLenum target, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetTexParameterIivOES(GLenum target, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetTexParameterIuiv(GLenum target, GLenum pname, GLuint *params);
GLAPI void APIENTRY glGetTexParameterIuivEXT(GLenum target, GLenum pname, GLuint *params);
GLAPI void APIENTRY glGetTexParameterIuivOES(GLenum target, GLenum pname, GLuint *params);
GLAPI void APIENTRY glGetTexParameterPointervAPPLE(GLenum target, GLenum pname, void **params);
GLAPI void APIENTRY glGetTexParameterfv(GLenum target, GLenum pname, GLfloat *params);
GLAPI void APIENTRY glGetTexParameteriv(GLenum target, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetTexParameterxv(GLenum target, GLenum pname, GLfixed *params);
GLAPI void APIENTRY glGetTexParameterxvOES(GLenum target, GLenum pname, GLfixed *params);
GLAPI GLuint64 APIENTRY glGetTextureHandleARB(GLuint texture);
GLAPI GLuint64 APIENTRY glGetTextureHandleIMG(GLuint texture);
GLAPI GLuint64 APIENTRY glGetTextureHandleNV(GLuint texture);
GLAPI void APIENTRY glGetTextureImage(GLuint texture, GLint level, GLenum format, GLenum type, GLsizei bufSize, void *pixels);
GLAPI void APIENTRY glGetTextureImageEXT(GLuint texture, GLenum target, GLint level, GLenum format, GLenum type, void *pixels);
GLAPI void APIENTRY glGetTextureLevelParameterfv(GLuint texture, GLint level, GLenum pname, GLfloat *params);
GLAPI void APIENTRY glGetTextureLevelParameterfvEXT(GLuint texture, GLenum target, GLint level, GLenum pname, GLfloat *params);
GLAPI void APIENTRY glGetTextureLevelParameteriv(GLuint texture, GLint level, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetTextureLevelParameterivEXT(GLuint texture, GLenum target, GLint level, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetTextureParameterIiv(GLuint texture, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetTextureParameterIivEXT(GLuint texture, GLenum target, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetTextureParameterIuiv(GLuint texture, GLenum pname, GLuint *params);
GLAPI void APIENTRY glGetTextureParameterIuivEXT(GLuint texture, GLenum target, GLenum pname, GLuint *params);
GLAPI void APIENTRY glGetTextureParameterfv(GLuint texture, GLenum pname, GLfloat *params);
GLAPI void APIENTRY glGetTextureParameterfvEXT(GLuint texture, GLenum target, GLenum pname, GLfloat *params);
GLAPI void APIENTRY glGetTextureParameteriv(GLuint texture, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetTextureParameterivEXT(GLuint texture, GLenum target, GLenum pname, GLint *params);
GLAPI GLuint64 APIENTRY glGetTextureSamplerHandleARB(GLuint texture, GLuint sampler);
GLAPI GLuint64 APIENTRY glGetTextureSamplerHandleIMG(GLuint texture, GLuint sampler);
GLAPI GLuint64 APIENTRY glGetTextureSamplerHandleNV(GLuint texture, GLuint sampler);
GLAPI void APIENTRY glGetTextureSubImage(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, GLsizei bufSize, void *pixels);
GLAPI void APIENTRY glGetTrackMatrixivNV(GLenum target, GLuint address, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetTransformFeedbackVarying(GLuint program, GLuint index, GLsizei bufSize, GLsizei *length, GLsizei *size, GLenum *type, GLchar *name);
GLAPI void APIENTRY glGetTransformFeedbackVaryingEXT(GLuint program, GLuint index, GLsizei bufSize, GLsizei *length, GLsizei *size, GLenum *type, GLchar *name);
GLAPI void APIENTRY glGetTransformFeedbackVaryingNV(GLuint program, GLuint index, GLint *location);
GLAPI void APIENTRY glGetTransformFeedbacki64_v(GLuint xfb, GLenum pname, GLuint index, GLint64 *param);
GLAPI void APIENTRY glGetTransformFeedbacki_v(GLuint xfb, GLenum pname, GLuint index, GLint *param);
GLAPI void APIENTRY glGetTransformFeedbackiv(GLuint xfb, GLenum pname, GLint *param);
GLAPI void APIENTRY glGetTranslatedShaderSourceANGLE(GLuint shader, GLsizei bufSize, GLsizei *length, GLchar *source);
GLAPI GLuint APIENTRY glGetUniformBlockIndex(GLuint program, const GLchar *uniformBlockName);
GLAPI GLint APIENTRY glGetUniformBufferSizeEXT(GLuint program, GLint location);
GLAPI void APIENTRY glGetUniformIndices(GLuint program, GLsizei uniformCount, const GLchar *const *uniformNames, GLuint *uniformIndices);
GLAPI GLint APIENTRY glGetUniformLocation(GLuint program, const GLchar *name);
GLAPI GLint APIENTRY glGetUniformLocationARB(GLhandleARB programObj, const GLcharARB *name);
GLAPI GLintptr APIENTRY glGetUniformOffsetEXT(GLuint program, GLint location);
GLAPI void APIENTRY glGetUniformSubroutineuiv(GLenum shadertype, GLint location, GLuint *params);
GLAPI void APIENTRY glGetUniformdv(GLuint program, GLint location, GLdouble *params);
GLAPI void APIENTRY glGetUniformfv(GLuint program, GLint location, GLfloat *params);
GLAPI void APIENTRY glGetUniformfvARB(GLhandleARB programObj, GLint location, GLfloat *params);
GLAPI void APIENTRY glGetUniformi64vARB(GLuint program, GLint location, GLint64 *params);
GLAPI void APIENTRY glGetUniformi64vNV(GLuint program, GLint location, GLint64 *params);
GLAPI void APIENTRY glGetUniformiv(GLuint program, GLint location, GLint *params);
GLAPI void APIENTRY glGetUniformivARB(GLhandleARB programObj, GLint location, GLint *params);
GLAPI void APIENTRY glGetUniformui64vARB(GLuint program, GLint location, GLuint64 *params);
GLAPI void APIENTRY glGetUniformui64vNV(GLuint program, GLint location, GLuint64 *params);
GLAPI void APIENTRY glGetUniformuiv(GLuint program, GLint location, GLuint *params);
GLAPI void APIENTRY glGetUniformuivEXT(GLuint program, GLint location, GLuint *params);
GLAPI void APIENTRY glGetUnsignedBytei_vEXT(GLenum target, GLuint index, GLubyte *data);
GLAPI void APIENTRY glGetUnsignedBytevEXT(GLenum pname, GLubyte *data);
GLAPI void APIENTRY glGetVariantArrayObjectfvATI(GLuint id, GLenum pname, GLfloat *params);
GLAPI void APIENTRY glGetVariantArrayObjectivATI(GLuint id, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetVariantBooleanvEXT(GLuint id, GLenum value, GLboolean *data);
GLAPI void APIENTRY glGetVariantFloatvEXT(GLuint id, GLenum value, GLfloat *data);
GLAPI void APIENTRY glGetVariantIntegervEXT(GLuint id, GLenum value, GLint *data);
GLAPI void APIENTRY glGetVariantPointervEXT(GLuint id, GLenum value, void **data);
GLAPI GLint APIENTRY glGetVaryingLocationNV(GLuint program, const GLchar *name);
GLAPI void APIENTRY glGetVertexArrayIndexed64iv(GLuint vaobj, GLuint index, GLenum pname, GLint64 *param);
GLAPI void APIENTRY glGetVertexArrayIndexediv(GLuint vaobj, GLuint index, GLenum pname, GLint *param);
GLAPI void APIENTRY glGetVertexArrayIntegeri_vEXT(GLuint vaobj, GLuint index, GLenum pname, GLint *param);
GLAPI void APIENTRY glGetVertexArrayIntegervEXT(GLuint vaobj, GLenum pname, GLint *param);
GLAPI void APIENTRY glGetVertexArrayPointeri_vEXT(GLuint vaobj, GLuint index, GLenum pname, void **param);
GLAPI void APIENTRY glGetVertexArrayPointervEXT(GLuint vaobj, GLenum pname, void **param);
GLAPI void APIENTRY glGetVertexArrayiv(GLuint vaobj, GLenum pname, GLint *param);
GLAPI void APIENTRY glGetVertexAttribArrayObjectfvATI(GLuint index, GLenum pname, GLfloat *params);
GLAPI void APIENTRY glGetVertexAttribArrayObjectivATI(GLuint index, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetVertexAttribIiv(GLuint index, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetVertexAttribIivEXT(GLuint index, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetVertexAttribIuiv(GLuint index, GLenum pname, GLuint *params);
GLAPI void APIENTRY glGetVertexAttribIuivEXT(GLuint index, GLenum pname, GLuint *params);
GLAPI void APIENTRY glGetVertexAttribLdv(GLuint index, GLenum pname, GLdouble *params);
GLAPI void APIENTRY glGetVertexAttribLdvEXT(GLuint index, GLenum pname, GLdouble *params);
GLAPI void APIENTRY glGetVertexAttribLi64vNV(GLuint index, GLenum pname, GLint64 *params);
GLAPI void APIENTRY glGetVertexAttribLui64vARB(GLuint index, GLenum pname, GLuint64 *params);
GLAPI void APIENTRY glGetVertexAttribLui64vNV(GLuint index, GLenum pname, GLuint64 *params);
GLAPI void APIENTRY glGetVertexAttribPointerv(GLuint index, GLenum pname, void **pointer);
GLAPI void APIENTRY glGetVertexAttribPointervARB(GLuint index, GLenum pname, void **pointer);
GLAPI void APIENTRY glGetVertexAttribPointervNV(GLuint index, GLenum pname, void **pointer);
GLAPI void APIENTRY glGetVertexAttribdv(GLuint index, GLenum pname, GLdouble *params);
GLAPI void APIENTRY glGetVertexAttribdvARB(GLuint index, GLenum pname, GLdouble *params);
GLAPI void APIENTRY glGetVertexAttribdvNV(GLuint index, GLenum pname, GLdouble *params);
GLAPI void APIENTRY glGetVertexAttribfv(GLuint index, GLenum pname, GLfloat *params);
GLAPI void APIENTRY glGetVertexAttribfvARB(GLuint index, GLenum pname, GLfloat *params);
GLAPI void APIENTRY glGetVertexAttribfvNV(GLuint index, GLenum pname, GLfloat *params);
GLAPI void APIENTRY glGetVertexAttribiv(GLuint index, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetVertexAttribivARB(GLuint index, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetVertexAttribivNV(GLuint index, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetVideoCaptureANCStreamivNVX(GLuint video_capture_slot, GLuint stream, GLenum pname, GLenum frame_region, GLenum anc_region, GLint *params);
GLAPI void APIENTRY glGetVideoCaptureStreamdvNV(GLuint video_capture_slot, GLuint stream, GLenum pname, GLdouble *params);
GLAPI void APIENTRY glGetVideoCaptureStreamfvNV(GLuint video_capture_slot, GLuint stream, GLenum pname, GLfloat *params);
GLAPI void APIENTRY glGetVideoCaptureStreamivNV(GLuint video_capture_slot, GLuint stream, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetVideoCaptureivNV(GLuint video_capture_slot, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetVideoi64vNV(GLuint video_slot, GLenum pname, GLint64 *params);
GLAPI void APIENTRY glGetVideoivNV(GLuint video_slot, GLenum pname, GLint *params);
GLAPI void APIENTRY glGetVideoui64vNV(GLuint video_slot, GLenum pname, GLuint64 *params);
GLAPI void APIENTRY glGetVideouivNV(GLuint video_slot, GLenum pname, GLuint *params);
GLAPI GLVULKANPROCNV APIENTRY glGetVkProcAddrNV(const GLchar *name);
GLAPI void APIENTRY glGetnColorTable(GLenum target, GLenum format, GLenum type, GLsizei bufSize, void *table);
GLAPI void APIENTRY glGetnColorTableARB(GLenum target, GLenum format, GLenum type, GLsizei bufSize, void *table);
GLAPI void APIENTRY glGetnCompressedTexImage(GLenum target, GLint lod, GLsizei bufSize, void *pixels);
GLAPI void APIENTRY glGetnCompressedTexImageARB(GLenum target, GLint lod, GLsizei bufSize, void *img);
GLAPI void APIENTRY glGetnConvolutionFilter(GLenum target, GLenum format, GLenum type, GLsizei bufSize, void *image);
GLAPI void APIENTRY glGetnConvolutionFilterARB(GLenum target, GLenum format, GLenum type, GLsizei bufSize, void *image);
GLAPI void APIENTRY glGetnHistogram(GLenum target, GLboolean reset, GLenum format, GLenum type, GLsizei bufSize, void *values);
GLAPI void APIENTRY glGetnHistogramARB(GLenum target, GLboolean reset, GLenum format, GLenum type, GLsizei bufSize, void *values);
GLAPI void APIENTRY glGetnMapdv(GLenum target, GLenum query, GLsizei bufSize, GLdouble *v);
GLAPI void APIENTRY glGetnMapdvARB(GLenum target, GLenum query, GLsizei bufSize, GLdouble *v);
GLAPI void APIENTRY glGetnMapfv(GLenum target, GLenum query, GLsizei bufSize, GLfloat *v);
GLAPI void APIENTRY glGetnMapfvARB(GLenum target, GLenum query, GLsizei bufSize, GLfloat *v);
GLAPI void APIENTRY glGetnMapiv(GLenum target, GLenum query, GLsizei bufSize, GLint *v);
GLAPI void APIENTRY glGetnMapivARB(GLenum target, GLenum query, GLsizei bufSize, GLint *v);
GLAPI void APIENTRY glGetnMinmax(GLenum target, GLboolean reset, GLenum format, GLenum type, GLsizei bufSize, void *values);
GLAPI void APIENTRY glGetnMinmaxARB(GLenum target, GLboolean reset, GLenum format, GLenum type, GLsizei bufSize, void *values);
GLAPI void APIENTRY glGetnPixelMapfv(GLenum map, GLsizei bufSize, GLfloat *values);
GLAPI void APIENTRY glGetnPixelMapfvARB(GLenum map, GLsizei bufSize, GLfloat *values);
GLAPI void APIENTRY glGetnPixelMapuiv(GLenum map, GLsizei bufSize, GLuint *values);
GLAPI void APIENTRY glGetnPixelMapuivARB(GLenum map, GLsizei bufSize, GLuint *values);
GLAPI void APIENTRY glGetnPixelMapusv(GLenum map, GLsizei bufSize, GLushort *values);
GLAPI void APIENTRY glGetnPixelMapusvARB(GLenum map, GLsizei bufSize, GLushort *values);
GLAPI void APIENTRY glGetnPolygonStipple(GLsizei bufSize, GLubyte *pattern);
GLAPI void APIENTRY glGetnPolygonStippleARB(GLsizei bufSize, GLubyte *pattern);
GLAPI void APIENTRY glGetnSeparableFilter(GLenum target, GLenum format, GLenum type, GLsizei rowBufSize, void *row, GLsizei columnBufSize, void *column, void *span);
GLAPI void APIENTRY glGetnSeparableFilterARB(GLenum target, GLenum format, GLenum type, GLsizei rowBufSize, void *row, GLsizei columnBufSize, void *column, void *span);
GLAPI void APIENTRY glGetnTexImage(GLenum target, GLint level, GLenum format, GLenum type, GLsizei bufSize, void *pixels);
GLAPI void APIENTRY glGetnTexImageARB(GLenum target, GLint level, GLenum format, GLenum type, GLsizei bufSize, void *img);
GLAPI void APIENTRY glGetnUniformdv(GLuint program, GLint location, GLsizei bufSize, GLdouble *params);
GLAPI void APIENTRY glGetnUniformdvARB(GLuint program, GLint location, GLsizei bufSize, GLdouble *params);
GLAPI void APIENTRY glGetnUniformfv(GLuint program, GLint location, GLsizei bufSize, GLfloat *params);
GLAPI void APIENTRY glGetnUniformfvARB(GLuint program, GLint location, GLsizei bufSize, GLfloat *params);
GLAPI void APIENTRY glGetnUniformfvEXT(GLuint program, GLint location, GLsizei bufSize, GLfloat *params);
GLAPI void APIENTRY glGetnUniformfvKHR(GLuint program, GLint location, GLsizei bufSize, GLfloat *params);
GLAPI void APIENTRY glGetnUniformi64vARB(GLuint program, GLint location, GLsizei bufSize, GLint64 *params);
GLAPI void APIENTRY glGetnUniformiv(GLuint program, GLint location, GLsizei bufSize, GLint *params);
GLAPI void APIENTRY glGetnUniformivARB(GLuint program, GLint location, GLsizei bufSize, GLint *params);
GLAPI void APIENTRY glGetnUniformivEXT(GLuint program, GLint location, GLsizei bufSize, GLint *params);
GLAPI void APIENTRY glGetnUniformivKHR(GLuint program, GLint location, GLsizei bufSize, GLint *params);
GLAPI void APIENTRY glGetnUniformui64vARB(GLuint program, GLint location, GLsizei bufSize, GLuint64 *params);
GLAPI void APIENTRY glGetnUniformuiv(GLuint program, GLint location, GLsizei bufSize, GLuint *params);
GLAPI void APIENTRY glGetnUniformuivARB(GLuint program, GLint location, GLsizei bufSize, GLuint *params);
GLAPI void APIENTRY glGetnUniformuivKHR(GLuint program, GLint location, GLsizei bufSize, GLuint *params);
GLAPI void APIENTRY glGlobalAlphaFactorbSUN(GLbyte factor);
GLAPI void APIENTRY glGlobalAlphaFactordSUN(GLdouble factor);
GLAPI void APIENTRY glGlobalAlphaFactorfSUN(GLfloat factor);
GLAPI void APIENTRY glGlobalAlphaFactoriSUN(GLint factor);
GLAPI void APIENTRY glGlobalAlphaFactorsSUN(GLshort factor);
GLAPI void APIENTRY glGlobalAlphaFactorubSUN(GLubyte factor);
GLAPI void APIENTRY glGlobalAlphaFactoruiSUN(GLuint factor);
GLAPI void APIENTRY glGlobalAlphaFactorusSUN(GLushort factor);
GLAPI void APIENTRY glGpuSyncAcquireNVX(GLintptr sync);
GLAPI GLintptr APIENTRY glGpuSyncCreateNVX(void);
GLAPI void APIENTRY glGpuSyncDestroyNVX(GLintptr sync);
GLAPI void APIENTRY glGpuSyncReleaseNVX(GLintptr sync);
GLAPI void APIENTRY glHint(GLenum target, GLenum mode);
GLAPI void APIENTRY glHintPGI(GLenum target, GLint mode);
GLAPI void APIENTRY glHistogram(GLenum target, GLsizei width, GLenum internalformat, GLboolean sink);
GLAPI void APIENTRY glHistogramEXT(GLenum target, GLsizei width, GLenum internalformat, GLboolean sink);
GLAPI void APIENTRY glIglooInterfaceSGIX(GLenum pname, const void *params);
GLAPI void APIENTRY glImageTransformParameterfHP(GLenum target, GLenum pname, GLfloat param);
GLAPI void APIENTRY glImageTransformParameterfvHP(GLenum target, GLenum pname, const GLfloat *params);
GLAPI void APIENTRY glImageTransformParameteriHP(GLenum target, GLenum pname, GLint param);
GLAPI void APIENTRY glImageTransformParameterivHP(GLenum target, GLenum pname, const GLint *params);
GLAPI void APIENTRY glImportMemoryFdEXT(GLuint memory, GLuint64 size, GLenum handleType, GLint fd);
GLAPI void APIENTRY glImportMemoryWin32HandleEXT(GLuint memory, GLuint64 size, GLenum handleType, void *handle);
GLAPI void APIENTRY glImportMemoryWin32NameEXT(GLuint memory, GLuint64 size, GLenum handleType, const void *name);
GLAPI void APIENTRY glImportSemaphoreFdEXT(GLuint semaphore, GLenum handleType, GLint fd);
GLAPI void APIENTRY glImportSemaphoreWin32HandleEXT(GLuint semaphore, GLenum handleType, void *handle);
GLAPI void APIENTRY glImportSemaphoreWin32NameEXT(GLuint semaphore, GLenum handleType, const void *name);
GLAPI GLsync APIENTRY glImportSyncEXT(GLenum external_sync_type, GLintptr external_sync, GLbitfield flags);
GLAPI void APIENTRY glIndexFormatNV(GLenum type, GLsizei stride);
GLAPI void APIENTRY glIndexFuncEXT(GLenum func, GLclampf ref);
GLAPI void APIENTRY glIndexMask(GLuint mask);
GLAPI void APIENTRY glIndexMaterialEXT(GLenum face, GLenum mode);
GLAPI void APIENTRY glIndexPointer(GLenum type, GLsizei stride, const void *pointer);
GLAPI void APIENTRY glIndexPointerEXT(GLenum type, GLsizei stride, GLsizei count, const void *pointer);
GLAPI void APIENTRY glIndexPointerListIBM(GLenum type, GLint stride, const void **pointer, GLint ptrstride);
GLAPI void APIENTRY glIndexd(GLdouble c);
GLAPI void APIENTRY glIndexdv(const GLdouble *c);
GLAPI void APIENTRY glIndexf(GLfloat c);
GLAPI void APIENTRY glIndexfv(const GLfloat *c);
GLAPI void APIENTRY glIndexi(GLint c);
GLAPI void APIENTRY glIndexiv(const GLint *c);
GLAPI void APIENTRY glIndexs(GLshort c);
GLAPI void APIENTRY glIndexsv(const GLshort *c);
GLAPI void APIENTRY glIndexub(GLubyte c);
GLAPI void APIENTRY glIndexubv(const GLubyte *c);
GLAPI void APIENTRY glIndexxOES(GLfixed component);
GLAPI void APIENTRY glIndexxvOES(const GLfixed *component);
GLAPI void APIENTRY glInitNames(void);
GLAPI void APIENTRY glInsertComponentEXT(GLuint res, GLuint src, GLuint num);
GLAPI void APIENTRY glInsertEventMarkerEXT(GLsizei length, const GLchar *marker);
GLAPI void APIENTRY glInstrumentsBufferSGIX(GLsizei size, GLint *buffer);
GLAPI void APIENTRY glInterleavedArrays(GLenum format, GLsizei stride, const void *pointer);
GLAPI void APIENTRY glInterpolatePathsNV(GLuint resultPath, GLuint pathA, GLuint pathB, GLfloat weight);
GLAPI void APIENTRY glInvalidateBufferData(GLuint buffer);
GLAPI void APIENTRY glInvalidateBufferSubData(GLuint buffer, GLintptr offset, GLsizeiptr length);
GLAPI void APIENTRY glInvalidateFramebuffer(GLenum target, GLsizei numAttachments, const GLenum *attachments);
GLAPI void APIENTRY glInvalidateNamedFramebufferData(GLuint framebuffer, GLsizei numAttachments, const GLenum *attachments);
GLAPI void APIENTRY glInvalidateNamedFramebufferSubData(GLuint framebuffer, GLsizei numAttachments, const GLenum *attachments, GLint x, GLint y, GLsizei width, GLsizei height);
GLAPI void APIENTRY glInvalidateSubFramebuffer(GLenum target, GLsizei numAttachments, const GLenum *attachments, GLint x, GLint y, GLsizei width, GLsizei height);
GLAPI void APIENTRY glInvalidateTexImage(GLuint texture, GLint level);
GLAPI void APIENTRY glInvalidateTexSubImage(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth);
GLAPI GLboolean APIENTRY glIsAsyncMarkerSGIX(GLuint marker);
GLAPI GLboolean APIENTRY glIsBuffer(GLuint buffer);
GLAPI GLboolean APIENTRY glIsBufferARB(GLuint buffer);
GLAPI GLboolean APIENTRY glIsBufferResidentNV(GLenum target);
GLAPI GLboolean APIENTRY glIsCommandListNV(GLuint list);
GLAPI GLboolean APIENTRY glIsEnabled(GLenum cap);
GLAPI GLboolean APIENTRY glIsEnabledIndexedEXT(GLenum target, GLuint index);
GLAPI GLboolean APIENTRY glIsEnabledi(GLenum target, GLuint index);
GLAPI GLboolean APIENTRY glIsEnablediEXT(GLenum target, GLuint index);
GLAPI GLboolean APIENTRY glIsEnablediNV(GLenum target, GLuint index);
GLAPI GLboolean APIENTRY glIsEnablediOES(GLenum target, GLuint index);
GLAPI GLboolean APIENTRY glIsFenceAPPLE(GLuint fence);
GLAPI GLboolean APIENTRY glIsFenceNV(GLuint fence);
GLAPI GLboolean APIENTRY glIsFramebuffer(GLuint framebuffer);
GLAPI GLboolean APIENTRY glIsFramebufferEXT(GLuint framebuffer);
GLAPI GLboolean APIENTRY glIsFramebufferOES(GLuint framebuffer);
GLAPI GLboolean APIENTRY glIsImageHandleResidentARB(GLuint64 handle);
GLAPI GLboolean APIENTRY glIsImageHandleResidentNV(GLuint64 handle);
GLAPI GLboolean APIENTRY glIsList(GLuint list);
GLAPI GLboolean APIENTRY glIsMemoryObjectEXT(GLuint memoryObject);
GLAPI GLboolean APIENTRY glIsNameAMD(GLenum identifier, GLuint name);
GLAPI GLboolean APIENTRY glIsNamedBufferResidentNV(GLuint buffer);
GLAPI GLboolean APIENTRY glIsNamedStringARB(GLint namelen, const GLchar *name);
GLAPI GLboolean APIENTRY glIsObjectBufferATI(GLuint buffer);
GLAPI GLboolean APIENTRY glIsOcclusionQueryNV(GLuint id);
GLAPI GLboolean APIENTRY glIsPathNV(GLuint path);
GLAPI GLboolean APIENTRY glIsPointInFillPathNV(GLuint path, GLuint mask, GLfloat x, GLfloat y);
GLAPI GLboolean APIENTRY glIsPointInStrokePathNV(GLuint path, GLfloat x, GLfloat y);
GLAPI GLboolean APIENTRY glIsProgram(GLuint program);
GLAPI GLboolean APIENTRY glIsProgramARB(GLuint program);
GLAPI GLboolean APIENTRY glIsProgramNV(GLuint id);
GLAPI GLboolean APIENTRY glIsProgramPipeline(GLuint pipeline);
GLAPI GLboolean APIENTRY glIsProgramPipelineEXT(GLuint pipeline);
GLAPI GLboolean APIENTRY glIsQuery(GLuint id);
GLAPI GLboolean APIENTRY glIsQueryARB(GLuint id);
GLAPI GLboolean APIENTRY glIsQueryEXT(GLuint id);
GLAPI GLboolean APIENTRY glIsRenderbuffer(GLuint renderbuffer);
GLAPI GLboolean APIENTRY glIsRenderbufferEXT(GLuint renderbuffer);
GLAPI GLboolean APIENTRY glIsRenderbufferOES(GLuint renderbuffer);
GLAPI GLboolean APIENTRY glIsSampler(GLuint sampler);
GLAPI GLboolean APIENTRY glIsSemaphoreEXT(GLuint semaphore);
GLAPI GLboolean APIENTRY glIsShader(GLuint shader);
GLAPI GLboolean APIENTRY glIsStateNV(GLuint state);
GLAPI GLboolean APIENTRY glIsSync(GLsync sync);
GLAPI GLboolean APIENTRY glIsSyncAPPLE(GLsync sync);
GLAPI GLboolean APIENTRY glIsTexture(GLuint texture);
GLAPI GLboolean APIENTRY glIsTextureEXT(GLuint texture);
GLAPI GLboolean APIENTRY glIsTextureHandleResidentARB(GLuint64 handle);
GLAPI GLboolean APIENTRY glIsTextureHandleResidentNV(GLuint64 handle);
GLAPI GLboolean APIENTRY glIsTransformFeedback(GLuint id);
GLAPI GLboolean APIENTRY glIsTransformFeedbackEXT(GLuint id);
GLAPI GLboolean APIENTRY glIsTransformFeedbackNV(GLuint id);
GLAPI GLboolean APIENTRY glIsVariantEnabledEXT(GLuint id, GLenum cap);
GLAPI GLboolean APIENTRY glIsVertexArray(GLuint array);
GLAPI GLboolean APIENTRY glIsVertexArrayAPPLE(GLuint array);
GLAPI GLboolean APIENTRY glIsVertexArrayOES(GLuint array);
GLAPI GLboolean APIENTRY glIsVertexAttribEnabledAPPLE(GLuint index, GLenum pname);
GLAPI void APIENTRY glLGPUCopyImageSubDataNVX(GLuint sourceGpu, GLbitfield destinationGpuMask, GLuint srcName, GLenum srcTarget, GLint srcLevel, GLint srcX, GLint srxY, GLint srcZ, GLuint dstName, GLenum dstTarget, GLint dstLevel, GLint dstX, GLint dstY, GLint dstZ, GLsizei width, GLsizei height, GLsizei depth);
GLAPI void APIENTRY glLGPUInterlockNVX(void);
GLAPI void APIENTRY glLGPUNamedBufferSubDataNVX(GLbitfield gpuMask, GLuint buffer, GLintptr offset, GLsizeiptr size, const void *data);
GLAPI void APIENTRY glLabelObjectEXT(GLenum type, GLuint object, GLsizei length, const GLchar *label);
GLAPI void APIENTRY glLightEnviSGIX(GLenum pname, GLint param);
GLAPI void APIENTRY glLightModelf(GLenum pname, GLfloat param);
GLAPI void APIENTRY glLightModelfv(GLenum pname, const GLfloat *params);
GLAPI void APIENTRY glLightModeli(GLenum pname, GLint param);
GLAPI void APIENTRY glLightModeliv(GLenum pname, const GLint *params);
GLAPI void APIENTRY glLightModelx(GLenum pname, GLfixed param);
GLAPI void APIENTRY glLightModelxOES(GLenum pname, GLfixed param);
GLAPI void APIENTRY glLightModelxv(GLenum pname, const GLfixed *param);
GLAPI void APIENTRY glLightModelxvOES(GLenum pname, const GLfixed *param);
GLAPI void APIENTRY glLightf(GLenum light, GLenum pname, GLfloat param);
GLAPI void APIENTRY glLightfv(GLenum light, GLenum pname, const GLfloat *params);
GLAPI void APIENTRY glLighti(GLenum light, GLenum pname, GLint param);
GLAPI void APIENTRY glLightiv(GLenum light, GLenum pname, const GLint *params);
GLAPI void APIENTRY glLightx(GLenum light, GLenum pname, GLfixed param);
GLAPI void APIENTRY glLightxOES(GLenum light, GLenum pname, GLfixed param);
GLAPI void APIENTRY glLightxv(GLenum light, GLenum pname, const GLfixed *params);
GLAPI void APIENTRY glLightxvOES(GLenum light, GLenum pname, const GLfixed *params);
GLAPI void APIENTRY glLineStipple(GLint factor, GLushort pattern);
GLAPI void APIENTRY glLineWidth(GLfloat width);
GLAPI void APIENTRY glLineWidthx(GLfixed width);
GLAPI void APIENTRY glLineWidthxOES(GLfixed width);
GLAPI void APIENTRY glLinkProgram(GLuint program);
GLAPI void APIENTRY glLinkProgramARB(GLhandleARB programObj);
GLAPI void APIENTRY glListBase(GLuint base);
GLAPI void APIENTRY glListDrawCommandsStatesClientNV(GLuint list, GLuint segment, const void **indirects, const GLsizei *sizes, const GLuint *states, const GLuint *fbos, GLuint count);
GLAPI void APIENTRY glListParameterfSGIX(GLuint list, GLenum pname, GLfloat param);
GLAPI void APIENTRY glListParameterfvSGIX(GLuint list, GLenum pname, const GLfloat *params);
GLAPI void APIENTRY glListParameteriSGIX(GLuint list, GLenum pname, GLint param);
GLAPI void APIENTRY glListParameterivSGIX(GLuint list, GLenum pname, const GLint *params);
GLAPI void APIENTRY glLoadIdentity(void);
GLAPI void APIENTRY glLoadIdentityDeformationMapSGIX(GLbitfield mask);
GLAPI void APIENTRY glLoadMatrixd(const GLdouble *m);
GLAPI void APIENTRY glLoadMatrixf(const GLfloat *m);
GLAPI void APIENTRY glLoadMatrixx(const GLfixed *m);
GLAPI void APIENTRY glLoadMatrixxOES(const GLfixed *m);
GLAPI void APIENTRY glLoadName(GLuint name);
GLAPI void APIENTRY glLoadPaletteFromModelViewMatrixOES(void);
GLAPI void APIENTRY glLoadProgramNV(GLenum target, GLuint id, GLsizei len, const GLubyte *program);
GLAPI void APIENTRY glLoadTransformEXT(GLenum transform);
GLAPI void APIENTRY glLoadTransposeMatrixd(const GLdouble *m);
GLAPI void APIENTRY glLoadTransposeMatrixdARB(const GLdouble *m);
GLAPI void APIENTRY glLoadTransposeMatrixf(const GLfloat *m);
GLAPI void APIENTRY glLoadTransposeMatrixfARB(const GLfloat *m);
GLAPI void APIENTRY glLoadTransposeMatrixxOES(const GLfixed *m);
GLAPI void APIENTRY glLockArraysEXT(GLint first, GLsizei count);
GLAPI void APIENTRY glLogicOp(GLenum opcode);
GLAPI void APIENTRY glMakeBufferNonResidentNV(GLenum target);
GLAPI void APIENTRY glMakeBufferResidentNV(GLenum target, GLenum access);
GLAPI void APIENTRY glMakeImageHandleNonResidentARB(GLuint64 handle);
GLAPI void APIENTRY glMakeImageHandleNonResidentNV(GLuint64 handle);
GLAPI void APIENTRY glMakeImageHandleResidentARB(GLuint64 handle, GLenum access);
GLAPI void APIENTRY glMakeImageHandleResidentNV(GLuint64 handle, GLenum access);
GLAPI void APIENTRY glMakeNamedBufferNonResidentNV(GLuint buffer);
GLAPI void APIENTRY glMakeNamedBufferResidentNV(GLuint buffer, GLenum access);
GLAPI void APIENTRY glMakeTextureHandleNonResidentARB(GLuint64 handle);
GLAPI void APIENTRY glMakeTextureHandleNonResidentNV(GLuint64 handle);
GLAPI void APIENTRY glMakeTextureHandleResidentARB(GLuint64 handle);
GLAPI void APIENTRY glMakeTextureHandleResidentNV(GLuint64 handle);
GLAPI void APIENTRY glMap1d(GLenum target, GLdouble u1, GLdouble u2, GLint stride, GLint order, const GLdouble *points);
GLAPI void APIENTRY glMap1f(GLenum target, GLfloat u1, GLfloat u2, GLint stride, GLint order, const GLfloat *points);
GLAPI void APIENTRY glMap1xOES(GLenum target, GLfixed u1, GLfixed u2, GLint stride, GLint order, GLfixed points);
GLAPI void APIENTRY glMap2d(GLenum target, GLdouble u1, GLdouble u2, GLint ustride, GLint uorder, GLdouble v1, GLdouble v2, GLint vstride, GLint vorder, const GLdouble *points);
GLAPI void APIENTRY glMap2f(GLenum target, GLfloat u1, GLfloat u2, GLint ustride, GLint uorder, GLfloat v1, GLfloat v2, GLint vstride, GLint vorder, const GLfloat *points);
GLAPI void APIENTRY glMap2xOES(GLenum target, GLfixed u1, GLfixed u2, GLint ustride, GLint uorder, GLfixed v1, GLfixed v2, GLint vstride, GLint vorder, GLfixed points);
GLAPI void * APIENTRY glMapBuffer(GLenum target, GLenum access);
GLAPI void * APIENTRY glMapBufferARB(GLenum target, GLenum access);
GLAPI void * APIENTRY glMapBufferOES(GLenum target, GLenum access);
GLAPI void * APIENTRY glMapBufferRange(GLenum target, GLintptr offset, GLsizeiptr length, GLbitfield access);
GLAPI void * APIENTRY glMapBufferRangeEXT(GLenum target, GLintptr offset, GLsizeiptr length, GLbitfield access);
GLAPI void APIENTRY glMapControlPointsNV(GLenum target, GLuint index, GLenum type, GLsizei ustride, GLsizei vstride, GLint uorder, GLint vorder, GLboolean packed, const void *points);
GLAPI void APIENTRY glMapGrid1d(GLint un, GLdouble u1, GLdouble u2);
GLAPI void APIENTRY glMapGrid1f(GLint un, GLfloat u1, GLfloat u2);
GLAPI void APIENTRY glMapGrid1xOES(GLint n, GLfixed u1, GLfixed u2);
GLAPI void APIENTRY glMapGrid2d(GLint un, GLdouble u1, GLdouble u2, GLint vn, GLdouble v1, GLdouble v2);
GLAPI void APIENTRY glMapGrid2f(GLint un, GLfloat u1, GLfloat u2, GLint vn, GLfloat v1, GLfloat v2);
GLAPI void APIENTRY glMapGrid2xOES(GLint n, GLfixed u1, GLfixed u2, GLfixed v1, GLfixed v2);
GLAPI void * APIENTRY glMapNamedBuffer(GLuint buffer, GLenum access);
GLAPI void * APIENTRY glMapNamedBufferEXT(GLuint buffer, GLenum access);
GLAPI void * APIENTRY glMapNamedBufferRange(GLuint buffer, GLintptr offset, GLsizeiptr length, GLbitfield access);
GLAPI void * APIENTRY glMapNamedBufferRangeEXT(GLuint buffer, GLintptr offset, GLsizeiptr length, GLbitfield access);
GLAPI void * APIENTRY glMapObjectBufferATI(GLuint buffer);
GLAPI void APIENTRY glMapParameterfvNV(GLenum target, GLenum pname, const GLfloat *params);
GLAPI void APIENTRY glMapParameterivNV(GLenum target, GLenum pname, const GLint *params);
GLAPI void * APIENTRY glMapTexture2DINTEL(GLuint texture, GLint level, GLbitfield access, GLint *stride, GLenum *layout);
GLAPI void APIENTRY glMapVertexAttrib1dAPPLE(GLuint index, GLuint size, GLdouble u1, GLdouble u2, GLint stride, GLint order, const GLdouble *points);
GLAPI void APIENTRY glMapVertexAttrib1fAPPLE(GLuint index, GLuint size, GLfloat u1, GLfloat u2, GLint stride, GLint order, const GLfloat *points);
GLAPI void APIENTRY glMapVertexAttrib2dAPPLE(GLuint index, GLuint size, GLdouble u1, GLdouble u2, GLint ustride, GLint uorder, GLdouble v1, GLdouble v2, GLint vstride, GLint vorder, const GLdouble *points);
GLAPI void APIENTRY glMapVertexAttrib2fAPPLE(GLuint index, GLuint size, GLfloat u1, GLfloat u2, GLint ustride, GLint uorder, GLfloat v1, GLfloat v2, GLint vstride, GLint vorder, const GLfloat *points);
GLAPI void APIENTRY glMaterialf(GLenum face, GLenum pname, GLfloat param);
GLAPI void APIENTRY glMaterialfv(GLenum face, GLenum pname, const GLfloat *params);
GLAPI void APIENTRY glMateriali(GLenum face, GLenum pname, GLint param);
GLAPI void APIENTRY glMaterialiv(GLenum face, GLenum pname, const GLint *params);
GLAPI void APIENTRY glMaterialx(GLenum face, GLenum pname, GLfixed param);
GLAPI void APIENTRY glMaterialxOES(GLenum face, GLenum pname, GLfixed param);
GLAPI void APIENTRY glMaterialxv(GLenum face, GLenum pname, const GLfixed *param);
GLAPI void APIENTRY glMaterialxvOES(GLenum face, GLenum pname, const GLfixed *param);
GLAPI void APIENTRY glMatrixFrustumEXT(GLenum mode, GLdouble left, GLdouble right, GLdouble bottom, GLdouble top, GLdouble zNear, GLdouble zFar);
GLAPI void APIENTRY glMatrixIndexPointerARB(GLint size, GLenum type, GLsizei stride, const void *pointer);
GLAPI void APIENTRY glMatrixIndexPointerOES(GLint size, GLenum type, GLsizei stride, const void *pointer);
GLAPI void APIENTRY glMatrixIndexubvARB(GLint size, const GLubyte *indices);
GLAPI void APIENTRY glMatrixIndexuivARB(GLint size, const GLuint *indices);
GLAPI void APIENTRY glMatrixIndexusvARB(GLint size, const GLushort *indices);
GLAPI void APIENTRY glMatrixLoad3x2fNV(GLenum matrixMode, const GLfloat *m);
GLAPI void APIENTRY glMatrixLoad3x3fNV(GLenum matrixMode, const GLfloat *m);
GLAPI void APIENTRY glMatrixLoadIdentityEXT(GLenum mode);
GLAPI void APIENTRY glMatrixLoadTranspose3x3fNV(GLenum matrixMode, const GLfloat *m);
GLAPI void APIENTRY glMatrixLoadTransposedEXT(GLenum mode, const GLdouble *m);
GLAPI void APIENTRY glMatrixLoadTransposefEXT(GLenum mode, const GLfloat *m);
GLAPI void APIENTRY glMatrixLoaddEXT(GLenum mode, const GLdouble *m);
GLAPI void APIENTRY glMatrixLoadfEXT(GLenum mode, const GLfloat *m);
GLAPI void APIENTRY glMatrixMode(GLenum mode);
GLAPI void APIENTRY glMatrixMult3x2fNV(GLenum matrixMode, const GLfloat *m);
GLAPI void APIENTRY glMatrixMult3x3fNV(GLenum matrixMode, const GLfloat *m);
GLAPI void APIENTRY glMatrixMultTranspose3x3fNV(GLenum matrixMode, const GLfloat *m);
GLAPI void APIENTRY glMatrixMultTransposedEXT(GLenum mode, const GLdouble *m);
GLAPI void APIENTRY glMatrixMultTransposefEXT(GLenum mode, const GLfloat *m);
GLAPI void APIENTRY glMatrixMultdEXT(GLenum mode, const GLdouble *m);
GLAPI void APIENTRY glMatrixMultfEXT(GLenum mode, const GLfloat *m);
GLAPI void APIENTRY glMatrixOrthoEXT(GLenum mode, GLdouble left, GLdouble right, GLdouble bottom, GLdouble top, GLdouble zNear, GLdouble zFar);
GLAPI void APIENTRY glMatrixPopEXT(GLenum mode);
GLAPI void APIENTRY glMatrixPushEXT(GLenum mode);
GLAPI void APIENTRY glMatrixRotatedEXT(GLenum mode, GLdouble angle, GLdouble x, GLdouble y, GLdouble z);
GLAPI void APIENTRY glMatrixRotatefEXT(GLenum mode, GLfloat angle, GLfloat x, GLfloat y, GLfloat z);
GLAPI void APIENTRY glMatrixScaledEXT(GLenum mode, GLdouble x, GLdouble y, GLdouble z);
GLAPI void APIENTRY glMatrixScalefEXT(GLenum mode, GLfloat x, GLfloat y, GLfloat z);
GLAPI void APIENTRY glMatrixTranslatedEXT(GLenum mode, GLdouble x, GLdouble y, GLdouble z);
GLAPI void APIENTRY glMatrixTranslatefEXT(GLenum mode, GLfloat x, GLfloat y, GLfloat z);
GLAPI void APIENTRY glMaxShaderCompilerThreadsARB(GLuint count);
GLAPI void APIENTRY glMaxShaderCompilerThreadsKHR(GLuint count);
GLAPI void APIENTRY glMemoryBarrier(GLbitfield barriers);
GLAPI void APIENTRY glMemoryBarrierByRegion(GLbitfield barriers);
GLAPI void APIENTRY glMemoryBarrierEXT(GLbitfield barriers);
GLAPI void APIENTRY glMemoryObjectParameterivEXT(GLuint memoryObject, GLenum pname, const GLint *params);
GLAPI void APIENTRY glMinSampleShading(GLfloat value);
GLAPI void APIENTRY glMinSampleShadingARB(GLfloat value);
GLAPI void APIENTRY glMinSampleShadingOES(GLfloat value);
GLAPI void APIENTRY glMinmax(GLenum target, GLenum internalformat, GLboolean sink);
GLAPI void APIENTRY glMinmaxEXT(GLenum target, GLenum internalformat, GLboolean sink);
GLAPI void APIENTRY glMultMatrixd(const GLdouble *m);
GLAPI void APIENTRY glMultMatrixf(const GLfloat *m);
GLAPI void APIENTRY glMultMatrixx(const GLfixed *m);
GLAPI void APIENTRY glMultMatrixxOES(const GLfixed *m);
GLAPI void APIENTRY glMultTransformEXT(GLenum transform);
GLAPI void APIENTRY glMultTransposeMatrixd(const GLdouble *m);
GLAPI void APIENTRY glMultTransposeMatrixdARB(const GLdouble *m);
GLAPI void APIENTRY glMultTransposeMatrixf(const GLfloat *m);
GLAPI void APIENTRY glMultTransposeMatrixfARB(const GLfloat *m);
GLAPI void APIENTRY glMultTransposeMatrixxOES(const GLfixed *m);
GLAPI void APIENTRY glMultiDrawArrays(GLenum mode, const GLint *first, const GLsizei *count, GLsizei drawcount);
GLAPI void APIENTRY glMultiDrawArraysEXT(GLenum mode, const GLint *first, const GLsizei *count, GLsizei primcount);
GLAPI void APIENTRY glMultiDrawArraysIndirect(GLenum mode, const void *indirect, GLsizei drawcount, GLsizei stride);
GLAPI void APIENTRY glMultiDrawArraysIndirectAMD(GLenum mode, const void *indirect, GLsizei primcount, GLsizei stride);
GLAPI void APIENTRY glMultiDrawArraysIndirectBindlessCountNV(GLenum mode, const void *indirect, GLsizei drawCount, GLsizei maxDrawCount, GLsizei stride, GLint vertexBufferCount);
GLAPI void APIENTRY glMultiDrawArraysIndirectBindlessNV(GLenum mode, const void *indirect, GLsizei drawCount, GLsizei stride, GLint vertexBufferCount);
GLAPI void APIENTRY glMultiDrawArraysIndirectCount(GLenum mode, const void *indirect, GLintptr drawcount, GLsizei maxdrawcount, GLsizei stride);
GLAPI void APIENTRY glMultiDrawArraysIndirectCountARB(GLenum mode, const void *indirect, GLintptr drawcount, GLsizei maxdrawcount, GLsizei stride);
GLAPI void APIENTRY glMultiDrawArraysIndirectEXT(GLenum mode, const void *indirect, GLsizei drawcount, GLsizei stride);
GLAPI void APIENTRY glMultiDrawElementArrayAPPLE(GLenum mode, const GLint *first, const GLsizei *count, GLsizei primcount);
GLAPI void APIENTRY glMultiDrawElements(GLenum mode, const GLsizei *count, GLenum type, const void *const *indices, GLsizei drawcount);
GLAPI void APIENTRY glMultiDrawElementsBaseVertex(GLenum mode, const GLsizei *count, GLenum type, const void *const *indices, GLsizei drawcount, const GLint *basevertex);
GLAPI void APIENTRY glMultiDrawElementsBaseVertexEXT(GLenum mode, const GLsizei *count, GLenum type, const void *const *indices, GLsizei drawcount, const GLint *basevertex);
GLAPI void APIENTRY glMultiDrawElementsEXT(GLenum mode, const GLsizei *count, GLenum type, const void *const *indices, GLsizei primcount);
GLAPI void APIENTRY glMultiDrawElementsIndirect(GLenum mode, GLenum type, const void *indirect, GLsizei drawcount, GLsizei stride);
GLAPI void APIENTRY glMultiDrawElementsIndirectAMD(GLenum mode, GLenum type, const void *indirect, GLsizei primcount, GLsizei stride);
GLAPI void APIENTRY glMultiDrawElementsIndirectBindlessCountNV(GLenum mode, GLenum type, const void *indirect, GLsizei drawCount, GLsizei maxDrawCount, GLsizei stride, GLint vertexBufferCount);
GLAPI void APIENTRY glMultiDrawElementsIndirectBindlessNV(GLenum mode, GLenum type, const void *indirect, GLsizei drawCount, GLsizei stride, GLint vertexBufferCount);
GLAPI void APIENTRY glMultiDrawElementsIndirectCount(GLenum mode, GLenum type, const void *indirect, GLintptr drawcount, GLsizei maxdrawcount, GLsizei stride);
GLAPI void APIENTRY glMultiDrawElementsIndirectCountARB(GLenum mode, GLenum type, const void *indirect, GLintptr drawcount, GLsizei maxdrawcount, GLsizei stride);
GLAPI void APIENTRY glMultiDrawElementsIndirectEXT(GLenum mode, GLenum type, const void *indirect, GLsizei drawcount, GLsizei stride);
GLAPI void APIENTRY glMultiDrawMeshTasksIndirectCountNV(GLintptr indirect, GLintptr drawcount, GLsizei maxdrawcount, GLsizei stride);
GLAPI void APIENTRY glMultiDrawMeshTasksIndirectNV(GLintptr indirect, GLsizei drawcount, GLsizei stride);
GLAPI void APIENTRY glMultiDrawRangeElementArrayAPPLE(GLenum mode, GLuint start, GLuint end, const GLint *first, const GLsizei *count, GLsizei primcount);
GLAPI void APIENTRY glMultiModeDrawArraysIBM(const GLenum *mode, const GLint *first, const GLsizei *count, GLsizei primcount, GLint modestride);
GLAPI void APIENTRY glMultiModeDrawElementsIBM(const GLenum *mode, const GLsizei *count, GLenum type, const void *const *indices, GLsizei primcount, GLint modestride);
GLAPI void APIENTRY glMultiTexBufferEXT(GLenum texunit, GLenum target, GLenum internalformat, GLuint buffer);
GLAPI void APIENTRY glMultiTexCoord1bOES(GLenum texture, GLbyte s);
GLAPI void APIENTRY glMultiTexCoord1bvOES(GLenum texture, const GLbyte *coords);
GLAPI void APIENTRY glMultiTexCoord1d(GLenum target, GLdouble s);
GLAPI void APIENTRY glMultiTexCoord1dARB(GLenum target, GLdouble s);
GLAPI void APIENTRY glMultiTexCoord1dv(GLenum target, const GLdouble *v);
GLAPI void APIENTRY glMultiTexCoord1dvARB(GLenum target, const GLdouble *v);
GLAPI void APIENTRY glMultiTexCoord1f(GLenum target, GLfloat s);
GLAPI void APIENTRY glMultiTexCoord1fARB(GLenum target, GLfloat s);
GLAPI void APIENTRY glMultiTexCoord1fv(GLenum target, const GLfloat *v);
GLAPI void APIENTRY glMultiTexCoord1fvARB(GLenum target, const GLfloat *v);
GLAPI void APIENTRY glMultiTexCoord1hNV(GLenum target, GLhalf s);
GLAPI void APIENTRY glMultiTexCoord1hvNV(GLenum target, const GLhalf *v);
GLAPI void APIENTRY glMultiTexCoord1i(GLenum target, GLint s);
GLAPI void APIENTRY glMultiTexCoord1iARB(GLenum target, GLint s);
GLAPI void APIENTRY glMultiTexCoord1iv(GLenum target, const GLint *v);
GLAPI void APIENTRY glMultiTexCoord1ivARB(GLenum target, const GLint *v);
GLAPI void APIENTRY glMultiTexCoord1s(GLenum target, GLshort s);
GLAPI void APIENTRY glMultiTexCoord1sARB(GLenum target, GLshort s);
GLAPI void APIENTRY glMultiTexCoord1sv(GLenum target, const GLshort *v);
GLAPI void APIENTRY glMultiTexCoord1svARB(GLenum target, const GLshort *v);
GLAPI void APIENTRY glMultiTexCoord1x(GLenum target, GLfixed s);
GLAPI void APIENTRY glMultiTexCoord1xOES(GLenum texture, GLfixed s);
GLAPI void APIENTRY glMultiTexCoord1xv(GLenum target, const GLfixed *v);
GLAPI void APIENTRY glMultiTexCoord1xvOES(GLenum texture, const GLfixed *coords);
GLAPI void APIENTRY glMultiTexCoord2bOES(GLenum texture, GLbyte s, GLbyte t);
GLAPI void APIENTRY glMultiTexCoord2bvOES(GLenum texture, const GLbyte *coords);
GLAPI void APIENTRY glMultiTexCoord2d(GLenum target, GLdouble s, GLdouble t);
GLAPI void APIENTRY glMultiTexCoord2dARB(GLenum target, GLdouble s, GLdouble t);
GLAPI void APIENTRY glMultiTexCoord2dv(GLenum target, const GLdouble *v);
GLAPI void APIENTRY glMultiTexCoord2dvARB(GLenum target, const GLdouble *v);
GLAPI void APIENTRY glMultiTexCoord2f(GLenum target, GLfloat s, GLfloat t);
GLAPI void APIENTRY glMultiTexCoord2fARB(GLenum target, GLfloat s, GLfloat t);
GLAPI void APIENTRY glMultiTexCoord2fv(GLenum target, const GLfloat *v);
GLAPI void APIENTRY glMultiTexCoord2fvARB(GLenum target, const GLfloat *v);
GLAPI void APIENTRY glMultiTexCoord2hNV(GLenum target, GLhalf s, GLhalf t);
GLAPI void APIENTRY glMultiTexCoord2hvNV(GLenum target, const GLhalf *v);
GLAPI void APIENTRY glMultiTexCoord2i(GLenum target, GLint s, GLint t);
GLAPI void APIENTRY glMultiTexCoord2iARB(GLenum target, GLint s, GLint t);
GLAPI void APIENTRY glMultiTexCoord2iv(GLenum target, const GLint *v);
GLAPI void APIENTRY glMultiTexCoord2ivARB(GLenum target, const GLint *v);
GLAPI void APIENTRY glMultiTexCoord2s(GLenum target, GLshort s, GLshort t);
GLAPI void APIENTRY glMultiTexCoord2sARB(GLenum target, GLshort s, GLshort t);
GLAPI void APIENTRY glMultiTexCoord2sv(GLenum target, const GLshort *v);
GLAPI void APIENTRY glMultiTexCoord2svARB(GLenum target, const GLshort *v);
GLAPI void APIENTRY glMultiTexCoord2x(GLenum target, GLfixed s, GLfixed t);
GLAPI void APIENTRY glMultiTexCoord2xOES(GLenum texture, GLfixed s, GLfixed t);
GLAPI void APIENTRY glMultiTexCoord2xv(GLenum target, const GLfixed *v);
GLAPI void APIENTRY glMultiTexCoord2xvOES(GLenum texture, const GLfixed *coords);
GLAPI void APIENTRY glMultiTexCoord3bOES(GLenum texture, GLbyte s, GLbyte t, GLbyte r);
GLAPI void APIENTRY glMultiTexCoord3bvOES(GLenum texture, const GLbyte *coords);
GLAPI void APIENTRY glMultiTexCoord3d(GLenum target, GLdouble s, GLdouble t, GLdouble r);
GLAPI void APIENTRY glMultiTexCoord3dARB(GLenum target, GLdouble s, GLdouble t, GLdouble r);
GLAPI void APIENTRY glMultiTexCoord3dv(GLenum target, const GLdouble *v);
GLAPI void APIENTRY glMultiTexCoord3dvARB(GLenum target, const GLdouble *v);
GLAPI void APIENTRY glMultiTexCoord3f(GLenum target, GLfloat s, GLfloat t, GLfloat r);
GLAPI void APIENTRY glMultiTexCoord3fARB(GLenum target, GLfloat s, GLfloat t, GLfloat r);
GLAPI void APIENTRY glMultiTexCoord3fv(GLenum target, const GLfloat *v);
GLAPI void APIENTRY glMultiTexCoord3fvARB(GLenum target, const GLfloat *v);
GLAPI void APIENTRY glMultiTexCoord3hNV(GLenum target, GLhalf s, GLhalf t, GLhalf r);
GLAPI void APIENTRY glMultiTexCoord3hvNV(GLenum target, const GLhalf *v);
GLAPI void APIENTRY glMultiTexCoord3i(GLenum target, GLint s, GLint t, GLint r);
GLAPI void APIENTRY glMultiTexCoord3iARB(GLenum target, GLint s, GLint t, GLint r);
GLAPI void APIENTRY glMultiTexCoord3iv(GLenum target, const GLint *v);
GLAPI void APIENTRY glMultiTexCoord3ivARB(GLenum target, const GLint *v);
GLAPI void APIENTRY glMultiTexCoord3s(GLenum target, GLshort s, GLshort t, GLshort r);
GLAPI void APIENTRY glMultiTexCoord3sARB(GLenum target, GLshort s, GLshort t, GLshort r);
GLAPI void APIENTRY glMultiTexCoord3sv(GLenum target, const GLshort *v);
GLAPI void APIENTRY glMultiTexCoord3svARB(GLenum target, const GLshort *v);
GLAPI void APIENTRY glMultiTexCoord3x(GLenum target, GLfixed s, GLfixed t, GLfixed r);
GLAPI void APIENTRY glMultiTexCoord3xOES(GLenum texture, GLfixed s, GLfixed t, GLfixed r);
GLAPI void APIENTRY glMultiTexCoord3xv(GLenum target, const GLfixed *v);
GLAPI void APIENTRY glMultiTexCoord3xvOES(GLenum texture, const GLfixed *coords);
GLAPI void APIENTRY glMultiTexCoord4bOES(GLenum texture, GLbyte s, GLbyte t, GLbyte r, GLbyte q);
GLAPI void APIENTRY glMultiTexCoord4bvOES(GLenum texture, const GLbyte *coords);
GLAPI void APIENTRY glMultiTexCoord4d(GLenum target, GLdouble s, GLdouble t, GLdouble r, GLdouble q);
GLAPI void APIENTRY glMultiTexCoord4dARB(GLenum target, GLdouble s, GLdouble t, GLdouble r, GLdouble q);
GLAPI void APIENTRY glMultiTexCoord4dv(GLenum target, const GLdouble *v);
GLAPI void APIENTRY glMultiTexCoord4dvARB(GLenum target, const GLdouble *v);
GLAPI void APIENTRY glMultiTexCoord4f(GLenum target, GLfloat s, GLfloat t, GLfloat r, GLfloat q);
GLAPI void APIENTRY glMultiTexCoord4fARB(GLenum target, GLfloat s, GLfloat t, GLfloat r, GLfloat q);
GLAPI void APIENTRY glMultiTexCoord4fv(GLenum target, const GLfloat *v);
GLAPI void APIENTRY glMultiTexCoord4fvARB(GLenum target, const GLfloat *v);
GLAPI void APIENTRY glMultiTexCoord4hNV(GLenum target, GLhalf s, GLhalf t, GLhalf r, GLhalf q);
GLAPI void APIENTRY glMultiTexCoord4hvNV(GLenum target, const GLhalf *v);
GLAPI void APIENTRY glMultiTexCoord4i(GLenum target, GLint s, GLint t, GLint r, GLint q);
GLAPI void APIENTRY glMultiTexCoord4iARB(GLenum target, GLint s, GLint t, GLint r, GLint q);
GLAPI void APIENTRY glMultiTexCoord4iv(GLenum target, const GLint *v);
GLAPI void APIENTRY glMultiTexCoord4ivARB(GLenum target, const GLint *v);
GLAPI void APIENTRY glMultiTexCoord4s(GLenum target, GLshort s, GLshort t, GLshort r, GLshort q);
GLAPI void APIENTRY glMultiTexCoord4sARB(GLenum target, GLshort s, GLshort t, GLshort r, GLshort q);
GLAPI void APIENTRY glMultiTexCoord4sv(GLenum target, const GLshort *v);
GLAPI void APIENTRY glMultiTexCoord4svARB(GLenum target, const GLshort *v);
GLAPI void APIENTRY glMultiTexCoord4x(GLenum texture, GLfixed s, GLfixed t, GLfixed r, GLfixed q);
GLAPI void APIENTRY glMultiTexCoord4xOES(GLenum texture, GLfixed s, GLfixed t, GLfixed r, GLfixed q);
GLAPI void APIENTRY glMultiTexCoord4xv(GLenum target, const GLfixed *v);
GLAPI void APIENTRY glMultiTexCoord4xvOES(GLenum texture, const GLfixed *coords);
GLAPI void APIENTRY glMultiTexCoordP1ui(GLenum texture, GLenum type, GLuint coords);
GLAPI void APIENTRY glMultiTexCoordP1uiv(GLenum texture, GLenum type, const GLuint *coords);
GLAPI void APIENTRY glMultiTexCoordP2ui(GLenum texture, GLenum type, GLuint coords);
GLAPI void APIENTRY glMultiTexCoordP2uiv(GLenum texture, GLenum type, const GLuint *coords);
GLAPI void APIENTRY glMultiTexCoordP3ui(GLenum texture, GLenum type, GLuint coords);
GLAPI void APIENTRY glMultiTexCoordP3uiv(GLenum texture, GLenum type, const GLuint *coords);
GLAPI void APIENTRY glMultiTexCoordP4ui(GLenum texture, GLenum type, GLuint coords);
GLAPI void APIENTRY glMultiTexCoordP4uiv(GLenum texture, GLenum type, const GLuint *coords);
GLAPI void APIENTRY glMultiTexCoordPointerEXT(GLenum texunit, GLint size, GLenum type, GLsizei stride, const void *pointer);
GLAPI void APIENTRY glMultiTexEnvfEXT(GLenum texunit, GLenum target, GLenum pname, GLfloat param);
GLAPI void APIENTRY glMultiTexEnvfvEXT(GLenum texunit, GLenum target, GLenum pname, const GLfloat *params);
GLAPI void APIENTRY glMultiTexEnviEXT(GLenum texunit, GLenum target, GLenum pname, GLint param);
GLAPI void APIENTRY glMultiTexEnvivEXT(GLenum texunit, GLenum target, GLenum pname, const GLint *params);
GLAPI void APIENTRY glMultiTexGendEXT(GLenum texunit, GLenum coord, GLenum pname, GLdouble param);
GLAPI void APIENTRY glMultiTexGendvEXT(GLenum texunit, GLenum coord, GLenum pname, const GLdouble *params);
GLAPI void APIENTRY glMultiTexGenfEXT(GLenum texunit, GLenum coord, GLenum pname, GLfloat param);
GLAPI void APIENTRY glMultiTexGenfvEXT(GLenum texunit, GLenum coord, GLenum pname, const GLfloat *params);
GLAPI void APIENTRY glMultiTexGeniEXT(GLenum texunit, GLenum coord, GLenum pname, GLint param);
GLAPI void APIENTRY glMultiTexGenivEXT(GLenum texunit, GLenum coord, GLenum pname, const GLint *params);
GLAPI void APIENTRY glMultiTexImage1DEXT(GLenum texunit, GLenum target, GLint level, GLint internalformat, GLsizei width, GLint border, GLenum format, GLenum type, const void *pixels);
GLAPI void APIENTRY glMultiTexImage2DEXT(GLenum texunit, GLenum target, GLint level, GLint internalformat, GLsizei width, GLsizei height, GLint border, GLenum format, GLenum type, const void *pixels);
GLAPI void APIENTRY glMultiTexImage3DEXT(GLenum texunit, GLenum target, GLint level, GLint internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLenum format, GLenum type, const void *pixels);
GLAPI void APIENTRY glMultiTexParameterIivEXT(GLenum texunit, GLenum target, GLenum pname, const GLint *params);
GLAPI void APIENTRY glMultiTexParameterIuivEXT(GLenum texunit, GLenum target, GLenum pname, const GLuint *params);
GLAPI void APIENTRY glMultiTexParameterfEXT(GLenum texunit, GLenum target, GLenum pname, GLfloat param);
GLAPI void APIENTRY glMultiTexParameterfvEXT(GLenum texunit, GLenum target, GLenum pname, const GLfloat *params);
GLAPI void APIENTRY glMultiTexParameteriEXT(GLenum texunit, GLenum target, GLenum pname, GLint param);
GLAPI void APIENTRY glMultiTexParameterivEXT(GLenum texunit, GLenum target, GLenum pname, const GLint *params);
GLAPI void APIENTRY glMultiTexRenderbufferEXT(GLenum texunit, GLenum target, GLuint renderbuffer);
GLAPI void APIENTRY glMultiTexSubImage1DEXT(GLenum texunit, GLenum target, GLint level, GLint xoffset, GLsizei width, GLenum format, GLenum type, const void *pixels);
GLAPI void APIENTRY glMultiTexSubImage2DEXT(GLenum texunit, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLenum type, const void *pixels);
GLAPI void APIENTRY glMultiTexSubImage3DEXT(GLenum texunit, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void *pixels);
GLAPI void APIENTRY glMulticastBarrierNV(void);
GLAPI void APIENTRY glMulticastBlitFramebufferNV(GLuint srcGpu, GLuint dstGpu, GLint srcX0, GLint srcY0, GLint srcX1, GLint srcY1, GLint dstX0, GLint dstY0, GLint dstX1, GLint dstY1, GLbitfield mask, GLenum filter);
GLAPI void APIENTRY glMulticastBufferSubDataNV(GLbitfield gpuMask, GLuint buffer, GLintptr offset, GLsizeiptr size, const void *data);
GLAPI void APIENTRY glMulticastCopyBufferSubDataNV(GLuint readGpu, GLbitfield writeGpuMask, GLuint readBuffer, GLuint writeBuffer, GLintptr readOffset, GLintptr writeOffset, GLsizeiptr size);
GLAPI void APIENTRY glMulticastCopyImageSubDataNV(GLuint srcGpu, GLbitfield dstGpuMask, GLuint srcName, GLenum srcTarget, GLint srcLevel, GLint srcX, GLint srcY, GLint srcZ, GLuint dstName, GLenum dstTarget, GLint dstLevel, GLint dstX, GLint dstY, GLint dstZ, GLsizei srcWidth, GLsizei srcHeight, GLsizei srcDepth);
GLAPI void APIENTRY glMulticastFramebufferSampleLocationsfvNV(GLuint gpu, GLuint framebuffer, GLuint start, GLsizei count, const GLfloat *v);
GLAPI void APIENTRY glMulticastGetQueryObjecti64vNV(GLuint gpu, GLuint id, GLenum pname, GLint64 *params);
GLAPI void APIENTRY glMulticastGetQueryObjectivNV(GLuint gpu, GLuint id, GLenum pname, GLint *params);
GLAPI void APIENTRY glMulticastGetQueryObjectui64vNV(GLuint gpu, GLuint id, GLenum pname, GLuint64 *params);
GLAPI void APIENTRY glMulticastGetQueryObjectuivNV(GLuint gpu, GLuint id, GLenum pname, GLuint *params);
GLAPI void APIENTRY glMulticastScissorArrayvNVX(GLuint gpu, GLuint first, GLsizei count, const GLint *v);
GLAPI void APIENTRY glMulticastViewportArrayvNVX(GLuint gpu, GLuint first, GLsizei count, const GLfloat *v);
GLAPI void APIENTRY glMulticastViewportPositionWScaleNVX(GLuint gpu, GLuint index, GLfloat xcoeff, GLfloat ycoeff);
GLAPI void APIENTRY glMulticastWaitSyncNV(GLuint signalGpu, GLbitfield waitGpuMask);
GLAPI void APIENTRY glNVENCInterOpFunctionNVX(void *dataPtr);
GLAPI void APIENTRY glNamedBufferAttachMemoryNV(GLuint buffer, GLuint memory, GLuint64 offset);
GLAPI void APIENTRY glNamedBufferData(GLuint buffer, GLsizeiptr size, const void *data, GLenum usage);
GLAPI void APIENTRY glNamedBufferDataEXT(GLuint buffer, GLsizeiptr size, const void *data, GLenum usage);
GLAPI void APIENTRY glNamedBufferPageCommitmentARB(GLuint buffer, GLintptr offset, GLsizeiptr size, GLboolean commit);
GLAPI void APIENTRY glNamedBufferPageCommitmentEXT(GLuint buffer, GLintptr offset, GLsizeiptr size, GLboolean commit);
GLAPI void APIENTRY glNamedBufferStorage(GLuint buffer, GLsizeiptr size, const void *data, GLbitfield flags);
GLAPI void APIENTRY glNamedBufferStorageEXT(GLuint buffer, GLsizeiptr size, const void *data, GLbitfield flags);
GLAPI void APIENTRY glNamedBufferStorageExternalEXT(GLuint buffer, GLintptr offset, GLsizeiptr size, GLeglClientBufferEXT clientBuffer, GLbitfield flags);
GLAPI void APIENTRY glNamedBufferStorageMemEXT(GLuint buffer, GLsizeiptr size, GLuint memory, GLuint64 offset);
GLAPI void APIENTRY glNamedBufferSubData(GLuint buffer, GLintptr offset, GLsizeiptr size, const void *data);
GLAPI void APIENTRY glNamedBufferSubDataEXT(GLuint buffer, GLintptr offset, GLsizeiptr size, const void *data);
GLAPI void APIENTRY glNamedCopyBufferSubDataEXT(GLuint readBuffer, GLuint writeBuffer, GLintptr readOffset, GLintptr writeOffset, GLsizeiptr size);
GLAPI void APIENTRY glNamedFramebufferDrawBuffer(GLuint framebuffer, GLenum buf);
GLAPI void APIENTRY glNamedFramebufferDrawBuffers(GLuint framebuffer, GLsizei n, const GLenum *bufs);
GLAPI void APIENTRY glNamedFramebufferParameteri(GLuint framebuffer, GLenum pname, GLint param);
GLAPI void APIENTRY glNamedFramebufferParameteriEXT(GLuint framebuffer, GLenum pname, GLint param);
GLAPI void APIENTRY glNamedFramebufferReadBuffer(GLuint framebuffer, GLenum src);
GLAPI void APIENTRY glNamedFramebufferRenderbuffer(GLuint framebuffer, GLenum attachment, GLenum renderbuffertarget, GLuint renderbuffer);
GLAPI void APIENTRY glNamedFramebufferRenderbufferEXT(GLuint framebuffer, GLenum attachment, GLenum renderbuffertarget, GLuint renderbuffer);
GLAPI void APIENTRY glNamedFramebufferSampleLocationsfvARB(GLuint framebuffer, GLuint start, GLsizei count, const GLfloat *v);
GLAPI void APIENTRY glNamedFramebufferSampleLocationsfvNV(GLuint framebuffer, GLuint start, GLsizei count, const GLfloat *v);
GLAPI void APIENTRY glNamedFramebufferSamplePositionsfvAMD(GLuint framebuffer, GLuint numsamples, GLuint pixelindex, const GLfloat *values);
GLAPI void APIENTRY glNamedFramebufferTexture(GLuint framebuffer, GLenum attachment, GLuint texture, GLint level);
GLAPI void APIENTRY glNamedFramebufferTexture1DEXT(GLuint framebuffer, GLenum attachment, GLenum textarget, GLuint texture, GLint level);
GLAPI void APIENTRY glNamedFramebufferTexture2DEXT(GLuint framebuffer, GLenum attachment, GLenum textarget, GLuint texture, GLint level);
GLAPI void APIENTRY glNamedFramebufferTexture3DEXT(GLuint framebuffer, GLenum attachment, GLenum textarget, GLuint texture, GLint level, GLint zoffset);
GLAPI void APIENTRY glNamedFramebufferTextureEXT(GLuint framebuffer, GLenum attachment, GLuint texture, GLint level);
GLAPI void APIENTRY glNamedFramebufferTextureFaceEXT(GLuint framebuffer, GLenum attachment, GLuint texture, GLint level, GLenum face);
GLAPI void APIENTRY glNamedFramebufferTextureLayer(GLuint framebuffer, GLenum attachment, GLuint texture, GLint level, GLint layer);
GLAPI void APIENTRY glNamedFramebufferTextureLayerEXT(GLuint framebuffer, GLenum attachment, GLuint texture, GLint level, GLint layer);
GLAPI void APIENTRY glNamedProgramLocalParameter4dEXT(GLuint program, GLenum target, GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w);
GLAPI void APIENTRY glNamedProgramLocalParameter4dvEXT(GLuint program, GLenum target, GLuint index, const GLdouble *params);
GLAPI void APIENTRY glNamedProgramLocalParameter4fEXT(GLuint program, GLenum target, GLuint index, GLfloat x, GLfloat y, GLfloat z, GLfloat w);
GLAPI void APIENTRY glNamedProgramLocalParameter4fvEXT(GLuint program, GLenum target, GLuint index, const GLfloat *params);
GLAPI void APIENTRY glNamedProgramLocalParameterI4iEXT(GLuint program, GLenum target, GLuint index, GLint x, GLint y, GLint z, GLint w);
GLAPI void APIENTRY glNamedProgramLocalParameterI4ivEXT(GLuint program, GLenum target, GLuint index, const GLint *params);
GLAPI void APIENTRY glNamedProgramLocalParameterI4uiEXT(GLuint program, GLenum target, GLuint index, GLuint x, GLuint y, GLuint z, GLuint w);
GLAPI void APIENTRY glNamedProgramLocalParameterI4uivEXT(GLuint program, GLenum target, GLuint index, const GLuint *params);
GLAPI void APIENTRY glNamedProgramLocalParameters4fvEXT(GLuint program, GLenum target, GLuint index, GLsizei count, const GLfloat *params);
GLAPI void APIENTRY glNamedProgramLocalParametersI4ivEXT(GLuint program, GLenum target, GLuint index, GLsizei count, const GLint *params);
GLAPI void APIENTRY glNamedProgramLocalParametersI4uivEXT(GLuint program, GLenum target, GLuint index, GLsizei count, const GLuint *params);
GLAPI void APIENTRY glNamedProgramStringEXT(GLuint program, GLenum target, GLenum format, GLsizei len, const void *string);
GLAPI void APIENTRY glNamedRenderbufferStorage(GLuint renderbuffer, GLenum internalformat, GLsizei width, GLsizei height);
GLAPI void APIENTRY glNamedRenderbufferStorageEXT(GLuint renderbuffer, GLenum internalformat, GLsizei width, GLsizei height);
GLAPI void APIENTRY glNamedRenderbufferStorageMultisample(GLuint renderbuffer, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height);
GLAPI void APIENTRY glNamedRenderbufferStorageMultisampleAdvancedAMD(GLuint renderbuffer, GLsizei samples, GLsizei storageSamples, GLenum internalformat, GLsizei width, GLsizei height);
GLAPI void APIENTRY glNamedRenderbufferStorageMultisampleCoverageEXT(GLuint renderbuffer, GLsizei coverageSamples, GLsizei colorSamples, GLenum internalformat, GLsizei width, GLsizei height);
GLAPI void APIENTRY glNamedRenderbufferStorageMultisampleEXT(GLuint renderbuffer, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height);
GLAPI void APIENTRY glNamedStringARB(GLenum type, GLint namelen, const GLchar *name, GLint stringlen, const GLchar *string);
GLAPI void APIENTRY glNewList(GLuint list, GLenum mode);
GLAPI GLuint APIENTRY glNewObjectBufferATI(GLsizei size, const void *pointer, GLenum usage);
GLAPI void APIENTRY glNormal3b(GLbyte nx, GLbyte ny, GLbyte nz);
GLAPI void APIENTRY glNormal3bv(const GLbyte *v);
GLAPI void APIENTRY glNormal3d(GLdouble nx, GLdouble ny, GLdouble nz);
GLAPI void APIENTRY glNormal3dv(const GLdouble *v);
GLAPI void APIENTRY glNormal3f(GLfloat nx, GLfloat ny, GLfloat nz);
GLAPI void APIENTRY glNormal3fVertex3fSUN(GLfloat nx, GLfloat ny, GLfloat nz, GLfloat x, GLfloat y, GLfloat z);
GLAPI void APIENTRY glNormal3fVertex3fvSUN(const GLfloat *n, const GLfloat *v);
GLAPI void APIENTRY glNormal3fv(const GLfloat *v);
GLAPI void APIENTRY glNormal3hNV(GLhalf nx, GLhalf ny, GLhalf nz);
GLAPI void APIENTRY glNormal3hvNV(const GLhalf *v);
GLAPI void APIENTRY glNormal3i(GLint nx, GLint ny, GLint nz);
GLAPI void APIENTRY glNormal3iv(const GLint *v);
GLAPI void APIENTRY glNormal3s(GLshort nx, GLshort ny, GLshort nz);
GLAPI void APIENTRY glNormal3sv(const GLshort *v);
GLAPI void APIENTRY glNormal3x(GLfixed nx, GLfixed ny, GLfixed nz);
GLAPI void APIENTRY glNormal3xOES(GLfixed nx, GLfixed ny, GLfixed nz);
GLAPI void APIENTRY glNormal3xvOES(const GLfixed *coords);
GLAPI void APIENTRY glNormalFormatNV(GLenum type, GLsizei stride);
GLAPI void APIENTRY glNormalP3ui(GLenum type, GLuint coords);
GLAPI void APIENTRY glNormalP3uiv(GLenum type, const GLuint *coords);
GLAPI void APIENTRY glNormalPointer(GLenum type, GLsizei stride, const void *pointer);
GLAPI void APIENTRY glNormalPointerEXT(GLenum type, GLsizei stride, GLsizei count, const void *pointer);
GLAPI void APIENTRY glNormalPointerListIBM(GLenum type, GLint stride, const void **pointer, GLint ptrstride);
GLAPI void APIENTRY glNormalPointervINTEL(GLenum type, const void **pointer);
GLAPI void APIENTRY glNormalStream3bATI(GLenum stream, GLbyte nx, GLbyte ny, GLbyte nz);
GLAPI void APIENTRY glNormalStream3bvATI(GLenum stream, const GLbyte *coords);
GLAPI void APIENTRY glNormalStream3dATI(GLenum stream, GLdouble nx, GLdouble ny, GLdouble nz);
GLAPI void APIENTRY glNormalStream3dvATI(GLenum stream, const GLdouble *coords);
GLAPI void APIENTRY glNormalStream3fATI(GLenum stream, GLfloat nx, GLfloat ny, GLfloat nz);
GLAPI void APIENTRY glNormalStream3fvATI(GLenum stream, const GLfloat *coords);
GLAPI void APIENTRY glNormalStream3iATI(GLenum stream, GLint nx, GLint ny, GLint nz);
GLAPI void APIENTRY glNormalStream3ivATI(GLenum stream, const GLint *coords);
GLAPI void APIENTRY glNormalStream3sATI(GLenum stream, GLshort nx, GLshort ny, GLshort nz);
GLAPI void APIENTRY glNormalStream3svATI(GLenum stream, const GLshort *coords);
GLAPI void APIENTRY glObjectLabel(GLenum identifier, GLuint name, GLsizei length, const GLchar *label);
GLAPI void APIENTRY glObjectLabelKHR(GLenum identifier, GLuint name, GLsizei length, const GLchar *label);
GLAPI void APIENTRY glObjectLabelOES(GLenum identifier, GLuint name, GLsizei length, const GLchar *label);
GLAPI void APIENTRY glObjectPtrLabel(const void *ptr, GLsizei length, const GLchar *label);
GLAPI void APIENTRY glObjectPtrLabelKHR(const void *ptr, GLsizei length, const GLchar *label);
GLAPI void APIENTRY glObjectPtrLabelOES(void *ptr, GLsizei length, const GLchar *label);
GLAPI GLenum APIENTRY glObjectPurgeableAPPLE(GLenum objectType, GLuint name, GLenum option);
GLAPI GLenum APIENTRY glObjectUnpurgeableAPPLE(GLenum objectType, GLuint name, GLenum option);
GLAPI void APIENTRY glOrtho(GLdouble left, GLdouble right, GLdouble bottom, GLdouble top, GLdouble zNear, GLdouble zFar);
GLAPI void APIENTRY glOrthof(GLfloat l, GLfloat r, GLfloat b, GLfloat t, GLfloat n, GLfloat f);
GLAPI void APIENTRY glOrthofOES(GLfloat l, GLfloat r, GLfloat b, GLfloat t, GLfloat n, GLfloat f);
GLAPI void APIENTRY glOrthox(GLfixed l, GLfixed r, GLfixed b, GLfixed t, GLfixed n, GLfixed f);
GLAPI void APIENTRY glOrthoxOES(GLfixed l, GLfixed r, GLfixed b, GLfixed t, GLfixed n, GLfixed f);
GLAPI void APIENTRY glPNTrianglesfATI(GLenum pname, GLfloat param);
GLAPI void APIENTRY glPNTrianglesiATI(GLenum pname, GLint param);
GLAPI void APIENTRY glPassTexCoordATI(GLuint dst, GLuint coord, GLenum swizzle);
GLAPI void APIENTRY glPassThrough(GLfloat token);
GLAPI void APIENTRY glPassThroughxOES(GLfixed token);
GLAPI void APIENTRY glPatchParameterfv(GLenum pname, const GLfloat *values);
GLAPI void APIENTRY glPatchParameterfvEXT(GLenum pname, const GLfloat *values);
GLAPI void APIENTRY glPatchParameterfvNV(GLenum pname, const GLfloat *values);
GLAPI void APIENTRY glPatchParameteri(GLenum pname, GLint value);
GLAPI void APIENTRY glPatchParameteriEXT(GLenum pname, GLint value);
GLAPI void APIENTRY glPatchParameteriNV(GLenum pname, GLint value);
GLAPI void APIENTRY glPatchParameteriOES(GLenum pname, GLint value);
GLAPI void APIENTRY glPathColorGenNV(GLenum color, GLenum genMode, GLenum colorFormat, const GLfloat *coeffs);
GLAPI void APIENTRY glPathCommandsNV(GLuint path, GLsizei numCommands, const GLubyte *commands, GLsizei numCoords, GLenum coordType, const void *coords);
GLAPI void APIENTRY glPathCoordsNV(GLuint path, GLsizei numCoords, GLenum coordType, const void *coords);
GLAPI void APIENTRY glPathCoverDepthFuncNV(GLenum func);
GLAPI void APIENTRY glPathDashArrayNV(GLuint path, GLsizei dashCount, const GLfloat *dashArray);
GLAPI void APIENTRY glPathFogGenNV(GLenum genMode);
GLAPI GLenum APIENTRY glPathGlyphIndexArrayNV(GLuint firstPathName, GLenum fontTarget, const void *fontName, GLbitfield fontStyle, GLuint firstGlyphIndex, GLsizei numGlyphs, GLuint pathParameterTemplate, GLfloat emScale);
GLAPI GLenum APIENTRY glPathGlyphIndexRangeNV(GLenum fontTarget, const void *fontName, GLbitfield fontStyle, GLuint pathParameterTemplate, GLfloat emScale, GLuint *baseAndCount);
GLAPI void APIENTRY glPathGlyphRangeNV(GLuint firstPathName, GLenum fontTarget, const void *fontName, GLbitfield fontStyle, GLuint firstGlyph, GLsizei numGlyphs, GLenum handleMissingGlyphs, GLuint pathParameterTemplate, GLfloat emScale);
GLAPI void APIENTRY glPathGlyphsNV(GLuint firstPathName, GLenum fontTarget, const void *fontName, GLbitfield fontStyle, GLsizei numGlyphs, GLenum type, const void *charcodes, GLenum handleMissingGlyphs, GLuint pathParameterTemplate, GLfloat emScale);
GLAPI GLenum APIENTRY glPathMemoryGlyphIndexArrayNV(GLuint firstPathName, GLenum fontTarget, GLsizeiptr fontSize, const void *fontData, GLsizei faceIndex, GLuint firstGlyphIndex, GLsizei numGlyphs, GLuint pathParameterTemplate, GLfloat emScale);
GLAPI void APIENTRY glPathParameterfNV(GLuint path, GLenum pname, GLfloat value);
GLAPI void APIENTRY glPathParameterfvNV(GLuint path, GLenum pname, const GLfloat *value);
GLAPI void APIENTRY glPathParameteriNV(GLuint path, GLenum pname, GLint value);
GLAPI void APIENTRY glPathParameterivNV(GLuint path, GLenum pname, const GLint *value);
GLAPI void APIENTRY glPathStencilDepthOffsetNV(GLfloat factor, GLfloat units);
GLAPI void APIENTRY glPathStencilFuncNV(GLenum func, GLint ref, GLuint mask);
GLAPI void APIENTRY glPathStringNV(GLuint path, GLenum format, GLsizei length, const void *pathString);
GLAPI void APIENTRY glPathSubCommandsNV(GLuint path, GLsizei commandStart, GLsizei commandsToDelete, GLsizei numCommands, const GLubyte *commands, GLsizei numCoords, GLenum coordType, const void *coords);
GLAPI void APIENTRY glPathSubCoordsNV(GLuint path, GLsizei coordStart, GLsizei numCoords, GLenum coordType, const void *coords);
GLAPI void APIENTRY glPathTexGenNV(GLenum texCoordSet, GLenum genMode, GLint components, const GLfloat *coeffs);
GLAPI void APIENTRY glPauseTransformFeedback(void);
GLAPI void APIENTRY glPauseTransformFeedbackEXT(void);
GLAPI void APIENTRY glPauseTransformFeedbackNV(void);
GLAPI void APIENTRY glPixelDataRangeNV(GLenum target, GLsizei length, const void *pointer);
GLAPI void APIENTRY glPixelMapfv(GLenum map, GLsizei mapsize, const GLfloat *values);
GLAPI void APIENTRY glPixelMapuiv(GLenum map, GLsizei mapsize, const GLuint *values);
GLAPI void APIENTRY glPixelMapusv(GLenum map, GLsizei mapsize, const GLushort *values);
GLAPI void APIENTRY glPixelMapx(GLenum map, GLint size, const GLfixed *values);
GLAPI void APIENTRY glPixelStoref(GLenum pname, GLfloat param);
GLAPI void APIENTRY glPixelStorei(GLenum pname, GLint param);
GLAPI void APIENTRY glPixelStorex(GLenum pname, GLfixed param);
GLAPI void APIENTRY glPixelTexGenParameterfSGIS(GLenum pname, GLfloat param);
GLAPI void APIENTRY glPixelTexGenParameterfvSGIS(GLenum pname, const GLfloat *params);
GLAPI void APIENTRY glPixelTexGenParameteriSGIS(GLenum pname, GLint param);
GLAPI void APIENTRY glPixelTexGenParameterivSGIS(GLenum pname, const GLint *params);
GLAPI void APIENTRY glPixelTexGenSGIX(GLenum mode);
GLAPI void APIENTRY glPixelTransferf(GLenum pname, GLfloat param);
GLAPI void APIENTRY glPixelTransferi(GLenum pname, GLint param);
GLAPI void APIENTRY glPixelTransferxOES(GLenum pname, GLfixed param);
GLAPI void APIENTRY glPixelTransformParameterfEXT(GLenum target, GLenum pname, GLfloat param);
GLAPI void APIENTRY glPixelTransformParameterfvEXT(GLenum target, GLenum pname, const GLfloat *params);
GLAPI void APIENTRY glPixelTransformParameteriEXT(GLenum target, GLenum pname, GLint param);
GLAPI void APIENTRY glPixelTransformParameterivEXT(GLenum target, GLenum pname, const GLint *params);
GLAPI void APIENTRY glPixelZoom(GLfloat xfactor, GLfloat yfactor);
GLAPI void APIENTRY glPixelZoomxOES(GLfixed xfactor, GLfixed yfactor);
GLAPI GLboolean APIENTRY glPointAlongPathNV(GLuint path, GLsizei startSegment, GLsizei numSegments, GLfloat distance, GLfloat *x, GLfloat *y, GLfloat *tangentX, GLfloat *tangentY);
GLAPI void APIENTRY glPointParameterf(GLenum pname, GLfloat param);
GLAPI void APIENTRY glPointParameterfARB(GLenum pname, GLfloat param);
GLAPI void APIENTRY glPointParameterfEXT(GLenum pname, GLfloat param);
GLAPI void APIENTRY glPointParameterfSGIS(GLenum pname, GLfloat param);
GLAPI void APIENTRY glPointParameterfv(GLenum pname, const GLfloat *params);
GLAPI void APIENTRY glPointParameterfvARB(GLenum pname, const GLfloat *params);
GLAPI void APIENTRY glPointParameterfvEXT(GLenum pname, const GLfloat *params);
GLAPI void APIENTRY glPointParameterfvSGIS(GLenum pname, const GLfloat *params);
GLAPI void APIENTRY glPointParameteri(GLenum pname, GLint param);
GLAPI void APIENTRY glPointParameteriNV(GLenum pname, GLint param);
GLAPI void APIENTRY glPointParameteriv(GLenum pname, const GLint *params);
GLAPI void APIENTRY glPointParameterivNV(GLenum pname, const GLint *params);
GLAPI void APIENTRY glPointParameterx(GLenum pname, GLfixed param);
GLAPI void APIENTRY glPointParameterxOES(GLenum pname, GLfixed param);
GLAPI void APIENTRY glPointParameterxv(GLenum pname, const GLfixed *params);
GLAPI void APIENTRY glPointParameterxvOES(GLenum pname, const GLfixed *params);
GLAPI void APIENTRY glPointSize(GLfloat size);
GLAPI void APIENTRY glPointSizePointerOES(GLenum type, GLsizei stride, const void *pointer);
GLAPI void APIENTRY glPointSizex(GLfixed size);
GLAPI void APIENTRY glPointSizexOES(GLfixed size);
GLAPI GLint APIENTRY glPollAsyncSGIX(GLuint *markerp);
GLAPI GLint APIENTRY glPollInstrumentsSGIX(GLint *marker_p);
GLAPI void APIENTRY glPolygonMode(GLenum face, GLenum mode);
GLAPI void APIENTRY glPolygonModeNV(GLenum face, GLenum mode);
GLAPI void APIENTRY glPolygonOffset(GLfloat factor, GLfloat units);
GLAPI void APIENTRY glPolygonOffsetClamp(GLfloat factor, GLfloat units, GLfloat clamp);
GLAPI void APIENTRY glPolygonOffsetClampEXT(GLfloat factor, GLfloat units, GLfloat clamp);
GLAPI void APIENTRY glPolygonOffsetEXT(GLfloat factor, GLfloat bias);
GLAPI void APIENTRY glPolygonOffsetx(GLfixed factor, GLfixed units);
GLAPI void APIENTRY glPolygonOffsetxOES(GLfixed factor, GLfixed units);
GLAPI void APIENTRY glPolygonStipple(const GLubyte *mask);
GLAPI void APIENTRY glPopAttrib(void);
GLAPI void APIENTRY glPopClientAttrib(void);
GLAPI void APIENTRY glPopDebugGroup(void);
GLAPI void APIENTRY glPopDebugGroupKHR(void);
GLAPI void APIENTRY glPopDebugGroupOES(void);
GLAPI void APIENTRY glPopGroupMarkerEXT(void);
GLAPI void APIENTRY glPopMatrix(void);
GLAPI void APIENTRY glPopName(void);
GLAPI void APIENTRY glPresentFrameDualFillNV(GLuint video_slot, GLuint64 minPresentTime, GLuint beginPresentTimeId, GLuint presentDurationId, GLenum type, GLenum target0, GLuint fill0, GLenum target1, GLuint fill1, GLenum target2, GLuint fill2, GLenum target3, GLuint fill3);
GLAPI void APIENTRY glPresentFrameKeyedNV(GLuint video_slot, GLuint64 minPresentTime, GLuint beginPresentTimeId, GLuint presentDurationId, GLenum type, GLenum target0, GLuint fill0, GLuint key0, GLenum target1, GLuint fill1, GLuint key1);
GLAPI void APIENTRY glPrimitiveBoundingBox(GLfloat minX, GLfloat minY, GLfloat minZ, GLfloat minW, GLfloat maxX, GLfloat maxY, GLfloat maxZ, GLfloat maxW);
GLAPI void APIENTRY glPrimitiveBoundingBoxARB(GLfloat minX, GLfloat minY, GLfloat minZ, GLfloat minW, GLfloat maxX, GLfloat maxY, GLfloat maxZ, GLfloat maxW);
GLAPI void APIENTRY glPrimitiveBoundingBoxEXT(GLfloat minX, GLfloat minY, GLfloat minZ, GLfloat minW, GLfloat maxX, GLfloat maxY, GLfloat maxZ, GLfloat maxW);
GLAPI void APIENTRY glPrimitiveBoundingBoxOES(GLfloat minX, GLfloat minY, GLfloat minZ, GLfloat minW, GLfloat maxX, GLfloat maxY, GLfloat maxZ, GLfloat maxW);
GLAPI void APIENTRY glPrimitiveRestart(void);
GLAPI void APIENTRY glPrimitiveRestartIndex(GLuint index);
GLAPI void APIENTRY glPrimitiveRestartIndexNV(GLuint index);
GLAPI void APIENTRY glPrimitiveRestartNV(void);
GLAPI void APIENTRY glPrioritizeTextures(GLsizei n, const GLuint *textures, const GLfloat *priorities);
GLAPI void APIENTRY glPrioritizeTexturesEXT(GLsizei n, const GLuint *textures, const GLclampf *priorities);
GLAPI void APIENTRY glPrioritizeTexturesxOES(GLsizei n, const GLuint *textures, const GLfixed *priorities);
GLAPI void APIENTRY glProgramBinary(GLuint program, GLenum binaryFormat, const void *binary, GLsizei length);
GLAPI void APIENTRY glProgramBinaryOES(GLuint program, GLenum binaryFormat, const void *binary, GLint length);
GLAPI void APIENTRY glProgramBufferParametersIivNV(GLenum target, GLuint bindingIndex, GLuint wordIndex, GLsizei count, const GLint *params);
GLAPI void APIENTRY glProgramBufferParametersIuivNV(GLenum target, GLuint bindingIndex, GLuint wordIndex, GLsizei count, const GLuint *params);
GLAPI void APIENTRY glProgramBufferParametersfvNV(GLenum target, GLuint bindingIndex, GLuint wordIndex, GLsizei count, const GLfloat *params);
GLAPI void APIENTRY glProgramEnvParameter4dARB(GLenum target, GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w);
GLAPI void APIENTRY glProgramEnvParameter4dvARB(GLenum target, GLuint index, const GLdouble *params);
GLAPI void APIENTRY glProgramEnvParameter4fARB(GLenum target, GLuint index, GLfloat x, GLfloat y, GLfloat z, GLfloat w);
GLAPI void APIENTRY glProgramEnvParameter4fvARB(GLenum target, GLuint index, const GLfloat *params);
GLAPI void APIENTRY glProgramEnvParameterI4iNV(GLenum target, GLuint index, GLint x, GLint y, GLint z, GLint w);
GLAPI void APIENTRY glProgramEnvParameterI4ivNV(GLenum target, GLuint index, const GLint *params);
GLAPI void APIENTRY glProgramEnvParameterI4uiNV(GLenum target, GLuint index, GLuint x, GLuint y, GLuint z, GLuint w);
GLAPI void APIENTRY glProgramEnvParameterI4uivNV(GLenum target, GLuint index, const GLuint *params);
GLAPI void APIENTRY glProgramEnvParameters4fvEXT(GLenum target, GLuint index, GLsizei count, const GLfloat *params);
GLAPI void APIENTRY glProgramEnvParametersI4ivNV(GLenum target, GLuint index, GLsizei count, const GLint *params);
GLAPI void APIENTRY glProgramEnvParametersI4uivNV(GLenum target, GLuint index, GLsizei count, const GLuint *params);
GLAPI void APIENTRY glProgramLocalParameter4dARB(GLenum target, GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w);
GLAPI void APIENTRY glProgramLocalParameter4dvARB(GLenum target, GLuint index, const GLdouble *params);
GLAPI void APIENTRY glProgramLocalParameter4fARB(GLenum target, GLuint index, GLfloat x, GLfloat y, GLfloat z, GLfloat w);
GLAPI void APIENTRY glProgramLocalParameter4fvARB(GLenum target, GLuint index, const GLfloat *params);
GLAPI void APIENTRY glProgramLocalParameterI4iNV(GLenum target, GLuint index, GLint x, GLint y, GLint z, GLint w);
GLAPI void APIENTRY glProgramLocalParameterI4ivNV(GLenum target, GLuint index, const GLint *params);
GLAPI void APIENTRY glProgramLocalParameterI4uiNV(GLenum target, GLuint index, GLuint x, GLuint y, GLuint z, GLuint w);
GLAPI void APIENTRY glProgramLocalParameterI4uivNV(GLenum target, GLuint index, const GLuint *params);
GLAPI void APIENTRY glProgramLocalParameters4fvEXT(GLenum target, GLuint index, GLsizei count, const GLfloat *params);
GLAPI void APIENTRY glProgramLocalParametersI4ivNV(GLenum target, GLuint index, GLsizei count, const GLint *params);
GLAPI void APIENTRY glProgramLocalParametersI4uivNV(GLenum target, GLuint index, GLsizei count, const GLuint *params);
GLAPI void APIENTRY glProgramNamedParameter4dNV(GLuint id, GLsizei len, const GLubyte *name, GLdouble x, GLdouble y, GLdouble z, GLdouble w);
GLAPI void APIENTRY glProgramNamedParameter4dvNV(GLuint id, GLsizei len, const GLubyte *name, const GLdouble *v);
GLAPI void APIENTRY glProgramNamedParameter4fNV(GLuint id, GLsizei len, const GLubyte *name, GLfloat x, GLfloat y, GLfloat z, GLfloat w);
GLAPI void APIENTRY glProgramNamedParameter4fvNV(GLuint id, GLsizei len, const GLubyte *name, const GLfloat *v);
GLAPI void APIENTRY glProgramParameter4dNV(GLenum target, GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w);
GLAPI void APIENTRY glProgramParameter4dvNV(GLenum target, GLuint index, const GLdouble *v);
GLAPI void APIENTRY glProgramParameter4fNV(GLenum target, GLuint index, GLfloat x, GLfloat y, GLfloat z, GLfloat w);
GLAPI void APIENTRY glProgramParameter4fvNV(GLenum target, GLuint index, const GLfloat *v);
GLAPI void APIENTRY glProgramParameteri(GLuint program, GLenum pname, GLint value);
GLAPI void APIENTRY glProgramParameteriARB(GLuint program, GLenum pname, GLint value);
GLAPI void APIENTRY glProgramParameteriEXT(GLuint program, GLenum pname, GLint value);
GLAPI void APIENTRY glProgramParameters4dvNV(GLenum target, GLuint index, GLsizei count, const GLdouble *v);
GLAPI void APIENTRY glProgramParameters4fvNV(GLenum target, GLuint index, GLsizei count, const GLfloat *v);
GLAPI void APIENTRY glProgramPathFragmentInputGenNV(GLuint program, GLint location, GLenum genMode, GLint components, const GLfloat *coeffs);
GLAPI void APIENTRY glProgramStringARB(GLenum target, GLenum format, GLsizei len, const void *string);
GLAPI void APIENTRY glProgramSubroutineParametersuivNV(GLenum target, GLsizei count, const GLuint *params);
GLAPI void APIENTRY glProgramUniform1d(GLuint program, GLint location, GLdouble v0);
GLAPI void APIENTRY glProgramUniform1dEXT(GLuint program, GLint location, GLdouble x);
GLAPI void APIENTRY glProgramUniform1dv(GLuint program, GLint location, GLsizei count, const GLdouble *value);
GLAPI void APIENTRY glProgramUniform1dvEXT(GLuint program, GLint location, GLsizei count, const GLdouble *value);
GLAPI void APIENTRY glProgramUniform1f(GLuint program, GLint location, GLfloat v0);
GLAPI void APIENTRY glProgramUniform1fEXT(GLuint program, GLint location, GLfloat v0);
GLAPI void APIENTRY glProgramUniform1fv(GLuint program, GLint location, GLsizei count, const GLfloat *value);
GLAPI void APIENTRY glProgramUniform1fvEXT(GLuint program, GLint location, GLsizei count, const GLfloat *value);
GLAPI void APIENTRY glProgramUniform1i(GLuint program, GLint location, GLint v0);
GLAPI void APIENTRY glProgramUniform1i64ARB(GLuint program, GLint location, GLint64 x);
GLAPI void APIENTRY glProgramUniform1i64NV(GLuint program, GLint location, GLint64 x);
GLAPI void APIENTRY glProgramUniform1i64vARB(GLuint program, GLint location, GLsizei count, const GLint64 *value);
GLAPI void APIENTRY glProgramUniform1i64vNV(GLuint program, GLint location, GLsizei count, const GLint64 *value);
GLAPI void APIENTRY glProgramUniform1iEXT(GLuint program, GLint location, GLint v0);
GLAPI void APIENTRY glProgramUniform1iv(GLuint program, GLint location, GLsizei count, const GLint *value);
GLAPI void APIENTRY glProgramUniform1ivEXT(GLuint program, GLint location, GLsizei count, const GLint *value);
GLAPI void APIENTRY glProgramUniform1ui(GLuint program, GLint location, GLuint v0);
GLAPI void APIENTRY glProgramUniform1ui64ARB(GLuint program, GLint location, GLuint64 x);
GLAPI void APIENTRY glProgramUniform1ui64NV(GLuint program, GLint location, GLuint64 x);
GLAPI void APIENTRY glProgramUniform1ui64vARB(GLuint program, GLint location, GLsizei count, const GLuint64 *value);
GLAPI void APIENTRY glProgramUniform1ui64vNV(GLuint program, GLint location, GLsizei count, const GLuint64 *value);
GLAPI void APIENTRY glProgramUniform1uiEXT(GLuint program, GLint location, GLuint v0);
GLAPI void APIENTRY glProgramUniform1uiv(GLuint program, GLint location, GLsizei count, const GLuint *value);
GLAPI void APIENTRY glProgramUniform1uivEXT(GLuint program, GLint location, GLsizei count, const GLuint *value);
GLAPI void APIENTRY glProgramUniform2d(GLuint program, GLint location, GLdouble v0, GLdouble v1);
GLAPI void APIENTRY glProgramUniform2dEXT(GLuint program, GLint location, GLdouble x, GLdouble y);
GLAPI void APIENTRY glProgramUniform2dv(GLuint program, GLint location, GLsizei count, const GLdouble *value);
GLAPI void APIENTRY glProgramUniform2dvEXT(GLuint program, GLint location, GLsizei count, const GLdouble *value);
GLAPI void APIENTRY glProgramUniform2f(GLuint program, GLint location, GLfloat v0, GLfloat v1);
GLAPI void APIENTRY glProgramUniform2fEXT(GLuint program, GLint location, GLfloat v0, GLfloat v1);
GLAPI void APIENTRY glProgramUniform2fv(GLuint program, GLint location, GLsizei count, const GLfloat *value);
GLAPI void APIENTRY glProgramUniform2fvEXT(GLuint program, GLint location, GLsizei count, const GLfloat *value);
GLAPI void APIENTRY glProgramUniform2i(GLuint program, GLint location, GLint v0, GLint v1);
GLAPI void APIENTRY glProgramUniform2i64ARB(GLuint program, GLint location, GLint64 x, GLint64 y);
GLAPI void APIENTRY glProgramUniform2i64NV(GLuint program, GLint location, GLint64 x, GLint64 y);
GLAPI void APIENTRY glProgramUniform2i64vARB(GLuint program, GLint location, GLsizei count, const GLint64 *value);
GLAPI void APIENTRY glProgramUniform2i64vNV(GLuint program, GLint location, GLsizei count, const GLint64 *value);
GLAPI void APIENTRY glProgramUniform2iEXT(GLuint program, GLint location, GLint v0, GLint v1);
GLAPI void APIENTRY glProgramUniform2iv(GLuint program, GLint location, GLsizei count, const GLint *value);
GLAPI void APIENTRY glProgramUniform2ivEXT(GLuint program, GLint location, GLsizei count, const GLint *value);
GLAPI void APIENTRY glProgramUniform2ui(GLuint program, GLint location, GLuint v0, GLuint v1);
GLAPI void APIENTRY glProgramUniform2ui64ARB(GLuint program, GLint location, GLuint64 x, GLuint64 y);
GLAPI void APIENTRY glProgramUniform2ui64NV(GLuint program, GLint location, GLuint64 x, GLuint64 y);
GLAPI void APIENTRY glProgramUniform2ui64vARB(GLuint program, GLint location, GLsizei count, const GLuint64 *value);
GLAPI void APIENTRY glProgramUniform2ui64vNV(GLuint program, GLint location, GLsizei count, const GLuint64 *value);
GLAPI void APIENTRY glProgramUniform2uiEXT(GLuint program, GLint location, GLuint v0, GLuint v1);
GLAPI void APIENTRY glProgramUniform2uiv(GLuint program, GLint location, GLsizei count, const GLuint *value);
GLAPI void APIENTRY glProgramUniform2uivEXT(GLuint program, GLint location, GLsizei count, const GLuint *value);
GLAPI void APIENTRY glProgramUniform3d(GLuint program, GLint location, GLdouble v0, GLdouble v1, GLdouble v2);
GLAPI void APIENTRY glProgramUniform3dEXT(GLuint program, GLint location, GLdouble x, GLdouble y, GLdouble z);
GLAPI void APIENTRY glProgramUniform3dv(GLuint program, GLint location, GLsizei count, const GLdouble *value);
GLAPI void APIENTRY glProgramUniform3dvEXT(GLuint program, GLint location, GLsizei count, const GLdouble *value);
GLAPI void APIENTRY glProgramUniform3f(GLuint program, GLint location, GLfloat v0, GLfloat v1, GLfloat v2);
GLAPI void APIENTRY glProgramUniform3fEXT(GLuint program, GLint location, GLfloat v0, GLfloat v1, GLfloat v2);
GLAPI void APIENTRY glProgramUniform3fv(GLuint program, GLint location, GLsizei count, const GLfloat *value);
GLAPI void APIENTRY glProgramUniform3fvEXT(GLuint program, GLint location, GLsizei count, const GLfloat *value);
GLAPI void APIENTRY glProgramUniform3i(GLuint program, GLint location, GLint v0, GLint v1, GLint v2);
GLAPI void APIENTRY glProgramUniform3i64ARB(GLuint program, GLint location, GLint64 x, GLint64 y, GLint64 z);
GLAPI void APIENTRY glProgramUniform3i64NV(GLuint program, GLint location, GLint64 x, GLint64 y, GLint64 z);
GLAPI void APIENTRY glProgramUniform3i64vARB(GLuint program, GLint location, GLsizei count, const GLint64 *value);
GLAPI void APIENTRY glProgramUniform3i64vNV(GLuint program, GLint location, GLsizei count, const GLint64 *value);
GLAPI void APIENTRY glProgramUniform3iEXT(GLuint program, GLint location, GLint v0, GLint v1, GLint v2);
GLAPI void APIENTRY glProgramUniform3iv(GLuint program, GLint location, GLsizei count, const GLint *value);
GLAPI void APIENTRY glProgramUniform3ivEXT(GLuint program, GLint location, GLsizei count, const GLint *value);
GLAPI void APIENTRY glProgramUniform3ui(GLuint program, GLint location, GLuint v0, GLuint v1, GLuint v2);
GLAPI void APIENTRY glProgramUniform3ui64ARB(GLuint program, GLint location, GLuint64 x, GLuint64 y, GLuint64 z);
GLAPI void APIENTRY glProgramUniform3ui64NV(GLuint program, GLint location, GLuint64 x, GLuint64 y, GLuint64 z);
GLAPI void APIENTRY glProgramUniform3ui64vARB(GLuint program, GLint location, GLsizei count, const GLuint64 *value);
GLAPI void APIENTRY glProgramUniform3ui64vNV(GLuint program, GLint location, GLsizei count, const GLuint64 *value);
GLAPI void APIENTRY glProgramUniform3uiEXT(GLuint program, GLint location, GLuint v0, GLuint v1, GLuint v2);
GLAPI void APIENTRY glProgramUniform3uiv(GLuint program, GLint location, GLsizei count, const GLuint *value);
GLAPI void APIENTRY glProgramUniform3uivEXT(GLuint program, GLint location, GLsizei count, const GLuint *value);
GLAPI void APIENTRY glProgramUniform4d(GLuint program, GLint location, GLdouble v0, GLdouble v1, GLdouble v2, GLdouble v3);
GLAPI void APIENTRY glProgramUniform4dEXT(GLuint program, GLint location, GLdouble x, GLdouble y, GLdouble z, GLdouble w);
GLAPI void APIENTRY glProgramUniform4dv(GLuint program, GLint location, GLsizei count, const GLdouble *value);
GLAPI void APIENTRY glProgramUniform4dvEXT(GLuint program, GLint location, GLsizei count, const GLdouble *value);
GLAPI void APIENTRY glProgramUniform4f(GLuint program, GLint location, GLfloat v0, GLfloat v1, GLfloat v2, GLfloat v3);
GLAPI void APIENTRY glProgramUniform4fEXT(GLuint program, GLint location, GLfloat v0, GLfloat v1, GLfloat v2, GLfloat v3);
GLAPI void APIENTRY glProgramUniform4fv(GLuint program, GLint location, GLsizei count, const GLfloat *value);
GLAPI void APIENTRY glProgramUniform4fvEXT(GLuint program, GLint location, GLsizei count, const GLfloat *value);
GLAPI void APIENTRY glProgramUniform4i(GLuint program, GLint location, GLint v0, GLint v1, GLint v2, GLint v3);
GLAPI void APIENTRY glProgramUniform4i64ARB(GLuint program, GLint location, GLint64 x, GLint64 y, GLint64 z, GLint64 w);
GLAPI void APIENTRY glProgramUniform4i64NV(GLuint program, GLint location, GLint64 x, GLint64 y, GLint64 z, GLint64 w);
GLAPI void APIENTRY glProgramUniform4i64vARB(GLuint program, GLint location, GLsizei count, const GLint64 *value);
GLAPI void APIENTRY glProgramUniform4i64vNV(GLuint program, GLint location, GLsizei count, const GLint64 *value);
GLAPI void APIENTRY glProgramUniform4iEXT(GLuint program, GLint location, GLint v0, GLint v1, GLint v2, GLint v3);
GLAPI void APIENTRY glProgramUniform4iv(GLuint program, GLint location, GLsizei count, const GLint *value);
GLAPI void APIENTRY glProgramUniform4ivEXT(GLuint program, GLint location, GLsizei count, const GLint *value);
GLAPI void APIENTRY glProgramUniform4ui(GLuint program, GLint location, GLuint v0, GLuint v1, GLuint v2, GLuint v3);
GLAPI void APIENTRY glProgramUniform4ui64ARB(GLuint program, GLint location, GLuint64 x, GLuint64 y, GLuint64 z, GLuint64 w);
GLAPI void APIENTRY glProgramUniform4ui64NV(GLuint program, GLint location, GLuint64 x, GLuint64 y, GLuint64 z, GLuint64 w);
GLAPI void APIENTRY glProgramUniform4ui64vARB(GLuint program, GLint location, GLsizei count, const GLuint64 *value);
GLAPI void APIENTRY glProgramUniform4ui64vNV(GLuint program, GLint location, GLsizei count, const GLuint64 *value);
GLAPI void APIENTRY glProgramUniform4uiEXT(GLuint program, GLint location, GLuint v0, GLuint v1, GLuint v2, GLuint v3);
GLAPI void APIENTRY glProgramUniform4uiv(GLuint program, GLint location, GLsizei count, const GLuint *value);
GLAPI void APIENTRY glProgramUniform4uivEXT(GLuint program, GLint location, GLsizei count, const GLuint *value);
GLAPI void APIENTRY glProgramUniformHandleui64ARB(GLuint program, GLint location, GLuint64 value);
GLAPI void APIENTRY glProgramUniformHandleui64IMG(GLuint program, GLint location, GLuint64 value);
GLAPI void APIENTRY glProgramUniformHandleui64NV(GLuint program, GLint location, GLuint64 value);
GLAPI void APIENTRY glProgramUniformHandleui64vARB(GLuint program, GLint location, GLsizei count, const GLuint64 *values);
GLAPI void APIENTRY glProgramUniformHandleui64vIMG(GLuint program, GLint location, GLsizei count, const GLuint64 *values);
GLAPI void APIENTRY glProgramUniformHandleui64vNV(GLuint program, GLint location, GLsizei count, const GLuint64 *values);
GLAPI void APIENTRY glProgramUniformMatrix2dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value);
GLAPI void APIENTRY glProgramUniformMatrix2dvEXT(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value);
GLAPI void APIENTRY glProgramUniformMatrix2fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value);
GLAPI void APIENTRY glProgramUniformMatrix2fvEXT(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value);
GLAPI void APIENTRY glProgramUniformMatrix2x3dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value);
GLAPI void APIENTRY glProgramUniformMatrix2x3dvEXT(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value);
GLAPI void APIENTRY glProgramUniformMatrix2x3fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value);
GLAPI void APIENTRY glProgramUniformMatrix2x3fvEXT(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value);
GLAPI void APIENTRY glProgramUniformMatrix2x4dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value);
GLAPI void APIENTRY glProgramUniformMatrix2x4dvEXT(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value);
GLAPI void APIENTRY glProgramUniformMatrix2x4fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value);
GLAPI void APIENTRY glProgramUniformMatrix2x4fvEXT(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value);
GLAPI void APIENTRY glProgramUniformMatrix3dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value);
GLAPI void APIENTRY glProgramUniformMatrix3dvEXT(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value);
GLAPI void APIENTRY glProgramUniformMatrix3fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value);
GLAPI void APIENTRY glProgramUniformMatrix3fvEXT(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value);
GLAPI void APIENTRY glProgramUniformMatrix3x2dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value);
GLAPI void APIENTRY glProgramUniformMatrix3x2dvEXT(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value);
GLAPI void APIENTRY glProgramUniformMatrix3x2fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value);
GLAPI void APIENTRY glProgramUniformMatrix3x2fvEXT(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value);
GLAPI void APIENTRY glProgramUniformMatrix3x4dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value);
GLAPI void APIENTRY glProgramUniformMatrix3x4dvEXT(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value);
GLAPI void APIENTRY glProgramUniformMatrix3x4fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value);
GLAPI void APIENTRY glProgramUniformMatrix3x4fvEXT(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value);
GLAPI void APIENTRY glProgramUniformMatrix4dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value);
GLAPI void APIENTRY glProgramUniformMatrix4dvEXT(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value);
GLAPI void APIENTRY glProgramUniformMatrix4fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value);
GLAPI void APIENTRY glProgramUniformMatrix4fvEXT(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value);
GLAPI void APIENTRY glProgramUniformMatrix4x2dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value);
GLAPI void APIENTRY glProgramUniformMatrix4x2dvEXT(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value);
GLAPI void APIENTRY glProgramUniformMatrix4x2fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value);
GLAPI void APIENTRY glProgramUniformMatrix4x2fvEXT(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value);
GLAPI void APIENTRY glProgramUniformMatrix4x3dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value);
GLAPI void APIENTRY glProgramUniformMatrix4x3dvEXT(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value);
GLAPI void APIENTRY glProgramUniformMatrix4x3fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value);
GLAPI void APIENTRY glProgramUniformMatrix4x3fvEXT(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value);
GLAPI void APIENTRY glProgramUniformui64NV(GLuint program, GLint location, GLuint64 value);
GLAPI void APIENTRY glProgramUniformui64vNV(GLuint program, GLint location, GLsizei count, const GLuint64 *value);
GLAPI void APIENTRY glProgramVertexLimitNV(GLenum target, GLint limit);
GLAPI void APIENTRY glProvokingVertex(GLenum mode);
GLAPI void APIENTRY glProvokingVertexEXT(GLenum mode);
GLAPI void APIENTRY glPushAttrib(GLbitfield mask);
GLAPI void APIENTRY glPushClientAttrib(GLbitfield mask);
GLAPI void APIENTRY glPushClientAttribDefaultEXT(GLbitfield mask);
GLAPI void APIENTRY glPushDebugGroup(GLenum source, GLuint id, GLsizei length, const GLchar *message);
GLAPI void APIENTRY glPushDebugGroupKHR(GLenum source, GLuint id, GLsizei length, const GLchar *message);
GLAPI void APIENTRY glPushDebugGroupOES(GLenum source, GLuint id, GLsizei length, const GLchar *message);
GLAPI void APIENTRY glPushGroupMarkerEXT(GLsizei length, const GLchar *marker);
GLAPI void APIENTRY glPushMatrix(void);
GLAPI void APIENTRY glPushName(GLuint name);
GLAPI void APIENTRY glQueryCounter(GLuint id, GLenum target);
GLAPI void APIENTRY glQueryCounterEXT(GLuint id, GLenum target);
GLAPI void APIENTRY glQueryCounterNV(GLuint id, GLenum target);
GLAPI GLbitfield APIENTRY glQueryMatrixxOES(GLfixed *mantissa, GLint *exponent);
GLAPI void APIENTRY glQueryObjectParameteruiAMD(GLenum target, GLuint id, GLenum pname, GLuint param);
GLAPI GLint APIENTRY glQueryResourceNV(GLenum queryType, GLint tagId, GLuint count, GLint *buffer);
GLAPI void APIENTRY glQueryResourceTagNV(GLint tagId, const GLchar *tagString);
GLAPI void APIENTRY glRasterPos2d(GLdouble x, GLdouble y);
GLAPI void APIENTRY glRasterPos2dv(const GLdouble *v);
GLAPI void APIENTRY glRasterPos2f(GLfloat x, GLfloat y);
GLAPI void APIENTRY glRasterPos2fv(const GLfloat *v);
GLAPI void APIENTRY glRasterPos2i(GLint x, GLint y);
GLAPI void APIENTRY glRasterPos2iv(const GLint *v);
GLAPI void APIENTRY glRasterPos2s(GLshort x, GLshort y);
GLAPI void APIENTRY glRasterPos2sv(const GLshort *v);
GLAPI void APIENTRY glRasterPos2xOES(GLfixed x, GLfixed y);
GLAPI void APIENTRY glRasterPos2xvOES(const GLfixed *coords);
GLAPI void APIENTRY glRasterPos3d(GLdouble x, GLdouble y, GLdouble z);
GLAPI void APIENTRY glRasterPos3dv(const GLdouble *v);
GLAPI void APIENTRY glRasterPos3f(GLfloat x, GLfloat y, GLfloat z);
GLAPI void APIENTRY glRasterPos3fv(const GLfloat *v);
GLAPI void APIENTRY glRasterPos3i(GLint x, GLint y, GLint z);
GLAPI void APIENTRY glRasterPos3iv(const GLint *v);
GLAPI void APIENTRY glRasterPos3s(GLshort x, GLshort y, GLshort z);
GLAPI void APIENTRY glRasterPos3sv(const GLshort *v);
GLAPI void APIENTRY glRasterPos3xOES(GLfixed x, GLfixed y, GLfixed z);
GLAPI void APIENTRY glRasterPos3xvOES(const GLfixed *coords);
GLAPI void APIENTRY glRasterPos4d(GLdouble x, GLdouble y, GLdouble z, GLdouble w);
GLAPI void APIENTRY glRasterPos4dv(const GLdouble *v);
GLAPI void APIENTRY glRasterPos4f(GLfloat x, GLfloat y, GLfloat z, GLfloat w);
GLAPI void APIENTRY glRasterPos4fv(const GLfloat *v);
GLAPI void APIENTRY glRasterPos4i(GLint x, GLint y, GLint z, GLint w);
GLAPI void APIENTRY glRasterPos4iv(const GLint *v);
GLAPI void APIENTRY glRasterPos4s(GLshort x, GLshort y, GLshort z, GLshort w);
GLAPI void APIENTRY glRasterPos4sv(const GLshort *v);
GLAPI void APIENTRY glRasterPos4xOES(GLfixed x, GLfixed y, GLfixed z, GLfixed w);
GLAPI void APIENTRY glRasterPos4xvOES(const GLfixed *coords);
GLAPI void APIENTRY glRasterSamplesEXT(GLuint samples, GLboolean fixedsamplelocations);
GLAPI void APIENTRY glReadBuffer(GLenum src);
GLAPI void APIENTRY glReadBufferIndexedEXT(GLenum src, GLint index);
GLAPI void APIENTRY glReadBufferNV(GLenum mode);
GLAPI void APIENTRY glReadInstrumentsSGIX(GLint marker);
GLAPI void APIENTRY glReadPixels(GLint x, GLint y, GLsizei width, GLsizei height, GLenum format, GLenum type, void *pixels);
GLAPI void APIENTRY glReadnPixels(GLint x, GLint y, GLsizei width, GLsizei height, GLenum format, GLenum type, GLsizei bufSize, void *data);
GLAPI void APIENTRY glReadnPixelsARB(GLint x, GLint y, GLsizei width, GLsizei height, GLenum format, GLenum type, GLsizei bufSize, void *data);
GLAPI void APIENTRY glReadnPixelsEXT(GLint x, GLint y, GLsizei width, GLsizei height, GLenum format, GLenum type, GLsizei bufSize, void *data);
GLAPI void APIENTRY glReadnPixelsKHR(GLint x, GLint y, GLsizei width, GLsizei height, GLenum format, GLenum type, GLsizei bufSize, void *data);
GLAPI void APIENTRY glRectd(GLdouble x1, GLdouble y1, GLdouble x2, GLdouble y2);
GLAPI void APIENTRY glRectdv(const GLdouble *v1, const GLdouble *v2);
GLAPI void APIENTRY glRectf(GLfloat x1, GLfloat y1, GLfloat x2, GLfloat y2);
GLAPI void APIENTRY glRectfv(const GLfloat *v1, const GLfloat *v2);
GLAPI void APIENTRY glRecti(GLint x1, GLint y1, GLint x2, GLint y2);
GLAPI void APIENTRY glRectiv(const GLint *v1, const GLint *v2);
GLAPI void APIENTRY glRects(GLshort x1, GLshort y1, GLshort x2, GLshort y2);
GLAPI void APIENTRY glRectsv(const GLshort *v1, const GLshort *v2);
GLAPI void APIENTRY glRectxOES(GLfixed x1, GLfixed y1, GLfixed x2, GLfixed y2);
GLAPI void APIENTRY glRectxvOES(const GLfixed *v1, const GLfixed *v2);
GLAPI void APIENTRY glReferencePlaneSGIX(const GLdouble *equation);
GLAPI GLboolean APIENTRY glReleaseKeyedMutexWin32EXT(GLuint memory, GLuint64 key);
GLAPI void APIENTRY glReleaseShaderCompiler(void);
GLAPI void APIENTRY glRenderGpuMaskNV(GLbitfield mask);
GLAPI GLint APIENTRY glRenderMode(GLenum mode);
GLAPI void APIENTRY glRenderbufferStorage(GLenum target, GLenum internalformat, GLsizei width, GLsizei height);
GLAPI void APIENTRY glRenderbufferStorageEXT(GLenum target, GLenum internalformat, GLsizei width, GLsizei height);
GLAPI void APIENTRY glRenderbufferStorageMultisample(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height);
GLAPI void APIENTRY glRenderbufferStorageMultisampleANGLE(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height);
GLAPI void APIENTRY glRenderbufferStorageMultisampleAPPLE(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height);
GLAPI void APIENTRY glRenderbufferStorageMultisampleAdvancedAMD(GLenum target, GLsizei samples, GLsizei storageSamples, GLenum internalformat, GLsizei width, GLsizei height);
GLAPI void APIENTRY glRenderbufferStorageMultisampleCoverageNV(GLenum target, GLsizei coverageSamples, GLsizei colorSamples, GLenum internalformat, GLsizei width, GLsizei height);
GLAPI void APIENTRY glRenderbufferStorageMultisampleEXT(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height);
GLAPI void APIENTRY glRenderbufferStorageMultisampleIMG(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height);
GLAPI void APIENTRY glRenderbufferStorageMultisampleNV(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height);
GLAPI void APIENTRY glRenderbufferStorageOES(GLenum target, GLenum internalformat, GLsizei width, GLsizei height);
GLAPI void APIENTRY glReplacementCodePointerSUN(GLenum type, GLsizei stride, const void **pointer);
GLAPI void APIENTRY glReplacementCodeubSUN(GLubyte code);
GLAPI void APIENTRY glReplacementCodeubvSUN(const GLubyte *code);
GLAPI void APIENTRY glReplacementCodeuiColor3fVertex3fSUN(GLuint rc, GLfloat r, GLfloat g, GLfloat b, GLfloat x, GLfloat y, GLfloat z);
GLAPI void APIENTRY glReplacementCodeuiColor3fVertex3fvSUN(const GLuint *rc, const GLfloat *c, const GLfloat *v);
GLAPI void APIENTRY glReplacementCodeuiColor4fNormal3fVertex3fSUN(GLuint rc, GLfloat r, GLfloat g, GLfloat b, GLfloat a, GLfloat nx, GLfloat ny, GLfloat nz, GLfloat x, GLfloat y, GLfloat z);
GLAPI void APIENTRY glReplacementCodeuiColor4fNormal3fVertex3fvSUN(const GLuint *rc, const GLfloat *c, const GLfloat *n, const GLfloat *v);
GLAPI void APIENTRY glReplacementCodeuiColor4ubVertex3fSUN(GLuint rc, GLubyte r, GLubyte g, GLubyte b, GLubyte a, GLfloat x, GLfloat y, GLfloat z);
GLAPI void APIENTRY glReplacementCodeuiColor4ubVertex3fvSUN(const GLuint *rc, const GLubyte *c, const GLfloat *v);
GLAPI void APIENTRY glReplacementCodeuiNormal3fVertex3fSUN(GLuint rc, GLfloat nx, GLfloat ny, GLfloat nz, GLfloat x, GLfloat y, GLfloat z);
GLAPI void APIENTRY glReplacementCodeuiNormal3fVertex3fvSUN(const GLuint *rc, const GLfloat *n, const GLfloat *v);
GLAPI void APIENTRY glReplacementCodeuiSUN(GLuint code);
GLAPI void APIENTRY glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fSUN(GLuint rc, GLfloat s, GLfloat t, GLfloat r, GLfloat g, GLfloat b, GLfloat a, GLfloat nx, GLfloat ny, GLfloat nz, GLfloat x, GLfloat y, GLfloat z);
GLAPI void APIENTRY glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fvSUN(const GLuint *rc, const GLfloat *tc, const GLfloat *c, const GLfloat *n, const GLfloat *v);
GLAPI void APIENTRY glReplacementCodeuiTexCoord2fNormal3fVertex3fSUN(GLuint rc, GLfloat s, GLfloat t, GLfloat nx, GLfloat ny, GLfloat nz, GLfloat x, GLfloat y, GLfloat z);
GLAPI void APIENTRY glReplacementCodeuiTexCoord2fNormal3fVertex3fvSUN(const GLuint *rc, const GLfloat *tc, const GLfloat *n, const GLfloat *v);
GLAPI void APIENTRY glReplacementCodeuiTexCoord2fVertex3fSUN(GLuint rc, GLfloat s, GLfloat t, GLfloat x, GLfloat y, GLfloat z);
GLAPI void APIENTRY glReplacementCodeuiTexCoord2fVertex3fvSUN(const GLuint *rc, const GLfloat *tc, const GLfloat *v);
GLAPI void APIENTRY glReplacementCodeuiVertex3fSUN(GLuint rc, GLfloat x, GLfloat y, GLfloat z);
GLAPI void APIENTRY glReplacementCodeuiVertex3fvSUN(const GLuint *rc, const GLfloat *v);
GLAPI void APIENTRY glReplacementCodeuivSUN(const GLuint *code);
GLAPI void APIENTRY glReplacementCodeusSUN(GLushort code);
GLAPI void APIENTRY glReplacementCodeusvSUN(const GLushort *code);
GLAPI void APIENTRY glRequestResidentProgramsNV(GLsizei n, const GLuint *programs);
GLAPI void APIENTRY glResetHistogram(GLenum target);
GLAPI void APIENTRY glResetHistogramEXT(GLenum target);
GLAPI void APIENTRY glResetMemoryObjectParameterNV(GLuint memory, GLenum pname);
GLAPI void APIENTRY glResetMinmax(GLenum target);
GLAPI void APIENTRY glResetMinmaxEXT(GLenum target);
GLAPI void APIENTRY glResizeBuffersMESA(void);
GLAPI void APIENTRY glResolveDepthValuesNV(void);
GLAPI void APIENTRY glResolveMultisampleFramebufferAPPLE(void);
GLAPI void APIENTRY glResumeTransformFeedback(void);
GLAPI void APIENTRY glResumeTransformFeedbackEXT(void);
GLAPI void APIENTRY glResumeTransformFeedbackNV(void);
GLAPI void APIENTRY glRotated(GLdouble angle, GLdouble x, GLdouble y, GLdouble z);
GLAPI void APIENTRY glRotatef(GLfloat angle, GLfloat x, GLfloat y, GLfloat z);
GLAPI void APIENTRY glRotatex(GLfixed angle, GLfixed x, GLfixed y, GLfixed z);
GLAPI void APIENTRY glRotatexOES(GLfixed angle, GLfixed x, GLfixed y, GLfixed z);
GLAPI void APIENTRY glSampleCoverage(GLfloat value, GLboolean invert);
GLAPI void APIENTRY glSampleCoverageARB(GLfloat value, GLboolean invert);
GLAPI void APIENTRY glSampleCoveragex(GLclampx value, GLboolean invert);
GLAPI void APIENTRY glSampleCoveragexOES(GLclampx value, GLboolean invert);
GLAPI void APIENTRY glSampleMapATI(GLuint dst, GLuint interp, GLenum swizzle);
GLAPI void APIENTRY glSampleMaskEXT(GLclampf value, GLboolean invert);
GLAPI void APIENTRY glSampleMaskIndexedNV(GLuint index, GLbitfield mask);
GLAPI void APIENTRY glSampleMaskSGIS(GLclampf value, GLboolean invert);
GLAPI void APIENTRY glSampleMaski(GLuint maskNumber, GLbitfield mask);
GLAPI void APIENTRY glSamplePatternEXT(GLenum pattern);
GLAPI void APIENTRY glSamplePatternSGIS(GLenum pattern);
GLAPI void APIENTRY glSamplerParameterIiv(GLuint sampler, GLenum pname, const GLint *param);
GLAPI void APIENTRY glSamplerParameterIivEXT(GLuint sampler, GLenum pname, const GLint *param);
GLAPI void APIENTRY glSamplerParameterIivOES(GLuint sampler, GLenum pname, const GLint *param);
GLAPI void APIENTRY glSamplerParameterIuiv(GLuint sampler, GLenum pname, const GLuint *param);
GLAPI void APIENTRY glSamplerParameterIuivEXT(GLuint sampler, GLenum pname, const GLuint *param);
GLAPI void APIENTRY glSamplerParameterIuivOES(GLuint sampler, GLenum pname, const GLuint *param);
GLAPI void APIENTRY glSamplerParameterf(GLuint sampler, GLenum pname, GLfloat param);
GLAPI void APIENTRY glSamplerParameterfv(GLuint sampler, GLenum pname, const GLfloat *param);
GLAPI void APIENTRY glSamplerParameteri(GLuint sampler, GLenum pname, GLint param);
GLAPI void APIENTRY glSamplerParameteriv(GLuint sampler, GLenum pname, const GLint *param);
GLAPI void APIENTRY glScaled(GLdouble x, GLdouble y, GLdouble z);
GLAPI void APIENTRY glScalef(GLfloat x, GLfloat y, GLfloat z);
GLAPI void APIENTRY glScalex(GLfixed x, GLfixed y, GLfixed z);
GLAPI void APIENTRY glScalexOES(GLfixed x, GLfixed y, GLfixed z);
GLAPI void APIENTRY glScissor(GLint x, GLint y, GLsizei width, GLsizei height);
GLAPI void APIENTRY glScissorArrayv(GLuint first, GLsizei count, const GLint *v);
GLAPI void APIENTRY glScissorArrayvNV(GLuint first, GLsizei count, const GLint *v);
GLAPI void APIENTRY glScissorArrayvOES(GLuint first, GLsizei count, const GLint *v);
GLAPI void APIENTRY glScissorExclusiveArrayvNV(GLuint first, GLsizei count, const GLint *v);
GLAPI void APIENTRY glScissorExclusiveNV(GLint x, GLint y, GLsizei width, GLsizei height);
GLAPI void APIENTRY glScissorIndexed(GLuint index, GLint left, GLint bottom, GLsizei width, GLsizei height);
GLAPI void APIENTRY glScissorIndexedNV(GLuint index, GLint left, GLint bottom, GLsizei width, GLsizei height);
GLAPI void APIENTRY glScissorIndexedOES(GLuint index, GLint left, GLint bottom, GLsizei width, GLsizei height);
GLAPI void APIENTRY glScissorIndexedv(GLuint index, const GLint *v);
GLAPI void APIENTRY glScissorIndexedvNV(GLuint index, const GLint *v);
GLAPI void APIENTRY glScissorIndexedvOES(GLuint index, const GLint *v);
GLAPI void APIENTRY glSecondaryColor3b(GLbyte red, GLbyte green, GLbyte blue);
GLAPI void APIENTRY glSecondaryColor3bEXT(GLbyte red, GLbyte green, GLbyte blue);
GLAPI void APIENTRY glSecondaryColor3bv(const GLbyte *v);
GLAPI void APIENTRY glSecondaryColor3bvEXT(const GLbyte *v);
GLAPI void APIENTRY glSecondaryColor3d(GLdouble red, GLdouble green, GLdouble blue);
GLAPI void APIENTRY glSecondaryColor3dEXT(GLdouble red, GLdouble green, GLdouble blue);
GLAPI void APIENTRY glSecondaryColor3dv(const GLdouble *v);
GLAPI void APIENTRY glSecondaryColor3dvEXT(const GLdouble *v);
GLAPI void APIENTRY glSecondaryColor3f(GLfloat red, GLfloat green, GLfloat blue);
GLAPI void APIENTRY glSecondaryColor3fEXT(GLfloat red, GLfloat green, GLfloat blue);
GLAPI void APIENTRY glSecondaryColor3fv(const GLfloat *v);
GLAPI void APIENTRY glSecondaryColor3fvEXT(const GLfloat *v);
GLAPI void APIENTRY glSecondaryColor3hNV(GLhalf red, GLhalf green, GLhalf blue);
GLAPI void APIENTRY glSecondaryColor3hvNV(const GLhalf *v);
GLAPI void APIENTRY glSecondaryColor3i(GLint red, GLint green, GLint blue);
GLAPI void APIENTRY glSecondaryColor3iEXT(GLint red, GLint green, GLint blue);
GLAPI void APIENTRY glSecondaryColor3iv(const GLint *v);
GLAPI void APIENTRY glSecondaryColor3ivEXT(const GLint *v);
GLAPI void APIENTRY glSecondaryColor3s(GLshort red, GLshort green, GLshort blue);
GLAPI void APIENTRY glSecondaryColor3sEXT(GLshort red, GLshort green, GLshort blue);
GLAPI void APIENTRY glSecondaryColor3sv(const GLshort *v);
GLAPI void APIENTRY glSecondaryColor3svEXT(const GLshort *v);
GLAPI void APIENTRY glSecondaryColor3ub(GLubyte red, GLubyte green, GLubyte blue);
GLAPI void APIENTRY glSecondaryColor3ubEXT(GLubyte red, GLubyte green, GLubyte blue);
GLAPI void APIENTRY glSecondaryColor3ubv(const GLubyte *v);
GLAPI void APIENTRY glSecondaryColor3ubvEXT(const GLubyte *v);
GLAPI void APIENTRY glSecondaryColor3ui(GLuint red, GLuint green, GLuint blue);
GLAPI void APIENTRY glSecondaryColor3uiEXT(GLuint red, GLuint green, GLuint blue);
GLAPI void APIENTRY glSecondaryColor3uiv(const GLuint *v);
GLAPI void APIENTRY glSecondaryColor3uivEXT(const GLuint *v);
GLAPI void APIENTRY glSecondaryColor3us(GLushort red, GLushort green, GLushort blue);
GLAPI void APIENTRY glSecondaryColor3usEXT(GLushort red, GLushort green, GLushort blue);
GLAPI void APIENTRY glSecondaryColor3usv(const GLushort *v);
GLAPI void APIENTRY glSecondaryColor3usvEXT(const GLushort *v);
GLAPI void APIENTRY glSecondaryColorFormatNV(GLint size, GLenum type, GLsizei stride);
GLAPI void APIENTRY glSecondaryColorP3ui(GLenum type, GLuint color);
GLAPI void APIENTRY glSecondaryColorP3uiv(GLenum type, const GLuint *color);
GLAPI void APIENTRY glSecondaryColorPointer(GLint size, GLenum type, GLsizei stride, const void *pointer);
GLAPI void APIENTRY glSecondaryColorPointerEXT(GLint size, GLenum type, GLsizei stride, const void *pointer);
GLAPI void APIENTRY glSecondaryColorPointerListIBM(GLint size, GLenum type, GLint stride, const void **pointer, GLint ptrstride);
GLAPI void APIENTRY glSelectBuffer(GLsizei size, GLuint *buffer);
GLAPI void APIENTRY glSelectPerfMonitorCountersAMD(GLuint monitor, GLboolean enable, GLuint group, GLint numCounters, GLuint *counterList);
GLAPI void APIENTRY glSemaphoreParameterui64vEXT(GLuint semaphore, GLenum pname, const GLuint64 *params);
GLAPI void APIENTRY glSeparableFilter2D(GLenum target, GLenum internalformat, GLsizei width, GLsizei height, GLenum format, GLenum type, const void *row, const void *column);
GLAPI void APIENTRY glSeparableFilter2DEXT(GLenum target, GLenum internalformat, GLsizei width, GLsizei height, GLenum format, GLenum type, const void *row, const void *column);
GLAPI void APIENTRY glSetFenceAPPLE(GLuint fence);
GLAPI void APIENTRY glSetFenceNV(GLuint fence, GLenum condition);
GLAPI void APIENTRY glSetFragmentShaderConstantATI(GLuint dst, const GLfloat *value);
GLAPI void APIENTRY glSetInvariantEXT(GLuint id, GLenum type, const void *addr);
GLAPI void APIENTRY glSetLocalConstantEXT(GLuint id, GLenum type, const void *addr);
GLAPI void APIENTRY glSetMultisamplefvAMD(GLenum pname, GLuint index, const GLfloat *val);
GLAPI void APIENTRY glShadeModel(GLenum mode);
GLAPI void APIENTRY glShaderBinary(GLsizei count, const GLuint *shaders, GLenum binaryFormat, const void *binary, GLsizei length);
GLAPI void APIENTRY glShaderOp1EXT(GLenum op, GLuint res, GLuint arg1);
GLAPI void APIENTRY glShaderOp2EXT(GLenum op, GLuint res, GLuint arg1, GLuint arg2);
GLAPI void APIENTRY glShaderOp3EXT(GLenum op, GLuint res, GLuint arg1, GLuint arg2, GLuint arg3);
GLAPI void APIENTRY glShaderSource(GLuint shader, GLsizei count, const GLchar *const *string, const GLint *length);
GLAPI void APIENTRY glShaderSourceARB(GLhandleARB shaderObj, GLsizei count, const GLcharARB **string, const GLint *length);
GLAPI void APIENTRY glShaderStorageBlockBinding(GLuint program, GLuint storageBlockIndex, GLuint storageBlockBinding);
GLAPI void APIENTRY glShadingRateImageBarrierNV(GLboolean synchronize);
GLAPI void APIENTRY glShadingRateImagePaletteNV(GLuint viewport, GLuint first, GLsizei count, const GLenum *rates);
GLAPI void APIENTRY glShadingRateSampleOrderCustomNV(GLenum rate, GLuint samples, const GLint *locations);
GLAPI void APIENTRY glShadingRateSampleOrderNV(GLenum order);
GLAPI void APIENTRY glSharpenTexFuncSGIS(GLenum target, GLsizei n, const GLfloat *points);
GLAPI void APIENTRY glSignalSemaphoreEXT(GLuint semaphore, GLuint numBufferBarriers, const GLuint *buffers, GLuint numTextureBarriers, const GLuint *textures, const GLenum *dstLayouts);
GLAPI void APIENTRY glSignalSemaphoreui64NVX(GLuint signalGpu, GLsizei fenceObjectCount, const GLuint *semaphoreArray, const GLuint64 *fenceValueArray);
GLAPI void APIENTRY glSignalVkFenceNV(GLuint64 vkFence);
GLAPI void APIENTRY glSignalVkSemaphoreNV(GLuint64 vkSemaphore);
GLAPI void APIENTRY glSpecializeShader(GLuint shader, const GLchar *pEntryPoint, GLuint numSpecializationConstants, const GLuint *pConstantIndex, const GLuint *pConstantValue);
GLAPI void APIENTRY glSpecializeShaderARB(GLuint shader, const GLchar *pEntryPoint, GLuint numSpecializationConstants, const GLuint *pConstantIndex, const GLuint *pConstantValue);
GLAPI void APIENTRY glSpriteParameterfSGIX(GLenum pname, GLfloat param);
GLAPI void APIENTRY glSpriteParameterfvSGIX(GLenum pname, const GLfloat *params);
GLAPI void APIENTRY glSpriteParameteriSGIX(GLenum pname, GLint param);
GLAPI void APIENTRY glSpriteParameterivSGIX(GLenum pname, const GLint *params);
GLAPI void APIENTRY glStartInstrumentsSGIX(void);
GLAPI void APIENTRY glStartTilingQCOM(GLuint x, GLuint y, GLuint width, GLuint height, GLbitfield preserveMask);
GLAPI void APIENTRY glStateCaptureNV(GLuint state, GLenum mode);
GLAPI void APIENTRY glStencilClearTagEXT(GLsizei stencilTagBits, GLuint stencilClearTag);
GLAPI void APIENTRY glStencilFillPathInstancedNV(GLsizei numPaths, GLenum pathNameType, const void *paths, GLuint pathBase, GLenum fillMode, GLuint mask, GLenum transformType, const GLfloat *transformValues);
GLAPI void APIENTRY glStencilFillPathNV(GLuint path, GLenum fillMode, GLuint mask);
GLAPI void APIENTRY glStencilFunc(GLenum func, GLint ref, GLuint mask);
GLAPI void APIENTRY glStencilFuncSeparate(GLenum face, GLenum func, GLint ref, GLuint mask);
GLAPI void APIENTRY glStencilFuncSeparateATI(GLenum frontfunc, GLenum backfunc, GLint ref, GLuint mask);
GLAPI void APIENTRY glStencilMask(GLuint mask);
GLAPI void APIENTRY glStencilMaskSeparate(GLenum face, GLuint mask);
GLAPI void APIENTRY glStencilOp(GLenum fail, GLenum zfail, GLenum zpass);
GLAPI void APIENTRY glStencilOpSeparate(GLenum face, GLenum sfail, GLenum dpfail, GLenum dppass);
GLAPI void APIENTRY glStencilOpSeparateATI(GLenum face, GLenum sfail, GLenum dpfail, GLenum dppass);
GLAPI void APIENTRY glStencilOpValueAMD(GLenum face, GLuint value);
GLAPI void APIENTRY glStencilStrokePathInstancedNV(GLsizei numPaths, GLenum pathNameType, const void *paths, GLuint pathBase, GLint reference, GLuint mask, GLenum transformType, const GLfloat *transformValues);
GLAPI void APIENTRY glStencilStrokePathNV(GLuint path, GLint reference, GLuint mask);
GLAPI void APIENTRY glStencilThenCoverFillPathInstancedNV(GLsizei numPaths, GLenum pathNameType, const void *paths, GLuint pathBase, GLenum fillMode, GLuint mask, GLenum coverMode, GLenum transformType, const GLfloat *transformValues);
GLAPI void APIENTRY glStencilThenCoverFillPathNV(GLuint path, GLenum fillMode, GLuint mask, GLenum coverMode);
GLAPI void APIENTRY glStencilThenCoverStrokePathInstancedNV(GLsizei numPaths, GLenum pathNameType, const void *paths, GLuint pathBase, GLint reference, GLuint mask, GLenum coverMode, GLenum transformType, const GLfloat *transformValues);
GLAPI void APIENTRY glStencilThenCoverStrokePathNV(GLuint path, GLint reference, GLuint mask, GLenum coverMode);
GLAPI void APIENTRY glStopInstrumentsSGIX(GLint marker);
GLAPI void APIENTRY glStringMarkerGREMEDY(GLsizei len, const void *string);
GLAPI void APIENTRY glSubpixelPrecisionBiasNV(GLuint xbits, GLuint ybits);
GLAPI void APIENTRY glSwizzleEXT(GLuint res, GLuint in, GLenum outX, GLenum outY, GLenum outZ, GLenum outW);
GLAPI void APIENTRY glSyncTextureINTEL(GLuint texture);
GLAPI void APIENTRY glTagSampleBufferSGIX(void);
GLAPI void APIENTRY glTangent3bEXT(GLbyte tx, GLbyte ty, GLbyte tz);
GLAPI void APIENTRY glTangent3bvEXT(const GLbyte *v);
GLAPI void APIENTRY glTangent3dEXT(GLdouble tx, GLdouble ty, GLdouble tz);
GLAPI void APIENTRY glTangent3dvEXT(const GLdouble *v);
GLAPI void APIENTRY glTangent3fEXT(GLfloat tx, GLfloat ty, GLfloat tz);
GLAPI void APIENTRY glTangent3fvEXT(const GLfloat *v);
GLAPI void APIENTRY glTangent3iEXT(GLint tx, GLint ty, GLint tz);
GLAPI void APIENTRY glTangent3ivEXT(const GLint *v);
GLAPI void APIENTRY glTangent3sEXT(GLshort tx, GLshort ty, GLshort tz);
GLAPI void APIENTRY glTangent3svEXT(const GLshort *v);
GLAPI void APIENTRY glTangentPointerEXT(GLenum type, GLsizei stride, const void *pointer);
GLAPI void APIENTRY glTbufferMask3DFX(GLuint mask);
GLAPI void APIENTRY glTessellationFactorAMD(GLfloat factor);
GLAPI void APIENTRY glTessellationModeAMD(GLenum mode);
GLAPI GLboolean APIENTRY glTestFenceAPPLE(GLuint fence);
GLAPI GLboolean APIENTRY glTestFenceNV(GLuint fence);
GLAPI GLboolean APIENTRY glTestObjectAPPLE(GLenum object, GLuint name);
GLAPI void APIENTRY glTexAttachMemoryNV(GLenum target, GLuint memory, GLuint64 offset);
GLAPI void APIENTRY glTexBuffer(GLenum target, GLenum internalformat, GLuint buffer);
GLAPI void APIENTRY glTexBufferARB(GLenum target, GLenum internalformat, GLuint buffer);
GLAPI void APIENTRY glTexBufferEXT(GLenum target, GLenum internalformat, GLuint buffer);
GLAPI void APIENTRY glTexBufferOES(GLenum target, GLenum internalformat, GLuint buffer);
GLAPI void APIENTRY glTexBufferRange(GLenum target, GLenum internalformat, GLuint buffer, GLintptr offset, GLsizeiptr size);
GLAPI void APIENTRY glTexBufferRangeEXT(GLenum target, GLenum internalformat, GLuint buffer, GLintptr offset, GLsizeiptr size);
GLAPI void APIENTRY glTexBufferRangeOES(GLenum target, GLenum internalformat, GLuint buffer, GLintptr offset, GLsizeiptr size);
GLAPI void APIENTRY glTexBumpParameterfvATI(GLenum pname, const GLfloat *param);
GLAPI void APIENTRY glTexBumpParameterivATI(GLenum pname, const GLint *param);
GLAPI void APIENTRY glTexCoord1bOES(GLbyte s);
GLAPI void APIENTRY glTexCoord1bvOES(const GLbyte *coords);
GLAPI void APIENTRY glTexCoord1d(GLdouble s);
GLAPI void APIENTRY glTexCoord1dv(const GLdouble *v);
GLAPI void APIENTRY glTexCoord1f(GLfloat s);
GLAPI void APIENTRY glTexCoord1fv(const GLfloat *v);
GLAPI void APIENTRY glTexCoord1hNV(GLhalf s);
GLAPI void APIENTRY glTexCoord1hvNV(const GLhalf *v);
GLAPI void APIENTRY glTexCoord1i(GLint s);
GLAPI void APIENTRY glTexCoord1iv(const GLint *v);
GLAPI void APIENTRY glTexCoord1s(GLshort s);
GLAPI void APIENTRY glTexCoord1sv(const GLshort *v);
GLAPI void APIENTRY glTexCoord1xOES(GLfixed s);
GLAPI void APIENTRY glTexCoord1xvOES(const GLfixed *coords);
GLAPI void APIENTRY glTexCoord2bOES(GLbyte s, GLbyte t);
GLAPI void APIENTRY glTexCoord2bvOES(const GLbyte *coords);
GLAPI void APIENTRY glTexCoord2d(GLdouble s, GLdouble t);
GLAPI void APIENTRY glTexCoord2dv(const GLdouble *v);
GLAPI void APIENTRY glTexCoord2f(GLfloat s, GLfloat t);
GLAPI void APIENTRY glTexCoord2fColor3fVertex3fSUN(GLfloat s, GLfloat t, GLfloat r, GLfloat g, GLfloat b, GLfloat x, GLfloat y, GLfloat z);
GLAPI void APIENTRY glTexCoord2fColor3fVertex3fvSUN(const GLfloat *tc, const GLfloat *c, const GLfloat *v);
GLAPI void APIENTRY glTexCoord2fColor4fNormal3fVertex3fSUN(GLfloat s, GLfloat t, GLfloat r, GLfloat g, GLfloat b, GLfloat a, GLfloat nx, GLfloat ny, GLfloat nz, GLfloat x, GLfloat y, GLfloat z);
GLAPI void APIENTRY glTexCoord2fColor4fNormal3fVertex3fvSUN(const GLfloat *tc, const GLfloat *c, const GLfloat *n, const GLfloat *v);
GLAPI void APIENTRY glTexCoord2fColor4ubVertex3fSUN(GLfloat s, GLfloat t, GLubyte r, GLubyte g, GLubyte b, GLubyte a, GLfloat x, GLfloat y, GLfloat z);
GLAPI void APIENTRY glTexCoord2fColor4ubVertex3fvSUN(const GLfloat *tc, const GLubyte *c, const GLfloat *v);
GLAPI void APIENTRY glTexCoord2fNormal3fVertex3fSUN(GLfloat s, GLfloat t, GLfloat nx, GLfloat ny, GLfloat nz, GLfloat x, GLfloat y, GLfloat z);
GLAPI void APIENTRY glTexCoord2fNormal3fVertex3fvSUN(const GLfloat *tc, const GLfloat *n, const GLfloat *v);
GLAPI void APIENTRY glTexCoord2fVertex3fSUN(GLfloat s, GLfloat t, GLfloat x, GLfloat y, GLfloat z);
GLAPI void APIENTRY glTexCoord2fVertex3fvSUN(const GLfloat *tc, const GLfloat *v);
GLAPI void APIENTRY glTexCoord2fv(const GLfloat *v);
GLAPI void APIENTRY glTexCoord2hNV(GLhalf s, GLhalf t);
GLAPI void APIENTRY glTexCoord2hvNV(const GLhalf *v);
GLAPI void APIENTRY glTexCoord2i(GLint s, GLint t);
GLAPI void APIENTRY glTexCoord2iv(const GLint *v);
GLAPI void APIENTRY glTexCoord2s(GLshort s, GLshort t);
GLAPI void APIENTRY glTexCoord2sv(const GLshort *v);
GLAPI void APIENTRY glTexCoord2xOES(GLfixed s, GLfixed t);
GLAPI void APIENTRY glTexCoord2xvOES(const GLfixed *coords);
GLAPI void APIENTRY glTexCoord3bOES(GLbyte s, GLbyte t, GLbyte r);
GLAPI void APIENTRY glTexCoord3bvOES(const GLbyte *coords);
GLAPI void APIENTRY glTexCoord3d(GLdouble s, GLdouble t, GLdouble r);
GLAPI void APIENTRY glTexCoord3dv(const GLdouble *v);
GLAPI void APIENTRY glTexCoord3f(GLfloat s, GLfloat t, GLfloat r);
GLAPI void APIENTRY glTexCoord3fv(const GLfloat *v);
GLAPI void APIENTRY glTexCoord3hNV(GLhalf s, GLhalf t, GLhalf r);
GLAPI void APIENTRY glTexCoord3hvNV(const GLhalf *v);
GLAPI void APIENTRY glTexCoord3i(GLint s, GLint t, GLint r);
GLAPI void APIENTRY glTexCoord3iv(const GLint *v);
GLAPI void APIENTRY glTexCoord3s(GLshort s, GLshort t, GLshort r);
GLAPI void APIENTRY glTexCoord3sv(const GLshort *v);
GLAPI void APIENTRY glTexCoord3xOES(GLfixed s, GLfixed t, GLfixed r);
GLAPI void APIENTRY glTexCoord3xvOES(const GLfixed *coords);
GLAPI void APIENTRY glTexCoord4bOES(GLbyte s, GLbyte t, GLbyte r, GLbyte q);
GLAPI void APIENTRY glTexCoord4bvOES(const GLbyte *coords);
GLAPI void APIENTRY glTexCoord4d(GLdouble s, GLdouble t, GLdouble r, GLdouble q);
GLAPI void APIENTRY glTexCoord4dv(const GLdouble *v);
GLAPI void APIENTRY glTexCoord4f(GLfloat s, GLfloat t, GLfloat r, GLfloat q);
GLAPI void APIENTRY glTexCoord4fColor4fNormal3fVertex4fSUN(GLfloat s, GLfloat t, GLfloat p, GLfloat q, GLfloat r, GLfloat g, GLfloat b, GLfloat a, GLfloat nx, GLfloat ny, GLfloat nz, GLfloat x, GLfloat y, GLfloat z, GLfloat w);
GLAPI void APIENTRY glTexCoord4fColor4fNormal3fVertex4fvSUN(const GLfloat *tc, const GLfloat *c, const GLfloat *n, const GLfloat *v);
GLAPI void APIENTRY glTexCoord4fVertex4fSUN(GLfloat s, GLfloat t, GLfloat p, GLfloat q, GLfloat x, GLfloat y, GLfloat z, GLfloat w);
GLAPI void APIENTRY glTexCoord4fVertex4fvSUN(const GLfloat *tc, const GLfloat *v);
GLAPI void APIENTRY glTexCoord4fv(const GLfloat *v);
GLAPI void APIENTRY glTexCoord4hNV(GLhalf s, GLhalf t, GLhalf r, GLhalf q);
GLAPI void APIENTRY glTexCoord4hvNV(const GLhalf *v);
GLAPI void APIENTRY glTexCoord4i(GLint s, GLint t, GLint r, GLint q);
GLAPI void APIENTRY glTexCoord4iv(const GLint *v);
GLAPI void APIENTRY glTexCoord4s(GLshort s, GLshort t, GLshort r, GLshort q);
GLAPI void APIENTRY glTexCoord4sv(const GLshort *v);
GLAPI void APIENTRY glTexCoord4xOES(GLfixed s, GLfixed t, GLfixed r, GLfixed q);
GLAPI void APIENTRY glTexCoord4xvOES(const GLfixed *coords);
GLAPI void APIENTRY glTexCoordFormatNV(GLint size, GLenum type, GLsizei stride);
GLAPI void APIENTRY glTexCoordP1ui(GLenum type, GLuint coords);
GLAPI void APIENTRY glTexCoordP1uiv(GLenum type, const GLuint *coords);
GLAPI void APIENTRY glTexCoordP2ui(GLenum type, GLuint coords);
GLAPI void APIENTRY glTexCoordP2uiv(GLenum type, const GLuint *coords);
GLAPI void APIENTRY glTexCoordP3ui(GLenum type, GLuint coords);
GLAPI void APIENTRY glTexCoordP3uiv(GLenum type, const GLuint *coords);
GLAPI void APIENTRY glTexCoordP4ui(GLenum type, GLuint coords);
GLAPI void APIENTRY glTexCoordP4uiv(GLenum type, const GLuint *coords);
GLAPI void APIENTRY glTexCoordPointer(GLint size, GLenum type, GLsizei stride, const void *pointer);
GLAPI void APIENTRY glTexCoordPointerEXT(GLint size, GLenum type, GLsizei stride, GLsizei count, const void *pointer);
GLAPI void APIENTRY glTexCoordPointerListIBM(GLint size, GLenum type, GLint stride, const void **pointer, GLint ptrstride);
GLAPI void APIENTRY glTexCoordPointervINTEL(GLint size, GLenum type, const void **pointer);
GLAPI void APIENTRY glTexEnvf(GLenum target, GLenum pname, GLfloat param);
GLAPI void APIENTRY glTexEnvfv(GLenum target, GLenum pname, const GLfloat *params);
GLAPI void APIENTRY glTexEnvi(GLenum target, GLenum pname, GLint param);
GLAPI void APIENTRY glTexEnviv(GLenum target, GLenum pname, const GLint *params);
GLAPI void APIENTRY glTexEnvx(GLenum target, GLenum pname, GLfixed param);
GLAPI void APIENTRY glTexEnvxOES(GLenum target, GLenum pname, GLfixed param);
GLAPI void APIENTRY glTexEnvxv(GLenum target, GLenum pname, const GLfixed *params);
GLAPI void APIENTRY glTexEnvxvOES(GLenum target, GLenum pname, const GLfixed *params);
GLAPI void APIENTRY glTexFilterFuncSGIS(GLenum target, GLenum filter, GLsizei n, const GLfloat *weights);
GLAPI void APIENTRY glTexGend(GLenum coord, GLenum pname, GLdouble param);
GLAPI void APIENTRY glTexGendv(GLenum coord, GLenum pname, const GLdouble *params);
GLAPI void APIENTRY glTexGenf(GLenum coord, GLenum pname, GLfloat param);
GLAPI void APIENTRY glTexGenfOES(GLenum coord, GLenum pname, GLfloat param);
GLAPI void APIENTRY glTexGenfv(GLenum coord, GLenum pname, const GLfloat *params);
GLAPI void APIENTRY glTexGenfvOES(GLenum coord, GLenum pname, const GLfloat *params);
GLAPI void APIENTRY glTexGeni(GLenum coord, GLenum pname, GLint param);
GLAPI void APIENTRY glTexGeniOES(GLenum coord, GLenum pname, GLint param);
GLAPI void APIENTRY glTexGeniv(GLenum coord, GLenum pname, const GLint *params);
GLAPI void APIENTRY glTexGenivOES(GLenum coord, GLenum pname, const GLint *params);
GLAPI void APIENTRY glTexGenxOES(GLenum coord, GLenum pname, GLfixed param);
GLAPI void APIENTRY glTexGenxvOES(GLenum coord, GLenum pname, const GLfixed *params);
GLAPI void APIENTRY glTexImage1D(GLenum target, GLint level, GLint internalformat, GLsizei width, GLint border, GLenum format, GLenum type, const void *pixels);
GLAPI void APIENTRY glTexImage2D(GLenum target, GLint level, GLint internalformat, GLsizei width, GLsizei height, GLint border, GLenum format, GLenum type, const void *pixels);
GLAPI void APIENTRY glTexImage2DMultisample(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLboolean fixedsamplelocations);
GLAPI void APIENTRY glTexImage2DMultisampleCoverageNV(GLenum target, GLsizei coverageSamples, GLsizei colorSamples, GLint internalFormat, GLsizei width, GLsizei height, GLboolean fixedSampleLocations);
GLAPI void APIENTRY glTexImage3D(GLenum target, GLint level, GLint internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLenum format, GLenum type, const void *pixels);
GLAPI void APIENTRY glTexImage3DEXT(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLenum format, GLenum type, const void *pixels);
GLAPI void APIENTRY glTexImage3DMultisample(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedsamplelocations);
GLAPI void APIENTRY glTexImage3DMultisampleCoverageNV(GLenum target, GLsizei coverageSamples, GLsizei colorSamples, GLint internalFormat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedSampleLocations);
GLAPI void APIENTRY glTexImage3DNV(GLenum target, GLint level, GLint internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLenum format, GLenum type, const void *pixels);
GLAPI void APIENTRY glTexImage3DOES(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLenum format, GLenum type, const void *pixels);
GLAPI void APIENTRY glTexImage4DSGIS(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLsizei size4d, GLint border, GLenum format, GLenum type, const void *pixels);
GLAPI void APIENTRY glTexPageCommitmentARB(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLboolean commit);
GLAPI void APIENTRY glTexPageCommitmentEXT(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLboolean commit);
GLAPI void APIENTRY glTexParameterIiv(GLenum target, GLenum pname, const GLint *params);
GLAPI void APIENTRY glTexParameterIivEXT(GLenum target, GLenum pname, const GLint *params);
GLAPI void APIENTRY glTexParameterIivOES(GLenum target, GLenum pname, const GLint *params);
GLAPI void APIENTRY glTexParameterIuiv(GLenum target, GLenum pname, const GLuint *params);
GLAPI void APIENTRY glTexParameterIuivEXT(GLenum target, GLenum pname, const GLuint *params);
GLAPI void APIENTRY glTexParameterIuivOES(GLenum target, GLenum pname, const GLuint *params);
GLAPI void APIENTRY glTexParameterf(GLenum target, GLenum pname, GLfloat param);
GLAPI void APIENTRY glTexParameterfv(GLenum target, GLenum pname, const GLfloat *params);
GLAPI void APIENTRY glTexParameteri(GLenum target, GLenum pname, GLint param);
GLAPI void APIENTRY glTexParameteriv(GLenum target, GLenum pname, const GLint *params);
GLAPI void APIENTRY glTexParameterx(GLenum target, GLenum pname, GLfixed param);
GLAPI void APIENTRY glTexParameterxOES(GLenum target, GLenum pname, GLfixed param);
GLAPI void APIENTRY glTexParameterxv(GLenum target, GLenum pname, const GLfixed *params);
GLAPI void APIENTRY glTexParameterxvOES(GLenum target, GLenum pname, const GLfixed *params);
GLAPI void APIENTRY glTexRenderbufferNV(GLenum target, GLuint renderbuffer);
GLAPI void APIENTRY glTexStorage1D(GLenum target, GLsizei levels, GLenum internalformat, GLsizei width);
GLAPI void APIENTRY glTexStorage1DEXT(GLenum target, GLsizei levels, GLenum internalformat, GLsizei width);
GLAPI void APIENTRY glTexStorage2D(GLenum target, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height);
GLAPI void APIENTRY glTexStorage2DEXT(GLenum target, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height);
GLAPI void APIENTRY glTexStorage2DMultisample(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLboolean fixedsamplelocations);
GLAPI void APIENTRY glTexStorage3D(GLenum target, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth);
GLAPI void APIENTRY glTexStorage3DEXT(GLenum target, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth);
GLAPI void APIENTRY glTexStorage3DMultisample(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedsamplelocations);
GLAPI void APIENTRY glTexStorage3DMultisampleOES(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedsamplelocations);
GLAPI void APIENTRY glTexStorageMem1DEXT(GLenum target, GLsizei levels, GLenum internalFormat, GLsizei width, GLuint memory, GLuint64 offset);
GLAPI void APIENTRY glTexStorageMem2DEXT(GLenum target, GLsizei levels, GLenum internalFormat, GLsizei width, GLsizei height, GLuint memory, GLuint64 offset);
GLAPI void APIENTRY glTexStorageMem2DMultisampleEXT(GLenum target, GLsizei samples, GLenum internalFormat, GLsizei width, GLsizei height, GLboolean fixedSampleLocations, GLuint memory, GLuint64 offset);
GLAPI void APIENTRY glTexStorageMem3DEXT(GLenum target, GLsizei levels, GLenum internalFormat, GLsizei width, GLsizei height, GLsizei depth, GLuint memory, GLuint64 offset);
GLAPI void APIENTRY glTexStorageMem3DMultisampleEXT(GLenum target, GLsizei samples, GLenum internalFormat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedSampleLocations, GLuint memory, GLuint64 offset);
GLAPI void APIENTRY glTexStorageSparseAMD(GLenum target, GLenum internalFormat, GLsizei width, GLsizei height, GLsizei depth, GLsizei layers, GLbitfield flags);
GLAPI void APIENTRY glTexSubImage1D(GLenum target, GLint level, GLint xoffset, GLsizei width, GLenum format, GLenum type, const void *pixels);
GLAPI void APIENTRY glTexSubImage1DEXT(GLenum target, GLint level, GLint xoffset, GLsizei width, GLenum format, GLenum type, const void *pixels);
GLAPI void APIENTRY glTexSubImage2D(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLenum type, const void *pixels);
GLAPI void APIENTRY glTexSubImage2DEXT(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLenum type, const void *pixels);
GLAPI void APIENTRY glTexSubImage3D(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void *pixels);
GLAPI void APIENTRY glTexSubImage3DEXT(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void *pixels);
GLAPI void APIENTRY glTexSubImage3DNV(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void *pixels);
GLAPI void APIENTRY glTexSubImage3DOES(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void *pixels);
GLAPI void APIENTRY glTexSubImage4DSGIS(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLint woffset, GLsizei width, GLsizei height, GLsizei depth, GLsizei size4d, GLenum format, GLenum type, const void *pixels);
GLAPI void APIENTRY glTextureAttachMemoryNV(GLuint texture, GLuint memory, GLuint64 offset);
GLAPI void APIENTRY glTextureBarrier(void);
GLAPI void APIENTRY glTextureBarrierNV(void);
GLAPI void APIENTRY glTextureBuffer(GLuint texture, GLenum internalformat, GLuint buffer);
GLAPI void APIENTRY glTextureBufferEXT(GLuint texture, GLenum target, GLenum internalformat, GLuint buffer);
GLAPI void APIENTRY glTextureBufferRange(GLuint texture, GLenum internalformat, GLuint buffer, GLintptr offset, GLsizeiptr size);
GLAPI void APIENTRY glTextureBufferRangeEXT(GLuint texture, GLenum target, GLenum internalformat, GLuint buffer, GLintptr offset, GLsizeiptr size);
GLAPI void APIENTRY glTextureColorMaskSGIS(GLboolean red, GLboolean green, GLboolean blue, GLboolean alpha);
GLAPI void APIENTRY glTextureFoveationParametersQCOM(GLuint texture, GLuint layer, GLuint focalPoint, GLfloat focalX, GLfloat focalY, GLfloat gainX, GLfloat gainY, GLfloat foveaArea);
GLAPI void APIENTRY glTextureImage1DEXT(GLuint texture, GLenum target, GLint level, GLint internalformat, GLsizei width, GLint border, GLenum format, GLenum type, const void *pixels);
GLAPI void APIENTRY glTextureImage2DEXT(GLuint texture, GLenum target, GLint level, GLint internalformat, GLsizei width, GLsizei height, GLint border, GLenum format, GLenum type, const void *pixels);
GLAPI void APIENTRY glTextureImage2DMultisampleCoverageNV(GLuint texture, GLenum target, GLsizei coverageSamples, GLsizei colorSamples, GLint internalFormat, GLsizei width, GLsizei height, GLboolean fixedSampleLocations);
GLAPI void APIENTRY glTextureImage2DMultisampleNV(GLuint texture, GLenum target, GLsizei samples, GLint internalFormat, GLsizei width, GLsizei height, GLboolean fixedSampleLocations);
GLAPI void APIENTRY glTextureImage3DEXT(GLuint texture, GLenum target, GLint level, GLint internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLenum format, GLenum type, const void *pixels);
GLAPI void APIENTRY glTextureImage3DMultisampleCoverageNV(GLuint texture, GLenum target, GLsizei coverageSamples, GLsizei colorSamples, GLint internalFormat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedSampleLocations);
GLAPI void APIENTRY glTextureImage3DMultisampleNV(GLuint texture, GLenum target, GLsizei samples, GLint internalFormat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedSampleLocations);
GLAPI void APIENTRY glTextureLightEXT(GLenum pname);
GLAPI void APIENTRY glTextureMaterialEXT(GLenum face, GLenum mode);
GLAPI void APIENTRY glTextureNormalEXT(GLenum mode);
GLAPI void APIENTRY glTexturePageCommitmentEXT(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLboolean commit);
GLAPI void APIENTRY glTextureParameterIiv(GLuint texture, GLenum pname, const GLint *params);
GLAPI void APIENTRY glTextureParameterIivEXT(GLuint texture, GLenum target, GLenum pname, const GLint *params);
GLAPI void APIENTRY glTextureParameterIuiv(GLuint texture, GLenum pname, const GLuint *params);
GLAPI void APIENTRY glTextureParameterIuivEXT(GLuint texture, GLenum target, GLenum pname, const GLuint *params);
GLAPI void APIENTRY glTextureParameterf(GLuint texture, GLenum pname, GLfloat param);
GLAPI void APIENTRY glTextureParameterfEXT(GLuint texture, GLenum target, GLenum pname, GLfloat param);
GLAPI void APIENTRY glTextureParameterfv(GLuint texture, GLenum pname, const GLfloat *param);
GLAPI void APIENTRY glTextureParameterfvEXT(GLuint texture, GLenum target, GLenum pname, const GLfloat *params);
GLAPI void APIENTRY glTextureParameteri(GLuint texture, GLenum pname, GLint param);
GLAPI void APIENTRY glTextureParameteriEXT(GLuint texture, GLenum target, GLenum pname, GLint param);
GLAPI void APIENTRY glTextureParameteriv(GLuint texture, GLenum pname, const GLint *param);
GLAPI void APIENTRY glTextureParameterivEXT(GLuint texture, GLenum target, GLenum pname, const GLint *params);
GLAPI void APIENTRY glTextureRangeAPPLE(GLenum target, GLsizei length, const void *pointer);
GLAPI void APIENTRY glTextureRenderbufferEXT(GLuint texture, GLenum target, GLuint renderbuffer);
GLAPI void APIENTRY glTextureStorage1D(GLuint texture, GLsizei levels, GLenum internalformat, GLsizei width);
GLAPI void APIENTRY glTextureStorage1DEXT(GLuint texture, GLenum target, GLsizei levels, GLenum internalformat, GLsizei width);
GLAPI void APIENTRY glTextureStorage2D(GLuint texture, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height);
GLAPI void APIENTRY glTextureStorage2DEXT(GLuint texture, GLenum target, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height);
GLAPI void APIENTRY glTextureStorage2DMultisample(GLuint texture, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLboolean fixedsamplelocations);
GLAPI void APIENTRY glTextureStorage2DMultisampleEXT(GLuint texture, GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLboolean fixedsamplelocations);
GLAPI void APIENTRY glTextureStorage3D(GLuint texture, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth);
GLAPI void APIENTRY glTextureStorage3DEXT(GLuint texture, GLenum target, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth);
GLAPI void APIENTRY glTextureStorage3DMultisample(GLuint texture, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedsamplelocations);
GLAPI void APIENTRY glTextureStorage3DMultisampleEXT(GLuint texture, GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedsamplelocations);
GLAPI void APIENTRY glTextureStorageMem1DEXT(GLuint texture, GLsizei levels, GLenum internalFormat, GLsizei width, GLuint memory, GLuint64 offset);
GLAPI void APIENTRY glTextureStorageMem2DEXT(GLuint texture, GLsizei levels, GLenum internalFormat, GLsizei width, GLsizei height, GLuint memory, GLuint64 offset);
GLAPI void APIENTRY glTextureStorageMem2DMultisampleEXT(GLuint texture, GLsizei samples, GLenum internalFormat, GLsizei width, GLsizei height, GLboolean fixedSampleLocations, GLuint memory, GLuint64 offset);
GLAPI void APIENTRY glTextureStorageMem3DEXT(GLuint texture, GLsizei levels, GLenum internalFormat, GLsizei width, GLsizei height, GLsizei depth, GLuint memory, GLuint64 offset);
GLAPI void APIENTRY glTextureStorageMem3DMultisampleEXT(GLuint texture, GLsizei samples, GLenum internalFormat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedSampleLocations, GLuint memory, GLuint64 offset);
GLAPI void APIENTRY glTextureStorageSparseAMD(GLuint texture, GLenum target, GLenum internalFormat, GLsizei width, GLsizei height, GLsizei depth, GLsizei layers, GLbitfield flags);
GLAPI void APIENTRY glTextureSubImage1D(GLuint texture, GLint level, GLint xoffset, GLsizei width, GLenum format, GLenum type, const void *pixels);
GLAPI void APIENTRY glTextureSubImage1DEXT(GLuint texture, GLenum target, GLint level, GLint xoffset, GLsizei width, GLenum format, GLenum type, const void *pixels);
GLAPI void APIENTRY glTextureSubImage2D(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLenum type, const void *pixels);
GLAPI void APIENTRY glTextureSubImage2DEXT(GLuint texture, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLenum type, const void *pixels);
GLAPI void APIENTRY glTextureSubImage3D(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void *pixels);
GLAPI void APIENTRY glTextureSubImage3DEXT(GLuint texture, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void *pixels);
GLAPI void APIENTRY glTextureView(GLuint texture, GLenum target, GLuint origtexture, GLenum internalformat, GLuint minlevel, GLuint numlevels, GLuint minlayer, GLuint numlayers);
GLAPI void APIENTRY glTextureViewEXT(GLuint texture, GLenum target, GLuint origtexture, GLenum internalformat, GLuint minlevel, GLuint numlevels, GLuint minlayer, GLuint numlayers);
GLAPI void APIENTRY glTextureViewOES(GLuint texture, GLenum target, GLuint origtexture, GLenum internalformat, GLuint minlevel, GLuint numlevels, GLuint minlayer, GLuint numlayers);
GLAPI void APIENTRY glTrackMatrixNV(GLenum target, GLuint address, GLenum matrix, GLenum transform);
GLAPI void APIENTRY glTransformFeedbackAttribsNV(GLsizei count, const GLint *attribs, GLenum bufferMode);
GLAPI void APIENTRY glTransformFeedbackBufferBase(GLuint xfb, GLuint index, GLuint buffer);
GLAPI void APIENTRY glTransformFeedbackBufferRange(GLuint xfb, GLuint index, GLuint buffer, GLintptr offset, GLsizeiptr size);
GLAPI void APIENTRY glTransformFeedbackStreamAttribsNV(GLsizei count, const GLint *attribs, GLsizei nbuffers, const GLint *bufstreams, GLenum bufferMode);
GLAPI void APIENTRY glTransformFeedbackVaryings(GLuint program, GLsizei count, const GLchar *const *varyings, GLenum bufferMode);
GLAPI void APIENTRY glTransformFeedbackVaryingsEXT(GLuint program, GLsizei count, const GLchar *const *varyings, GLenum bufferMode);
GLAPI void APIENTRY glTransformFeedbackVaryingsNV(GLuint program, GLsizei count, const GLint *locations, GLenum bufferMode);
GLAPI void APIENTRY glTransformPathNV(GLuint resultPath, GLuint srcPath, GLenum transformType, const GLfloat *transformValues);
GLAPI void APIENTRY glTranslated(GLdouble x, GLdouble y, GLdouble z);
GLAPI void APIENTRY glTranslatef(GLfloat x, GLfloat y, GLfloat z);
GLAPI void APIENTRY glTranslatex(GLfixed x, GLfixed y, GLfixed z);
GLAPI void APIENTRY glTranslatexOES(GLfixed x, GLfixed y, GLfixed z);
GLAPI void APIENTRY glUniform1d(GLint location, GLdouble x);
GLAPI void APIENTRY glUniform1dv(GLint location, GLsizei count, const GLdouble *value);
GLAPI void APIENTRY glUniform1f(GLint location, GLfloat v0);
GLAPI void APIENTRY glUniform1fARB(GLint location, GLfloat v0);
GLAPI void APIENTRY glUniform1fv(GLint location, GLsizei count, const GLfloat *value);
GLAPI void APIENTRY glUniform1fvARB(GLint location, GLsizei count, const GLfloat *value);
GLAPI void APIENTRY glUniform1i(GLint location, GLint v0);
GLAPI void APIENTRY glUniform1i64ARB(GLint location, GLint64 x);
GLAPI void APIENTRY glUniform1i64NV(GLint location, GLint64 x);
GLAPI void APIENTRY glUniform1i64vARB(GLint location, GLsizei count, const GLint64 *value);
GLAPI void APIENTRY glUniform1i64vNV(GLint location, GLsizei count, const GLint64 *value);
GLAPI void APIENTRY glUniform1iARB(GLint location, GLint v0);
GLAPI void APIENTRY glUniform1iv(GLint location, GLsizei count, const GLint *value);
GLAPI void APIENTRY glUniform1ivARB(GLint location, GLsizei count, const GLint *value);
GLAPI void APIENTRY glUniform1ui(GLint location, GLuint v0);
GLAPI void APIENTRY glUniform1ui64ARB(GLint location, GLuint64 x);
GLAPI void APIENTRY glUniform1ui64NV(GLint location, GLuint64 x);
GLAPI void APIENTRY glUniform1ui64vARB(GLint location, GLsizei count, const GLuint64 *value);
GLAPI void APIENTRY glUniform1ui64vNV(GLint location, GLsizei count, const GLuint64 *value);
GLAPI void APIENTRY glUniform1uiEXT(GLint location, GLuint v0);
GLAPI void APIENTRY glUniform1uiv(GLint location, GLsizei count, const GLuint *value);
GLAPI void APIENTRY glUniform1uivEXT(GLint location, GLsizei count, const GLuint *value);
GLAPI void APIENTRY glUniform2d(GLint location, GLdouble x, GLdouble y);
GLAPI void APIENTRY glUniform2dv(GLint location, GLsizei count, const GLdouble *value);
GLAPI void APIENTRY glUniform2f(GLint location, GLfloat v0, GLfloat v1);
GLAPI void APIENTRY glUniform2fARB(GLint location, GLfloat v0, GLfloat v1);
GLAPI void APIENTRY glUniform2fv(GLint location, GLsizei count, const GLfloat *value);
GLAPI void APIENTRY glUniform2fvARB(GLint location, GLsizei count, const GLfloat *value);
GLAPI void APIENTRY glUniform2i(GLint location, GLint v0, GLint v1);
GLAPI void APIENTRY glUniform2i64ARB(GLint location, GLint64 x, GLint64 y);
GLAPI void APIENTRY glUniform2i64NV(GLint location, GLint64 x, GLint64 y);
GLAPI void APIENTRY glUniform2i64vARB(GLint location, GLsizei count, const GLint64 *value);
GLAPI void APIENTRY glUniform2i64vNV(GLint location, GLsizei count, const GLint64 *value);
GLAPI void APIENTRY glUniform2iARB(GLint location, GLint v0, GLint v1);
GLAPI void APIENTRY glUniform2iv(GLint location, GLsizei count, const GLint *value);
GLAPI void APIENTRY glUniform2ivARB(GLint location, GLsizei count, const GLint *value);
GLAPI void APIENTRY glUniform2ui(GLint location, GLuint v0, GLuint v1);
GLAPI void APIENTRY glUniform2ui64ARB(GLint location, GLuint64 x, GLuint64 y);
GLAPI void APIENTRY glUniform2ui64NV(GLint location, GLuint64 x, GLuint64 y);
GLAPI void APIENTRY glUniform2ui64vARB(GLint location, GLsizei count, const GLuint64 *value);
GLAPI void APIENTRY glUniform2ui64vNV(GLint location, GLsizei count, const GLuint64 *value);
GLAPI void APIENTRY glUniform2uiEXT(GLint location, GLuint v0, GLuint v1);
GLAPI void APIENTRY glUniform2uiv(GLint location, GLsizei count, const GLuint *value);
GLAPI void APIENTRY glUniform2uivEXT(GLint location, GLsizei count, const GLuint *value);
GLAPI void APIENTRY glUniform3d(GLint location, GLdouble x, GLdouble y, GLdouble z);
GLAPI void APIENTRY glUniform3dv(GLint location, GLsizei count, const GLdouble *value);
GLAPI void APIENTRY glUniform3f(GLint location, GLfloat v0, GLfloat v1, GLfloat v2);
GLAPI void APIENTRY glUniform3fARB(GLint location, GLfloat v0, GLfloat v1, GLfloat v2);
GLAPI void APIENTRY glUniform3fv(GLint location, GLsizei count, const GLfloat *value);
GLAPI void APIENTRY glUniform3fvARB(GLint location, GLsizei count, const GLfloat *value);
GLAPI void APIENTRY glUniform3i(GLint location, GLint v0, GLint v1, GLint v2);
GLAPI void APIENTRY glUniform3i64ARB(GLint location, GLint64 x, GLint64 y, GLint64 z);
GLAPI void APIENTRY glUniform3i64NV(GLint location, GLint64 x, GLint64 y, GLint64 z);
GLAPI void APIENTRY glUniform3i64vARB(GLint location, GLsizei count, const GLint64 *value);
GLAPI void APIENTRY glUniform3i64vNV(GLint location, GLsizei count, const GLint64 *value);
GLAPI void APIENTRY glUniform3iARB(GLint location, GLint v0, GLint v1, GLint v2);
GLAPI void APIENTRY glUniform3iv(GLint location, GLsizei count, const GLint *value);
GLAPI void APIENTRY glUniform3ivARB(GLint location, GLsizei count, const GLint *value);
GLAPI void APIENTRY glUniform3ui(GLint location, GLuint v0, GLuint v1, GLuint v2);
GLAPI void APIENTRY glUniform3ui64ARB(GLint location, GLuint64 x, GLuint64 y, GLuint64 z);
GLAPI void APIENTRY glUniform3ui64NV(GLint location, GLuint64 x, GLuint64 y, GLuint64 z);
GLAPI void APIENTRY glUniform3ui64vARB(GLint location, GLsizei count, const GLuint64 *value);
GLAPI void APIENTRY glUniform3ui64vNV(GLint location, GLsizei count, const GLuint64 *value);
GLAPI void APIENTRY glUniform3uiEXT(GLint location, GLuint v0, GLuint v1, GLuint v2);
GLAPI void APIENTRY glUniform3uiv(GLint location, GLsizei count, const GLuint *value);
GLAPI void APIENTRY glUniform3uivEXT(GLint location, GLsizei count, const GLuint *value);
GLAPI void APIENTRY glUniform4d(GLint location, GLdouble x, GLdouble y, GLdouble z, GLdouble w);
GLAPI void APIENTRY glUniform4dv(GLint location, GLsizei count, const GLdouble *value);
GLAPI void APIENTRY glUniform4f(GLint location, GLfloat v0, GLfloat v1, GLfloat v2, GLfloat v3);
GLAPI void APIENTRY glUniform4fARB(GLint location, GLfloat v0, GLfloat v1, GLfloat v2, GLfloat v3);
GLAPI void APIENTRY glUniform4fv(GLint location, GLsizei count, const GLfloat *value);
GLAPI void APIENTRY glUniform4fvARB(GLint location, GLsizei count, const GLfloat *value);
GLAPI void APIENTRY glUniform4i(GLint location, GLint v0, GLint v1, GLint v2, GLint v3);
GLAPI void APIENTRY glUniform4i64ARB(GLint location, GLint64 x, GLint64 y, GLint64 z, GLint64 w);
GLAPI void APIENTRY glUniform4i64NV(GLint location, GLint64 x, GLint64 y, GLint64 z, GLint64 w);
GLAPI void APIENTRY glUniform4i64vARB(GLint location, GLsizei count, const GLint64 *value);
GLAPI void APIENTRY glUniform4i64vNV(GLint location, GLsizei count, const GLint64 *value);
GLAPI void APIENTRY glUniform4iARB(GLint location, GLint v0, GLint v1, GLint v2, GLint v3);
GLAPI void APIENTRY glUniform4iv(GLint location, GLsizei count, const GLint *value);
GLAPI void APIENTRY glUniform4ivARB(GLint location, GLsizei count, const GLint *value);
GLAPI void APIENTRY glUniform4ui(GLint location, GLuint v0, GLuint v1, GLuint v2, GLuint v3);
GLAPI void APIENTRY glUniform4ui64ARB(GLint location, GLuint64 x, GLuint64 y, GLuint64 z, GLuint64 w);
GLAPI void APIENTRY glUniform4ui64NV(GLint location, GLuint64 x, GLuint64 y, GLuint64 z, GLuint64 w);
GLAPI void APIENTRY glUniform4ui64vARB(GLint location, GLsizei count, const GLuint64 *value);
GLAPI void APIENTRY glUniform4ui64vNV(GLint location, GLsizei count, const GLuint64 *value);
GLAPI void APIENTRY glUniform4uiEXT(GLint location, GLuint v0, GLuint v1, GLuint v2, GLuint v3);
GLAPI void APIENTRY glUniform4uiv(GLint location, GLsizei count, const GLuint *value);
GLAPI void APIENTRY glUniform4uivEXT(GLint location, GLsizei count, const GLuint *value);
GLAPI void APIENTRY glUniformBlockBinding(GLuint program, GLuint uniformBlockIndex, GLuint uniformBlockBinding);
GLAPI void APIENTRY glUniformBufferEXT(GLuint program, GLint location, GLuint buffer);
GLAPI void APIENTRY glUniformHandleui64ARB(GLint location, GLuint64 value);
GLAPI void APIENTRY glUniformHandleui64IMG(GLint location, GLuint64 value);
GLAPI void APIENTRY glUniformHandleui64NV(GLint location, GLuint64 value);
GLAPI void APIENTRY glUniformHandleui64vARB(GLint location, GLsizei count, const GLuint64 *value);
GLAPI void APIENTRY glUniformHandleui64vIMG(GLint location, GLsizei count, const GLuint64 *value);
GLAPI void APIENTRY glUniformHandleui64vNV(GLint location, GLsizei count, const GLuint64 *value);
GLAPI void APIENTRY glUniformMatrix2dv(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value);
GLAPI void APIENTRY glUniformMatrix2fv(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value);
GLAPI void APIENTRY glUniformMatrix2fvARB(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value);
GLAPI void APIENTRY glUniformMatrix2x3dv(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value);
GLAPI void APIENTRY glUniformMatrix2x3fv(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value);
GLAPI void APIENTRY glUniformMatrix2x3fvNV(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value);
GLAPI void APIENTRY glUniformMatrix2x4dv(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value);
GLAPI void APIENTRY glUniformMatrix2x4fv(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value);
GLAPI void APIENTRY glUniformMatrix2x4fvNV(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value);
GLAPI void APIENTRY glUniformMatrix3dv(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value);
GLAPI void APIENTRY glUniformMatrix3fv(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value);
GLAPI void APIENTRY glUniformMatrix3fvARB(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value);
GLAPI void APIENTRY glUniformMatrix3x2dv(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value);
GLAPI void APIENTRY glUniformMatrix3x2fv(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value);
GLAPI void APIENTRY glUniformMatrix3x2fvNV(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value);
GLAPI void APIENTRY glUniformMatrix3x4dv(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value);
GLAPI void APIENTRY glUniformMatrix3x4fv(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value);
GLAPI void APIENTRY glUniformMatrix3x4fvNV(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value);
GLAPI void APIENTRY glUniformMatrix4dv(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value);
GLAPI void APIENTRY glUniformMatrix4fv(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value);
GLAPI void APIENTRY glUniformMatrix4fvARB(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value);
GLAPI void APIENTRY glUniformMatrix4x2dv(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value);
GLAPI void APIENTRY glUniformMatrix4x2fv(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value);
GLAPI void APIENTRY glUniformMatrix4x2fvNV(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value);
GLAPI void APIENTRY glUniformMatrix4x3dv(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value);
GLAPI void APIENTRY glUniformMatrix4x3fv(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value);
GLAPI void APIENTRY glUniformMatrix4x3fvNV(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value);
GLAPI void APIENTRY glUniformSubroutinesuiv(GLenum shadertype, GLsizei count, const GLuint *indices);
GLAPI void APIENTRY glUniformui64NV(GLint location, GLuint64 value);
GLAPI void APIENTRY glUniformui64vNV(GLint location, GLsizei count, const GLuint64 *value);
GLAPI void APIENTRY glUnlockArraysEXT(void);
GLAPI GLboolean APIENTRY glUnmapBuffer(GLenum target);
GLAPI GLboolean APIENTRY glUnmapBufferARB(GLenum target);
GLAPI GLboolean APIENTRY glUnmapBufferOES(GLenum target);
GLAPI GLboolean APIENTRY glUnmapNamedBuffer(GLuint buffer);
GLAPI GLboolean APIENTRY glUnmapNamedBufferEXT(GLuint buffer);
GLAPI void APIENTRY glUnmapObjectBufferATI(GLuint buffer);
GLAPI void APIENTRY glUnmapTexture2DINTEL(GLuint texture, GLint level);
GLAPI void APIENTRY glUpdateObjectBufferATI(GLuint buffer, GLuint offset, GLsizei size, const void *pointer, GLenum preserve);
GLAPI void APIENTRY glUploadGpuMaskNVX(GLbitfield mask);
GLAPI void APIENTRY glUseProgram(GLuint program);
GLAPI void APIENTRY glUseProgramObjectARB(GLhandleARB programObj);
GLAPI void APIENTRY glUseProgramStages(GLuint pipeline, GLbitfield stages, GLuint program);
GLAPI void APIENTRY glUseProgramStagesEXT(GLuint pipeline, GLbitfield stages, GLuint program);
GLAPI void APIENTRY glUseShaderProgramEXT(GLenum type, GLuint program);
GLAPI void APIENTRY glVDPAUFiniNV(void);
GLAPI void APIENTRY glVDPAUGetSurfaceivNV(GLvdpauSurfaceNV surface, GLenum pname, GLsizei count, GLsizei *length, GLint *values);
GLAPI void APIENTRY glVDPAUInitNV(const void *vdpDevice, const void *getProcAddress);
GLAPI GLboolean APIENTRY glVDPAUIsSurfaceNV(GLvdpauSurfaceNV surface);
GLAPI void APIENTRY glVDPAUMapSurfacesNV(GLsizei numSurfaces, const GLvdpauSurfaceNV *surfaces);
GLAPI GLvdpauSurfaceNV APIENTRY glVDPAURegisterOutputSurfaceNV(const void *vdpSurface, GLenum target, GLsizei numTextureNames, const GLuint *textureNames);
GLAPI GLvdpauSurfaceNV APIENTRY glVDPAURegisterVideoSurfaceNV(const void *vdpSurface, GLenum target, GLsizei numTextureNames, const GLuint *textureNames);
GLAPI GLvdpauSurfaceNV APIENTRY glVDPAURegisterVideoSurfaceWithPictureStructureNV(const void *vdpSurface, GLenum target, GLsizei numTextureNames, const GLuint *textureNames, GLboolean isFrameStructure);
GLAPI void APIENTRY glVDPAUSurfaceAccessNV(GLvdpauSurfaceNV surface, GLenum access);
GLAPI void APIENTRY glVDPAUUnmapSurfacesNV(GLsizei numSurface, const GLvdpauSurfaceNV *surfaces);
GLAPI void APIENTRY glVDPAUUnregisterSurfaceNV(GLvdpauSurfaceNV surface);
GLAPI GLboolean APIENTRY glValidBackBufferHintAutodesk(GLint x, GLint y, GLsizei width, GLsizei height);
GLAPI void APIENTRY glValidateProgram(GLuint program);
GLAPI void APIENTRY glValidateProgramARB(GLhandleARB programObj);
GLAPI void APIENTRY glValidateProgramPipeline(GLuint pipeline);
GLAPI void APIENTRY glValidateProgramPipelineEXT(GLuint pipeline);
GLAPI void APIENTRY glVariantArrayObjectATI(GLuint id, GLenum type, GLsizei stride, GLuint buffer, GLuint offset);
GLAPI void APIENTRY glVariantPointerEXT(GLuint id, GLenum type, GLuint stride, const void *addr);
GLAPI void APIENTRY glVariantbvEXT(GLuint id, const GLbyte *addr);
GLAPI void APIENTRY glVariantdvEXT(GLuint id, const GLdouble *addr);
GLAPI void APIENTRY glVariantfvEXT(GLuint id, const GLfloat *addr);
GLAPI void APIENTRY glVariantivEXT(GLuint id, const GLint *addr);
GLAPI void APIENTRY glVariantsvEXT(GLuint id, const GLshort *addr);
GLAPI void APIENTRY glVariantubvEXT(GLuint id, const GLubyte *addr);
GLAPI void APIENTRY glVariantuivEXT(GLuint id, const GLuint *addr);
GLAPI void APIENTRY glVariantusvEXT(GLuint id, const GLushort *addr);
GLAPI void APIENTRY glVertex2bOES(GLbyte x, GLbyte y);
GLAPI void APIENTRY glVertex2bvOES(const GLbyte *coords);
GLAPI void APIENTRY glVertex2d(GLdouble x, GLdouble y);
GLAPI void APIENTRY glVertex2dv(const GLdouble *v);
GLAPI void APIENTRY glVertex2f(GLfloat x, GLfloat y);
GLAPI void APIENTRY glVertex2fv(const GLfloat *v);
GLAPI void APIENTRY glVertex2hNV(GLhalf x, GLhalf y);
GLAPI void APIENTRY glVertex2hvNV(const GLhalf *v);
GLAPI void APIENTRY glVertex2i(GLint x, GLint y);
GLAPI void APIENTRY glVertex2iv(const GLint *v);
GLAPI void APIENTRY glVertex2s(GLshort x, GLshort y);
GLAPI void APIENTRY glVertex2sv(const GLshort *v);
GLAPI void APIENTRY glVertex2xOES(GLfixed x);
GLAPI void APIENTRY glVertex2xvOES(const GLfixed *coords);
GLAPI void APIENTRY glVertex3bOES(GLbyte x, GLbyte y, GLbyte z);
GLAPI void APIENTRY glVertex3bvOES(const GLbyte *coords);
GLAPI void APIENTRY glVertex3d(GLdouble x, GLdouble y, GLdouble z);
GLAPI void APIENTRY glVertex3dv(const GLdouble *v);
GLAPI void APIENTRY glVertex3f(GLfloat x, GLfloat y, GLfloat z);
GLAPI void APIENTRY glVertex3fv(const GLfloat *v);
GLAPI void APIENTRY glVertex3hNV(GLhalf x, GLhalf y, GLhalf z);
GLAPI void APIENTRY glVertex3hvNV(const GLhalf *v);
GLAPI void APIENTRY glVertex3i(GLint x, GLint y, GLint z);
GLAPI void APIENTRY glVertex3iv(const GLint *v);
GLAPI void APIENTRY glVertex3s(GLshort x, GLshort y, GLshort z);
GLAPI void APIENTRY glVertex3sv(const GLshort *v);
GLAPI void APIENTRY glVertex3xOES(GLfixed x, GLfixed y);
GLAPI void APIENTRY glVertex3xvOES(const GLfixed *coords);
GLAPI void APIENTRY glVertex4bOES(GLbyte x, GLbyte y, GLbyte z, GLbyte w);
GLAPI void APIENTRY glVertex4bvOES(const GLbyte *coords);
GLAPI void APIENTRY glVertex4d(GLdouble x, GLdouble y, GLdouble z, GLdouble w);
GLAPI void APIENTRY glVertex4dv(const GLdouble *v);
GLAPI void APIENTRY glVertex4f(GLfloat x, GLfloat y, GLfloat z, GLfloat w);
GLAPI void APIENTRY glVertex4fv(const GLfloat *v);
GLAPI void APIENTRY glVertex4hNV(GLhalf x, GLhalf y, GLhalf z, GLhalf w);
GLAPI void APIENTRY glVertex4hvNV(const GLhalf *v);
GLAPI void APIENTRY glVertex4i(GLint x, GLint y, GLint z, GLint w);
GLAPI void APIENTRY glVertex4iv(const GLint *v);
GLAPI void APIENTRY glVertex4s(GLshort x, GLshort y, GLshort z, GLshort w);
GLAPI void APIENTRY glVertex4sv(const GLshort *v);
GLAPI void APIENTRY glVertex4xOES(GLfixed x, GLfixed y, GLfixed z);
GLAPI void APIENTRY glVertex4xvOES(const GLfixed *coords);
GLAPI void APIENTRY glVertexArrayAttribBinding(GLuint vaobj, GLuint attribindex, GLuint bindingindex);
GLAPI void APIENTRY glVertexArrayAttribFormat(GLuint vaobj, GLuint attribindex, GLint size, GLenum type, GLboolean normalized, GLuint relativeoffset);
GLAPI void APIENTRY glVertexArrayAttribIFormat(GLuint vaobj, GLuint attribindex, GLint size, GLenum type, GLuint relativeoffset);
GLAPI void APIENTRY glVertexArrayAttribLFormat(GLuint vaobj, GLuint attribindex, GLint size, GLenum type, GLuint relativeoffset);
GLAPI void APIENTRY glVertexArrayBindVertexBufferEXT(GLuint vaobj, GLuint bindingindex, GLuint buffer, GLintptr offset, GLsizei stride);
GLAPI void APIENTRY glVertexArrayBindingDivisor(GLuint vaobj, GLuint bindingindex, GLuint divisor);
GLAPI void APIENTRY glVertexArrayColorOffsetEXT(GLuint vaobj, GLuint buffer, GLint size, GLenum type, GLsizei stride, GLintptr offset);
GLAPI void APIENTRY glVertexArrayEdgeFlagOffsetEXT(GLuint vaobj, GLuint buffer, GLsizei stride, GLintptr offset);
GLAPI void APIENTRY glVertexArrayElementBuffer(GLuint vaobj, GLuint buffer);
GLAPI void APIENTRY glVertexArrayFogCoordOffsetEXT(GLuint vaobj, GLuint buffer, GLenum type, GLsizei stride, GLintptr offset);
GLAPI void APIENTRY glVertexArrayIndexOffsetEXT(GLuint vaobj, GLuint buffer, GLenum type, GLsizei stride, GLintptr offset);
GLAPI void APIENTRY glVertexArrayMultiTexCoordOffsetEXT(GLuint vaobj, GLuint buffer, GLenum texunit, GLint size, GLenum type, GLsizei stride, GLintptr offset);
GLAPI void APIENTRY glVertexArrayNormalOffsetEXT(GLuint vaobj, GLuint buffer, GLenum type, GLsizei stride, GLintptr offset);
GLAPI void APIENTRY glVertexArrayParameteriAPPLE(GLenum pname, GLint param);
GLAPI void APIENTRY glVertexArrayRangeAPPLE(GLsizei length, void *pointer);
GLAPI void APIENTRY glVertexArrayRangeNV(GLsizei length, const void *pointer);
GLAPI void APIENTRY glVertexArraySecondaryColorOffsetEXT(GLuint vaobj, GLuint buffer, GLint size, GLenum type, GLsizei stride, GLintptr offset);
GLAPI void APIENTRY glVertexArrayTexCoordOffsetEXT(GLuint vaobj, GLuint buffer, GLint size, GLenum type, GLsizei stride, GLintptr offset);
GLAPI void APIENTRY glVertexArrayVertexAttribBindingEXT(GLuint vaobj, GLuint attribindex, GLuint bindingindex);
GLAPI void APIENTRY glVertexArrayVertexAttribDivisorEXT(GLuint vaobj, GLuint index, GLuint divisor);
GLAPI void APIENTRY glVertexArrayVertexAttribFormatEXT(GLuint vaobj, GLuint attribindex, GLint size, GLenum type, GLboolean normalized, GLuint relativeoffset);
GLAPI void APIENTRY glVertexArrayVertexAttribIFormatEXT(GLuint vaobj, GLuint attribindex, GLint size, GLenum type, GLuint relativeoffset);
GLAPI void APIENTRY glVertexArrayVertexAttribIOffsetEXT(GLuint vaobj, GLuint buffer, GLuint index, GLint size, GLenum type, GLsizei stride, GLintptr offset);
GLAPI void APIENTRY glVertexArrayVertexAttribLFormatEXT(GLuint vaobj, GLuint attribindex, GLint size, GLenum type, GLuint relativeoffset);
GLAPI void APIENTRY glVertexArrayVertexAttribLOffsetEXT(GLuint vaobj, GLuint buffer, GLuint index, GLint size, GLenum type, GLsizei stride, GLintptr offset);
GLAPI void APIENTRY glVertexArrayVertexAttribOffsetEXT(GLuint vaobj, GLuint buffer, GLuint index, GLint size, GLenum type, GLboolean normalized, GLsizei stride, GLintptr offset);
GLAPI void APIENTRY glVertexArrayVertexBindingDivisorEXT(GLuint vaobj, GLuint bindingindex, GLuint divisor);
GLAPI void APIENTRY glVertexArrayVertexBuffer(GLuint vaobj, GLuint bindingindex, GLuint buffer, GLintptr offset, GLsizei stride);
GLAPI void APIENTRY glVertexArrayVertexBuffers(GLuint vaobj, GLuint first, GLsizei count, const GLuint *buffers, const GLintptr *offsets, const GLsizei *strides);
GLAPI void APIENTRY glVertexArrayVertexOffsetEXT(GLuint vaobj, GLuint buffer, GLint size, GLenum type, GLsizei stride, GLintptr offset);
GLAPI void APIENTRY glVertexAttrib1d(GLuint index, GLdouble x);
GLAPI void APIENTRY glVertexAttrib1dARB(GLuint index, GLdouble x);
GLAPI void APIENTRY glVertexAttrib1dNV(GLuint index, GLdouble x);
GLAPI void APIENTRY glVertexAttrib1dv(GLuint index, const GLdouble *v);
GLAPI void APIENTRY glVertexAttrib1dvARB(GLuint index, const GLdouble *v);
GLAPI void APIENTRY glVertexAttrib1dvNV(GLuint index, const GLdouble *v);
GLAPI void APIENTRY glVertexAttrib1f(GLuint index, GLfloat x);
GLAPI void APIENTRY glVertexAttrib1fARB(GLuint index, GLfloat x);
GLAPI void APIENTRY glVertexAttrib1fNV(GLuint index, GLfloat x);
GLAPI void APIENTRY glVertexAttrib1fv(GLuint index, const GLfloat *v);
GLAPI void APIENTRY glVertexAttrib1fvARB(GLuint index, const GLfloat *v);
GLAPI void APIENTRY glVertexAttrib1fvNV(GLuint index, const GLfloat *v);
GLAPI void APIENTRY glVertexAttrib1hNV(GLuint index, GLhalf x);
GLAPI void APIENTRY glVertexAttrib1hvNV(GLuint index, const GLhalf *v);
GLAPI void APIENTRY glVertexAttrib1s(GLuint index, GLshort x);
GLAPI void APIENTRY glVertexAttrib1sARB(GLuint index, GLshort x);
GLAPI void APIENTRY glVertexAttrib1sNV(GLuint index, GLshort x);
GLAPI void APIENTRY glVertexAttrib1sv(GLuint index, const GLshort *v);
GLAPI void APIENTRY glVertexAttrib1svARB(GLuint index, const GLshort *v);
GLAPI void APIENTRY glVertexAttrib1svNV(GLuint index, const GLshort *v);
GLAPI void APIENTRY glVertexAttrib2d(GLuint index, GLdouble x, GLdouble y);
GLAPI void APIENTRY glVertexAttrib2dARB(GLuint index, GLdouble x, GLdouble y);
GLAPI void APIENTRY glVertexAttrib2dNV(GLuint index, GLdouble x, GLdouble y);
GLAPI void APIENTRY glVertexAttrib2dv(GLuint index, const GLdouble *v);
GLAPI void APIENTRY glVertexAttrib2dvARB(GLuint index, const GLdouble *v);
GLAPI void APIENTRY glVertexAttrib2dvNV(GLuint index, const GLdouble *v);
GLAPI void APIENTRY glVertexAttrib2f(GLuint index, GLfloat x, GLfloat y);
GLAPI void APIENTRY glVertexAttrib2fARB(GLuint index, GLfloat x, GLfloat y);
GLAPI void APIENTRY glVertexAttrib2fNV(GLuint index, GLfloat x, GLfloat y);
GLAPI void APIENTRY glVertexAttrib2fv(GLuint index, const GLfloat *v);
GLAPI void APIENTRY glVertexAttrib2fvARB(GLuint index, const GLfloat *v);
GLAPI void APIENTRY glVertexAttrib2fvNV(GLuint index, const GLfloat *v);
GLAPI void APIENTRY glVertexAttrib2hNV(GLuint index, GLhalf x, GLhalf y);
GLAPI void APIENTRY glVertexAttrib2hvNV(GLuint index, const GLhalf *v);
GLAPI void APIENTRY glVertexAttrib2s(GLuint index, GLshort x, GLshort y);
GLAPI void APIENTRY glVertexAttrib2sARB(GLuint index, GLshort x, GLshort y);
GLAPI void APIENTRY glVertexAttrib2sNV(GLuint index, GLshort x, GLshort y);
GLAPI void APIENTRY glVertexAttrib2sv(GLuint index, const GLshort *v);
GLAPI void APIENTRY glVertexAttrib2svARB(GLuint index, const GLshort *v);
GLAPI void APIENTRY glVertexAttrib2svNV(GLuint index, const GLshort *v);
GLAPI void APIENTRY glVertexAttrib3d(GLuint index, GLdouble x, GLdouble y, GLdouble z);
GLAPI void APIENTRY glVertexAttrib3dARB(GLuint index, GLdouble x, GLdouble y, GLdouble z);
GLAPI void APIENTRY glVertexAttrib3dNV(GLuint index, GLdouble x, GLdouble y, GLdouble z);
GLAPI void APIENTRY glVertexAttrib3dv(GLuint index, const GLdouble *v);
GLAPI void APIENTRY glVertexAttrib3dvARB(GLuint index, const GLdouble *v);
GLAPI void APIENTRY glVertexAttrib3dvNV(GLuint index, const GLdouble *v);
GLAPI void APIENTRY glVertexAttrib3f(GLuint index, GLfloat x, GLfloat y, GLfloat z);
GLAPI void APIENTRY glVertexAttrib3fARB(GLuint index, GLfloat x, GLfloat y, GLfloat z);
GLAPI void APIENTRY glVertexAttrib3fNV(GLuint index, GLfloat x, GLfloat y, GLfloat z);
GLAPI void APIENTRY glVertexAttrib3fv(GLuint index, const GLfloat *v);
GLAPI void APIENTRY glVertexAttrib3fvARB(GLuint index, const GLfloat *v);
GLAPI void APIENTRY glVertexAttrib3fvNV(GLuint index, const GLfloat *v);
GLAPI void APIENTRY glVertexAttrib3hNV(GLuint index, GLhalf x, GLhalf y, GLhalf z);
GLAPI void APIENTRY glVertexAttrib3hvNV(GLuint index, const GLhalf *v);
GLAPI void APIENTRY glVertexAttrib3s(GLuint index, GLshort x, GLshort y, GLshort z);
GLAPI void APIENTRY glVertexAttrib3sARB(GLuint index, GLshort x, GLshort y, GLshort z);
GLAPI void APIENTRY glVertexAttrib3sNV(GLuint index, GLshort x, GLshort y, GLshort z);
GLAPI void APIENTRY glVertexAttrib3sv(GLuint index, const GLshort *v);
GLAPI void APIENTRY glVertexAttrib3svARB(GLuint index, const GLshort *v);
GLAPI void APIENTRY glVertexAttrib3svNV(GLuint index, const GLshort *v);
GLAPI void APIENTRY glVertexAttrib4Nbv(GLuint index, const GLbyte *v);
GLAPI void APIENTRY glVertexAttrib4NbvARB(GLuint index, const GLbyte *v);
GLAPI void APIENTRY glVertexAttrib4Niv(GLuint index, const GLint *v);
GLAPI void APIENTRY glVertexAttrib4NivARB(GLuint index, const GLint *v);
GLAPI void APIENTRY glVertexAttrib4Nsv(GLuint index, const GLshort *v);
GLAPI void APIENTRY glVertexAttrib4NsvARB(GLuint index, const GLshort *v);
GLAPI void APIENTRY glVertexAttrib4Nub(GLuint index, GLubyte x, GLubyte y, GLubyte z, GLubyte w);
GLAPI void APIENTRY glVertexAttrib4NubARB(GLuint index, GLubyte x, GLubyte y, GLubyte z, GLubyte w);
GLAPI void APIENTRY glVertexAttrib4Nubv(GLuint index, const GLubyte *v);
GLAPI void APIENTRY glVertexAttrib4NubvARB(GLuint index, const GLubyte *v);
GLAPI void APIENTRY glVertexAttrib4Nuiv(GLuint index, const GLuint *v);
GLAPI void APIENTRY glVertexAttrib4NuivARB(GLuint index, const GLuint *v);
GLAPI void APIENTRY glVertexAttrib4Nusv(GLuint index, const GLushort *v);
GLAPI void APIENTRY glVertexAttrib4NusvARB(GLuint index, const GLushort *v);
GLAPI void APIENTRY glVertexAttrib4bv(GLuint index, const GLbyte *v);
GLAPI void APIENTRY glVertexAttrib4bvARB(GLuint index, const GLbyte *v);
GLAPI void APIENTRY glVertexAttrib4d(GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w);
GLAPI void APIENTRY glVertexAttrib4dARB(GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w);
GLAPI void APIENTRY glVertexAttrib4dNV(GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w);
GLAPI void APIENTRY glVertexAttrib4dv(GLuint index, const GLdouble *v);
GLAPI void APIENTRY glVertexAttrib4dvARB(GLuint index, const GLdouble *v);
GLAPI void APIENTRY glVertexAttrib4dvNV(GLuint index, const GLdouble *v);
GLAPI void APIENTRY glVertexAttrib4f(GLuint index, GLfloat x, GLfloat y, GLfloat z, GLfloat w);
GLAPI void APIENTRY glVertexAttrib4fARB(GLuint index, GLfloat x, GLfloat y, GLfloat z, GLfloat w);
GLAPI void APIENTRY glVertexAttrib4fNV(GLuint index, GLfloat x, GLfloat y, GLfloat z, GLfloat w);
GLAPI void APIENTRY glVertexAttrib4fv(GLuint index, const GLfloat *v);
GLAPI void APIENTRY glVertexAttrib4fvARB(GLuint index, const GLfloat *v);
GLAPI void APIENTRY glVertexAttrib4fvNV(GLuint index, const GLfloat *v);
GLAPI void APIENTRY glVertexAttrib4hNV(GLuint index, GLhalf x, GLhalf y, GLhalf z, GLhalf w);
GLAPI void APIENTRY glVertexAttrib4hvNV(GLuint index, const GLhalf *v);
GLAPI void APIENTRY glVertexAttrib4iv(GLuint index, const GLint *v);
GLAPI void APIENTRY glVertexAttrib4ivARB(GLuint index, const GLint *v);
GLAPI void APIENTRY glVertexAttrib4s(GLuint index, GLshort x, GLshort y, GLshort z, GLshort w);
GLAPI void APIENTRY glVertexAttrib4sARB(GLuint index, GLshort x, GLshort y, GLshort z, GLshort w);
GLAPI void APIENTRY glVertexAttrib4sNV(GLuint index, GLshort x, GLshort y, GLshort z, GLshort w);
GLAPI void APIENTRY glVertexAttrib4sv(GLuint index, const GLshort *v);
GLAPI void APIENTRY glVertexAttrib4svARB(GLuint index, const GLshort *v);
GLAPI void APIENTRY glVertexAttrib4svNV(GLuint index, const GLshort *v);
GLAPI void APIENTRY glVertexAttrib4ubNV(GLuint index, GLubyte x, GLubyte y, GLubyte z, GLubyte w);
GLAPI void APIENTRY glVertexAttrib4ubv(GLuint index, const GLubyte *v);
GLAPI void APIENTRY glVertexAttrib4ubvARB(GLuint index, const GLubyte *v);
GLAPI void APIENTRY glVertexAttrib4ubvNV(GLuint index, const GLubyte *v);
GLAPI void APIENTRY glVertexAttrib4uiv(GLuint index, const GLuint *v);
GLAPI void APIENTRY glVertexAttrib4uivARB(GLuint index, const GLuint *v);
GLAPI void APIENTRY glVertexAttrib4usv(GLuint index, const GLushort *v);
GLAPI void APIENTRY glVertexAttrib4usvARB(GLuint index, const GLushort *v);
GLAPI void APIENTRY glVertexAttribArrayObjectATI(GLuint index, GLint size, GLenum type, GLboolean normalized, GLsizei stride, GLuint buffer, GLuint offset);
GLAPI void APIENTRY glVertexAttribBinding(GLuint attribindex, GLuint bindingindex);
GLAPI void APIENTRY glVertexAttribDivisor(GLuint index, GLuint divisor);
GLAPI void APIENTRY glVertexAttribDivisorANGLE(GLuint index, GLuint divisor);
GLAPI void APIENTRY glVertexAttribDivisorARB(GLuint index, GLuint divisor);
GLAPI void APIENTRY glVertexAttribDivisorEXT(GLuint index, GLuint divisor);
GLAPI void APIENTRY glVertexAttribDivisorNV(GLuint index, GLuint divisor);
GLAPI void APIENTRY glVertexAttribFormat(GLuint attribindex, GLint size, GLenum type, GLboolean normalized, GLuint relativeoffset);
GLAPI void APIENTRY glVertexAttribFormatNV(GLuint index, GLint size, GLenum type, GLboolean normalized, GLsizei stride);
GLAPI void APIENTRY glVertexAttribI1i(GLuint index, GLint x);
GLAPI void APIENTRY glVertexAttribI1iEXT(GLuint index, GLint x);
GLAPI void APIENTRY glVertexAttribI1iv(GLuint index, const GLint *v);
GLAPI void APIENTRY glVertexAttribI1ivEXT(GLuint index, const GLint *v);
GLAPI void APIENTRY glVertexAttribI1ui(GLuint index, GLuint x);
GLAPI void APIENTRY glVertexAttribI1uiEXT(GLuint index, GLuint x);
GLAPI void APIENTRY glVertexAttribI1uiv(GLuint index, const GLuint *v);
GLAPI void APIENTRY glVertexAttribI1uivEXT(GLuint index, const GLuint *v);
GLAPI void APIENTRY glVertexAttribI2i(GLuint index, GLint x, GLint y);
GLAPI void APIENTRY glVertexAttribI2iEXT(GLuint index, GLint x, GLint y);
GLAPI void APIENTRY glVertexAttribI2iv(GLuint index, const GLint *v);
GLAPI void APIENTRY glVertexAttribI2ivEXT(GLuint index, const GLint *v);
GLAPI void APIENTRY glVertexAttribI2ui(GLuint index, GLuint x, GLuint y);
GLAPI void APIENTRY glVertexAttribI2uiEXT(GLuint index, GLuint x, GLuint y);
GLAPI void APIENTRY glVertexAttribI2uiv(GLuint index, const GLuint *v);
GLAPI void APIENTRY glVertexAttribI2uivEXT(GLuint index, const GLuint *v);
GLAPI void APIENTRY glVertexAttribI3i(GLuint index, GLint x, GLint y, GLint z);
GLAPI void APIENTRY glVertexAttribI3iEXT(GLuint index, GLint x, GLint y, GLint z);
GLAPI void APIENTRY glVertexAttribI3iv(GLuint index, const GLint *v);
GLAPI void APIENTRY glVertexAttribI3ivEXT(GLuint index, const GLint *v);
GLAPI void APIENTRY glVertexAttribI3ui(GLuint index, GLuint x, GLuint y, GLuint z);
GLAPI void APIENTRY glVertexAttribI3uiEXT(GLuint index, GLuint x, GLuint y, GLuint z);
GLAPI void APIENTRY glVertexAttribI3uiv(GLuint index, const GLuint *v);
GLAPI void APIENTRY glVertexAttribI3uivEXT(GLuint index, const GLuint *v);
GLAPI void APIENTRY glVertexAttribI4bv(GLuint index, const GLbyte *v);
GLAPI void APIENTRY glVertexAttribI4bvEXT(GLuint index, const GLbyte *v);
GLAPI void APIENTRY glVertexAttribI4i(GLuint index, GLint x, GLint y, GLint z, GLint w);
GLAPI void APIENTRY glVertexAttribI4iEXT(GLuint index, GLint x, GLint y, GLint z, GLint w);
GLAPI void APIENTRY glVertexAttribI4iv(GLuint index, const GLint *v);
GLAPI void APIENTRY glVertexAttribI4ivEXT(GLuint index, const GLint *v);
GLAPI void APIENTRY glVertexAttribI4sv(GLuint index, const GLshort *v);
GLAPI void APIENTRY glVertexAttribI4svEXT(GLuint index, const GLshort *v);
GLAPI void APIENTRY glVertexAttribI4ubv(GLuint index, const GLubyte *v);
GLAPI void APIENTRY glVertexAttribI4ubvEXT(GLuint index, const GLubyte *v);
GLAPI void APIENTRY glVertexAttribI4ui(GLuint index, GLuint x, GLuint y, GLuint z, GLuint w);
GLAPI void APIENTRY glVertexAttribI4uiEXT(GLuint index, GLuint x, GLuint y, GLuint z, GLuint w);
GLAPI void APIENTRY glVertexAttribI4uiv(GLuint index, const GLuint *v);
GLAPI void APIENTRY glVertexAttribI4uivEXT(GLuint index, const GLuint *v);
GLAPI void APIENTRY glVertexAttribI4usv(GLuint index, const GLushort *v);
GLAPI void APIENTRY glVertexAttribI4usvEXT(GLuint index, const GLushort *v);
GLAPI void APIENTRY glVertexAttribIFormat(GLuint attribindex, GLint size, GLenum type, GLuint relativeoffset);
GLAPI void APIENTRY glVertexAttribIFormatNV(GLuint index, GLint size, GLenum type, GLsizei stride);
GLAPI void APIENTRY glVertexAttribIPointer(GLuint index, GLint size, GLenum type, GLsizei stride, const void *pointer);
GLAPI void APIENTRY glVertexAttribIPointerEXT(GLuint index, GLint size, GLenum type, GLsizei stride, const void *pointer);
GLAPI void APIENTRY glVertexAttribL1d(GLuint index, GLdouble x);
GLAPI void APIENTRY glVertexAttribL1dEXT(GLuint index, GLdouble x);
GLAPI void APIENTRY glVertexAttribL1dv(GLuint index, const GLdouble *v);
GLAPI void APIENTRY glVertexAttribL1dvEXT(GLuint index, const GLdouble *v);
GLAPI void APIENTRY glVertexAttribL1i64NV(GLuint index, GLint64 x);
GLAPI void APIENTRY glVertexAttribL1i64vNV(GLuint index, const GLint64 *v);
GLAPI void APIENTRY glVertexAttribL1ui64ARB(GLuint index, GLuint64 x);
GLAPI void APIENTRY glVertexAttribL1ui64NV(GLuint index, GLuint64 x);
GLAPI void APIENTRY glVertexAttribL1ui64vARB(GLuint index, const GLuint64 *v);
GLAPI void APIENTRY glVertexAttribL1ui64vNV(GLuint index, const GLuint64 *v);
GLAPI void APIENTRY glVertexAttribL2d(GLuint index, GLdouble x, GLdouble y);
GLAPI void APIENTRY glVertexAttribL2dEXT(GLuint index, GLdouble x, GLdouble y);
GLAPI void APIENTRY glVertexAttribL2dv(GLuint index, const GLdouble *v);
GLAPI void APIENTRY glVertexAttribL2dvEXT(GLuint index, const GLdouble *v);
GLAPI void APIENTRY glVertexAttribL2i64NV(GLuint index, GLint64 x, GLint64 y);
GLAPI void APIENTRY glVertexAttribL2i64vNV(GLuint index, const GLint64 *v);
GLAPI void APIENTRY glVertexAttribL2ui64NV(GLuint index, GLuint64 x, GLuint64 y);
GLAPI void APIENTRY glVertexAttribL2ui64vNV(GLuint index, const GLuint64 *v);
GLAPI void APIENTRY glVertexAttribL3d(GLuint index, GLdouble x, GLdouble y, GLdouble z);
GLAPI void APIENTRY glVertexAttribL3dEXT(GLuint index, GLdouble x, GLdouble y, GLdouble z);
GLAPI void APIENTRY glVertexAttribL3dv(GLuint index, const GLdouble *v);
GLAPI void APIENTRY glVertexAttribL3dvEXT(GLuint index, const GLdouble *v);
GLAPI void APIENTRY glVertexAttribL3i64NV(GLuint index, GLint64 x, GLint64 y, GLint64 z);
GLAPI void APIENTRY glVertexAttribL3i64vNV(GLuint index, const GLint64 *v);
GLAPI void APIENTRY glVertexAttribL3ui64NV(GLuint index, GLuint64 x, GLuint64 y, GLuint64 z);
GLAPI void APIENTRY glVertexAttribL3ui64vNV(GLuint index, const GLuint64 *v);
GLAPI void APIENTRY glVertexAttribL4d(GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w);
GLAPI void APIENTRY glVertexAttribL4dEXT(GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w);
GLAPI void APIENTRY glVertexAttribL4dv(GLuint index, const GLdouble *v);
GLAPI void APIENTRY glVertexAttribL4dvEXT(GLuint index, const GLdouble *v);
GLAPI void APIENTRY glVertexAttribL4i64NV(GLuint index, GLint64 x, GLint64 y, GLint64 z, GLint64 w);
GLAPI void APIENTRY glVertexAttribL4i64vNV(GLuint index, const GLint64 *v);
GLAPI void APIENTRY glVertexAttribL4ui64NV(GLuint index, GLuint64 x, GLuint64 y, GLuint64 z, GLuint64 w);
GLAPI void APIENTRY glVertexAttribL4ui64vNV(GLuint index, const GLuint64 *v);
GLAPI void APIENTRY glVertexAttribLFormat(GLuint attribindex, GLint size, GLenum type, GLuint relativeoffset);
GLAPI void APIENTRY glVertexAttribLFormatNV(GLuint index, GLint size, GLenum type, GLsizei stride);
GLAPI void APIENTRY glVertexAttribLPointer(GLuint index, GLint size, GLenum type, GLsizei stride, const void *pointer);
GLAPI void APIENTRY glVertexAttribLPointerEXT(GLuint index, GLint size, GLenum type, GLsizei stride, const void *pointer);
GLAPI void APIENTRY glVertexAttribP1ui(GLuint index, GLenum type, GLboolean normalized, GLuint value);
GLAPI void APIENTRY glVertexAttribP1uiv(GLuint index, GLenum type, GLboolean normalized, const GLuint *value);
GLAPI void APIENTRY glVertexAttribP2ui(GLuint index, GLenum type, GLboolean normalized, GLuint value);
GLAPI void APIENTRY glVertexAttribP2uiv(GLuint index, GLenum type, GLboolean normalized, const GLuint *value);
GLAPI void APIENTRY glVertexAttribP3ui(GLuint index, GLenum type, GLboolean normalized, GLuint value);
GLAPI void APIENTRY glVertexAttribP3uiv(GLuint index, GLenum type, GLboolean normalized, const GLuint *value);
GLAPI void APIENTRY glVertexAttribP4ui(GLuint index, GLenum type, GLboolean normalized, GLuint value);
GLAPI void APIENTRY glVertexAttribP4uiv(GLuint index, GLenum type, GLboolean normalized, const GLuint *value);
GLAPI void APIENTRY glVertexAttribParameteriAMD(GLuint index, GLenum pname, GLint param);
GLAPI void APIENTRY glVertexAttribPointer(GLuint index, GLint size, GLenum type, GLboolean normalized, GLsizei stride, const void *pointer);
GLAPI void APIENTRY glVertexAttribPointerARB(GLuint index, GLint size, GLenum type, GLboolean normalized, GLsizei stride, const void *pointer);
GLAPI void APIENTRY glVertexAttribPointerNV(GLuint index, GLint fsize, GLenum type, GLsizei stride, const void *pointer);
GLAPI void APIENTRY glVertexAttribs1dvNV(GLuint index, GLsizei count, const GLdouble *v);
GLAPI void APIENTRY glVertexAttribs1fvNV(GLuint index, GLsizei count, const GLfloat *v);
GLAPI void APIENTRY glVertexAttribs1hvNV(GLuint index, GLsizei n, const GLhalf *v);
GLAPI void APIENTRY glVertexAttribs1svNV(GLuint index, GLsizei count, const GLshort *v);
GLAPI void APIENTRY glVertexAttribs2dvNV(GLuint index, GLsizei count, const GLdouble *v);
GLAPI void APIENTRY glVertexAttribs2fvNV(GLuint index, GLsizei count, const GLfloat *v);
GLAPI void APIENTRY glVertexAttribs2hvNV(GLuint index, GLsizei n, const GLhalf *v);
GLAPI void APIENTRY glVertexAttribs2svNV(GLuint index, GLsizei count, const GLshort *v);
GLAPI void APIENTRY glVertexAttribs3dvNV(GLuint index, GLsizei count, const GLdouble *v);
GLAPI void APIENTRY glVertexAttribs3fvNV(GLuint index, GLsizei count, const GLfloat *v);
GLAPI void APIENTRY glVertexAttribs3hvNV(GLuint index, GLsizei n, const GLhalf *v);
GLAPI void APIENTRY glVertexAttribs3svNV(GLuint index, GLsizei count, const GLshort *v);
GLAPI void APIENTRY glVertexAttribs4dvNV(GLuint index, GLsizei count, const GLdouble *v);
GLAPI void APIENTRY glVertexAttribs4fvNV(GLuint index, GLsizei count, const GLfloat *v);
GLAPI void APIENTRY glVertexAttribs4hvNV(GLuint index, GLsizei n, const GLhalf *v);
GLAPI void APIENTRY glVertexAttribs4svNV(GLuint index, GLsizei count, const GLshort *v);
GLAPI void APIENTRY glVertexAttribs4ubvNV(GLuint index, GLsizei count, const GLubyte *v);
GLAPI void APIENTRY glVertexBindingDivisor(GLuint bindingindex, GLuint divisor);
GLAPI void APIENTRY glVertexBlendARB(GLint count);
GLAPI void APIENTRY glVertexBlendEnvfATI(GLenum pname, GLfloat param);
GLAPI void APIENTRY glVertexBlendEnviATI(GLenum pname, GLint param);
GLAPI void APIENTRY glVertexFormatNV(GLint size, GLenum type, GLsizei stride);
GLAPI void APIENTRY glVertexP2ui(GLenum type, GLuint value);
GLAPI void APIENTRY glVertexP2uiv(GLenum type, const GLuint *value);
GLAPI void APIENTRY glVertexP3ui(GLenum type, GLuint value);
GLAPI void APIENTRY glVertexP3uiv(GLenum type, const GLuint *value);
GLAPI void APIENTRY glVertexP4ui(GLenum type, GLuint value);
GLAPI void APIENTRY glVertexP4uiv(GLenum type, const GLuint *value);
GLAPI void APIENTRY glVertexPointer(GLint size, GLenum type, GLsizei stride, const void *pointer);
GLAPI void APIENTRY glVertexPointerEXT(GLint size, GLenum type, GLsizei stride, GLsizei count, const void *pointer);
GLAPI void APIENTRY glVertexPointerListIBM(GLint size, GLenum type, GLint stride, const void **pointer, GLint ptrstride);
GLAPI void APIENTRY glVertexPointervINTEL(GLint size, GLenum type, const void **pointer);
GLAPI void APIENTRY glVertexStream1dATI(GLenum stream, GLdouble x);
GLAPI void APIENTRY glVertexStream1dvATI(GLenum stream, const GLdouble *coords);
GLAPI void APIENTRY glVertexStream1fATI(GLenum stream, GLfloat x);
GLAPI void APIENTRY glVertexStream1fvATI(GLenum stream, const GLfloat *coords);
GLAPI void APIENTRY glVertexStream1iATI(GLenum stream, GLint x);
GLAPI void APIENTRY glVertexStream1ivATI(GLenum stream, const GLint *coords);
GLAPI void APIENTRY glVertexStream1sATI(GLenum stream, GLshort x);
GLAPI void APIENTRY glVertexStream1svATI(GLenum stream, const GLshort *coords);
GLAPI void APIENTRY glVertexStream2dATI(GLenum stream, GLdouble x, GLdouble y);
GLAPI void APIENTRY glVertexStream2dvATI(GLenum stream, const GLdouble *coords);
GLAPI void APIENTRY glVertexStream2fATI(GLenum stream, GLfloat x, GLfloat y);
GLAPI void APIENTRY glVertexStream2fvATI(GLenum stream, const GLfloat *coords);
GLAPI void APIENTRY glVertexStream2iATI(GLenum stream, GLint x, GLint y);
GLAPI void APIENTRY glVertexStream2ivATI(GLenum stream, const GLint *coords);
GLAPI void APIENTRY glVertexStream2sATI(GLenum stream, GLshort x, GLshort y);
GLAPI void APIENTRY glVertexStream2svATI(GLenum stream, const GLshort *coords);
GLAPI void APIENTRY glVertexStream3dATI(GLenum stream, GLdouble x, GLdouble y, GLdouble z);
GLAPI void APIENTRY glVertexStream3dvATI(GLenum stream, const GLdouble *coords);
GLAPI void APIENTRY glVertexStream3fATI(GLenum stream, GLfloat x, GLfloat y, GLfloat z);
GLAPI void APIENTRY glVertexStream3fvATI(GLenum stream, const GLfloat *coords);
GLAPI void APIENTRY glVertexStream3iATI(GLenum stream, GLint x, GLint y, GLint z);
GLAPI void APIENTRY glVertexStream3ivATI(GLenum stream, const GLint *coords);
GLAPI void APIENTRY glVertexStream3sATI(GLenum stream, GLshort x, GLshort y, GLshort z);
GLAPI void APIENTRY glVertexStream3svATI(GLenum stream, const GLshort *coords);
GLAPI void APIENTRY glVertexStream4dATI(GLenum stream, GLdouble x, GLdouble y, GLdouble z, GLdouble w);
GLAPI void APIENTRY glVertexStream4dvATI(GLenum stream, const GLdouble *coords);
GLAPI void APIENTRY glVertexStream4fATI(GLenum stream, GLfloat x, GLfloat y, GLfloat z, GLfloat w);
GLAPI void APIENTRY glVertexStream4fvATI(GLenum stream, const GLfloat *coords);
GLAPI void APIENTRY glVertexStream4iATI(GLenum stream, GLint x, GLint y, GLint z, GLint w);
GLAPI void APIENTRY glVertexStream4ivATI(GLenum stream, const GLint *coords);
GLAPI void APIENTRY glVertexStream4sATI(GLenum stream, GLshort x, GLshort y, GLshort z, GLshort w);
GLAPI void APIENTRY glVertexStream4svATI(GLenum stream, const GLshort *coords);
GLAPI void APIENTRY glVertexWeightPointerEXT(GLint size, GLenum type, GLsizei stride, const void *pointer);
GLAPI void APIENTRY glVertexWeightfEXT(GLfloat weight);
GLAPI void APIENTRY glVertexWeightfvEXT(const GLfloat *weight);
GLAPI void APIENTRY glVertexWeighthNV(GLhalf weight);
GLAPI void APIENTRY glVertexWeighthvNV(const GLhalf *weight);
GLAPI GLenum APIENTRY glVideoCaptureNV(GLuint video_capture_slot, GLuint *sequence_num, GLuint64 *capture_time);
GLAPI void APIENTRY glVideoCaptureStreamParameterdvNV(GLuint video_capture_slot, GLuint stream, GLenum pname, const GLdouble *params);
GLAPI void APIENTRY glVideoCaptureStreamParameterfvNV(GLuint video_capture_slot, GLuint stream, GLenum pname, const GLfloat *params);
GLAPI void APIENTRY glVideoCaptureStreamParameterivNV(GLuint video_capture_slot, GLuint stream, GLenum pname, const GLint *params);
GLAPI void APIENTRY glViewport(GLint x, GLint y, GLsizei width, GLsizei height);
GLAPI void APIENTRY glViewportArrayv(GLuint first, GLsizei count, const GLfloat *v);
GLAPI void APIENTRY glViewportArrayvNV(GLuint first, GLsizei count, const GLfloat *v);
GLAPI void APIENTRY glViewportArrayvOES(GLuint first, GLsizei count, const GLfloat *v);
GLAPI void APIENTRY glViewportIndexedf(GLuint index, GLfloat x, GLfloat y, GLfloat w, GLfloat h);
GLAPI void APIENTRY glViewportIndexedfNV(GLuint index, GLfloat x, GLfloat y, GLfloat w, GLfloat h);
GLAPI void APIENTRY glViewportIndexedfOES(GLuint index, GLfloat x, GLfloat y, GLfloat w, GLfloat h);
GLAPI void APIENTRY glViewportIndexedfv(GLuint index, const GLfloat *v);
GLAPI void APIENTRY glViewportIndexedfvNV(GLuint index, const GLfloat *v);
GLAPI void APIENTRY glViewportIndexedfvOES(GLuint index, const GLfloat *v);
GLAPI void APIENTRY glViewportPositionWScaleNV(GLuint index, GLfloat xcoeff, GLfloat ycoeff);
GLAPI void APIENTRY glViewportSwizzleNV(GLuint index, GLenum swizzlex, GLenum swizzley, GLenum swizzlez, GLenum swizzlew);
GLAPI void APIENTRY glWaitSemaphoreEXT(GLuint semaphore, GLuint numBufferBarriers, const GLuint *buffers, GLuint numTextureBarriers, const GLuint *textures, const GLenum *srcLayouts);
GLAPI void APIENTRY glWaitSemaphoreui64NVX(GLuint waitGpu, GLsizei fenceObjectCount, const GLuint *semaphoreArray, const GLuint64 *fenceValueArray);
GLAPI void APIENTRY glWaitSync(GLsync sync, GLbitfield flags, GLuint64 timeout);
GLAPI void APIENTRY glWaitSyncAPPLE(GLsync sync, GLbitfield flags, GLuint64 timeout);
GLAPI void APIENTRY glWaitSyncValueuiNVX(GLsync sync, GLbitfield flags, GLuint64 timeout, GLuint value, GLboolean GEQ);
GLAPI void APIENTRY glWaitVkSemaphoreNV(GLuint64 vkSemaphore);
GLAPI void APIENTRY glWeightPathsNV(GLuint resultPath, GLsizei numPaths, const GLuint *paths, const GLfloat *weights);
GLAPI void APIENTRY glWeightPointerARB(GLint size, GLenum type, GLsizei stride, const void *pointer);
GLAPI void APIENTRY glWeightPointerOES(GLint size, GLenum type, GLsizei stride, const void *pointer);
GLAPI void APIENTRY glWeightbvARB(GLint size, const GLbyte *weights);
GLAPI void APIENTRY glWeightdvARB(GLint size, const GLdouble *weights);
GLAPI void APIENTRY glWeightfvARB(GLint size, const GLfloat *weights);
GLAPI void APIENTRY glWeightivARB(GLint size, const GLint *weights);
GLAPI void APIENTRY glWeightsvARB(GLint size, const GLshort *weights);
GLAPI void APIENTRY glWeightubvARB(GLint size, const GLubyte *weights);
GLAPI void APIENTRY glWeightuivARB(GLint size, const GLuint *weights);
GLAPI void APIENTRY glWeightusvARB(GLint size, const GLushort *weights);
GLAPI void APIENTRY glWindowBackBufferHintAutodesk(void);
GLAPI void APIENTRY glWindowPos2d(GLdouble x, GLdouble y);
GLAPI void APIENTRY glWindowPos2dARB(GLdouble x, GLdouble y);
GLAPI void APIENTRY glWindowPos2dMESA(GLdouble x, GLdouble y);
GLAPI void APIENTRY glWindowPos2dv(const GLdouble *v);
GLAPI void APIENTRY glWindowPos2dvARB(const GLdouble *v);
GLAPI void APIENTRY glWindowPos2dvMESA(const GLdouble *v);
GLAPI void APIENTRY glWindowPos2f(GLfloat x, GLfloat y);
GLAPI void APIENTRY glWindowPos2fARB(GLfloat x, GLfloat y);
GLAPI void APIENTRY glWindowPos2fMESA(GLfloat x, GLfloat y);
GLAPI void APIENTRY glWindowPos2fv(const GLfloat *v);
GLAPI void APIENTRY glWindowPos2fvARB(const GLfloat *v);
GLAPI void APIENTRY glWindowPos2fvMESA(const GLfloat *v);
GLAPI void APIENTRY glWindowPos2i(GLint x, GLint y);
GLAPI void APIENTRY glWindowPos2iARB(GLint x, GLint y);
GLAPI void APIENTRY glWindowPos2iMESA(GLint x, GLint y);
GLAPI void APIENTRY glWindowPos2iv(const GLint *v);
GLAPI void APIENTRY glWindowPos2ivARB(const GLint *v);
GLAPI void APIENTRY glWindowPos2ivMESA(const GLint *v);
GLAPI void APIENTRY glWindowPos2s(GLshort x, GLshort y);
GLAPI void APIENTRY glWindowPos2sARB(GLshort x, GLshort y);
GLAPI void APIENTRY glWindowPos2sMESA(GLshort x, GLshort y);
GLAPI void APIENTRY glWindowPos2sv(const GLshort *v);
GLAPI void APIENTRY glWindowPos2svARB(const GLshort *v);
GLAPI void APIENTRY glWindowPos2svMESA(const GLshort *v);
GLAPI void APIENTRY glWindowPos3d(GLdouble x, GLdouble y, GLdouble z);
GLAPI void APIENTRY glWindowPos3dARB(GLdouble x, GLdouble y, GLdouble z);
GLAPI void APIENTRY glWindowPos3dMESA(GLdouble x, GLdouble y, GLdouble z);
GLAPI void APIENTRY glWindowPos3dv(const GLdouble *v);
GLAPI void APIENTRY glWindowPos3dvARB(const GLdouble *v);
GLAPI void APIENTRY glWindowPos3dvMESA(const GLdouble *v);
GLAPI void APIENTRY glWindowPos3f(GLfloat x, GLfloat y, GLfloat z);
GLAPI void APIENTRY glWindowPos3fARB(GLfloat x, GLfloat y, GLfloat z);
GLAPI void APIENTRY glWindowPos3fMESA(GLfloat x, GLfloat y, GLfloat z);
GLAPI void APIENTRY glWindowPos3fv(const GLfloat *v);
GLAPI void APIENTRY glWindowPos3fvARB(const GLfloat *v);
GLAPI void APIENTRY glWindowPos3fvMESA(const GLfloat *v);
GLAPI void APIENTRY glWindowPos3i(GLint x, GLint y, GLint z);
GLAPI void APIENTRY glWindowPos3iARB(GLint x, GLint y, GLint z);
GLAPI void APIENTRY glWindowPos3iMESA(GLint x, GLint y, GLint z);
GLAPI void APIENTRY glWindowPos3iv(const GLint *v);
GLAPI void APIENTRY glWindowPos3ivARB(const GLint *v);
GLAPI void APIENTRY glWindowPos3ivMESA(const GLint *v);
GLAPI void APIENTRY glWindowPos3s(GLshort x, GLshort y, GLshort z);
GLAPI void APIENTRY glWindowPos3sARB(GLshort x, GLshort y, GLshort z);
GLAPI void APIENTRY glWindowPos3sMESA(GLshort x, GLshort y, GLshort z);
GLAPI void APIENTRY glWindowPos3sv(const GLshort *v);
GLAPI void APIENTRY glWindowPos3svARB(const GLshort *v);
GLAPI void APIENTRY glWindowPos3svMESA(const GLshort *v);
GLAPI void APIENTRY glWindowPos4dMESA(GLdouble x, GLdouble y, GLdouble z, GLdouble w);
GLAPI void APIENTRY glWindowPos4dvMESA(const GLdouble *v);
GLAPI void APIENTRY glWindowPos4fMESA(GLfloat x, GLfloat y, GLfloat z, GLfloat w);
GLAPI void APIENTRY glWindowPos4fvMESA(const GLfloat *v);
GLAPI void APIENTRY glWindowPos4iMESA(GLint x, GLint y, GLint z, GLint w);
GLAPI void APIENTRY glWindowPos4ivMESA(const GLint *v);
GLAPI void APIENTRY glWindowPos4sMESA(GLshort x, GLshort y, GLshort z, GLshort w);
GLAPI void APIENTRY glWindowPos4svMESA(const GLshort *v);
GLAPI void APIENTRY glWindowRectanglesEXT(GLenum mode, GLsizei count, const GLint *box);
GLAPI void APIENTRY glWriteMaskEXT(GLuint res, GLuint in, GLenum outX, GLenum outY, GLenum outZ, GLenum outW);
#undef MAPI_TMP_DEFINES
#endif /* MAPI_TMP_DEFINES */

#ifdef MAPI_TMP_TABLE
#define MAPI_TABLE_NUM_STATIC 3352
#define MAPI_TABLE_NUM_DYNAMIC 4096
#undef MAPI_TMP_TABLE
#endif /* MAPI_TMP_TABLE */

#ifdef MAPI_TMP_NOOP_ARRAY
#ifdef DEBUG

static void APIENTRY noopAccum(GLenum op, GLfloat value)
{
   (void) op; (void) value;
   noop_warn("glAccum");
}

static void APIENTRY noopAccumxOES(GLenum op, GLfixed value)
{
   (void) op; (void) value;
   noop_warn("glAccumxOES");
}

static GLboolean APIENTRY noopAcquireKeyedMutexWin32EXT(GLuint memory, GLuint64 key, GLuint timeout)
{
   (void) memory; (void) key; (void) timeout;
   noop_warn("glAcquireKeyedMutexWin32EXT");
   return (GLboolean) 0;
}

static void APIENTRY noopActiveProgramEXT(GLuint program)
{
   (void) program;
   noop_warn("glActiveProgramEXT");
}

static void APIENTRY noopActiveShaderProgram(GLuint pipeline, GLuint program)
{
   (void) pipeline; (void) program;
   noop_warn("glActiveShaderProgram");
}

static void APIENTRY noopActiveShaderProgramEXT(GLuint pipeline, GLuint program)
{
   (void) pipeline; (void) program;
   noop_warn("glActiveShaderProgramEXT");
}

static void APIENTRY noopActiveStencilFaceEXT(GLenum face)
{
   (void) face;
   noop_warn("glActiveStencilFaceEXT");
}

static void APIENTRY noopActiveTexture(GLenum texture)
{
   (void) texture;
   noop_warn("glActiveTexture");
}

static void APIENTRY noopActiveTextureARB(GLenum texture)
{
   (void) texture;
   noop_warn("glActiveTextureARB");
}

static void APIENTRY noopActiveVaryingNV(GLuint program, const GLchar *name)
{
   (void) program; (void) name;
   noop_warn("glActiveVaryingNV");
}

static void APIENTRY noopAlphaFragmentOp1ATI(GLenum op, GLuint dst, GLuint dstMod, GLuint arg1, GLuint arg1Rep, GLuint arg1Mod)
{
   (void) op; (void) dst; (void) dstMod; (void) arg1; (void) arg1Rep; (void) arg1Mod;
   noop_warn("glAlphaFragmentOp1ATI");
}

static void APIENTRY noopAlphaFragmentOp2ATI(GLenum op, GLuint dst, GLuint dstMod, GLuint arg1, GLuint arg1Rep, GLuint arg1Mod, GLuint arg2, GLuint arg2Rep, GLuint arg2Mod)
{
   (void) op; (void) dst; (void) dstMod; (void) arg1; (void) arg1Rep; (void) arg1Mod; (void) arg2; (void) arg2Rep; (void) arg2Mod;
   noop_warn("glAlphaFragmentOp2ATI");
}

static void APIENTRY noopAlphaFragmentOp3ATI(GLenum op, GLuint dst, GLuint dstMod, GLuint arg1, GLuint arg1Rep, GLuint arg1Mod, GLuint arg2, GLuint arg2Rep, GLuint arg2Mod, GLuint arg3, GLuint arg3Rep, GLuint arg3Mod)
{
   (void) op; (void) dst; (void) dstMod; (void) arg1; (void) arg1Rep; (void) arg1Mod; (void) arg2; (void) arg2Rep; (void) arg2Mod; (void) arg3; (void) arg3Rep; (void) arg3Mod;
   noop_warn("glAlphaFragmentOp3ATI");
}

static void APIENTRY noopAlphaFunc(GLenum func, GLfloat ref)
{
   (void) func; (void) ref;
   noop_warn("glAlphaFunc");
}

static void APIENTRY noopAlphaFuncQCOM(GLenum func, GLclampf ref)
{
   (void) func; (void) ref;
   noop_warn("glAlphaFuncQCOM");
}

static void APIENTRY noopAlphaFuncx(GLenum func, GLfixed ref)
{
   (void) func; (void) ref;
   noop_warn("glAlphaFuncx");
}

static void APIENTRY noopAlphaFuncxOES(GLenum func, GLfixed ref)
{
   (void) func; (void) ref;
   noop_warn("glAlphaFuncxOES");
}

static void APIENTRY noopAlphaToCoverageDitherControlNV(GLenum mode)
{
   (void) mode;
   noop_warn("glAlphaToCoverageDitherControlNV");
}

static void APIENTRY noopApplyFramebufferAttachmentCMAAINTEL(void)
{
   noop_warn("glApplyFramebufferAttachmentCMAAINTEL");
}

static void APIENTRY noopApplyTextureEXT(GLenum mode)
{
   (void) mode;
   noop_warn("glApplyTextureEXT");
}

static GLboolean APIENTRY noopAreProgramsResidentNV(GLsizei n, const GLuint *programs, GLboolean *residences)
{
   (void) n; (void) programs; (void) residences;
   noop_warn("glAreProgramsResidentNV");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopAreTexturesResident(GLsizei n, const GLuint *textures, GLboolean *residences)
{
   (void) n; (void) textures; (void) residences;
   noop_warn("glAreTexturesResident");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopAreTexturesResidentEXT(GLsizei n, const GLuint *textures, GLboolean *residences)
{
   (void) n; (void) textures; (void) residences;
   noop_warn("glAreTexturesResidentEXT");
   return (GLboolean) 0;
}

static void APIENTRY noopArrayElement(GLint i)
{
   (void) i;
   noop_warn("glArrayElement");
}

static void APIENTRY noopArrayElementEXT(GLint i)
{
   (void) i;
   noop_warn("glArrayElementEXT");
}

static void APIENTRY noopArrayObjectATI(GLenum array, GLint size, GLenum type, GLsizei stride, GLuint buffer, GLuint offset)
{
   (void) array; (void) size; (void) type; (void) stride; (void) buffer; (void) offset;
   noop_warn("glArrayObjectATI");
}

static GLuint APIENTRY noopAsyncCopyBufferSubDataNVX(GLsizei waitSemaphoreCount, const GLuint *waitSemaphoreArray, const GLuint64 *fenceValueArray, GLuint readGpu, GLbitfield writeGpuMask, GLuint readBuffer, GLuint writeBuffer, GLintptr readOffset, GLintptr writeOffset, GLsizeiptr size, GLsizei signalSemaphoreCount, const GLuint *signalSemaphoreArray, const GLuint64 *signalValueArray)
{
   (void) waitSemaphoreCount; (void) waitSemaphoreArray; (void) fenceValueArray; (void) readGpu; (void) writeGpuMask; (void) readBuffer; (void) writeBuffer; (void) readOffset; (void) writeOffset; (void) size; (void) signalSemaphoreCount; (void) signalSemaphoreArray; (void) signalValueArray;
   noop_warn("glAsyncCopyBufferSubDataNVX");
   return (GLuint) 0;
}

static GLuint APIENTRY noopAsyncCopyImageSubDataNVX(GLsizei waitSemaphoreCount, const GLuint *waitSemaphoreArray, const GLuint64 *waitValueArray, GLuint srcGpu, GLbitfield dstGpuMask, GLuint srcName, GLenum srcTarget, GLint srcLevel, GLint srcX, GLint srcY, GLint srcZ, GLuint dstName, GLenum dstTarget, GLint dstLevel, GLint dstX, GLint dstY, GLint dstZ, GLsizei srcWidth, GLsizei srcHeight, GLsizei srcDepth, GLsizei signalSemaphoreCount, const GLuint *signalSemaphoreArray, const GLuint64 *signalValueArray)
{
   (void) waitSemaphoreCount; (void) waitSemaphoreArray; (void) waitValueArray; (void) srcGpu; (void) dstGpuMask; (void) srcName; (void) srcTarget; (void) srcLevel; (void) srcX; (void) srcY; (void) srcZ; (void) dstName; (void) dstTarget; (void) dstLevel; (void) dstX; (void) dstY; (void) dstZ; (void) srcWidth; (void) srcHeight; (void) srcDepth; (void) signalSemaphoreCount; (void) signalSemaphoreArray; (void) signalValueArray;
   noop_warn("glAsyncCopyImageSubDataNVX");
   return (GLuint) 0;
}

static void APIENTRY noopAsyncMarkerSGIX(GLuint marker)
{
   (void) marker;
   noop_warn("glAsyncMarkerSGIX");
}

static void APIENTRY noopAttachObjectARB(GLhandleARB containerObj, GLhandleARB obj)
{
   (void) containerObj; (void) obj;
   noop_warn("glAttachObjectARB");
}

static void APIENTRY noopAttachShader(GLuint program, GLuint shader)
{
   (void) program; (void) shader;
   noop_warn("glAttachShader");
}

static void APIENTRY noopBegin(GLenum mode)
{
   (void) mode;
   noop_warn("glBegin");
}

static void APIENTRY noopBeginConditionalRender(GLuint id, GLenum mode)
{
   (void) id; (void) mode;
   noop_warn("glBeginConditionalRender");
}

static void APIENTRY noopBeginConditionalRenderNV(GLuint id, GLenum mode)
{
   (void) id; (void) mode;
   noop_warn("glBeginConditionalRenderNV");
}

static void APIENTRY noopBeginConditionalRenderNVX(GLuint id)
{
   (void) id;
   noop_warn("glBeginConditionalRenderNVX");
}

static void APIENTRY noopBeginFragmentShaderATI(void)
{
   noop_warn("glBeginFragmentShaderATI");
}

static void APIENTRY noopBeginOcclusionQueryNV(GLuint id)
{
   (void) id;
   noop_warn("glBeginOcclusionQueryNV");
}

static void APIENTRY noopBeginPerfMonitorAMD(GLuint monitor)
{
   (void) monitor;
   noop_warn("glBeginPerfMonitorAMD");
}

static void APIENTRY noopBeginPerfQueryINTEL(GLuint queryHandle)
{
   (void) queryHandle;
   noop_warn("glBeginPerfQueryINTEL");
}

static void APIENTRY noopBeginQuery(GLenum target, GLuint id)
{
   (void) target; (void) id;
   noop_warn("glBeginQuery");
}

static void APIENTRY noopBeginQueryARB(GLenum target, GLuint id)
{
   (void) target; (void) id;
   noop_warn("glBeginQueryARB");
}

static void APIENTRY noopBeginQueryEXT(GLenum target, GLuint id)
{
   (void) target; (void) id;
   noop_warn("glBeginQueryEXT");
}

static void APIENTRY noopBeginQueryIndexed(GLenum target, GLuint index, GLuint id)
{
   (void) target; (void) index; (void) id;
   noop_warn("glBeginQueryIndexed");
}

static void APIENTRY noopBeginTransformFeedback(GLenum primitiveMode)
{
   (void) primitiveMode;
   noop_warn("glBeginTransformFeedback");
}

static void APIENTRY noopBeginTransformFeedbackEXT(GLenum primitiveMode)
{
   (void) primitiveMode;
   noop_warn("glBeginTransformFeedbackEXT");
}

static void APIENTRY noopBeginTransformFeedbackNV(GLenum primitiveMode)
{
   (void) primitiveMode;
   noop_warn("glBeginTransformFeedbackNV");
}

static void APIENTRY noopBeginVertexShaderEXT(void)
{
   noop_warn("glBeginVertexShaderEXT");
}

static void APIENTRY noopBeginVideoCaptureNV(GLuint video_capture_slot)
{
   (void) video_capture_slot;
   noop_warn("glBeginVideoCaptureNV");
}

static void APIENTRY noopBindANCCaptureStreamBufferNVX(GLuint video_capture_slot, GLuint stream, GLuint link, GLenum frame_region, GLenum anc_region, GLintptr offset)
{
   (void) video_capture_slot; (void) stream; (void) link; (void) frame_region; (void) anc_region; (void) offset;
   noop_warn("glBindANCCaptureStreamBufferNVX");
}

static void APIENTRY noopBindAttribLocation(GLuint program, GLuint index, const GLchar *name)
{
   (void) program; (void) index; (void) name;
   noop_warn("glBindAttribLocation");
}

static void APIENTRY noopBindAttribLocationARB(GLhandleARB programObj, GLuint index, const GLcharARB *name)
{
   (void) programObj; (void) index; (void) name;
   noop_warn("glBindAttribLocationARB");
}

static void APIENTRY noopBindBuffer(GLenum target, GLuint buffer)
{
   (void) target; (void) buffer;
   noop_warn("glBindBuffer");
}

static void APIENTRY noopBindBufferARB(GLenum target, GLuint buffer)
{
   (void) target; (void) buffer;
   noop_warn("glBindBufferARB");
}

static void APIENTRY noopBindBufferBase(GLenum target, GLuint index, GLuint buffer)
{
   (void) target; (void) index; (void) buffer;
   noop_warn("glBindBufferBase");
}

static void APIENTRY noopBindBufferBaseEXT(GLenum target, GLuint index, GLuint buffer)
{
   (void) target; (void) index; (void) buffer;
   noop_warn("glBindBufferBaseEXT");
}

static void APIENTRY noopBindBufferBaseNV(GLenum target, GLuint index, GLuint buffer)
{
   (void) target; (void) index; (void) buffer;
   noop_warn("glBindBufferBaseNV");
}

static void APIENTRY noopBindBufferOffsetEXT(GLenum target, GLuint index, GLuint buffer, GLintptr offset)
{
   (void) target; (void) index; (void) buffer; (void) offset;
   noop_warn("glBindBufferOffsetEXT");
}

static void APIENTRY noopBindBufferOffsetNV(GLenum target, GLuint index, GLuint buffer, GLintptr offset)
{
   (void) target; (void) index; (void) buffer; (void) offset;
   noop_warn("glBindBufferOffsetNV");
}

static void APIENTRY noopBindBufferRange(GLenum target, GLuint index, GLuint buffer, GLintptr offset, GLsizeiptr size)
{
   (void) target; (void) index; (void) buffer; (void) offset; (void) size;
   noop_warn("glBindBufferRange");
}

static void APIENTRY noopBindBufferRangeEXT(GLenum target, GLuint index, GLuint buffer, GLintptr offset, GLsizeiptr size)
{
   (void) target; (void) index; (void) buffer; (void) offset; (void) size;
   noop_warn("glBindBufferRangeEXT");
}

static void APIENTRY noopBindBufferRangeNV(GLenum target, GLuint index, GLuint buffer, GLintptr offset, GLsizeiptr size)
{
   (void) target; (void) index; (void) buffer; (void) offset; (void) size;
   noop_warn("glBindBufferRangeNV");
}

static void APIENTRY noopBindBuffersBase(GLenum target, GLuint first, GLsizei count, const GLuint *buffers)
{
   (void) target; (void) first; (void) count; (void) buffers;
   noop_warn("glBindBuffersBase");
}

static void APIENTRY noopBindBuffersRange(GLenum target, GLuint first, GLsizei count, const GLuint *buffers, const GLintptr *offsets, const GLsizeiptr *sizes)
{
   (void) target; (void) first; (void) count; (void) buffers; (void) offsets; (void) sizes;
   noop_warn("glBindBuffersRange");
}

static void APIENTRY noopBindFragDataLocation(GLuint program, GLuint color, const GLchar *name)
{
   (void) program; (void) color; (void) name;
   noop_warn("glBindFragDataLocation");
}

static void APIENTRY noopBindFragDataLocationEXT(GLuint program, GLuint color, const GLchar *name)
{
   (void) program; (void) color; (void) name;
   noop_warn("glBindFragDataLocationEXT");
}

static void APIENTRY noopBindFragDataLocationIndexed(GLuint program, GLuint colorNumber, GLuint index, const GLchar *name)
{
   (void) program; (void) colorNumber; (void) index; (void) name;
   noop_warn("glBindFragDataLocationIndexed");
}

static void APIENTRY noopBindFragDataLocationIndexedEXT(GLuint program, GLuint colorNumber, GLuint index, const GLchar *name)
{
   (void) program; (void) colorNumber; (void) index; (void) name;
   noop_warn("glBindFragDataLocationIndexedEXT");
}

static void APIENTRY noopBindFragmentShaderATI(GLuint id)
{
   (void) id;
   noop_warn("glBindFragmentShaderATI");
}

static void APIENTRY noopBindFramebuffer(GLenum target, GLuint framebuffer)
{
   (void) target; (void) framebuffer;
   noop_warn("glBindFramebuffer");
}

static void APIENTRY noopBindFramebufferEXT(GLenum target, GLuint framebuffer)
{
   (void) target; (void) framebuffer;
   noop_warn("glBindFramebufferEXT");
}

static void APIENTRY noopBindFramebufferOES(GLenum target, GLuint framebuffer)
{
   (void) target; (void) framebuffer;
   noop_warn("glBindFramebufferOES");
}

static void APIENTRY noopBindImageTexture(GLuint unit, GLuint texture, GLint level, GLboolean layered, GLint layer, GLenum access, GLenum format)
{
   (void) unit; (void) texture; (void) level; (void) layered; (void) layer; (void) access; (void) format;
   noop_warn("glBindImageTexture");
}

static void APIENTRY noopBindImageTextureEXT(GLuint index, GLuint texture, GLint level, GLboolean layered, GLint layer, GLenum access, GLint format)
{
   (void) index; (void) texture; (void) level; (void) layered; (void) layer; (void) access; (void) format;
   noop_warn("glBindImageTextureEXT");
}

static void APIENTRY noopBindImageTextures(GLuint first, GLsizei count, const GLuint *textures)
{
   (void) first; (void) count; (void) textures;
   noop_warn("glBindImageTextures");
}

static GLuint APIENTRY noopBindLightParameterEXT(GLenum light, GLenum value)
{
   (void) light; (void) value;
   noop_warn("glBindLightParameterEXT");
   return (GLuint) 0;
}

static GLuint APIENTRY noopBindMaterialParameterEXT(GLenum face, GLenum value)
{
   (void) face; (void) value;
   noop_warn("glBindMaterialParameterEXT");
   return (GLuint) 0;
}

static void APIENTRY noopBindMultiTextureEXT(GLenum texunit, GLenum target, GLuint texture)
{
   (void) texunit; (void) target; (void) texture;
   noop_warn("glBindMultiTextureEXT");
}

static GLuint APIENTRY noopBindParameterEXT(GLenum value)
{
   (void) value;
   noop_warn("glBindParameterEXT");
   return (GLuint) 0;
}

static void APIENTRY noopBindProgramARB(GLenum target, GLuint program)
{
   (void) target; (void) program;
   noop_warn("glBindProgramARB");
}

static void APIENTRY noopBindProgramNV(GLenum target, GLuint id)
{
   (void) target; (void) id;
   noop_warn("glBindProgramNV");
}

static void APIENTRY noopBindProgramPipeline(GLuint pipeline)
{
   (void) pipeline;
   noop_warn("glBindProgramPipeline");
}

static void APIENTRY noopBindProgramPipelineEXT(GLuint pipeline)
{
   (void) pipeline;
   noop_warn("glBindProgramPipelineEXT");
}

static void APIENTRY noopBindRenderbuffer(GLenum target, GLuint renderbuffer)
{
   (void) target; (void) renderbuffer;
   noop_warn("glBindRenderbuffer");
}

static void APIENTRY noopBindRenderbufferEXT(GLenum target, GLuint renderbuffer)
{
   (void) target; (void) renderbuffer;
   noop_warn("glBindRenderbufferEXT");
}

static void APIENTRY noopBindRenderbufferOES(GLenum target, GLuint renderbuffer)
{
   (void) target; (void) renderbuffer;
   noop_warn("glBindRenderbufferOES");
}

static void APIENTRY noopBindSampler(GLuint unit, GLuint sampler)
{
   (void) unit; (void) sampler;
   noop_warn("glBindSampler");
}

static void APIENTRY noopBindSamplers(GLuint first, GLsizei count, const GLuint *samplers)
{
   (void) first; (void) count; (void) samplers;
   noop_warn("glBindSamplers");
}

static void APIENTRY noopBindShadingRateImageNV(GLuint texture)
{
   (void) texture;
   noop_warn("glBindShadingRateImageNV");
}

static GLuint APIENTRY noopBindTexGenParameterEXT(GLenum unit, GLenum coord, GLenum value)
{
   (void) unit; (void) coord; (void) value;
   noop_warn("glBindTexGenParameterEXT");
   return (GLuint) 0;
}

static void APIENTRY noopBindTexture(GLenum target, GLuint texture)
{
   (void) target; (void) texture;
   noop_warn("glBindTexture");
}

static void APIENTRY noopBindTextureEXT(GLenum target, GLuint texture)
{
   (void) target; (void) texture;
   noop_warn("glBindTextureEXT");
}

static void APIENTRY noopBindTextureUnit(GLuint unit, GLuint texture)
{
   (void) unit; (void) texture;
   noop_warn("glBindTextureUnit");
}

static GLuint APIENTRY noopBindTextureUnitParameterEXT(GLenum unit, GLenum value)
{
   (void) unit; (void) value;
   noop_warn("glBindTextureUnitParameterEXT");
   return (GLuint) 0;
}

static void APIENTRY noopBindTextures(GLuint first, GLsizei count, const GLuint *textures)
{
   (void) first; (void) count; (void) textures;
   noop_warn("glBindTextures");
}

static void APIENTRY noopBindTransformFeedback(GLenum target, GLuint id)
{
   (void) target; (void) id;
   noop_warn("glBindTransformFeedback");
}

static void APIENTRY noopBindTransformFeedbackEXT(GLenum target, GLuint id)
{
   (void) target; (void) id;
   noop_warn("glBindTransformFeedbackEXT");
}

static void APIENTRY noopBindTransformFeedbackNV(GLenum target, GLuint id)
{
   (void) target; (void) id;
   noop_warn("glBindTransformFeedbackNV");
}

static void APIENTRY noopBindVertexArray(GLuint array)
{
   (void) array;
   noop_warn("glBindVertexArray");
}

static void APIENTRY noopBindVertexArrayAPPLE(GLuint array)
{
   (void) array;
   noop_warn("glBindVertexArrayAPPLE");
}

static void APIENTRY noopBindVertexArrayOES(GLuint array)
{
   (void) array;
   noop_warn("glBindVertexArrayOES");
}

static void APIENTRY noopBindVertexBuffer(GLuint bindingindex, GLuint buffer, GLintptr offset, GLsizei stride)
{
   (void) bindingindex; (void) buffer; (void) offset; (void) stride;
   noop_warn("glBindVertexBuffer");
}

static void APIENTRY noopBindVertexBuffers(GLuint first, GLsizei count, const GLuint *buffers, const GLintptr *offsets, const GLsizei *strides)
{
   (void) first; (void) count; (void) buffers; (void) offsets; (void) strides;
   noop_warn("glBindVertexBuffers");
}

static void APIENTRY noopBindVertexShaderEXT(GLuint id)
{
   (void) id;
   noop_warn("glBindVertexShaderEXT");
}

static void APIENTRY noopBindVideoCaptureStreamBufferNV(GLuint video_capture_slot, GLuint stream, GLenum frame_region, GLintptr offset)
{
   (void) video_capture_slot; (void) stream; (void) frame_region; (void) offset;
   noop_warn("glBindVideoCaptureStreamBufferNV");
}

static void APIENTRY noopBindVideoCaptureStreamTextureNV(GLuint video_capture_slot, GLuint stream, GLenum frame_region, GLenum target, GLuint texture)
{
   (void) video_capture_slot; (void) stream; (void) frame_region; (void) target; (void) texture;
   noop_warn("glBindVideoCaptureStreamTextureNV");
}

static void APIENTRY noopBinormal3bEXT(GLbyte bx, GLbyte by, GLbyte bz)
{
   (void) bx; (void) by; (void) bz;
   noop_warn("glBinormal3bEXT");
}

static void APIENTRY noopBinormal3bvEXT(const GLbyte *v)
{
   (void) v;
   noop_warn("glBinormal3bvEXT");
}

static void APIENTRY noopBinormal3dEXT(GLdouble bx, GLdouble by, GLdouble bz)
{
   (void) bx; (void) by; (void) bz;
   noop_warn("glBinormal3dEXT");
}

static void APIENTRY noopBinormal3dvEXT(const GLdouble *v)
{
   (void) v;
   noop_warn("glBinormal3dvEXT");
}

static void APIENTRY noopBinormal3fEXT(GLfloat bx, GLfloat by, GLfloat bz)
{
   (void) bx; (void) by; (void) bz;
   noop_warn("glBinormal3fEXT");
}

static void APIENTRY noopBinormal3fvEXT(const GLfloat *v)
{
   (void) v;
   noop_warn("glBinormal3fvEXT");
}

static void APIENTRY noopBinormal3iEXT(GLint bx, GLint by, GLint bz)
{
   (void) bx; (void) by; (void) bz;
   noop_warn("glBinormal3iEXT");
}

static void APIENTRY noopBinormal3ivEXT(const GLint *v)
{
   (void) v;
   noop_warn("glBinormal3ivEXT");
}

static void APIENTRY noopBinormal3sEXT(GLshort bx, GLshort by, GLshort bz)
{
   (void) bx; (void) by; (void) bz;
   noop_warn("glBinormal3sEXT");
}

static void APIENTRY noopBinormal3svEXT(const GLshort *v)
{
   (void) v;
   noop_warn("glBinormal3svEXT");
}

static void APIENTRY noopBinormalPointerEXT(GLenum type, GLsizei stride, const void *pointer)
{
   (void) type; (void) stride; (void) pointer;
   noop_warn("glBinormalPointerEXT");
}

static void APIENTRY noopBitmap(GLsizei width, GLsizei height, GLfloat xorig, GLfloat yorig, GLfloat xmove, GLfloat ymove, const GLubyte *bitmap)
{
   (void) width; (void) height; (void) xorig; (void) yorig; (void) xmove; (void) ymove; (void) bitmap;
   noop_warn("glBitmap");
}

static void APIENTRY noopBitmapxOES(GLsizei width, GLsizei height, GLfixed xorig, GLfixed yorig, GLfixed xmove, GLfixed ymove, const GLubyte *bitmap)
{
   (void) width; (void) height; (void) xorig; (void) yorig; (void) xmove; (void) ymove; (void) bitmap;
   noop_warn("glBitmapxOES");
}

static void APIENTRY noopBlendBarrier(void)
{
   noop_warn("glBlendBarrier");
}

static void APIENTRY noopBlendBarrierKHR(void)
{
   noop_warn("glBlendBarrierKHR");
}

static void APIENTRY noopBlendBarrierNV(void)
{
   noop_warn("glBlendBarrierNV");
}

static void APIENTRY noopBlendColor(GLfloat red, GLfloat green, GLfloat blue, GLfloat alpha)
{
   (void) red; (void) green; (void) blue; (void) alpha;
   noop_warn("glBlendColor");
}

static void APIENTRY noopBlendColorEXT(GLfloat red, GLfloat green, GLfloat blue, GLfloat alpha)
{
   (void) red; (void) green; (void) blue; (void) alpha;
   noop_warn("glBlendColorEXT");
}

static void APIENTRY noopBlendColorxOES(GLfixed red, GLfixed green, GLfixed blue, GLfixed alpha)
{
   (void) red; (void) green; (void) blue; (void) alpha;
   noop_warn("glBlendColorxOES");
}

static void APIENTRY noopBlendEquation(GLenum mode)
{
   (void) mode;
   noop_warn("glBlendEquation");
}

static void APIENTRY noopBlendEquationEXT(GLenum mode)
{
   (void) mode;
   noop_warn("glBlendEquationEXT");
}

static void APIENTRY noopBlendEquationIndexedAMD(GLuint buf, GLenum mode)
{
   (void) buf; (void) mode;
   noop_warn("glBlendEquationIndexedAMD");
}

static void APIENTRY noopBlendEquationOES(GLenum mode)
{
   (void) mode;
   noop_warn("glBlendEquationOES");
}

static void APIENTRY noopBlendEquationSeparate(GLenum modeRGB, GLenum modeAlpha)
{
   (void) modeRGB; (void) modeAlpha;
   noop_warn("glBlendEquationSeparate");
}

static void APIENTRY noopBlendEquationSeparateEXT(GLenum modeRGB, GLenum modeAlpha)
{
   (void) modeRGB; (void) modeAlpha;
   noop_warn("glBlendEquationSeparateEXT");
}

static void APIENTRY noopBlendEquationSeparateIndexedAMD(GLuint buf, GLenum modeRGB, GLenum modeAlpha)
{
   (void) buf; (void) modeRGB; (void) modeAlpha;
   noop_warn("glBlendEquationSeparateIndexedAMD");
}

static void APIENTRY noopBlendEquationSeparateOES(GLenum modeRGB, GLenum modeAlpha)
{
   (void) modeRGB; (void) modeAlpha;
   noop_warn("glBlendEquationSeparateOES");
}

static void APIENTRY noopBlendEquationSeparatei(GLuint buf, GLenum modeRGB, GLenum modeAlpha)
{
   (void) buf; (void) modeRGB; (void) modeAlpha;
   noop_warn("glBlendEquationSeparatei");
}

static void APIENTRY noopBlendEquationSeparateiARB(GLuint buf, GLenum modeRGB, GLenum modeAlpha)
{
   (void) buf; (void) modeRGB; (void) modeAlpha;
   noop_warn("glBlendEquationSeparateiARB");
}

static void APIENTRY noopBlendEquationSeparateiEXT(GLuint buf, GLenum modeRGB, GLenum modeAlpha)
{
   (void) buf; (void) modeRGB; (void) modeAlpha;
   noop_warn("glBlendEquationSeparateiEXT");
}

static void APIENTRY noopBlendEquationSeparateiOES(GLuint buf, GLenum modeRGB, GLenum modeAlpha)
{
   (void) buf; (void) modeRGB; (void) modeAlpha;
   noop_warn("glBlendEquationSeparateiOES");
}

static void APIENTRY noopBlendEquationi(GLuint buf, GLenum mode)
{
   (void) buf; (void) mode;
   noop_warn("glBlendEquationi");
}

static void APIENTRY noopBlendEquationiARB(GLuint buf, GLenum mode)
{
   (void) buf; (void) mode;
   noop_warn("glBlendEquationiARB");
}

static void APIENTRY noopBlendEquationiEXT(GLuint buf, GLenum mode)
{
   (void) buf; (void) mode;
   noop_warn("glBlendEquationiEXT");
}

static void APIENTRY noopBlendEquationiOES(GLuint buf, GLenum mode)
{
   (void) buf; (void) mode;
   noop_warn("glBlendEquationiOES");
}

static void APIENTRY noopBlendFunc(GLenum sfactor, GLenum dfactor)
{
   (void) sfactor; (void) dfactor;
   noop_warn("glBlendFunc");
}

static void APIENTRY noopBlendFuncIndexedAMD(GLuint buf, GLenum src, GLenum dst)
{
   (void) buf; (void) src; (void) dst;
   noop_warn("glBlendFuncIndexedAMD");
}

static void APIENTRY noopBlendFuncSeparate(GLenum sfactorRGB, GLenum dfactorRGB, GLenum sfactorAlpha, GLenum dfactorAlpha)
{
   (void) sfactorRGB; (void) dfactorRGB; (void) sfactorAlpha; (void) dfactorAlpha;
   noop_warn("glBlendFuncSeparate");
}

static void APIENTRY noopBlendFuncSeparateEXT(GLenum sfactorRGB, GLenum dfactorRGB, GLenum sfactorAlpha, GLenum dfactorAlpha)
{
   (void) sfactorRGB; (void) dfactorRGB; (void) sfactorAlpha; (void) dfactorAlpha;
   noop_warn("glBlendFuncSeparateEXT");
}

static void APIENTRY noopBlendFuncSeparateINGR(GLenum sfactorRGB, GLenum dfactorRGB, GLenum sfactorAlpha, GLenum dfactorAlpha)
{
   (void) sfactorRGB; (void) dfactorRGB; (void) sfactorAlpha; (void) dfactorAlpha;
   noop_warn("glBlendFuncSeparateINGR");
}

static void APIENTRY noopBlendFuncSeparateIndexedAMD(GLuint buf, GLenum srcRGB, GLenum dstRGB, GLenum srcAlpha, GLenum dstAlpha)
{
   (void) buf; (void) srcRGB; (void) dstRGB; (void) srcAlpha; (void) dstAlpha;
   noop_warn("glBlendFuncSeparateIndexedAMD");
}

static void APIENTRY noopBlendFuncSeparateOES(GLenum srcRGB, GLenum dstRGB, GLenum srcAlpha, GLenum dstAlpha)
{
   (void) srcRGB; (void) dstRGB; (void) srcAlpha; (void) dstAlpha;
   noop_warn("glBlendFuncSeparateOES");
}

static void APIENTRY noopBlendFuncSeparatei(GLuint buf, GLenum srcRGB, GLenum dstRGB, GLenum srcAlpha, GLenum dstAlpha)
{
   (void) buf; (void) srcRGB; (void) dstRGB; (void) srcAlpha; (void) dstAlpha;
   noop_warn("glBlendFuncSeparatei");
}

static void APIENTRY noopBlendFuncSeparateiARB(GLuint buf, GLenum srcRGB, GLenum dstRGB, GLenum srcAlpha, GLenum dstAlpha)
{
   (void) buf; (void) srcRGB; (void) dstRGB; (void) srcAlpha; (void) dstAlpha;
   noop_warn("glBlendFuncSeparateiARB");
}

static void APIENTRY noopBlendFuncSeparateiEXT(GLuint buf, GLenum srcRGB, GLenum dstRGB, GLenum srcAlpha, GLenum dstAlpha)
{
   (void) buf; (void) srcRGB; (void) dstRGB; (void) srcAlpha; (void) dstAlpha;
   noop_warn("glBlendFuncSeparateiEXT");
}

static void APIENTRY noopBlendFuncSeparateiOES(GLuint buf, GLenum srcRGB, GLenum dstRGB, GLenum srcAlpha, GLenum dstAlpha)
{
   (void) buf; (void) srcRGB; (void) dstRGB; (void) srcAlpha; (void) dstAlpha;
   noop_warn("glBlendFuncSeparateiOES");
}

static void APIENTRY noopBlendFunci(GLuint buf, GLenum src, GLenum dst)
{
   (void) buf; (void) src; (void) dst;
   noop_warn("glBlendFunci");
}

static void APIENTRY noopBlendFunciARB(GLuint buf, GLenum src, GLenum dst)
{
   (void) buf; (void) src; (void) dst;
   noop_warn("glBlendFunciARB");
}

static void APIENTRY noopBlendFunciEXT(GLuint buf, GLenum src, GLenum dst)
{
   (void) buf; (void) src; (void) dst;
   noop_warn("glBlendFunciEXT");
}

static void APIENTRY noopBlendFunciOES(GLuint buf, GLenum src, GLenum dst)
{
   (void) buf; (void) src; (void) dst;
   noop_warn("glBlendFunciOES");
}

static void APIENTRY noopBlendParameteriNV(GLenum pname, GLint value)
{
   (void) pname; (void) value;
   noop_warn("glBlendParameteriNV");
}

static void APIENTRY noopBlitFramebuffer(GLint srcX0, GLint srcY0, GLint srcX1, GLint srcY1, GLint dstX0, GLint dstY0, GLint dstX1, GLint dstY1, GLbitfield mask, GLenum filter)
{
   (void) srcX0; (void) srcY0; (void) srcX1; (void) srcY1; (void) dstX0; (void) dstY0; (void) dstX1; (void) dstY1; (void) mask; (void) filter;
   noop_warn("glBlitFramebuffer");
}

static void APIENTRY noopBlitFramebufferANGLE(GLint srcX0, GLint srcY0, GLint srcX1, GLint srcY1, GLint dstX0, GLint dstY0, GLint dstX1, GLint dstY1, GLbitfield mask, GLenum filter)
{
   (void) srcX0; (void) srcY0; (void) srcX1; (void) srcY1; (void) dstX0; (void) dstY0; (void) dstX1; (void) dstY1; (void) mask; (void) filter;
   noop_warn("glBlitFramebufferANGLE");
}

static void APIENTRY noopBlitFramebufferEXT(GLint srcX0, GLint srcY0, GLint srcX1, GLint srcY1, GLint dstX0, GLint dstY0, GLint dstX1, GLint dstY1, GLbitfield mask, GLenum filter)
{
   (void) srcX0; (void) srcY0; (void) srcX1; (void) srcY1; (void) dstX0; (void) dstY0; (void) dstX1; (void) dstY1; (void) mask; (void) filter;
   noop_warn("glBlitFramebufferEXT");
}

static void APIENTRY noopBlitFramebufferNV(GLint srcX0, GLint srcY0, GLint srcX1, GLint srcY1, GLint dstX0, GLint dstY0, GLint dstX1, GLint dstY1, GLbitfield mask, GLenum filter)
{
   (void) srcX0; (void) srcY0; (void) srcX1; (void) srcY1; (void) dstX0; (void) dstY0; (void) dstX1; (void) dstY1; (void) mask; (void) filter;
   noop_warn("glBlitFramebufferNV");
}

static void APIENTRY noopBlitNamedFramebuffer(GLuint readFramebuffer, GLuint drawFramebuffer, GLint srcX0, GLint srcY0, GLint srcX1, GLint srcY1, GLint dstX0, GLint dstY0, GLint dstX1, GLint dstY1, GLbitfield mask, GLenum filter)
{
   (void) readFramebuffer; (void) drawFramebuffer; (void) srcX0; (void) srcY0; (void) srcX1; (void) srcY1; (void) dstX0; (void) dstY0; (void) dstX1; (void) dstY1; (void) mask; (void) filter;
   noop_warn("glBlitNamedFramebuffer");
}

static void APIENTRY noopBufferAddressRangeNV(GLenum pname, GLuint index, GLuint64 address, GLsizeiptr length)
{
   (void) pname; (void) index; (void) address; (void) length;
   noop_warn("glBufferAddressRangeNV");
}

static void APIENTRY noopBufferAttachMemoryNV(GLenum target, GLuint memory, GLuint64 offset)
{
   (void) target; (void) memory; (void) offset;
   noop_warn("glBufferAttachMemoryNV");
}

static void APIENTRY noopBufferData(GLenum target, GLsizeiptr size, const void *data, GLenum usage)
{
   (void) target; (void) size; (void) data; (void) usage;
   noop_warn("glBufferData");
}

static void APIENTRY noopBufferDataARB(GLenum target, GLsizeiptr size, const void *data, GLenum usage)
{
   (void) target; (void) size; (void) data; (void) usage;
   noop_warn("glBufferDataARB");
}

static void APIENTRY noopBufferDataSysmem(GLenum target, GLsizeiptr size, const void *data, GLenum usage)
{
   (void) target; (void) size; (void) data; (void) usage;
   noop_warn("glBufferDataSysmem");
}

static void APIENTRY noopBufferPageCommitmentARB(GLenum target, GLintptr offset, GLsizeiptr size, GLboolean commit)
{
   (void) target; (void) offset; (void) size; (void) commit;
   noop_warn("glBufferPageCommitmentARB");
}

static void APIENTRY noopBufferParameteriAPPLE(GLenum target, GLenum pname, GLint param)
{
   (void) target; (void) pname; (void) param;
   noop_warn("glBufferParameteriAPPLE");
}

static void APIENTRY noopBufferStorage(GLenum target, GLsizeiptr size, const void *data, GLbitfield flags)
{
   (void) target; (void) size; (void) data; (void) flags;
   noop_warn("glBufferStorage");
}

static void APIENTRY noopBufferStorageEXT(GLenum target, GLsizeiptr size, const void *data, GLbitfield flags)
{
   (void) target; (void) size; (void) data; (void) flags;
   noop_warn("glBufferStorageEXT");
}

static void APIENTRY noopBufferStorageExternalEXT(GLenum target, GLintptr offset, GLsizeiptr size, GLeglClientBufferEXT clientBuffer, GLbitfield flags)
{
   (void) target; (void) offset; (void) size; (void) clientBuffer; (void) flags;
   noop_warn("glBufferStorageExternalEXT");
}

static void APIENTRY noopBufferStorageMemEXT(GLenum target, GLsizeiptr size, GLuint memory, GLuint64 offset)
{
   (void) target; (void) size; (void) memory; (void) offset;
   noop_warn("glBufferStorageMemEXT");
}

static void APIENTRY noopBufferSubData(GLenum target, GLintptr offset, GLsizeiptr size, const void *data)
{
   (void) target; (void) offset; (void) size; (void) data;
   noop_warn("glBufferSubData");
}

static void APIENTRY noopBufferSubDataARB(GLenum target, GLintptr offset, GLsizeiptr size, const void *data)
{
   (void) target; (void) offset; (void) size; (void) data;
   noop_warn("glBufferSubDataARB");
}

static void APIENTRY noopCallCommandListNV(GLuint list)
{
   (void) list;
   noop_warn("glCallCommandListNV");
}

static void APIENTRY noopCallList(GLuint list)
{
   (void) list;
   noop_warn("glCallList");
}

static void APIENTRY noopCallLists(GLsizei n, GLenum type, const void *lists)
{
   (void) n; (void) type; (void) lists;
   noop_warn("glCallLists");
}

static GLenum APIENTRY noopCheckFramebufferStatus(GLenum target)
{
   (void) target;
   noop_warn("glCheckFramebufferStatus");
   return (GLenum) 0;
}

static GLenum APIENTRY noopCheckFramebufferStatusEXT(GLenum target)
{
   (void) target;
   noop_warn("glCheckFramebufferStatusEXT");
   return (GLenum) 0;
}

static GLenum APIENTRY noopCheckFramebufferStatusOES(GLenum target)
{
   (void) target;
   noop_warn("glCheckFramebufferStatusOES");
   return (GLenum) 0;
}

static GLenum APIENTRY noopCheckNamedFramebufferStatus(GLuint framebuffer, GLenum target)
{
   (void) framebuffer; (void) target;
   noop_warn("glCheckNamedFramebufferStatus");
   return (GLenum) 0;
}

static GLenum APIENTRY noopCheckNamedFramebufferStatusEXT(GLuint framebuffer, GLenum target)
{
   (void) framebuffer; (void) target;
   noop_warn("glCheckNamedFramebufferStatusEXT");
   return (GLenum) 0;
}

static void APIENTRY noopClampColor(GLenum target, GLenum clamp)
{
   (void) target; (void) clamp;
   noop_warn("glClampColor");
}

static void APIENTRY noopClampColorARB(GLenum target, GLenum clamp)
{
   (void) target; (void) clamp;
   noop_warn("glClampColorARB");
}

static void APIENTRY noopClear(GLbitfield mask)
{
   (void) mask;
   noop_warn("glClear");
}

static void APIENTRY noopClearAccum(GLfloat red, GLfloat green, GLfloat blue, GLfloat alpha)
{
   (void) red; (void) green; (void) blue; (void) alpha;
   noop_warn("glClearAccum");
}

static void APIENTRY noopClearAccumxOES(GLfixed red, GLfixed green, GLfixed blue, GLfixed alpha)
{
   (void) red; (void) green; (void) blue; (void) alpha;
   noop_warn("glClearAccumxOES");
}

static void APIENTRY noopClearBufferData(GLenum target, GLenum internalformat, GLenum format, GLenum type, const void *data)
{
   (void) target; (void) internalformat; (void) format; (void) type; (void) data;
   noop_warn("glClearBufferData");
}

static void APIENTRY noopClearBufferSubData(GLenum target, GLenum internalformat, GLintptr offset, GLsizeiptr size, GLenum format, GLenum type, const void *data)
{
   (void) target; (void) internalformat; (void) offset; (void) size; (void) format; (void) type; (void) data;
   noop_warn("glClearBufferSubData");
}

static void APIENTRY noopClearBufferfi(GLenum buffer, GLint drawbuffer, GLfloat depth, GLint stencil)
{
   (void) buffer; (void) drawbuffer; (void) depth; (void) stencil;
   noop_warn("glClearBufferfi");
}

static void APIENTRY noopClearBufferfv(GLenum buffer, GLint drawbuffer, const GLfloat *value)
{
   (void) buffer; (void) drawbuffer; (void) value;
   noop_warn("glClearBufferfv");
}

static void APIENTRY noopClearBufferiv(GLenum buffer, GLint drawbuffer, const GLint *value)
{
   (void) buffer; (void) drawbuffer; (void) value;
   noop_warn("glClearBufferiv");
}

static void APIENTRY noopClearBufferuiv(GLenum buffer, GLint drawbuffer, const GLuint *value)
{
   (void) buffer; (void) drawbuffer; (void) value;
   noop_warn("glClearBufferuiv");
}

static void APIENTRY noopClearColor(GLfloat red, GLfloat green, GLfloat blue, GLfloat alpha)
{
   (void) red; (void) green; (void) blue; (void) alpha;
   noop_warn("glClearColor");
}

static void APIENTRY noopClearColorIiEXT(GLint red, GLint green, GLint blue, GLint alpha)
{
   (void) red; (void) green; (void) blue; (void) alpha;
   noop_warn("glClearColorIiEXT");
}

static void APIENTRY noopClearColorIuiEXT(GLuint red, GLuint green, GLuint blue, GLuint alpha)
{
   (void) red; (void) green; (void) blue; (void) alpha;
   noop_warn("glClearColorIuiEXT");
}

static void APIENTRY noopClearColorx(GLfixed red, GLfixed green, GLfixed blue, GLfixed alpha)
{
   (void) red; (void) green; (void) blue; (void) alpha;
   noop_warn("glClearColorx");
}

static void APIENTRY noopClearColorxOES(GLfixed red, GLfixed green, GLfixed blue, GLfixed alpha)
{
   (void) red; (void) green; (void) blue; (void) alpha;
   noop_warn("glClearColorxOES");
}

static void APIENTRY noopClearDepth(GLdouble depth)
{
   (void) depth;
   noop_warn("glClearDepth");
}

static void APIENTRY noopClearDepthdNV(GLdouble depth)
{
   (void) depth;
   noop_warn("glClearDepthdNV");
}

static void APIENTRY noopClearDepthf(GLfloat d)
{
   (void) d;
   noop_warn("glClearDepthf");
}

static void APIENTRY noopClearDepthfOES(GLclampf depth)
{
   (void) depth;
   noop_warn("glClearDepthfOES");
}

static void APIENTRY noopClearDepthx(GLfixed depth)
{
   (void) depth;
   noop_warn("glClearDepthx");
}

static void APIENTRY noopClearDepthxOES(GLfixed depth)
{
   (void) depth;
   noop_warn("glClearDepthxOES");
}

static void APIENTRY noopClearIndex(GLfloat c)
{
   (void) c;
   noop_warn("glClearIndex");
}

static void APIENTRY noopClearNamedBufferData(GLuint buffer, GLenum internalformat, GLenum format, GLenum type, const void *data)
{
   (void) buffer; (void) internalformat; (void) format; (void) type; (void) data;
   noop_warn("glClearNamedBufferData");
}

static void APIENTRY noopClearNamedBufferDataEXT(GLuint buffer, GLenum internalformat, GLenum format, GLenum type, const void *data)
{
   (void) buffer; (void) internalformat; (void) format; (void) type; (void) data;
   noop_warn("glClearNamedBufferDataEXT");
}

static void APIENTRY noopClearNamedBufferSubData(GLuint buffer, GLenum internalformat, GLintptr offset, GLsizeiptr size, GLenum format, GLenum type, const void *data)
{
   (void) buffer; (void) internalformat; (void) offset; (void) size; (void) format; (void) type; (void) data;
   noop_warn("glClearNamedBufferSubData");
}

static void APIENTRY noopClearNamedBufferSubDataEXT(GLuint buffer, GLenum internalformat, GLsizeiptr offset, GLsizeiptr size, GLenum format, GLenum type, const void *data)
{
   (void) buffer; (void) internalformat; (void) offset; (void) size; (void) format; (void) type; (void) data;
   noop_warn("glClearNamedBufferSubDataEXT");
}

static void APIENTRY noopClearNamedFramebufferfi(GLuint framebuffer, GLenum buffer, GLint drawbuffer, GLfloat depth, GLint stencil)
{
   (void) framebuffer; (void) buffer; (void) drawbuffer; (void) depth; (void) stencil;
   noop_warn("glClearNamedFramebufferfi");
}

static void APIENTRY noopClearNamedFramebufferfv(GLuint framebuffer, GLenum buffer, GLint drawbuffer, const GLfloat *value)
{
   (void) framebuffer; (void) buffer; (void) drawbuffer; (void) value;
   noop_warn("glClearNamedFramebufferfv");
}

static void APIENTRY noopClearNamedFramebufferiv(GLuint framebuffer, GLenum buffer, GLint drawbuffer, const GLint *value)
{
   (void) framebuffer; (void) buffer; (void) drawbuffer; (void) value;
   noop_warn("glClearNamedFramebufferiv");
}

static void APIENTRY noopClearNamedFramebufferuiv(GLuint framebuffer, GLenum buffer, GLint drawbuffer, const GLuint *value)
{
   (void) framebuffer; (void) buffer; (void) drawbuffer; (void) value;
   noop_warn("glClearNamedFramebufferuiv");
}

static void APIENTRY noopClearPixelLocalStorageuiEXT(GLsizei offset, GLsizei n, const GLuint *values)
{
   (void) offset; (void) n; (void) values;
   noop_warn("glClearPixelLocalStorageuiEXT");
}

static void APIENTRY noopClearStencil(GLint s)
{
   (void) s;
   noop_warn("glClearStencil");
}

static void APIENTRY noopClearTexImage(GLuint texture, GLint level, GLenum format, GLenum type, const void *data)
{
   (void) texture; (void) level; (void) format; (void) type; (void) data;
   noop_warn("glClearTexImage");
}

static void APIENTRY noopClearTexImageEXT(GLuint texture, GLint level, GLenum format, GLenum type, const void *data)
{
   (void) texture; (void) level; (void) format; (void) type; (void) data;
   noop_warn("glClearTexImageEXT");
}

static void APIENTRY noopClearTexSubImage(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void *data)
{
   (void) texture; (void) level; (void) xoffset; (void) yoffset; (void) zoffset; (void) width; (void) height; (void) depth; (void) format; (void) type; (void) data;
   noop_warn("glClearTexSubImage");
}

static void APIENTRY noopClearTexSubImageEXT(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void *data)
{
   (void) texture; (void) level; (void) xoffset; (void) yoffset; (void) zoffset; (void) width; (void) height; (void) depth; (void) format; (void) type; (void) data;
   noop_warn("glClearTexSubImageEXT");
}

static void APIENTRY noopClientActiveTexture(GLenum texture)
{
   (void) texture;
   noop_warn("glClientActiveTexture");
}

static void APIENTRY noopClientActiveTextureARB(GLenum texture)
{
   (void) texture;
   noop_warn("glClientActiveTextureARB");
}

static void APIENTRY noopClientActiveVertexStreamATI(GLenum stream)
{
   (void) stream;
   noop_warn("glClientActiveVertexStreamATI");
}

static void APIENTRY noopClientAttribDefaultEXT(GLbitfield mask)
{
   (void) mask;
   noop_warn("glClientAttribDefaultEXT");
}

static void APIENTRY noopClientWaitSemaphoreui64NVX(GLsizei fenceObjectCount, const GLuint *semaphoreArray, const GLuint64 *fenceValueArray)
{
   (void) fenceObjectCount; (void) semaphoreArray; (void) fenceValueArray;
   noop_warn("glClientWaitSemaphoreui64NVX");
}

static GLenum APIENTRY noopClientWaitSync(GLsync sync, GLbitfield flags, GLuint64 timeout)
{
   (void) sync; (void) flags; (void) timeout;
   noop_warn("glClientWaitSync");
   return (GLenum) 0;
}

static GLenum APIENTRY noopClientWaitSyncAPPLE(GLsync sync, GLbitfield flags, GLuint64 timeout)
{
   (void) sync; (void) flags; (void) timeout;
   noop_warn("glClientWaitSyncAPPLE");
   return (GLenum) 0;
}

static GLenum APIENTRY noopClientWaitSyncValueuiNVX(GLsync sync, GLbitfield flags, GLuint64 timeout, GLuint value, GLboolean GEQ)
{
   (void) sync; (void) flags; (void) timeout; (void) value; (void) GEQ;
   noop_warn("glClientWaitSyncValueuiNVX");
   return (GLenum) 0;
}

static void APIENTRY noopClipControl(GLenum origin, GLenum depth)
{
   (void) origin; (void) depth;
   noop_warn("glClipControl");
}

static void APIENTRY noopClipControlEXT(GLenum origin, GLenum depth)
{
   (void) origin; (void) depth;
   noop_warn("glClipControlEXT");
}

static void APIENTRY noopClipPlane(GLenum plane, const GLdouble *equation)
{
   (void) plane; (void) equation;
   noop_warn("glClipPlane");
}

static void APIENTRY noopClipPlanef(GLenum p, const GLfloat *eqn)
{
   (void) p; (void) eqn;
   noop_warn("glClipPlanef");
}

static void APIENTRY noopClipPlanefIMG(GLenum p, const GLfloat *eqn)
{
   (void) p; (void) eqn;
   noop_warn("glClipPlanefIMG");
}

static void APIENTRY noopClipPlanefOES(GLenum plane, const GLfloat *equation)
{
   (void) plane; (void) equation;
   noop_warn("glClipPlanefOES");
}

static void APIENTRY noopClipPlanex(GLenum plane, const GLfixed *equation)
{
   (void) plane; (void) equation;
   noop_warn("glClipPlanex");
}

static void APIENTRY noopClipPlanexIMG(GLenum p, const GLfixed *eqn)
{
   (void) p; (void) eqn;
   noop_warn("glClipPlanexIMG");
}

static void APIENTRY noopClipPlanexOES(GLenum plane, const GLfixed *equation)
{
   (void) plane; (void) equation;
   noop_warn("glClipPlanexOES");
}

static void APIENTRY noopColor3b(GLbyte red, GLbyte green, GLbyte blue)
{
   (void) red; (void) green; (void) blue;
   noop_warn("glColor3b");
}

static void APIENTRY noopColor3bv(const GLbyte *v)
{
   (void) v;
   noop_warn("glColor3bv");
}

static void APIENTRY noopColor3d(GLdouble red, GLdouble green, GLdouble blue)
{
   (void) red; (void) green; (void) blue;
   noop_warn("glColor3d");
}

static void APIENTRY noopColor3dv(const GLdouble *v)
{
   (void) v;
   noop_warn("glColor3dv");
}

static void APIENTRY noopColor3f(GLfloat red, GLfloat green, GLfloat blue)
{
   (void) red; (void) green; (void) blue;
   noop_warn("glColor3f");
}

static void APIENTRY noopColor3fVertex3fSUN(GLfloat r, GLfloat g, GLfloat b, GLfloat x, GLfloat y, GLfloat z)
{
   (void) r; (void) g; (void) b; (void) x; (void) y; (void) z;
   noop_warn("glColor3fVertex3fSUN");
}

static void APIENTRY noopColor3fVertex3fvSUN(const GLfloat *c, const GLfloat *v)
{
   (void) c; (void) v;
   noop_warn("glColor3fVertex3fvSUN");
}

static void APIENTRY noopColor3fv(const GLfloat *v)
{
   (void) v;
   noop_warn("glColor3fv");
}

static void APIENTRY noopColor3hNV(GLhalf red, GLhalf green, GLhalf blue)
{
   (void) red; (void) green; (void) blue;
   noop_warn("glColor3hNV");
}

static void APIENTRY noopColor3hvNV(const GLhalf *v)
{
   (void) v;
   noop_warn("glColor3hvNV");
}

static void APIENTRY noopColor3i(GLint red, GLint green, GLint blue)
{
   (void) red; (void) green; (void) blue;
   noop_warn("glColor3i");
}

static void APIENTRY noopColor3iv(const GLint *v)
{
   (void) v;
   noop_warn("glColor3iv");
}

static void APIENTRY noopColor3s(GLshort red, GLshort green, GLshort blue)
{
   (void) red; (void) green; (void) blue;
   noop_warn("glColor3s");
}

static void APIENTRY noopColor3sv(const GLshort *v)
{
   (void) v;
   noop_warn("glColor3sv");
}

static void APIENTRY noopColor3ub(GLubyte red, GLubyte green, GLubyte blue)
{
   (void) red; (void) green; (void) blue;
   noop_warn("glColor3ub");
}

static void APIENTRY noopColor3ubv(const GLubyte *v)
{
   (void) v;
   noop_warn("glColor3ubv");
}

static void APIENTRY noopColor3ui(GLuint red, GLuint green, GLuint blue)
{
   (void) red; (void) green; (void) blue;
   noop_warn("glColor3ui");
}

static void APIENTRY noopColor3uiv(const GLuint *v)
{
   (void) v;
   noop_warn("glColor3uiv");
}

static void APIENTRY noopColor3us(GLushort red, GLushort green, GLushort blue)
{
   (void) red; (void) green; (void) blue;
   noop_warn("glColor3us");
}

static void APIENTRY noopColor3usv(const GLushort *v)
{
   (void) v;
   noop_warn("glColor3usv");
}

static void APIENTRY noopColor3x(GLfixed red, GLfixed green, GLfixed blue)
{
   (void) red; (void) green; (void) blue;
   noop_warn("glColor3x");
}

static void APIENTRY noopColor3xOES(GLfixed red, GLfixed green, GLfixed blue)
{
   (void) red; (void) green; (void) blue;
   noop_warn("glColor3xOES");
}

static void APIENTRY noopColor3xvOES(const GLfixed *components)
{
   (void) components;
   noop_warn("glColor3xvOES");
}

static void APIENTRY noopColor4b(GLbyte red, GLbyte green, GLbyte blue, GLbyte alpha)
{
   (void) red; (void) green; (void) blue; (void) alpha;
   noop_warn("glColor4b");
}

static void APIENTRY noopColor4bv(const GLbyte *v)
{
   (void) v;
   noop_warn("glColor4bv");
}

static void APIENTRY noopColor4d(GLdouble red, GLdouble green, GLdouble blue, GLdouble alpha)
{
   (void) red; (void) green; (void) blue; (void) alpha;
   noop_warn("glColor4d");
}

static void APIENTRY noopColor4dv(const GLdouble *v)
{
   (void) v;
   noop_warn("glColor4dv");
}

static void APIENTRY noopColor4f(GLfloat red, GLfloat green, GLfloat blue, GLfloat alpha)
{
   (void) red; (void) green; (void) blue; (void) alpha;
   noop_warn("glColor4f");
}

static void APIENTRY noopColor4fNormal3fVertex3fSUN(GLfloat r, GLfloat g, GLfloat b, GLfloat a, GLfloat nx, GLfloat ny, GLfloat nz, GLfloat x, GLfloat y, GLfloat z)
{
   (void) r; (void) g; (void) b; (void) a; (void) nx; (void) ny; (void) nz; (void) x; (void) y; (void) z;
   noop_warn("glColor4fNormal3fVertex3fSUN");
}

static void APIENTRY noopColor4fNormal3fVertex3fvSUN(const GLfloat *c, const GLfloat *n, const GLfloat *v)
{
   (void) c; (void) n; (void) v;
   noop_warn("glColor4fNormal3fVertex3fvSUN");
}

static void APIENTRY noopColor4fv(const GLfloat *v)
{
   (void) v;
   noop_warn("glColor4fv");
}

static void APIENTRY noopColor4hNV(GLhalf red, GLhalf green, GLhalf blue, GLhalf alpha)
{
   (void) red; (void) green; (void) blue; (void) alpha;
   noop_warn("glColor4hNV");
}

static void APIENTRY noopColor4hvNV(const GLhalf *v)
{
   (void) v;
   noop_warn("glColor4hvNV");
}

static void APIENTRY noopColor4i(GLint red, GLint green, GLint blue, GLint alpha)
{
   (void) red; (void) green; (void) blue; (void) alpha;
   noop_warn("glColor4i");
}

static void APIENTRY noopColor4iv(const GLint *v)
{
   (void) v;
   noop_warn("glColor4iv");
}

static void APIENTRY noopColor4s(GLshort red, GLshort green, GLshort blue, GLshort alpha)
{
   (void) red; (void) green; (void) blue; (void) alpha;
   noop_warn("glColor4s");
}

static void APIENTRY noopColor4sv(const GLshort *v)
{
   (void) v;
   noop_warn("glColor4sv");
}

static void APIENTRY noopColor4ub(GLubyte red, GLubyte green, GLubyte blue, GLubyte alpha)
{
   (void) red; (void) green; (void) blue; (void) alpha;
   noop_warn("glColor4ub");
}

static void APIENTRY noopColor4ubVertex2fSUN(GLubyte r, GLubyte g, GLubyte b, GLubyte a, GLfloat x, GLfloat y)
{
   (void) r; (void) g; (void) b; (void) a; (void) x; (void) y;
   noop_warn("glColor4ubVertex2fSUN");
}

static void APIENTRY noopColor4ubVertex2fvSUN(const GLubyte *c, const GLfloat *v)
{
   (void) c; (void) v;
   noop_warn("glColor4ubVertex2fvSUN");
}

static void APIENTRY noopColor4ubVertex3fSUN(GLubyte r, GLubyte g, GLubyte b, GLubyte a, GLfloat x, GLfloat y, GLfloat z)
{
   (void) r; (void) g; (void) b; (void) a; (void) x; (void) y; (void) z;
   noop_warn("glColor4ubVertex3fSUN");
}

static void APIENTRY noopColor4ubVertex3fvSUN(const GLubyte *c, const GLfloat *v)
{
   (void) c; (void) v;
   noop_warn("glColor4ubVertex3fvSUN");
}

static void APIENTRY noopColor4ubv(const GLubyte *v)
{
   (void) v;
   noop_warn("glColor4ubv");
}

static void APIENTRY noopColor4ui(GLuint red, GLuint green, GLuint blue, GLuint alpha)
{
   (void) red; (void) green; (void) blue; (void) alpha;
   noop_warn("glColor4ui");
}

static void APIENTRY noopColor4uiv(const GLuint *v)
{
   (void) v;
   noop_warn("glColor4uiv");
}

static void APIENTRY noopColor4us(GLushort red, GLushort green, GLushort blue, GLushort alpha)
{
   (void) red; (void) green; (void) blue; (void) alpha;
   noop_warn("glColor4us");
}

static void APIENTRY noopColor4usv(const GLushort *v)
{
   (void) v;
   noop_warn("glColor4usv");
}

static void APIENTRY noopColor4x(GLfixed red, GLfixed green, GLfixed blue, GLfixed alpha)
{
   (void) red; (void) green; (void) blue; (void) alpha;
   noop_warn("glColor4x");
}

static void APIENTRY noopColor4xOES(GLfixed red, GLfixed green, GLfixed blue, GLfixed alpha)
{
   (void) red; (void) green; (void) blue; (void) alpha;
   noop_warn("glColor4xOES");
}

static void APIENTRY noopColor4xvOES(const GLfixed *components)
{
   (void) components;
   noop_warn("glColor4xvOES");
}

static void APIENTRY noopColorFormatNV(GLint size, GLenum type, GLsizei stride)
{
   (void) size; (void) type; (void) stride;
   noop_warn("glColorFormatNV");
}

static void APIENTRY noopColorFragmentOp1ATI(GLenum op, GLuint dst, GLuint dstMask, GLuint dstMod, GLuint arg1, GLuint arg1Rep, GLuint arg1Mod)
{
   (void) op; (void) dst; (void) dstMask; (void) dstMod; (void) arg1; (void) arg1Rep; (void) arg1Mod;
   noop_warn("glColorFragmentOp1ATI");
}

static void APIENTRY noopColorFragmentOp2ATI(GLenum op, GLuint dst, GLuint dstMask, GLuint dstMod, GLuint arg1, GLuint arg1Rep, GLuint arg1Mod, GLuint arg2, GLuint arg2Rep, GLuint arg2Mod)
{
   (void) op; (void) dst; (void) dstMask; (void) dstMod; (void) arg1; (void) arg1Rep; (void) arg1Mod; (void) arg2; (void) arg2Rep; (void) arg2Mod;
   noop_warn("glColorFragmentOp2ATI");
}

static void APIENTRY noopColorFragmentOp3ATI(GLenum op, GLuint dst, GLuint dstMask, GLuint dstMod, GLuint arg1, GLuint arg1Rep, GLuint arg1Mod, GLuint arg2, GLuint arg2Rep, GLuint arg2Mod, GLuint arg3, GLuint arg3Rep, GLuint arg3Mod)
{
   (void) op; (void) dst; (void) dstMask; (void) dstMod; (void) arg1; (void) arg1Rep; (void) arg1Mod; (void) arg2; (void) arg2Rep; (void) arg2Mod; (void) arg3; (void) arg3Rep; (void) arg3Mod;
   noop_warn("glColorFragmentOp3ATI");
}

static void APIENTRY noopColorMask(GLboolean red, GLboolean green, GLboolean blue, GLboolean alpha)
{
   (void) red; (void) green; (void) blue; (void) alpha;
   noop_warn("glColorMask");
}

static void APIENTRY noopColorMaskIndexedEXT(GLuint index, GLboolean r, GLboolean g, GLboolean b, GLboolean a)
{
   (void) index; (void) r; (void) g; (void) b; (void) a;
   noop_warn("glColorMaskIndexedEXT");
}

static void APIENTRY noopColorMaski(GLuint index, GLboolean r, GLboolean g, GLboolean b, GLboolean a)
{
   (void) index; (void) r; (void) g; (void) b; (void) a;
   noop_warn("glColorMaski");
}

static void APIENTRY noopColorMaskiEXT(GLuint index, GLboolean r, GLboolean g, GLboolean b, GLboolean a)
{
   (void) index; (void) r; (void) g; (void) b; (void) a;
   noop_warn("glColorMaskiEXT");
}

static void APIENTRY noopColorMaskiOES(GLuint index, GLboolean r, GLboolean g, GLboolean b, GLboolean a)
{
   (void) index; (void) r; (void) g; (void) b; (void) a;
   noop_warn("glColorMaskiOES");
}

static void APIENTRY noopColorMaterial(GLenum face, GLenum mode)
{
   (void) face; (void) mode;
   noop_warn("glColorMaterial");
}

static void APIENTRY noopColorP3ui(GLenum type, GLuint color)
{
   (void) type; (void) color;
   noop_warn("glColorP3ui");
}

static void APIENTRY noopColorP3uiv(GLenum type, const GLuint *color)
{
   (void) type; (void) color;
   noop_warn("glColorP3uiv");
}

static void APIENTRY noopColorP4ui(GLenum type, GLuint color)
{
   (void) type; (void) color;
   noop_warn("glColorP4ui");
}

static void APIENTRY noopColorP4uiv(GLenum type, const GLuint *color)
{
   (void) type; (void) color;
   noop_warn("glColorP4uiv");
}

static void APIENTRY noopColorPointer(GLint size, GLenum type, GLsizei stride, const void *pointer)
{
   (void) size; (void) type; (void) stride; (void) pointer;
   noop_warn("glColorPointer");
}

static void APIENTRY noopColorPointerEXT(GLint size, GLenum type, GLsizei stride, GLsizei count, const void *pointer)
{
   (void) size; (void) type; (void) stride; (void) count; (void) pointer;
   noop_warn("glColorPointerEXT");
}

static void APIENTRY noopColorPointerListIBM(GLint size, GLenum type, GLint stride, const void **pointer, GLint ptrstride)
{
   (void) size; (void) type; (void) stride; (void) pointer; (void) ptrstride;
   noop_warn("glColorPointerListIBM");
}

static void APIENTRY noopColorPointervINTEL(GLint size, GLenum type, const void **pointer)
{
   (void) size; (void) type; (void) pointer;
   noop_warn("glColorPointervINTEL");
}

static void APIENTRY noopColorSubTable(GLenum target, GLsizei start, GLsizei count, GLenum format, GLenum type, const void *data)
{
   (void) target; (void) start; (void) count; (void) format; (void) type; (void) data;
   noop_warn("glColorSubTable");
}

static void APIENTRY noopColorSubTableEXT(GLenum target, GLsizei start, GLsizei count, GLenum format, GLenum type, const void *data)
{
   (void) target; (void) start; (void) count; (void) format; (void) type; (void) data;
   noop_warn("glColorSubTableEXT");
}

static void APIENTRY noopColorTable(GLenum target, GLenum internalformat, GLsizei width, GLenum format, GLenum type, const void *table)
{
   (void) target; (void) internalformat; (void) width; (void) format; (void) type; (void) table;
   noop_warn("glColorTable");
}

static void APIENTRY noopColorTableEXT(GLenum target, GLenum internalFormat, GLsizei width, GLenum format, GLenum type, const void *table)
{
   (void) target; (void) internalFormat; (void) width; (void) format; (void) type; (void) table;
   noop_warn("glColorTableEXT");
}

static void APIENTRY noopColorTableParameterfv(GLenum target, GLenum pname, const GLfloat *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glColorTableParameterfv");
}

static void APIENTRY noopColorTableParameterfvSGI(GLenum target, GLenum pname, const GLfloat *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glColorTableParameterfvSGI");
}

static void APIENTRY noopColorTableParameteriv(GLenum target, GLenum pname, const GLint *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glColorTableParameteriv");
}

static void APIENTRY noopColorTableParameterivSGI(GLenum target, GLenum pname, const GLint *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glColorTableParameterivSGI");
}

static void APIENTRY noopColorTableSGI(GLenum target, GLenum internalformat, GLsizei width, GLenum format, GLenum type, const void *table)
{
   (void) target; (void) internalformat; (void) width; (void) format; (void) type; (void) table;
   noop_warn("glColorTableSGI");
}

static void APIENTRY noopCombinerInputNV(GLenum stage, GLenum portion, GLenum variable, GLenum input, GLenum mapping, GLenum componentUsage)
{
   (void) stage; (void) portion; (void) variable; (void) input; (void) mapping; (void) componentUsage;
   noop_warn("glCombinerInputNV");
}

static void APIENTRY noopCombinerOutputNV(GLenum stage, GLenum portion, GLenum abOutput, GLenum cdOutput, GLenum sumOutput, GLenum scale, GLenum bias, GLboolean abDotProduct, GLboolean cdDotProduct, GLboolean muxSum)
{
   (void) stage; (void) portion; (void) abOutput; (void) cdOutput; (void) sumOutput; (void) scale; (void) bias; (void) abDotProduct; (void) cdDotProduct; (void) muxSum;
   noop_warn("glCombinerOutputNV");
}

static void APIENTRY noopCombinerParameterfNV(GLenum pname, GLfloat param)
{
   (void) pname; (void) param;
   noop_warn("glCombinerParameterfNV");
}

static void APIENTRY noopCombinerParameterfvNV(GLenum pname, const GLfloat *params)
{
   (void) pname; (void) params;
   noop_warn("glCombinerParameterfvNV");
}

static void APIENTRY noopCombinerParameteriNV(GLenum pname, GLint param)
{
   (void) pname; (void) param;
   noop_warn("glCombinerParameteriNV");
}

static void APIENTRY noopCombinerParameterivNV(GLenum pname, const GLint *params)
{
   (void) pname; (void) params;
   noop_warn("glCombinerParameterivNV");
}

static void APIENTRY noopCombinerStageParameterfvNV(GLenum stage, GLenum pname, const GLfloat *params)
{
   (void) stage; (void) pname; (void) params;
   noop_warn("glCombinerStageParameterfvNV");
}

static void APIENTRY noopCommandListSegmentsNV(GLuint list, GLuint segments)
{
   (void) list; (void) segments;
   noop_warn("glCommandListSegmentsNV");
}

static void APIENTRY noopCompileCommandListNV(GLuint list)
{
   (void) list;
   noop_warn("glCompileCommandListNV");
}

static void APIENTRY noopCompileShader(GLuint shader)
{
   (void) shader;
   noop_warn("glCompileShader");
}

static void APIENTRY noopCompileShaderARB(GLhandleARB shaderObj)
{
   (void) shaderObj;
   noop_warn("glCompileShaderARB");
}

static void APIENTRY noopCompileShaderIncludeARB(GLuint shader, GLsizei count, const GLchar *const *path, const GLint *length)
{
   (void) shader; (void) count; (void) path; (void) length;
   noop_warn("glCompileShaderIncludeARB");
}

static void APIENTRY noopCompressedMultiTexImage1DEXT(GLenum texunit, GLenum target, GLint level, GLenum internalformat, GLsizei width, GLint border, GLsizei imageSize, const void *bits)
{
   (void) texunit; (void) target; (void) level; (void) internalformat; (void) width; (void) border; (void) imageSize; (void) bits;
   noop_warn("glCompressedMultiTexImage1DEXT");
}

static void APIENTRY noopCompressedMultiTexImage2DEXT(GLenum texunit, GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLint border, GLsizei imageSize, const void *bits)
{
   (void) texunit; (void) target; (void) level; (void) internalformat; (void) width; (void) height; (void) border; (void) imageSize; (void) bits;
   noop_warn("glCompressedMultiTexImage2DEXT");
}

static void APIENTRY noopCompressedMultiTexImage3DEXT(GLenum texunit, GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLsizei imageSize, const void *bits)
{
   (void) texunit; (void) target; (void) level; (void) internalformat; (void) width; (void) height; (void) depth; (void) border; (void) imageSize; (void) bits;
   noop_warn("glCompressedMultiTexImage3DEXT");
}

static void APIENTRY noopCompressedMultiTexSubImage1DEXT(GLenum texunit, GLenum target, GLint level, GLint xoffset, GLsizei width, GLenum format, GLsizei imageSize, const void *bits)
{
   (void) texunit; (void) target; (void) level; (void) xoffset; (void) width; (void) format; (void) imageSize; (void) bits;
   noop_warn("glCompressedMultiTexSubImage1DEXT");
}

static void APIENTRY noopCompressedMultiTexSubImage2DEXT(GLenum texunit, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLsizei imageSize, const void *bits)
{
   (void) texunit; (void) target; (void) level; (void) xoffset; (void) yoffset; (void) width; (void) height; (void) format; (void) imageSize; (void) bits;
   noop_warn("glCompressedMultiTexSubImage2DEXT");
}

static void APIENTRY noopCompressedMultiTexSubImage3DEXT(GLenum texunit, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLsizei imageSize, const void *bits)
{
   (void) texunit; (void) target; (void) level; (void) xoffset; (void) yoffset; (void) zoffset; (void) width; (void) height; (void) depth; (void) format; (void) imageSize; (void) bits;
   noop_warn("glCompressedMultiTexSubImage3DEXT");
}

static void APIENTRY noopCompressedTexImage1D(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLint border, GLsizei imageSize, const void *data)
{
   (void) target; (void) level; (void) internalformat; (void) width; (void) border; (void) imageSize; (void) data;
   noop_warn("glCompressedTexImage1D");
}

static void APIENTRY noopCompressedTexImage1DARB(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLint border, GLsizei imageSize, const void *data)
{
   (void) target; (void) level; (void) internalformat; (void) width; (void) border; (void) imageSize; (void) data;
   noop_warn("glCompressedTexImage1DARB");
}

static void APIENTRY noopCompressedTexImage2D(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLint border, GLsizei imageSize, const void *data)
{
   (void) target; (void) level; (void) internalformat; (void) width; (void) height; (void) border; (void) imageSize; (void) data;
   noop_warn("glCompressedTexImage2D");
}

static void APIENTRY noopCompressedTexImage2DARB(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLint border, GLsizei imageSize, const void *data)
{
   (void) target; (void) level; (void) internalformat; (void) width; (void) height; (void) border; (void) imageSize; (void) data;
   noop_warn("glCompressedTexImage2DARB");
}

static void APIENTRY noopCompressedTexImage3D(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLsizei imageSize, const void *data)
{
   (void) target; (void) level; (void) internalformat; (void) width; (void) height; (void) depth; (void) border; (void) imageSize; (void) data;
   noop_warn("glCompressedTexImage3D");
}

static void APIENTRY noopCompressedTexImage3DARB(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLsizei imageSize, const void *data)
{
   (void) target; (void) level; (void) internalformat; (void) width; (void) height; (void) depth; (void) border; (void) imageSize; (void) data;
   noop_warn("glCompressedTexImage3DARB");
}

static void APIENTRY noopCompressedTexImage3DNV(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLsizei imageSize, const void *data)
{
   (void) target; (void) level; (void) internalformat; (void) width; (void) height; (void) depth; (void) border; (void) imageSize; (void) data;
   noop_warn("glCompressedTexImage3DNV");
}

static void APIENTRY noopCompressedTexImage3DOES(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLsizei imageSize, const void *data)
{
   (void) target; (void) level; (void) internalformat; (void) width; (void) height; (void) depth; (void) border; (void) imageSize; (void) data;
   noop_warn("glCompressedTexImage3DOES");
}

static void APIENTRY noopCompressedTexSubImage1D(GLenum target, GLint level, GLint xoffset, GLsizei width, GLenum format, GLsizei imageSize, const void *data)
{
   (void) target; (void) level; (void) xoffset; (void) width; (void) format; (void) imageSize; (void) data;
   noop_warn("glCompressedTexSubImage1D");
}

static void APIENTRY noopCompressedTexSubImage1DARB(GLenum target, GLint level, GLint xoffset, GLsizei width, GLenum format, GLsizei imageSize, const void *data)
{
   (void) target; (void) level; (void) xoffset; (void) width; (void) format; (void) imageSize; (void) data;
   noop_warn("glCompressedTexSubImage1DARB");
}

static void APIENTRY noopCompressedTexSubImage2D(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLsizei imageSize, const void *data)
{
   (void) target; (void) level; (void) xoffset; (void) yoffset; (void) width; (void) height; (void) format; (void) imageSize; (void) data;
   noop_warn("glCompressedTexSubImage2D");
}

static void APIENTRY noopCompressedTexSubImage2DARB(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLsizei imageSize, const void *data)
{
   (void) target; (void) level; (void) xoffset; (void) yoffset; (void) width; (void) height; (void) format; (void) imageSize; (void) data;
   noop_warn("glCompressedTexSubImage2DARB");
}

static void APIENTRY noopCompressedTexSubImage3D(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLsizei imageSize, const void *data)
{
   (void) target; (void) level; (void) xoffset; (void) yoffset; (void) zoffset; (void) width; (void) height; (void) depth; (void) format; (void) imageSize; (void) data;
   noop_warn("glCompressedTexSubImage3D");
}

static void APIENTRY noopCompressedTexSubImage3DARB(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLsizei imageSize, const void *data)
{
   (void) target; (void) level; (void) xoffset; (void) yoffset; (void) zoffset; (void) width; (void) height; (void) depth; (void) format; (void) imageSize; (void) data;
   noop_warn("glCompressedTexSubImage3DARB");
}

static void APIENTRY noopCompressedTexSubImage3DNV(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLsizei imageSize, const void *data)
{
   (void) target; (void) level; (void) xoffset; (void) yoffset; (void) zoffset; (void) width; (void) height; (void) depth; (void) format; (void) imageSize; (void) data;
   noop_warn("glCompressedTexSubImage3DNV");
}

static void APIENTRY noopCompressedTexSubImage3DOES(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLsizei imageSize, const void *data)
{
   (void) target; (void) level; (void) xoffset; (void) yoffset; (void) zoffset; (void) width; (void) height; (void) depth; (void) format; (void) imageSize; (void) data;
   noop_warn("glCompressedTexSubImage3DOES");
}

static void APIENTRY noopCompressedTextureImage1DEXT(GLuint texture, GLenum target, GLint level, GLenum internalformat, GLsizei width, GLint border, GLsizei imageSize, const void *bits)
{
   (void) texture; (void) target; (void) level; (void) internalformat; (void) width; (void) border; (void) imageSize; (void) bits;
   noop_warn("glCompressedTextureImage1DEXT");
}

static void APIENTRY noopCompressedTextureImage2DEXT(GLuint texture, GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLint border, GLsizei imageSize, const void *bits)
{
   (void) texture; (void) target; (void) level; (void) internalformat; (void) width; (void) height; (void) border; (void) imageSize; (void) bits;
   noop_warn("glCompressedTextureImage2DEXT");
}

static void APIENTRY noopCompressedTextureImage3DEXT(GLuint texture, GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLsizei imageSize, const void *bits)
{
   (void) texture; (void) target; (void) level; (void) internalformat; (void) width; (void) height; (void) depth; (void) border; (void) imageSize; (void) bits;
   noop_warn("glCompressedTextureImage3DEXT");
}

static void APIENTRY noopCompressedTextureSubImage1D(GLuint texture, GLint level, GLint xoffset, GLsizei width, GLenum format, GLsizei imageSize, const void *data)
{
   (void) texture; (void) level; (void) xoffset; (void) width; (void) format; (void) imageSize; (void) data;
   noop_warn("glCompressedTextureSubImage1D");
}

static void APIENTRY noopCompressedTextureSubImage1DEXT(GLuint texture, GLenum target, GLint level, GLint xoffset, GLsizei width, GLenum format, GLsizei imageSize, const void *bits)
{
   (void) texture; (void) target; (void) level; (void) xoffset; (void) width; (void) format; (void) imageSize; (void) bits;
   noop_warn("glCompressedTextureSubImage1DEXT");
}

static void APIENTRY noopCompressedTextureSubImage2D(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLsizei imageSize, const void *data)
{
   (void) texture; (void) level; (void) xoffset; (void) yoffset; (void) width; (void) height; (void) format; (void) imageSize; (void) data;
   noop_warn("glCompressedTextureSubImage2D");
}

static void APIENTRY noopCompressedTextureSubImage2DEXT(GLuint texture, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLsizei imageSize, const void *bits)
{
   (void) texture; (void) target; (void) level; (void) xoffset; (void) yoffset; (void) width; (void) height; (void) format; (void) imageSize; (void) bits;
   noop_warn("glCompressedTextureSubImage2DEXT");
}

static void APIENTRY noopCompressedTextureSubImage3D(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLsizei imageSize, const void *data)
{
   (void) texture; (void) level; (void) xoffset; (void) yoffset; (void) zoffset; (void) width; (void) height; (void) depth; (void) format; (void) imageSize; (void) data;
   noop_warn("glCompressedTextureSubImage3D");
}

static void APIENTRY noopCompressedTextureSubImage3DEXT(GLuint texture, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLsizei imageSize, const void *bits)
{
   (void) texture; (void) target; (void) level; (void) xoffset; (void) yoffset; (void) zoffset; (void) width; (void) height; (void) depth; (void) format; (void) imageSize; (void) bits;
   noop_warn("glCompressedTextureSubImage3DEXT");
}

static void APIENTRY noopConservativeRasterParameterfNV(GLenum pname, GLfloat value)
{
   (void) pname; (void) value;
   noop_warn("glConservativeRasterParameterfNV");
}

static void APIENTRY noopConservativeRasterParameteriNV(GLenum pname, GLint param)
{
   (void) pname; (void) param;
   noop_warn("glConservativeRasterParameteriNV");
}

static void APIENTRY noopConvolutionFilter1D(GLenum target, GLenum internalformat, GLsizei width, GLenum format, GLenum type, const void *image)
{
   (void) target; (void) internalformat; (void) width; (void) format; (void) type; (void) image;
   noop_warn("glConvolutionFilter1D");
}

static void APIENTRY noopConvolutionFilter1DEXT(GLenum target, GLenum internalformat, GLsizei width, GLenum format, GLenum type, const void *image)
{
   (void) target; (void) internalformat; (void) width; (void) format; (void) type; (void) image;
   noop_warn("glConvolutionFilter1DEXT");
}

static void APIENTRY noopConvolutionFilter2D(GLenum target, GLenum internalformat, GLsizei width, GLsizei height, GLenum format, GLenum type, const void *image)
{
   (void) target; (void) internalformat; (void) width; (void) height; (void) format; (void) type; (void) image;
   noop_warn("glConvolutionFilter2D");
}

static void APIENTRY noopConvolutionFilter2DEXT(GLenum target, GLenum internalformat, GLsizei width, GLsizei height, GLenum format, GLenum type, const void *image)
{
   (void) target; (void) internalformat; (void) width; (void) height; (void) format; (void) type; (void) image;
   noop_warn("glConvolutionFilter2DEXT");
}

static void APIENTRY noopConvolutionParameterf(GLenum target, GLenum pname, GLfloat params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glConvolutionParameterf");
}

static void APIENTRY noopConvolutionParameterfEXT(GLenum target, GLenum pname, GLfloat params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glConvolutionParameterfEXT");
}

static void APIENTRY noopConvolutionParameterfv(GLenum target, GLenum pname, const GLfloat *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glConvolutionParameterfv");
}

static void APIENTRY noopConvolutionParameterfvEXT(GLenum target, GLenum pname, const GLfloat *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glConvolutionParameterfvEXT");
}

static void APIENTRY noopConvolutionParameteri(GLenum target, GLenum pname, GLint params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glConvolutionParameteri");
}

static void APIENTRY noopConvolutionParameteriEXT(GLenum target, GLenum pname, GLint params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glConvolutionParameteriEXT");
}

static void APIENTRY noopConvolutionParameteriv(GLenum target, GLenum pname, const GLint *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glConvolutionParameteriv");
}

static void APIENTRY noopConvolutionParameterivEXT(GLenum target, GLenum pname, const GLint *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glConvolutionParameterivEXT");
}

static void APIENTRY noopConvolutionParameterxOES(GLenum target, GLenum pname, GLfixed param)
{
   (void) target; (void) pname; (void) param;
   noop_warn("glConvolutionParameterxOES");
}

static void APIENTRY noopConvolutionParameterxvOES(GLenum target, GLenum pname, const GLfixed *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glConvolutionParameterxvOES");
}

static void APIENTRY noopCopyBufferSubData(GLenum readTarget, GLenum writeTarget, GLintptr readOffset, GLintptr writeOffset, GLsizeiptr size)
{
   (void) readTarget; (void) writeTarget; (void) readOffset; (void) writeOffset; (void) size;
   noop_warn("glCopyBufferSubData");
}

static void APIENTRY noopCopyBufferSubDataNV(GLenum readTarget, GLenum writeTarget, GLintptr readOffset, GLintptr writeOffset, GLsizeiptr size)
{
   (void) readTarget; (void) writeTarget; (void) readOffset; (void) writeOffset; (void) size;
   noop_warn("glCopyBufferSubDataNV");
}

static void APIENTRY noopCopyColorSubTable(GLenum target, GLsizei start, GLint x, GLint y, GLsizei width)
{
   (void) target; (void) start; (void) x; (void) y; (void) width;
   noop_warn("glCopyColorSubTable");
}

static void APIENTRY noopCopyColorSubTableEXT(GLenum target, GLsizei start, GLint x, GLint y, GLsizei width)
{
   (void) target; (void) start; (void) x; (void) y; (void) width;
   noop_warn("glCopyColorSubTableEXT");
}

static void APIENTRY noopCopyColorTable(GLenum target, GLenum internalformat, GLint x, GLint y, GLsizei width)
{
   (void) target; (void) internalformat; (void) x; (void) y; (void) width;
   noop_warn("glCopyColorTable");
}

static void APIENTRY noopCopyColorTableSGI(GLenum target, GLenum internalformat, GLint x, GLint y, GLsizei width)
{
   (void) target; (void) internalformat; (void) x; (void) y; (void) width;
   noop_warn("glCopyColorTableSGI");
}

static void APIENTRY noopCopyConvolutionFilter1D(GLenum target, GLenum internalformat, GLint x, GLint y, GLsizei width)
{
   (void) target; (void) internalformat; (void) x; (void) y; (void) width;
   noop_warn("glCopyConvolutionFilter1D");
}

static void APIENTRY noopCopyConvolutionFilter1DEXT(GLenum target, GLenum internalformat, GLint x, GLint y, GLsizei width)
{
   (void) target; (void) internalformat; (void) x; (void) y; (void) width;
   noop_warn("glCopyConvolutionFilter1DEXT");
}

static void APIENTRY noopCopyConvolutionFilter2D(GLenum target, GLenum internalformat, GLint x, GLint y, GLsizei width, GLsizei height)
{
   (void) target; (void) internalformat; (void) x; (void) y; (void) width; (void) height;
   noop_warn("glCopyConvolutionFilter2D");
}

static void APIENTRY noopCopyConvolutionFilter2DEXT(GLenum target, GLenum internalformat, GLint x, GLint y, GLsizei width, GLsizei height)
{
   (void) target; (void) internalformat; (void) x; (void) y; (void) width; (void) height;
   noop_warn("glCopyConvolutionFilter2DEXT");
}

static void APIENTRY noopCopyImageSubData(GLuint srcName, GLenum srcTarget, GLint srcLevel, GLint srcX, GLint srcY, GLint srcZ, GLuint dstName, GLenum dstTarget, GLint dstLevel, GLint dstX, GLint dstY, GLint dstZ, GLsizei srcWidth, GLsizei srcHeight, GLsizei srcDepth)
{
   (void) srcName; (void) srcTarget; (void) srcLevel; (void) srcX; (void) srcY; (void) srcZ; (void) dstName; (void) dstTarget; (void) dstLevel; (void) dstX; (void) dstY; (void) dstZ; (void) srcWidth; (void) srcHeight; (void) srcDepth;
   noop_warn("glCopyImageSubData");
}

static void APIENTRY noopCopyImageSubDataEXT(GLuint srcName, GLenum srcTarget, GLint srcLevel, GLint srcX, GLint srcY, GLint srcZ, GLuint dstName, GLenum dstTarget, GLint dstLevel, GLint dstX, GLint dstY, GLint dstZ, GLsizei srcWidth, GLsizei srcHeight, GLsizei srcDepth)
{
   (void) srcName; (void) srcTarget; (void) srcLevel; (void) srcX; (void) srcY; (void) srcZ; (void) dstName; (void) dstTarget; (void) dstLevel; (void) dstX; (void) dstY; (void) dstZ; (void) srcWidth; (void) srcHeight; (void) srcDepth;
   noop_warn("glCopyImageSubDataEXT");
}

static void APIENTRY noopCopyImageSubDataNV(GLuint srcName, GLenum srcTarget, GLint srcLevel, GLint srcX, GLint srcY, GLint srcZ, GLuint dstName, GLenum dstTarget, GLint dstLevel, GLint dstX, GLint dstY, GLint dstZ, GLsizei width, GLsizei height, GLsizei depth)
{
   (void) srcName; (void) srcTarget; (void) srcLevel; (void) srcX; (void) srcY; (void) srcZ; (void) dstName; (void) dstTarget; (void) dstLevel; (void) dstX; (void) dstY; (void) dstZ; (void) width; (void) height; (void) depth;
   noop_warn("glCopyImageSubDataNV");
}

static void APIENTRY noopCopyImageSubDataOES(GLuint srcName, GLenum srcTarget, GLint srcLevel, GLint srcX, GLint srcY, GLint srcZ, GLuint dstName, GLenum dstTarget, GLint dstLevel, GLint dstX, GLint dstY, GLint dstZ, GLsizei srcWidth, GLsizei srcHeight, GLsizei srcDepth)
{
   (void) srcName; (void) srcTarget; (void) srcLevel; (void) srcX; (void) srcY; (void) srcZ; (void) dstName; (void) dstTarget; (void) dstLevel; (void) dstX; (void) dstY; (void) dstZ; (void) srcWidth; (void) srcHeight; (void) srcDepth;
   noop_warn("glCopyImageSubDataOES");
}

static void APIENTRY noopCopyMultiTexImage1DEXT(GLenum texunit, GLenum target, GLint level, GLenum internalformat, GLint x, GLint y, GLsizei width, GLint border)
{
   (void) texunit; (void) target; (void) level; (void) internalformat; (void) x; (void) y; (void) width; (void) border;
   noop_warn("glCopyMultiTexImage1DEXT");
}

static void APIENTRY noopCopyMultiTexImage2DEXT(GLenum texunit, GLenum target, GLint level, GLenum internalformat, GLint x, GLint y, GLsizei width, GLsizei height, GLint border)
{
   (void) texunit; (void) target; (void) level; (void) internalformat; (void) x; (void) y; (void) width; (void) height; (void) border;
   noop_warn("glCopyMultiTexImage2DEXT");
}

static void APIENTRY noopCopyMultiTexSubImage1DEXT(GLenum texunit, GLenum target, GLint level, GLint xoffset, GLint x, GLint y, GLsizei width)
{
   (void) texunit; (void) target; (void) level; (void) xoffset; (void) x; (void) y; (void) width;
   noop_warn("glCopyMultiTexSubImage1DEXT");
}

static void APIENTRY noopCopyMultiTexSubImage2DEXT(GLenum texunit, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint x, GLint y, GLsizei width, GLsizei height)
{
   (void) texunit; (void) target; (void) level; (void) xoffset; (void) yoffset; (void) x; (void) y; (void) width; (void) height;
   noop_warn("glCopyMultiTexSubImage2DEXT");
}

static void APIENTRY noopCopyMultiTexSubImage3DEXT(GLenum texunit, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLint x, GLint y, GLsizei width, GLsizei height)
{
   (void) texunit; (void) target; (void) level; (void) xoffset; (void) yoffset; (void) zoffset; (void) x; (void) y; (void) width; (void) height;
   noop_warn("glCopyMultiTexSubImage3DEXT");
}

static void APIENTRY noopCopyNamedBufferSubData(GLuint readBuffer, GLuint writeBuffer, GLintptr readOffset, GLintptr writeOffset, GLsizeiptr size)
{
   (void) readBuffer; (void) writeBuffer; (void) readOffset; (void) writeOffset; (void) size;
   noop_warn("glCopyNamedBufferSubData");
}

static void APIENTRY noopCopyPathNV(GLuint resultPath, GLuint srcPath)
{
   (void) resultPath; (void) srcPath;
   noop_warn("glCopyPathNV");
}

static void APIENTRY noopCopyPixels(GLint x, GLint y, GLsizei width, GLsizei height, GLenum type)
{
   (void) x; (void) y; (void) width; (void) height; (void) type;
   noop_warn("glCopyPixels");
}

static void APIENTRY noopCopyTexImage1D(GLenum target, GLint level, GLenum internalformat, GLint x, GLint y, GLsizei width, GLint border)
{
   (void) target; (void) level; (void) internalformat; (void) x; (void) y; (void) width; (void) border;
   noop_warn("glCopyTexImage1D");
}

static void APIENTRY noopCopyTexImage1DEXT(GLenum target, GLint level, GLenum internalformat, GLint x, GLint y, GLsizei width, GLint border)
{
   (void) target; (void) level; (void) internalformat; (void) x; (void) y; (void) width; (void) border;
   noop_warn("glCopyTexImage1DEXT");
}

static void APIENTRY noopCopyTexImage2D(GLenum target, GLint level, GLenum internalformat, GLint x, GLint y, GLsizei width, GLsizei height, GLint border)
{
   (void) target; (void) level; (void) internalformat; (void) x; (void) y; (void) width; (void) height; (void) border;
   noop_warn("glCopyTexImage2D");
}

static void APIENTRY noopCopyTexImage2DEXT(GLenum target, GLint level, GLenum internalformat, GLint x, GLint y, GLsizei width, GLsizei height, GLint border)
{
   (void) target; (void) level; (void) internalformat; (void) x; (void) y; (void) width; (void) height; (void) border;
   noop_warn("glCopyTexImage2DEXT");
}

static void APIENTRY noopCopyTexSubImage1D(GLenum target, GLint level, GLint xoffset, GLint x, GLint y, GLsizei width)
{
   (void) target; (void) level; (void) xoffset; (void) x; (void) y; (void) width;
   noop_warn("glCopyTexSubImage1D");
}

static void APIENTRY noopCopyTexSubImage1DEXT(GLenum target, GLint level, GLint xoffset, GLint x, GLint y, GLsizei width)
{
   (void) target; (void) level; (void) xoffset; (void) x; (void) y; (void) width;
   noop_warn("glCopyTexSubImage1DEXT");
}

static void APIENTRY noopCopyTexSubImage2D(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint x, GLint y, GLsizei width, GLsizei height)
{
   (void) target; (void) level; (void) xoffset; (void) yoffset; (void) x; (void) y; (void) width; (void) height;
   noop_warn("glCopyTexSubImage2D");
}

static void APIENTRY noopCopyTexSubImage2DEXT(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint x, GLint y, GLsizei width, GLsizei height)
{
   (void) target; (void) level; (void) xoffset; (void) yoffset; (void) x; (void) y; (void) width; (void) height;
   noop_warn("glCopyTexSubImage2DEXT");
}

static void APIENTRY noopCopyTexSubImage3D(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLint x, GLint y, GLsizei width, GLsizei height)
{
   (void) target; (void) level; (void) xoffset; (void) yoffset; (void) zoffset; (void) x; (void) y; (void) width; (void) height;
   noop_warn("glCopyTexSubImage3D");
}

static void APIENTRY noopCopyTexSubImage3DEXT(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLint x, GLint y, GLsizei width, GLsizei height)
{
   (void) target; (void) level; (void) xoffset; (void) yoffset; (void) zoffset; (void) x; (void) y; (void) width; (void) height;
   noop_warn("glCopyTexSubImage3DEXT");
}

static void APIENTRY noopCopyTexSubImage3DNV(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLint x, GLint y, GLsizei width, GLsizei height)
{
   (void) target; (void) level; (void) xoffset; (void) yoffset; (void) zoffset; (void) x; (void) y; (void) width; (void) height;
   noop_warn("glCopyTexSubImage3DNV");
}

static void APIENTRY noopCopyTexSubImage3DOES(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLint x, GLint y, GLsizei width, GLsizei height)
{
   (void) target; (void) level; (void) xoffset; (void) yoffset; (void) zoffset; (void) x; (void) y; (void) width; (void) height;
   noop_warn("glCopyTexSubImage3DOES");
}

static void APIENTRY noopCopyTextureImage1DEXT(GLuint texture, GLenum target, GLint level, GLenum internalformat, GLint x, GLint y, GLsizei width, GLint border)
{
   (void) texture; (void) target; (void) level; (void) internalformat; (void) x; (void) y; (void) width; (void) border;
   noop_warn("glCopyTextureImage1DEXT");
}

static void APIENTRY noopCopyTextureImage2DEXT(GLuint texture, GLenum target, GLint level, GLenum internalformat, GLint x, GLint y, GLsizei width, GLsizei height, GLint border)
{
   (void) texture; (void) target; (void) level; (void) internalformat; (void) x; (void) y; (void) width; (void) height; (void) border;
   noop_warn("glCopyTextureImage2DEXT");
}

static void APIENTRY noopCopyTextureLevelsAPPLE(GLuint destinationTexture, GLuint sourceTexture, GLint sourceBaseLevel, GLsizei sourceLevelCount)
{
   (void) destinationTexture; (void) sourceTexture; (void) sourceBaseLevel; (void) sourceLevelCount;
   noop_warn("glCopyTextureLevelsAPPLE");
}

static void APIENTRY noopCopyTextureSubImage1D(GLuint texture, GLint level, GLint xoffset, GLint x, GLint y, GLsizei width)
{
   (void) texture; (void) level; (void) xoffset; (void) x; (void) y; (void) width;
   noop_warn("glCopyTextureSubImage1D");
}

static void APIENTRY noopCopyTextureSubImage1DEXT(GLuint texture, GLenum target, GLint level, GLint xoffset, GLint x, GLint y, GLsizei width)
{
   (void) texture; (void) target; (void) level; (void) xoffset; (void) x; (void) y; (void) width;
   noop_warn("glCopyTextureSubImage1DEXT");
}

static void APIENTRY noopCopyTextureSubImage2D(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint x, GLint y, GLsizei width, GLsizei height)
{
   (void) texture; (void) level; (void) xoffset; (void) yoffset; (void) x; (void) y; (void) width; (void) height;
   noop_warn("glCopyTextureSubImage2D");
}

static void APIENTRY noopCopyTextureSubImage2DEXT(GLuint texture, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint x, GLint y, GLsizei width, GLsizei height)
{
   (void) texture; (void) target; (void) level; (void) xoffset; (void) yoffset; (void) x; (void) y; (void) width; (void) height;
   noop_warn("glCopyTextureSubImage2DEXT");
}

static void APIENTRY noopCopyTextureSubImage3D(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLint x, GLint y, GLsizei width, GLsizei height)
{
   (void) texture; (void) level; (void) xoffset; (void) yoffset; (void) zoffset; (void) x; (void) y; (void) width; (void) height;
   noop_warn("glCopyTextureSubImage3D");
}

static void APIENTRY noopCopyTextureSubImage3DEXT(GLuint texture, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLint x, GLint y, GLsizei width, GLsizei height)
{
   (void) texture; (void) target; (void) level; (void) xoffset; (void) yoffset; (void) zoffset; (void) x; (void) y; (void) width; (void) height;
   noop_warn("glCopyTextureSubImage3DEXT");
}

static void APIENTRY noopCoverFillPathInstancedNV(GLsizei numPaths, GLenum pathNameType, const void *paths, GLuint pathBase, GLenum coverMode, GLenum transformType, const GLfloat *transformValues)
{
   (void) numPaths; (void) pathNameType; (void) paths; (void) pathBase; (void) coverMode; (void) transformType; (void) transformValues;
   noop_warn("glCoverFillPathInstancedNV");
}

static void APIENTRY noopCoverFillPathNV(GLuint path, GLenum coverMode)
{
   (void) path; (void) coverMode;
   noop_warn("glCoverFillPathNV");
}

static void APIENTRY noopCoverStrokePathInstancedNV(GLsizei numPaths, GLenum pathNameType, const void *paths, GLuint pathBase, GLenum coverMode, GLenum transformType, const GLfloat *transformValues)
{
   (void) numPaths; (void) pathNameType; (void) paths; (void) pathBase; (void) coverMode; (void) transformType; (void) transformValues;
   noop_warn("glCoverStrokePathInstancedNV");
}

static void APIENTRY noopCoverStrokePathNV(GLuint path, GLenum coverMode)
{
   (void) path; (void) coverMode;
   noop_warn("glCoverStrokePathNV");
}

static void APIENTRY noopCoverageMaskNV(GLboolean mask)
{
   (void) mask;
   noop_warn("glCoverageMaskNV");
}

static void APIENTRY noopCoverageModulationNV(GLenum components)
{
   (void) components;
   noop_warn("glCoverageModulationNV");
}

static void APIENTRY noopCoverageModulationTableNV(GLsizei n, const GLfloat *v)
{
   (void) n; (void) v;
   noop_warn("glCoverageModulationTableNV");
}

static void APIENTRY noopCoverageOperationNV(GLenum operation)
{
   (void) operation;
   noop_warn("glCoverageOperationNV");
}

static void APIENTRY noopCreateBuffers(GLsizei n, GLuint *buffers)
{
   (void) n; (void) buffers;
   noop_warn("glCreateBuffers");
}

static void APIENTRY noopCreateCommandListsNV(GLsizei n, GLuint *lists)
{
   (void) n; (void) lists;
   noop_warn("glCreateCommandListsNV");
}

static void APIENTRY noopCreateFramebuffers(GLsizei n, GLuint *framebuffers)
{
   (void) n; (void) framebuffers;
   noop_warn("glCreateFramebuffers");
}

static void APIENTRY noopCreateMemoryObjectsEXT(GLsizei n, GLuint *memoryObjects)
{
   (void) n; (void) memoryObjects;
   noop_warn("glCreateMemoryObjectsEXT");
}

static void APIENTRY noopCreatePerfQueryINTEL(GLuint queryId, GLuint *queryHandle)
{
   (void) queryId; (void) queryHandle;
   noop_warn("glCreatePerfQueryINTEL");
}

static GLuint APIENTRY noopCreateProgram(void)
{
   noop_warn("glCreateProgram");
   return (GLuint) 0;
}

static GLhandleARB APIENTRY noopCreateProgramObjectARB(void)
{
   noop_warn("glCreateProgramObjectARB");
   return (GLhandleARB) 0;
}

static void APIENTRY noopCreateProgramPipelines(GLsizei n, GLuint *pipelines)
{
   (void) n; (void) pipelines;
   noop_warn("glCreateProgramPipelines");
}

static GLuint APIENTRY noopCreateProgressFenceNVX(void)
{
   noop_warn("glCreateProgressFenceNVX");
   return (GLuint) 0;
}

static void APIENTRY noopCreateQueries(GLenum target, GLsizei n, GLuint *ids)
{
   (void) target; (void) n; (void) ids;
   noop_warn("glCreateQueries");
}

static void APIENTRY noopCreateRenderbuffers(GLsizei n, GLuint *renderbuffers)
{
   (void) n; (void) renderbuffers;
   noop_warn("glCreateRenderbuffers");
}

static void APIENTRY noopCreateSamplers(GLsizei n, GLuint *samplers)
{
   (void) n; (void) samplers;
   noop_warn("glCreateSamplers");
}

static GLuint APIENTRY noopCreateShader(GLenum type)
{
   (void) type;
   noop_warn("glCreateShader");
   return (GLuint) 0;
}

static GLhandleARB APIENTRY noopCreateShaderObjectARB(GLenum shaderType)
{
   (void) shaderType;
   noop_warn("glCreateShaderObjectARB");
   return (GLhandleARB) 0;
}

static GLuint APIENTRY noopCreateShaderProgramEXT(GLenum type, const GLchar *string)
{
   (void) type; (void) string;
   noop_warn("glCreateShaderProgramEXT");
   return (GLuint) 0;
}

static GLuint APIENTRY noopCreateShaderProgramv(GLenum type, GLsizei count, const GLchar *const *strings)
{
   (void) type; (void) count; (void) strings;
   noop_warn("glCreateShaderProgramv");
   return (GLuint) 0;
}

static GLuint APIENTRY noopCreateShaderProgramvEXT(GLenum type, GLsizei count, const GLchar **strings)
{
   (void) type; (void) count; (void) strings;
   noop_warn("glCreateShaderProgramvEXT");
   return (GLuint) 0;
}

static void APIENTRY noopCreateStatesNV(GLsizei n, GLuint *states)
{
   (void) n; (void) states;
   noop_warn("glCreateStatesNV");
}

static GLsync APIENTRY noopCreateSyncFromCLeventARB(struct _cl_context *context, struct _cl_event *event, GLbitfield flags)
{
   (void) context; (void) event; (void) flags;
   noop_warn("glCreateSyncFromCLeventARB");
   return (GLsync) 0;
}

static void APIENTRY noopCreateTextures(GLenum target, GLsizei n, GLuint *textures)
{
   (void) target; (void) n; (void) textures;
   noop_warn("glCreateTextures");
}

static void APIENTRY noopCreateTransformFeedbacks(GLsizei n, GLuint *ids)
{
   (void) n; (void) ids;
   noop_warn("glCreateTransformFeedbacks");
}

static void APIENTRY noopCreateVertexArrays(GLsizei n, GLuint *arrays)
{
   (void) n; (void) arrays;
   noop_warn("glCreateVertexArrays");
}

static void APIENTRY noopCullFace(GLenum mode)
{
   (void) mode;
   noop_warn("glCullFace");
}

static void APIENTRY noopCullParameterdvEXT(GLenum pname, GLdouble *params)
{
   (void) pname; (void) params;
   noop_warn("glCullParameterdvEXT");
}

static void APIENTRY noopCullParameterfvEXT(GLenum pname, GLfloat *params)
{
   (void) pname; (void) params;
   noop_warn("glCullParameterfvEXT");
}

static void APIENTRY noopCurrentPaletteMatrixARB(GLint index)
{
   (void) index;
   noop_warn("glCurrentPaletteMatrixARB");
}

static void APIENTRY noopCurrentPaletteMatrixOES(GLuint matrixpaletteindex)
{
   (void) matrixpaletteindex;
   noop_warn("glCurrentPaletteMatrixOES");
}

static void APIENTRY noopDebugMessageCallback(GLDEBUGPROC callback, const void *userParam)
{
   (void) callback; (void) userParam;
   noop_warn("glDebugMessageCallback");
}

static void APIENTRY noopDebugMessageCallbackAMD(GLDEBUGPROCAMD callback, void *userParam)
{
   (void) callback; (void) userParam;
   noop_warn("glDebugMessageCallbackAMD");
}

static void APIENTRY noopDebugMessageCallbackARB(GLDEBUGPROCARB callback, const void *userParam)
{
   (void) callback; (void) userParam;
   noop_warn("glDebugMessageCallbackARB");
}

static void APIENTRY noopDebugMessageCallbackKHR(GLDEBUGPROCKHR callback, const void *userParam)
{
   (void) callback; (void) userParam;
   noop_warn("glDebugMessageCallbackKHR");
}

static void APIENTRY noopDebugMessageCallbackOES(GLDEBUGPROC callback, const void *userParam)
{
   (void) callback; (void) userParam;
   noop_warn("glDebugMessageCallbackOES");
}

static void APIENTRY noopDebugMessageControl(GLenum source, GLenum type, GLenum severity, GLsizei count, const GLuint *ids, GLboolean enabled)
{
   (void) source; (void) type; (void) severity; (void) count; (void) ids; (void) enabled;
   noop_warn("glDebugMessageControl");
}

static void APIENTRY noopDebugMessageControlARB(GLenum source, GLenum type, GLenum severity, GLsizei count, const GLuint *ids, GLboolean enabled)
{
   (void) source; (void) type; (void) severity; (void) count; (void) ids; (void) enabled;
   noop_warn("glDebugMessageControlARB");
}

static void APIENTRY noopDebugMessageControlKHR(GLenum source, GLenum type, GLenum severity, GLsizei count, const GLuint *ids, GLboolean enabled)
{
   (void) source; (void) type; (void) severity; (void) count; (void) ids; (void) enabled;
   noop_warn("glDebugMessageControlKHR");
}

static void APIENTRY noopDebugMessageControlOES(GLenum source, GLenum type, GLenum severity, GLsizei count, const GLuint *ids, GLboolean enabled)
{
   (void) source; (void) type; (void) severity; (void) count; (void) ids; (void) enabled;
   noop_warn("glDebugMessageControlOES");
}

static void APIENTRY noopDebugMessageEnableAMD(GLenum category, GLenum severity, GLsizei count, const GLuint *ids, GLboolean enabled)
{
   (void) category; (void) severity; (void) count; (void) ids; (void) enabled;
   noop_warn("glDebugMessageEnableAMD");
}

static void APIENTRY noopDebugMessageInsert(GLenum source, GLenum type, GLuint id, GLenum severity, GLsizei length, const GLchar *buf)
{
   (void) source; (void) type; (void) id; (void) severity; (void) length; (void) buf;
   noop_warn("glDebugMessageInsert");
}

static void APIENTRY noopDebugMessageInsertAMD(GLenum category, GLenum severity, GLuint id, GLsizei length, const GLchar *buf)
{
   (void) category; (void) severity; (void) id; (void) length; (void) buf;
   noop_warn("glDebugMessageInsertAMD");
}

static void APIENTRY noopDebugMessageInsertARB(GLenum source, GLenum type, GLuint id, GLenum severity, GLsizei length, const GLchar *buf)
{
   (void) source; (void) type; (void) id; (void) severity; (void) length; (void) buf;
   noop_warn("glDebugMessageInsertARB");
}

static void APIENTRY noopDebugMessageInsertKHR(GLenum source, GLenum type, GLuint id, GLenum severity, GLsizei length, const GLchar *buf)
{
   (void) source; (void) type; (void) id; (void) severity; (void) length; (void) buf;
   noop_warn("glDebugMessageInsertKHR");
}

static void APIENTRY noopDebugMessageInsertOES(GLenum source, GLenum type, GLuint id, GLenum severity, GLsizei length, const GLchar *buf)
{
   (void) source; (void) type; (void) id; (void) severity; (void) length; (void) buf;
   noop_warn("glDebugMessageInsertOES");
}

static void APIENTRY noopDeformSGIX(GLbitfield mask)
{
   (void) mask;
   noop_warn("glDeformSGIX");
}

static void APIENTRY noopDeformationMap3dSGIX(GLenum target, GLdouble u1, GLdouble u2, GLint ustride, GLint uorder, GLdouble v1, GLdouble v2, GLint vstride, GLint vorder, GLdouble w1, GLdouble w2, GLint wstride, GLint worder, const GLdouble *points)
{
   (void) target; (void) u1; (void) u2; (void) ustride; (void) uorder; (void) v1; (void) v2; (void) vstride; (void) vorder; (void) w1; (void) w2; (void) wstride; (void) worder; (void) points;
   noop_warn("glDeformationMap3dSGIX");
}

static void APIENTRY noopDeformationMap3fSGIX(GLenum target, GLfloat u1, GLfloat u2, GLint ustride, GLint uorder, GLfloat v1, GLfloat v2, GLint vstride, GLint vorder, GLfloat w1, GLfloat w2, GLint wstride, GLint worder, const GLfloat *points)
{
   (void) target; (void) u1; (void) u2; (void) ustride; (void) uorder; (void) v1; (void) v2; (void) vstride; (void) vorder; (void) w1; (void) w2; (void) wstride; (void) worder; (void) points;
   noop_warn("glDeformationMap3fSGIX");
}

static void APIENTRY noopDeleteAsyncMarkersSGIX(GLuint marker, GLsizei range)
{
   (void) marker; (void) range;
   noop_warn("glDeleteAsyncMarkersSGIX");
}

static void APIENTRY noopDeleteBuffers(GLsizei n, const GLuint *buffers)
{
   (void) n; (void) buffers;
   noop_warn("glDeleteBuffers");
}

static void APIENTRY noopDeleteBuffersARB(GLsizei n, const GLuint *buffers)
{
   (void) n; (void) buffers;
   noop_warn("glDeleteBuffersARB");
}

static void APIENTRY noopDeleteCommandListsNV(GLsizei n, const GLuint *lists)
{
   (void) n; (void) lists;
   noop_warn("glDeleteCommandListsNV");
}

static void APIENTRY noopDeleteFencesAPPLE(GLsizei n, const GLuint *fences)
{
   (void) n; (void) fences;
   noop_warn("glDeleteFencesAPPLE");
}

static void APIENTRY noopDeleteFencesNV(GLsizei n, const GLuint *fences)
{
   (void) n; (void) fences;
   noop_warn("glDeleteFencesNV");
}

static void APIENTRY noopDeleteFragmentShaderATI(GLuint id)
{
   (void) id;
   noop_warn("glDeleteFragmentShaderATI");
}

static void APIENTRY noopDeleteFramebuffers(GLsizei n, const GLuint *framebuffers)
{
   (void) n; (void) framebuffers;
   noop_warn("glDeleteFramebuffers");
}

static void APIENTRY noopDeleteFramebuffersEXT(GLsizei n, const GLuint *framebuffers)
{
   (void) n; (void) framebuffers;
   noop_warn("glDeleteFramebuffersEXT");
}

static void APIENTRY noopDeleteFramebuffersOES(GLsizei n, const GLuint *framebuffers)
{
   (void) n; (void) framebuffers;
   noop_warn("glDeleteFramebuffersOES");
}

static void APIENTRY noopDeleteLists(GLuint list, GLsizei range)
{
   (void) list; (void) range;
   noop_warn("glDeleteLists");
}

static void APIENTRY noopDeleteMemoryObjectsEXT(GLsizei n, const GLuint *memoryObjects)
{
   (void) n; (void) memoryObjects;
   noop_warn("glDeleteMemoryObjectsEXT");
}

static void APIENTRY noopDeleteNamedStringARB(GLint namelen, const GLchar *name)
{
   (void) namelen; (void) name;
   noop_warn("glDeleteNamedStringARB");
}

static void APIENTRY noopDeleteNamesAMD(GLenum identifier, GLuint num, const GLuint *names)
{
   (void) identifier; (void) num; (void) names;
   noop_warn("glDeleteNamesAMD");
}

static void APIENTRY noopDeleteObjectARB(GLhandleARB obj)
{
   (void) obj;
   noop_warn("glDeleteObjectARB");
}

static void APIENTRY noopDeleteOcclusionQueriesNV(GLsizei n, const GLuint *ids)
{
   (void) n; (void) ids;
   noop_warn("glDeleteOcclusionQueriesNV");
}

static void APIENTRY noopDeletePathsNV(GLuint path, GLsizei range)
{
   (void) path; (void) range;
   noop_warn("glDeletePathsNV");
}

static void APIENTRY noopDeletePerfMonitorsAMD(GLsizei n, GLuint *monitors)
{
   (void) n; (void) monitors;
   noop_warn("glDeletePerfMonitorsAMD");
}

static void APIENTRY noopDeletePerfQueryINTEL(GLuint queryHandle)
{
   (void) queryHandle;
   noop_warn("glDeletePerfQueryINTEL");
}

static void APIENTRY noopDeleteProgram(GLuint program)
{
   (void) program;
   noop_warn("glDeleteProgram");
}

static void APIENTRY noopDeleteProgramPipelines(GLsizei n, const GLuint *pipelines)
{
   (void) n; (void) pipelines;
   noop_warn("glDeleteProgramPipelines");
}

static void APIENTRY noopDeleteProgramPipelinesEXT(GLsizei n, const GLuint *pipelines)
{
   (void) n; (void) pipelines;
   noop_warn("glDeleteProgramPipelinesEXT");
}

static void APIENTRY noopDeleteProgramsARB(GLsizei n, const GLuint *programs)
{
   (void) n; (void) programs;
   noop_warn("glDeleteProgramsARB");
}

static void APIENTRY noopDeleteProgramsNV(GLsizei n, const GLuint *programs)
{
   (void) n; (void) programs;
   noop_warn("glDeleteProgramsNV");
}

static void APIENTRY noopDeleteQueries(GLsizei n, const GLuint *ids)
{
   (void) n; (void) ids;
   noop_warn("glDeleteQueries");
}

static void APIENTRY noopDeleteQueriesARB(GLsizei n, const GLuint *ids)
{
   (void) n; (void) ids;
   noop_warn("glDeleteQueriesARB");
}

static void APIENTRY noopDeleteQueriesEXT(GLsizei n, const GLuint *ids)
{
   (void) n; (void) ids;
   noop_warn("glDeleteQueriesEXT");
}

static void APIENTRY noopDeleteQueryResourceTagNV(GLsizei n, const GLint *tagIds)
{
   (void) n; (void) tagIds;
   noop_warn("glDeleteQueryResourceTagNV");
}

static void APIENTRY noopDeleteRenderbuffers(GLsizei n, const GLuint *renderbuffers)
{
   (void) n; (void) renderbuffers;
   noop_warn("glDeleteRenderbuffers");
}

static void APIENTRY noopDeleteRenderbuffersEXT(GLsizei n, const GLuint *renderbuffers)
{
   (void) n; (void) renderbuffers;
   noop_warn("glDeleteRenderbuffersEXT");
}

static void APIENTRY noopDeleteRenderbuffersOES(GLsizei n, const GLuint *renderbuffers)
{
   (void) n; (void) renderbuffers;
   noop_warn("glDeleteRenderbuffersOES");
}

static void APIENTRY noopDeleteSamplers(GLsizei count, const GLuint *samplers)
{
   (void) count; (void) samplers;
   noop_warn("glDeleteSamplers");
}

static void APIENTRY noopDeleteSemaphoresEXT(GLsizei n, const GLuint *semaphores)
{
   (void) n; (void) semaphores;
   noop_warn("glDeleteSemaphoresEXT");
}

static void APIENTRY noopDeleteShader(GLuint shader)
{
   (void) shader;
   noop_warn("glDeleteShader");
}

static void APIENTRY noopDeleteStatesNV(GLsizei n, const GLuint *states)
{
   (void) n; (void) states;
   noop_warn("glDeleteStatesNV");
}

static void APIENTRY noopDeleteSync(GLsync sync)
{
   (void) sync;
   noop_warn("glDeleteSync");
}

static void APIENTRY noopDeleteSyncAPPLE(GLsync sync)
{
   (void) sync;
   noop_warn("glDeleteSyncAPPLE");
}

static void APIENTRY noopDeleteTextures(GLsizei n, const GLuint *textures)
{
   (void) n; (void) textures;
   noop_warn("glDeleteTextures");
}

static void APIENTRY noopDeleteTexturesEXT(GLsizei n, const GLuint *textures)
{
   (void) n; (void) textures;
   noop_warn("glDeleteTexturesEXT");
}

static void APIENTRY noopDeleteTransformFeedbacks(GLsizei n, const GLuint *ids)
{
   (void) n; (void) ids;
   noop_warn("glDeleteTransformFeedbacks");
}

static void APIENTRY noopDeleteTransformFeedbacksEXT(GLsizei n, const GLuint *ids)
{
   (void) n; (void) ids;
   noop_warn("glDeleteTransformFeedbacksEXT");
}

static void APIENTRY noopDeleteTransformFeedbacksNV(GLsizei n, const GLuint *ids)
{
   (void) n; (void) ids;
   noop_warn("glDeleteTransformFeedbacksNV");
}

static void APIENTRY noopDeleteVertexArrays(GLsizei n, const GLuint *arrays)
{
   (void) n; (void) arrays;
   noop_warn("glDeleteVertexArrays");
}

static void APIENTRY noopDeleteVertexArraysAPPLE(GLsizei n, const GLuint *arrays)
{
   (void) n; (void) arrays;
   noop_warn("glDeleteVertexArraysAPPLE");
}

static void APIENTRY noopDeleteVertexArraysOES(GLsizei n, const GLuint *arrays)
{
   (void) n; (void) arrays;
   noop_warn("glDeleteVertexArraysOES");
}

static void APIENTRY noopDeleteVertexShaderEXT(GLuint id)
{
   (void) id;
   noop_warn("glDeleteVertexShaderEXT");
}

static void APIENTRY noopDepthBoundsEXT(GLclampd zmin, GLclampd zmax)
{
   (void) zmin; (void) zmax;
   noop_warn("glDepthBoundsEXT");
}

static void APIENTRY noopDepthBoundsdNV(GLdouble zmin, GLdouble zmax)
{
   (void) zmin; (void) zmax;
   noop_warn("glDepthBoundsdNV");
}

static void APIENTRY noopDepthFunc(GLenum func)
{
   (void) func;
   noop_warn("glDepthFunc");
}

static void APIENTRY noopDepthMask(GLboolean flag)
{
   (void) flag;
   noop_warn("glDepthMask");
}

static void APIENTRY noopDepthRange(GLdouble n, GLdouble f)
{
   (void) n; (void) f;
   noop_warn("glDepthRange");
}

static void APIENTRY noopDepthRangeArraydvNV(GLuint first, GLsizei count, const GLdouble *v)
{
   (void) first; (void) count; (void) v;
   noop_warn("glDepthRangeArraydvNV");
}

static void APIENTRY noopDepthRangeArrayfvNV(GLuint first, GLsizei count, const GLfloat *v)
{
   (void) first; (void) count; (void) v;
   noop_warn("glDepthRangeArrayfvNV");
}

static void APIENTRY noopDepthRangeArrayfvOES(GLuint first, GLsizei count, const GLfloat *v)
{
   (void) first; (void) count; (void) v;
   noop_warn("glDepthRangeArrayfvOES");
}

static void APIENTRY noopDepthRangeArrayv(GLuint first, GLsizei count, const GLdouble *v)
{
   (void) first; (void) count; (void) v;
   noop_warn("glDepthRangeArrayv");
}

static void APIENTRY noopDepthRangeIndexed(GLuint index, GLdouble n, GLdouble f)
{
   (void) index; (void) n; (void) f;
   noop_warn("glDepthRangeIndexed");
}

static void APIENTRY noopDepthRangeIndexeddNV(GLuint index, GLdouble n, GLdouble f)
{
   (void) index; (void) n; (void) f;
   noop_warn("glDepthRangeIndexeddNV");
}

static void APIENTRY noopDepthRangeIndexedfNV(GLuint index, GLfloat n, GLfloat f)
{
   (void) index; (void) n; (void) f;
   noop_warn("glDepthRangeIndexedfNV");
}

static void APIENTRY noopDepthRangeIndexedfOES(GLuint index, GLfloat n, GLfloat f)
{
   (void) index; (void) n; (void) f;
   noop_warn("glDepthRangeIndexedfOES");
}

static void APIENTRY noopDepthRangedNV(GLdouble zNear, GLdouble zFar)
{
   (void) zNear; (void) zFar;
   noop_warn("glDepthRangedNV");
}

static void APIENTRY noopDepthRangef(GLfloat n, GLfloat f)
{
   (void) n; (void) f;
   noop_warn("glDepthRangef");
}

static void APIENTRY noopDepthRangefOES(GLclampf n, GLclampf f)
{
   (void) n; (void) f;
   noop_warn("glDepthRangefOES");
}

static void APIENTRY noopDepthRangex(GLfixed n, GLfixed f)
{
   (void) n; (void) f;
   noop_warn("glDepthRangex");
}

static void APIENTRY noopDepthRangexOES(GLfixed n, GLfixed f)
{
   (void) n; (void) f;
   noop_warn("glDepthRangexOES");
}

static void APIENTRY noopDetachObjectARB(GLhandleARB containerObj, GLhandleARB attachedObj)
{
   (void) containerObj; (void) attachedObj;
   noop_warn("glDetachObjectARB");
}

static void APIENTRY noopDetachShader(GLuint program, GLuint shader)
{
   (void) program; (void) shader;
   noop_warn("glDetachShader");
}

static void APIENTRY noopDetailTexFuncSGIS(GLenum target, GLsizei n, const GLfloat *points)
{
   (void) target; (void) n; (void) points;
   noop_warn("glDetailTexFuncSGIS");
}

static void APIENTRY noopDevtoolsCorrelationIdNVX(GLuint64 id)
{
   (void) id;
   noop_warn("glDevtoolsCorrelationIdNVX");
}

static void APIENTRY noopDevtoolsInvokeStreamedCallbackNVX(void *fnptr, void *userdata)
{
   (void) fnptr; (void) userdata;
   noop_warn("glDevtoolsInvokeStreamedCallbackNVX");
}

static void APIENTRY noopDisable(GLenum cap)
{
   (void) cap;
   noop_warn("glDisable");
}

static void APIENTRY noopDisableClientState(GLenum array)
{
   (void) array;
   noop_warn("glDisableClientState");
}

static void APIENTRY noopDisableClientStateIndexedEXT(GLenum array, GLuint index)
{
   (void) array; (void) index;
   noop_warn("glDisableClientStateIndexedEXT");
}

static void APIENTRY noopDisableClientStateiEXT(GLenum array, GLuint index)
{
   (void) array; (void) index;
   noop_warn("glDisableClientStateiEXT");
}

static void APIENTRY noopDisableDriverControlQCOM(GLuint driverControl)
{
   (void) driverControl;
   noop_warn("glDisableDriverControlQCOM");
}

static void APIENTRY noopDisableIndexedEXT(GLenum target, GLuint index)
{
   (void) target; (void) index;
   noop_warn("glDisableIndexedEXT");
}

static void APIENTRY noopDisableVariantClientStateEXT(GLuint id)
{
   (void) id;
   noop_warn("glDisableVariantClientStateEXT");
}

static void APIENTRY noopDisableVertexArrayAttrib(GLuint vaobj, GLuint index)
{
   (void) vaobj; (void) index;
   noop_warn("glDisableVertexArrayAttrib");
}

static void APIENTRY noopDisableVertexArrayAttribEXT(GLuint vaobj, GLuint index)
{
   (void) vaobj; (void) index;
   noop_warn("glDisableVertexArrayAttribEXT");
}

static void APIENTRY noopDisableVertexArrayEXT(GLuint vaobj, GLenum array)
{
   (void) vaobj; (void) array;
   noop_warn("glDisableVertexArrayEXT");
}

static void APIENTRY noopDisableVertexAttribAPPLE(GLuint index, GLenum pname)
{
   (void) index; (void) pname;
   noop_warn("glDisableVertexAttribAPPLE");
}

static void APIENTRY noopDisableVertexAttribArray(GLuint index)
{
   (void) index;
   noop_warn("glDisableVertexAttribArray");
}

static void APIENTRY noopDisableVertexAttribArrayARB(GLuint index)
{
   (void) index;
   noop_warn("glDisableVertexAttribArrayARB");
}

static void APIENTRY noopDisablei(GLenum target, GLuint index)
{
   (void) target; (void) index;
   noop_warn("glDisablei");
}

static void APIENTRY noopDisableiEXT(GLenum target, GLuint index)
{
   (void) target; (void) index;
   noop_warn("glDisableiEXT");
}

static void APIENTRY noopDisableiNV(GLenum target, GLuint index)
{
   (void) target; (void) index;
   noop_warn("glDisableiNV");
}

static void APIENTRY noopDisableiOES(GLenum target, GLuint index)
{
   (void) target; (void) index;
   noop_warn("glDisableiOES");
}

static void APIENTRY noopDiscardFramebufferEXT(GLenum target, GLsizei numAttachments, const GLenum *attachments)
{
   (void) target; (void) numAttachments; (void) attachments;
   noop_warn("glDiscardFramebufferEXT");
}

static void APIENTRY noopDispatchCompute(GLuint num_groups_x, GLuint num_groups_y, GLuint num_groups_z)
{
   (void) num_groups_x; (void) num_groups_y; (void) num_groups_z;
   noop_warn("glDispatchCompute");
}

static void APIENTRY noopDispatchComputeGroupSizeARB(GLuint num_groups_x, GLuint num_groups_y, GLuint num_groups_z, GLuint group_size_x, GLuint group_size_y, GLuint group_size_z)
{
   (void) num_groups_x; (void) num_groups_y; (void) num_groups_z; (void) group_size_x; (void) group_size_y; (void) group_size_z;
   noop_warn("glDispatchComputeGroupSizeARB");
}

static void APIENTRY noopDispatchComputeIndirect(GLintptr indirect)
{
   (void) indirect;
   noop_warn("glDispatchComputeIndirect");
}

static void APIENTRY noopDrawArrays(GLenum mode, GLint first, GLsizei count)
{
   (void) mode; (void) first; (void) count;
   noop_warn("glDrawArrays");
}

static void APIENTRY noopDrawArraysEXT(GLenum mode, GLint first, GLsizei count)
{
   (void) mode; (void) first; (void) count;
   noop_warn("glDrawArraysEXT");
}

static void APIENTRY noopDrawArraysIndirect(GLenum mode, const void *indirect)
{
   (void) mode; (void) indirect;
   noop_warn("glDrawArraysIndirect");
}

static void APIENTRY noopDrawArraysInstanced(GLenum mode, GLint first, GLsizei count, GLsizei instancecount)
{
   (void) mode; (void) first; (void) count; (void) instancecount;
   noop_warn("glDrawArraysInstanced");
}

static void APIENTRY noopDrawArraysInstancedANGLE(GLenum mode, GLint first, GLsizei count, GLsizei primcount)
{
   (void) mode; (void) first; (void) count; (void) primcount;
   noop_warn("glDrawArraysInstancedANGLE");
}

static void APIENTRY noopDrawArraysInstancedARB(GLenum mode, GLint first, GLsizei count, GLsizei primcount)
{
   (void) mode; (void) first; (void) count; (void) primcount;
   noop_warn("glDrawArraysInstancedARB");
}

static void APIENTRY noopDrawArraysInstancedBaseInstance(GLenum mode, GLint first, GLsizei count, GLsizei instancecount, GLuint baseinstance)
{
   (void) mode; (void) first; (void) count; (void) instancecount; (void) baseinstance;
   noop_warn("glDrawArraysInstancedBaseInstance");
}

static void APIENTRY noopDrawArraysInstancedBaseInstanceEXT(GLenum mode, GLint first, GLsizei count, GLsizei instancecount, GLuint baseinstance)
{
   (void) mode; (void) first; (void) count; (void) instancecount; (void) baseinstance;
   noop_warn("glDrawArraysInstancedBaseInstanceEXT");
}

static void APIENTRY noopDrawArraysInstancedEXT(GLenum mode, GLint start, GLsizei count, GLsizei primcount)
{
   (void) mode; (void) start; (void) count; (void) primcount;
   noop_warn("glDrawArraysInstancedEXT");
}

static void APIENTRY noopDrawArraysInstancedNV(GLenum mode, GLint first, GLsizei count, GLsizei primcount)
{
   (void) mode; (void) first; (void) count; (void) primcount;
   noop_warn("glDrawArraysInstancedNV");
}

static void APIENTRY noopDrawBuffer(GLenum buf)
{
   (void) buf;
   noop_warn("glDrawBuffer");
}

static void APIENTRY noopDrawBuffers(GLsizei n, const GLenum *bufs)
{
   (void) n; (void) bufs;
   noop_warn("glDrawBuffers");
}

static void APIENTRY noopDrawBuffersARB(GLsizei n, const GLenum *bufs)
{
   (void) n; (void) bufs;
   noop_warn("glDrawBuffersARB");
}

static void APIENTRY noopDrawBuffersATI(GLsizei n, const GLenum *bufs)
{
   (void) n; (void) bufs;
   noop_warn("glDrawBuffersATI");
}

static void APIENTRY noopDrawBuffersEXT(GLsizei n, const GLenum *bufs)
{
   (void) n; (void) bufs;
   noop_warn("glDrawBuffersEXT");
}

static void APIENTRY noopDrawBuffersIndexedEXT(GLint n, const GLenum *location, const GLint *indices)
{
   (void) n; (void) location; (void) indices;
   noop_warn("glDrawBuffersIndexedEXT");
}

static void APIENTRY noopDrawBuffersNV(GLsizei n, const GLenum *bufs)
{
   (void) n; (void) bufs;
   noop_warn("glDrawBuffersNV");
}

static void APIENTRY noopDrawCommandsAddressNV(GLenum primitiveMode, const GLuint64 *indirects, const GLsizei *sizes, GLuint count)
{
   (void) primitiveMode; (void) indirects; (void) sizes; (void) count;
   noop_warn("glDrawCommandsAddressNV");
}

static void APIENTRY noopDrawCommandsNV(GLenum primitiveMode, GLuint buffer, const GLintptr *indirects, const GLsizei *sizes, GLuint count)
{
   (void) primitiveMode; (void) buffer; (void) indirects; (void) sizes; (void) count;
   noop_warn("glDrawCommandsNV");
}

static void APIENTRY noopDrawCommandsStatesAddressNV(const GLuint64 *indirects, const GLsizei *sizes, const GLuint *states, const GLuint *fbos, GLuint count)
{
   (void) indirects; (void) sizes; (void) states; (void) fbos; (void) count;
   noop_warn("glDrawCommandsStatesAddressNV");
}

static void APIENTRY noopDrawCommandsStatesNV(GLuint buffer, const GLintptr *indirects, const GLsizei *sizes, const GLuint *states, const GLuint *fbos, GLuint count)
{
   (void) buffer; (void) indirects; (void) sizes; (void) states; (void) fbos; (void) count;
   noop_warn("glDrawCommandsStatesNV");
}

static void APIENTRY noopDrawElementArrayAPPLE(GLenum mode, GLint first, GLsizei count)
{
   (void) mode; (void) first; (void) count;
   noop_warn("glDrawElementArrayAPPLE");
}

static void APIENTRY noopDrawElementArrayATI(GLenum mode, GLsizei count)
{
   (void) mode; (void) count;
   noop_warn("glDrawElementArrayATI");
}

static void APIENTRY noopDrawElements(GLenum mode, GLsizei count, GLenum type, const void *indices)
{
   (void) mode; (void) count; (void) type; (void) indices;
   noop_warn("glDrawElements");
}

static void APIENTRY noopDrawElementsBaseVertex(GLenum mode, GLsizei count, GLenum type, const void *indices, GLint basevertex)
{
   (void) mode; (void) count; (void) type; (void) indices; (void) basevertex;
   noop_warn("glDrawElementsBaseVertex");
}

static void APIENTRY noopDrawElementsBaseVertexEXT(GLenum mode, GLsizei count, GLenum type, const void *indices, GLint basevertex)
{
   (void) mode; (void) count; (void) type; (void) indices; (void) basevertex;
   noop_warn("glDrawElementsBaseVertexEXT");
}

static void APIENTRY noopDrawElementsBaseVertexOES(GLenum mode, GLsizei count, GLenum type, const void *indices, GLint basevertex)
{
   (void) mode; (void) count; (void) type; (void) indices; (void) basevertex;
   noop_warn("glDrawElementsBaseVertexOES");
}

static void APIENTRY noopDrawElementsIndirect(GLenum mode, GLenum type, const void *indirect)
{
   (void) mode; (void) type; (void) indirect;
   noop_warn("glDrawElementsIndirect");
}

static void APIENTRY noopDrawElementsInstanced(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei instancecount)
{
   (void) mode; (void) count; (void) type; (void) indices; (void) instancecount;
   noop_warn("glDrawElementsInstanced");
}

static void APIENTRY noopDrawElementsInstancedANGLE(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei primcount)
{
   (void) mode; (void) count; (void) type; (void) indices; (void) primcount;
   noop_warn("glDrawElementsInstancedANGLE");
}

static void APIENTRY noopDrawElementsInstancedARB(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei primcount)
{
   (void) mode; (void) count; (void) type; (void) indices; (void) primcount;
   noop_warn("glDrawElementsInstancedARB");
}

static void APIENTRY noopDrawElementsInstancedBaseInstance(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei instancecount, GLuint baseinstance)
{
   (void) mode; (void) count; (void) type; (void) indices; (void) instancecount; (void) baseinstance;
   noop_warn("glDrawElementsInstancedBaseInstance");
}

static void APIENTRY noopDrawElementsInstancedBaseInstanceEXT(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei instancecount, GLuint baseinstance)
{
   (void) mode; (void) count; (void) type; (void) indices; (void) instancecount; (void) baseinstance;
   noop_warn("glDrawElementsInstancedBaseInstanceEXT");
}

static void APIENTRY noopDrawElementsInstancedBaseVertex(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei instancecount, GLint basevertex)
{
   (void) mode; (void) count; (void) type; (void) indices; (void) instancecount; (void) basevertex;
   noop_warn("glDrawElementsInstancedBaseVertex");
}

static void APIENTRY noopDrawElementsInstancedBaseVertexBaseInstance(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei instancecount, GLint basevertex, GLuint baseinstance)
{
   (void) mode; (void) count; (void) type; (void) indices; (void) instancecount; (void) basevertex; (void) baseinstance;
   noop_warn("glDrawElementsInstancedBaseVertexBaseInstance");
}

static void APIENTRY noopDrawElementsInstancedBaseVertexBaseInstanceEXT(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei instancecount, GLint basevertex, GLuint baseinstance)
{
   (void) mode; (void) count; (void) type; (void) indices; (void) instancecount; (void) basevertex; (void) baseinstance;
   noop_warn("glDrawElementsInstancedBaseVertexBaseInstanceEXT");
}

static void APIENTRY noopDrawElementsInstancedBaseVertexEXT(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei instancecount, GLint basevertex)
{
   (void) mode; (void) count; (void) type; (void) indices; (void) instancecount; (void) basevertex;
   noop_warn("glDrawElementsInstancedBaseVertexEXT");
}

static void APIENTRY noopDrawElementsInstancedBaseVertexOES(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei instancecount, GLint basevertex)
{
   (void) mode; (void) count; (void) type; (void) indices; (void) instancecount; (void) basevertex;
   noop_warn("glDrawElementsInstancedBaseVertexOES");
}

static void APIENTRY noopDrawElementsInstancedEXT(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei primcount)
{
   (void) mode; (void) count; (void) type; (void) indices; (void) primcount;
   noop_warn("glDrawElementsInstancedEXT");
}

static void APIENTRY noopDrawElementsInstancedNV(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei primcount)
{
   (void) mode; (void) count; (void) type; (void) indices; (void) primcount;
   noop_warn("glDrawElementsInstancedNV");
}

static void APIENTRY noopDrawMeshArraysSUN(GLenum mode, GLint first, GLsizei count, GLsizei width)
{
   (void) mode; (void) first; (void) count; (void) width;
   noop_warn("glDrawMeshArraysSUN");
}

static void APIENTRY noopDrawMeshNV(GLenum mode, GLsizei count, GLenum type, GLsizei stride, const void *indicesTexCoord, const void *indicesNormal, const void *indicesVertex)
{
   (void) mode; (void) count; (void) type; (void) stride; (void) indicesTexCoord; (void) indicesNormal; (void) indicesVertex;
   noop_warn("glDrawMeshNV");
}

static void APIENTRY noopDrawMeshTasksIndirectNV(GLintptr indirect)
{
   (void) indirect;
   noop_warn("glDrawMeshTasksIndirectNV");
}

static void APIENTRY noopDrawMeshTasksNV(GLuint first, GLuint count)
{
   (void) first; (void) count;
   noop_warn("glDrawMeshTasksNV");
}

static void APIENTRY noopDrawPixels(GLsizei width, GLsizei height, GLenum format, GLenum type, const void *pixels)
{
   (void) width; (void) height; (void) format; (void) type; (void) pixels;
   noop_warn("glDrawPixels");
}

static void APIENTRY noopDrawRangeElementArrayAPPLE(GLenum mode, GLuint start, GLuint end, GLint first, GLsizei count)
{
   (void) mode; (void) start; (void) end; (void) first; (void) count;
   noop_warn("glDrawRangeElementArrayAPPLE");
}

static void APIENTRY noopDrawRangeElementArrayATI(GLenum mode, GLuint start, GLuint end, GLsizei count)
{
   (void) mode; (void) start; (void) end; (void) count;
   noop_warn("glDrawRangeElementArrayATI");
}

static void APIENTRY noopDrawRangeElements(GLenum mode, GLuint start, GLuint end, GLsizei count, GLenum type, const void *indices)
{
   (void) mode; (void) start; (void) end; (void) count; (void) type; (void) indices;
   noop_warn("glDrawRangeElements");
}

static void APIENTRY noopDrawRangeElementsBaseVertex(GLenum mode, GLuint start, GLuint end, GLsizei count, GLenum type, const void *indices, GLint basevertex)
{
   (void) mode; (void) start; (void) end; (void) count; (void) type; (void) indices; (void) basevertex;
   noop_warn("glDrawRangeElementsBaseVertex");
}

static void APIENTRY noopDrawRangeElementsBaseVertexEXT(GLenum mode, GLuint start, GLuint end, GLsizei count, GLenum type, const void *indices, GLint basevertex)
{
   (void) mode; (void) start; (void) end; (void) count; (void) type; (void) indices; (void) basevertex;
   noop_warn("glDrawRangeElementsBaseVertexEXT");
}

static void APIENTRY noopDrawRangeElementsBaseVertexOES(GLenum mode, GLuint start, GLuint end, GLsizei count, GLenum type, const void *indices, GLint basevertex)
{
   (void) mode; (void) start; (void) end; (void) count; (void) type; (void) indices; (void) basevertex;
   noop_warn("glDrawRangeElementsBaseVertexOES");
}

static void APIENTRY noopDrawRangeElementsEXT(GLenum mode, GLuint start, GLuint end, GLsizei count, GLenum type, const void *indices)
{
   (void) mode; (void) start; (void) end; (void) count; (void) type; (void) indices;
   noop_warn("glDrawRangeElementsEXT");
}

static void APIENTRY noopDrawTexfOES(GLfloat x, GLfloat y, GLfloat z, GLfloat width, GLfloat height)
{
   (void) x; (void) y; (void) z; (void) width; (void) height;
   noop_warn("glDrawTexfOES");
}

static void APIENTRY noopDrawTexfvOES(const GLfloat *coords)
{
   (void) coords;
   noop_warn("glDrawTexfvOES");
}

static void APIENTRY noopDrawTexiOES(GLint x, GLint y, GLint z, GLint width, GLint height)
{
   (void) x; (void) y; (void) z; (void) width; (void) height;
   noop_warn("glDrawTexiOES");
}

static void APIENTRY noopDrawTexivOES(const GLint *coords)
{
   (void) coords;
   noop_warn("glDrawTexivOES");
}

static void APIENTRY noopDrawTexsOES(GLshort x, GLshort y, GLshort z, GLshort width, GLshort height)
{
   (void) x; (void) y; (void) z; (void) width; (void) height;
   noop_warn("glDrawTexsOES");
}

static void APIENTRY noopDrawTexsvOES(const GLshort *coords)
{
   (void) coords;
   noop_warn("glDrawTexsvOES");
}

static void APIENTRY noopDrawTextureNV(GLuint texture, GLuint sampler, GLfloat x0, GLfloat y0, GLfloat x1, GLfloat y1, GLfloat z, GLfloat s0, GLfloat t0, GLfloat s1, GLfloat t1)
{
   (void) texture; (void) sampler; (void) x0; (void) y0; (void) x1; (void) y1; (void) z; (void) s0; (void) t0; (void) s1; (void) t1;
   noop_warn("glDrawTextureNV");
}

static void APIENTRY noopDrawTexxOES(GLfixed x, GLfixed y, GLfixed z, GLfixed width, GLfixed height)
{
   (void) x; (void) y; (void) z; (void) width; (void) height;
   noop_warn("glDrawTexxOES");
}

static void APIENTRY noopDrawTexxvOES(const GLfixed *coords)
{
   (void) coords;
   noop_warn("glDrawTexxvOES");
}

static void APIENTRY noopDrawTransformFeedback(GLenum mode, GLuint id)
{
   (void) mode; (void) id;
   noop_warn("glDrawTransformFeedback");
}

static void APIENTRY noopDrawTransformFeedbackEXT(GLenum mode, GLuint id)
{
   (void) mode; (void) id;
   noop_warn("glDrawTransformFeedbackEXT");
}

static void APIENTRY noopDrawTransformFeedbackInstanced(GLenum mode, GLuint id, GLsizei instancecount)
{
   (void) mode; (void) id; (void) instancecount;
   noop_warn("glDrawTransformFeedbackInstanced");
}

static void APIENTRY noopDrawTransformFeedbackInstancedEXT(GLenum mode, GLuint id, GLsizei instancecount)
{
   (void) mode; (void) id; (void) instancecount;
   noop_warn("glDrawTransformFeedbackInstancedEXT");
}

static void APIENTRY noopDrawTransformFeedbackNV(GLenum mode, GLuint id)
{
   (void) mode; (void) id;
   noop_warn("glDrawTransformFeedbackNV");
}

static void APIENTRY noopDrawTransformFeedbackStream(GLenum mode, GLuint id, GLuint stream)
{
   (void) mode; (void) id; (void) stream;
   noop_warn("glDrawTransformFeedbackStream");
}

static void APIENTRY noopDrawTransformFeedbackStreamInstanced(GLenum mode, GLuint id, GLuint stream, GLsizei instancecount)
{
   (void) mode; (void) id; (void) stream; (void) instancecount;
   noop_warn("glDrawTransformFeedbackStreamInstanced");
}

static void APIENTRY noopDrawVkImageNV(GLuint64 vkImage, GLuint sampler, GLfloat x0, GLfloat y0, GLfloat x1, GLfloat y1, GLfloat z, GLfloat s0, GLfloat t0, GLfloat s1, GLfloat t1)
{
   (void) vkImage; (void) sampler; (void) x0; (void) y0; (void) x1; (void) y1; (void) z; (void) s0; (void) t0; (void) s1; (void) t1;
   noop_warn("glDrawVkImageNV");
}

static void APIENTRY noopEGLImageTargetRenderbufferStorageOES(GLenum target, GLeglImageOES image)
{
   (void) target; (void) image;
   noop_warn("glEGLImageTargetRenderbufferStorageOES");
}

static void APIENTRY noopEGLImageTargetTexStorageEXT(GLenum target, GLeglImageOES image, const GLint *attrib_list)
{
   (void) target; (void) image; (void) attrib_list;
   noop_warn("glEGLImageTargetTexStorageEXT");
}

static void APIENTRY noopEGLImageTargetTexture2DOES(GLenum target, GLeglImageOES image)
{
   (void) target; (void) image;
   noop_warn("glEGLImageTargetTexture2DOES");
}

static void APIENTRY noopEGLImageTargetTextureStorageEXT(GLuint texture, GLeglImageOES image, const GLint *attrib_list)
{
   (void) texture; (void) image; (void) attrib_list;
   noop_warn("glEGLImageTargetTextureStorageEXT");
}

static void APIENTRY noopEdgeFlag(GLboolean flag)
{
   (void) flag;
   noop_warn("glEdgeFlag");
}

static void APIENTRY noopEdgeFlagFormatNV(GLsizei stride)
{
   (void) stride;
   noop_warn("glEdgeFlagFormatNV");
}

static void APIENTRY noopEdgeFlagPointer(GLsizei stride, const void *pointer)
{
   (void) stride; (void) pointer;
   noop_warn("glEdgeFlagPointer");
}

static void APIENTRY noopEdgeFlagPointerEXT(GLsizei stride, GLsizei count, const GLboolean *pointer)
{
   (void) stride; (void) count; (void) pointer;
   noop_warn("glEdgeFlagPointerEXT");
}

static void APIENTRY noopEdgeFlagPointerListIBM(GLint stride, const GLboolean **pointer, GLint ptrstride)
{
   (void) stride; (void) pointer; (void) ptrstride;
   noop_warn("glEdgeFlagPointerListIBM");
}

static void APIENTRY noopEdgeFlagv(const GLboolean *flag)
{
   (void) flag;
   noop_warn("glEdgeFlagv");
}

static void APIENTRY noopElementPointerAPPLE(GLenum type, const void *pointer)
{
   (void) type; (void) pointer;
   noop_warn("glElementPointerAPPLE");
}

static void APIENTRY noopElementPointerATI(GLenum type, const void *pointer)
{
   (void) type; (void) pointer;
   noop_warn("glElementPointerATI");
}

static void APIENTRY noopEnable(GLenum cap)
{
   (void) cap;
   noop_warn("glEnable");
}

static void APIENTRY noopEnableClientState(GLenum array)
{
   (void) array;
   noop_warn("glEnableClientState");
}

static void APIENTRY noopEnableClientStateIndexedEXT(GLenum array, GLuint index)
{
   (void) array; (void) index;
   noop_warn("glEnableClientStateIndexedEXT");
}

static void APIENTRY noopEnableClientStateiEXT(GLenum array, GLuint index)
{
   (void) array; (void) index;
   noop_warn("glEnableClientStateiEXT");
}

static void APIENTRY noopEnableDriverControlQCOM(GLuint driverControl)
{
   (void) driverControl;
   noop_warn("glEnableDriverControlQCOM");
}

static void APIENTRY noopEnableIndexedEXT(GLenum target, GLuint index)
{
   (void) target; (void) index;
   noop_warn("glEnableIndexedEXT");
}

static void APIENTRY noopEnableVariantClientStateEXT(GLuint id)
{
   (void) id;
   noop_warn("glEnableVariantClientStateEXT");
}

static void APIENTRY noopEnableVertexArrayAttrib(GLuint vaobj, GLuint index)
{
   (void) vaobj; (void) index;
   noop_warn("glEnableVertexArrayAttrib");
}

static void APIENTRY noopEnableVertexArrayAttribEXT(GLuint vaobj, GLuint index)
{
   (void) vaobj; (void) index;
   noop_warn("glEnableVertexArrayAttribEXT");
}

static void APIENTRY noopEnableVertexArrayEXT(GLuint vaobj, GLenum array)
{
   (void) vaobj; (void) array;
   noop_warn("glEnableVertexArrayEXT");
}

static void APIENTRY noopEnableVertexAttribAPPLE(GLuint index, GLenum pname)
{
   (void) index; (void) pname;
   noop_warn("glEnableVertexAttribAPPLE");
}

static void APIENTRY noopEnableVertexAttribArray(GLuint index)
{
   (void) index;
   noop_warn("glEnableVertexAttribArray");
}

static void APIENTRY noopEnableVertexAttribArrayARB(GLuint index)
{
   (void) index;
   noop_warn("glEnableVertexAttribArrayARB");
}

static void APIENTRY noopEnablei(GLenum target, GLuint index)
{
   (void) target; (void) index;
   noop_warn("glEnablei");
}

static void APIENTRY noopEnableiEXT(GLenum target, GLuint index)
{
   (void) target; (void) index;
   noop_warn("glEnableiEXT");
}

static void APIENTRY noopEnableiNV(GLenum target, GLuint index)
{
   (void) target; (void) index;
   noop_warn("glEnableiNV");
}

static void APIENTRY noopEnableiOES(GLenum target, GLuint index)
{
   (void) target; (void) index;
   noop_warn("glEnableiOES");
}

static void APIENTRY noopEnd(void)
{
   noop_warn("glEnd");
}

static void APIENTRY noopEndConditionalRender(void)
{
   noop_warn("glEndConditionalRender");
}

static void APIENTRY noopEndConditionalRenderNV(void)
{
   noop_warn("glEndConditionalRenderNV");
}

static void APIENTRY noopEndConditionalRenderNVX(void)
{
   noop_warn("glEndConditionalRenderNVX");
}

static void APIENTRY noopEndFragmentShaderATI(void)
{
   noop_warn("glEndFragmentShaderATI");
}

static void APIENTRY noopEndList(void)
{
   noop_warn("glEndList");
}

static void APIENTRY noopEndOcclusionQueryNV(void)
{
   noop_warn("glEndOcclusionQueryNV");
}

static void APIENTRY noopEndPerfMonitorAMD(GLuint monitor)
{
   (void) monitor;
   noop_warn("glEndPerfMonitorAMD");
}

static void APIENTRY noopEndPerfQueryINTEL(GLuint queryHandle)
{
   (void) queryHandle;
   noop_warn("glEndPerfQueryINTEL");
}

static void APIENTRY noopEndQuery(GLenum target)
{
   (void) target;
   noop_warn("glEndQuery");
}

static void APIENTRY noopEndQueryARB(GLenum target)
{
   (void) target;
   noop_warn("glEndQueryARB");
}

static void APIENTRY noopEndQueryEXT(GLenum target)
{
   (void) target;
   noop_warn("glEndQueryEXT");
}

static void APIENTRY noopEndQueryIndexed(GLenum target, GLuint index)
{
   (void) target; (void) index;
   noop_warn("glEndQueryIndexed");
}

static void APIENTRY noopEndTilingQCOM(GLbitfield preserveMask)
{
   (void) preserveMask;
   noop_warn("glEndTilingQCOM");
}

static void APIENTRY noopEndTransformFeedback(void)
{
   noop_warn("glEndTransformFeedback");
}

static void APIENTRY noopEndTransformFeedbackEXT(void)
{
   noop_warn("glEndTransformFeedbackEXT");
}

static void APIENTRY noopEndTransformFeedbackNV(void)
{
   noop_warn("glEndTransformFeedbackNV");
}

static void APIENTRY noopEndVertexShaderEXT(void)
{
   noop_warn("glEndVertexShaderEXT");
}

static void APIENTRY noopEndVideoCaptureNV(GLuint video_capture_slot)
{
   (void) video_capture_slot;
   noop_warn("glEndVideoCaptureNV");
}

static void APIENTRY noopEvalCoord1d(GLdouble u)
{
   (void) u;
   noop_warn("glEvalCoord1d");
}

static void APIENTRY noopEvalCoord1dv(const GLdouble *u)
{
   (void) u;
   noop_warn("glEvalCoord1dv");
}

static void APIENTRY noopEvalCoord1f(GLfloat u)
{
   (void) u;
   noop_warn("glEvalCoord1f");
}

static void APIENTRY noopEvalCoord1fv(const GLfloat *u)
{
   (void) u;
   noop_warn("glEvalCoord1fv");
}

static void APIENTRY noopEvalCoord1xOES(GLfixed u)
{
   (void) u;
   noop_warn("glEvalCoord1xOES");
}

static void APIENTRY noopEvalCoord1xvOES(const GLfixed *coords)
{
   (void) coords;
   noop_warn("glEvalCoord1xvOES");
}

static void APIENTRY noopEvalCoord2d(GLdouble u, GLdouble v)
{
   (void) u; (void) v;
   noop_warn("glEvalCoord2d");
}

static void APIENTRY noopEvalCoord2dv(const GLdouble *u)
{
   (void) u;
   noop_warn("glEvalCoord2dv");
}

static void APIENTRY noopEvalCoord2f(GLfloat u, GLfloat v)
{
   (void) u; (void) v;
   noop_warn("glEvalCoord2f");
}

static void APIENTRY noopEvalCoord2fv(const GLfloat *u)
{
   (void) u;
   noop_warn("glEvalCoord2fv");
}

static void APIENTRY noopEvalCoord2xOES(GLfixed u, GLfixed v)
{
   (void) u; (void) v;
   noop_warn("glEvalCoord2xOES");
}

static void APIENTRY noopEvalCoord2xvOES(const GLfixed *coords)
{
   (void) coords;
   noop_warn("glEvalCoord2xvOES");
}

static void APIENTRY noopEvalMapsNV(GLenum target, GLenum mode)
{
   (void) target; (void) mode;
   noop_warn("glEvalMapsNV");
}

static void APIENTRY noopEvalMesh1(GLenum mode, GLint i1, GLint i2)
{
   (void) mode; (void) i1; (void) i2;
   noop_warn("glEvalMesh1");
}

static void APIENTRY noopEvalMesh2(GLenum mode, GLint i1, GLint i2, GLint j1, GLint j2)
{
   (void) mode; (void) i1; (void) i2; (void) j1; (void) j2;
   noop_warn("glEvalMesh2");
}

static void APIENTRY noopEvalPoint1(GLint i)
{
   (void) i;
   noop_warn("glEvalPoint1");
}

static void APIENTRY noopEvalPoint2(GLint i, GLint j)
{
   (void) i; (void) j;
   noop_warn("glEvalPoint2");
}

static void APIENTRY noopEvaluateDepthValuesARB(void)
{
   noop_warn("glEvaluateDepthValuesARB");
}

static void APIENTRY noopExecuteProgramNV(GLenum target, GLuint id, const GLfloat *params)
{
   (void) target; (void) id; (void) params;
   noop_warn("glExecuteProgramNV");
}

static void APIENTRY noopExtGetBufferPointervQCOM(GLenum target, void **params)
{
   (void) target; (void) params;
   noop_warn("glExtGetBufferPointervQCOM");
}

static void APIENTRY noopExtGetBuffersQCOM(GLuint *buffers, GLint maxBuffers, GLint *numBuffers)
{
   (void) buffers; (void) maxBuffers; (void) numBuffers;
   noop_warn("glExtGetBuffersQCOM");
}

static void APIENTRY noopExtGetFramebuffersQCOM(GLuint *framebuffers, GLint maxFramebuffers, GLint *numFramebuffers)
{
   (void) framebuffers; (void) maxFramebuffers; (void) numFramebuffers;
   noop_warn("glExtGetFramebuffersQCOM");
}

static void APIENTRY noopExtGetProgramBinarySourceQCOM(GLuint program, GLenum shadertype, GLchar *source, GLint *length)
{
   (void) program; (void) shadertype; (void) source; (void) length;
   noop_warn("glExtGetProgramBinarySourceQCOM");
}

static void APIENTRY noopExtGetProgramsQCOM(GLuint *programs, GLint maxPrograms, GLint *numPrograms)
{
   (void) programs; (void) maxPrograms; (void) numPrograms;
   noop_warn("glExtGetProgramsQCOM");
}

static void APIENTRY noopExtGetRenderbuffersQCOM(GLuint *renderbuffers, GLint maxRenderbuffers, GLint *numRenderbuffers)
{
   (void) renderbuffers; (void) maxRenderbuffers; (void) numRenderbuffers;
   noop_warn("glExtGetRenderbuffersQCOM");
}

static void APIENTRY noopExtGetShadersQCOM(GLuint *shaders, GLint maxShaders, GLint *numShaders)
{
   (void) shaders; (void) maxShaders; (void) numShaders;
   noop_warn("glExtGetShadersQCOM");
}

static void APIENTRY noopExtGetTexLevelParameterivQCOM(GLuint texture, GLenum face, GLint level, GLenum pname, GLint *params)
{
   (void) texture; (void) face; (void) level; (void) pname; (void) params;
   noop_warn("glExtGetTexLevelParameterivQCOM");
}

static void APIENTRY noopExtGetTexSubImageQCOM(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, void *texels)
{
   (void) target; (void) level; (void) xoffset; (void) yoffset; (void) zoffset; (void) width; (void) height; (void) depth; (void) format; (void) type; (void) texels;
   noop_warn("glExtGetTexSubImageQCOM");
}

static void APIENTRY noopExtGetTexturesQCOM(GLuint *textures, GLint maxTextures, GLint *numTextures)
{
   (void) textures; (void) maxTextures; (void) numTextures;
   noop_warn("glExtGetTexturesQCOM");
}

static GLboolean APIENTRY noopExtIsProgramBinaryQCOM(GLuint program)
{
   (void) program;
   noop_warn("glExtIsProgramBinaryQCOM");
   return (GLboolean) 0;
}

static void APIENTRY noopExtTexObjectStateOverrideiQCOM(GLenum target, GLenum pname, GLint param)
{
   (void) target; (void) pname; (void) param;
   noop_warn("glExtTexObjectStateOverrideiQCOM");
}

static void APIENTRY noopExtractComponentEXT(GLuint res, GLuint src, GLuint num)
{
   (void) res; (void) src; (void) num;
   noop_warn("glExtractComponentEXT");
}

static void APIENTRY noopFeedbackBuffer(GLsizei size, GLenum type, GLfloat *buffer)
{
   (void) size; (void) type; (void) buffer;
   noop_warn("glFeedbackBuffer");
}

static void APIENTRY noopFeedbackBufferxOES(GLsizei n, GLenum type, const GLfixed *buffer)
{
   (void) n; (void) type; (void) buffer;
   noop_warn("glFeedbackBufferxOES");
}

static GLsync APIENTRY noopFenceSync(GLenum condition, GLbitfield flags)
{
   (void) condition; (void) flags;
   noop_warn("glFenceSync");
   return (GLsync) 0;
}

static GLsync APIENTRY noopFenceSyncAPPLE(GLenum condition, GLbitfield flags)
{
   (void) condition; (void) flags;
   noop_warn("glFenceSyncAPPLE");
   return (GLsync) 0;
}

static void APIENTRY noopFenceValueuiNVX(GLsync sync, GLenum condition, GLbitfield flags, GLuint value)
{
   (void) sync; (void) condition; (void) flags; (void) value;
   noop_warn("glFenceValueuiNVX");
}

static void APIENTRY noopFinalCombinerInputNV(GLenum variable, GLenum input, GLenum mapping, GLenum componentUsage)
{
   (void) variable; (void) input; (void) mapping; (void) componentUsage;
   noop_warn("glFinalCombinerInputNV");
}

static void APIENTRY noopFinish(void)
{
   noop_warn("glFinish");
}

static GLint APIENTRY noopFinishAsyncSGIX(GLuint *markerp)
{
   (void) markerp;
   noop_warn("glFinishAsyncSGIX");
   return (GLint) 0;
}

static void APIENTRY noopFinishFenceAPPLE(GLuint fence)
{
   (void) fence;
   noop_warn("glFinishFenceAPPLE");
}

static void APIENTRY noopFinishFenceNV(GLuint fence)
{
   (void) fence;
   noop_warn("glFinishFenceNV");
}

static void APIENTRY noopFinishObjectAPPLE(GLenum object, GLint name)
{
   (void) object; (void) name;
   noop_warn("glFinishObjectAPPLE");
}

static void APIENTRY noopFinishTextureSUNX(void)
{
   noop_warn("glFinishTextureSUNX");
}

static void APIENTRY noopFlush(void)
{
   noop_warn("glFlush");
}

static void APIENTRY noopFlushMappedBufferRange(GLenum target, GLintptr offset, GLsizeiptr length)
{
   (void) target; (void) offset; (void) length;
   noop_warn("glFlushMappedBufferRange");
}

static void APIENTRY noopFlushMappedBufferRangeAPPLE(GLenum target, GLintptr offset, GLsizeiptr size)
{
   (void) target; (void) offset; (void) size;
   noop_warn("glFlushMappedBufferRangeAPPLE");
}

static void APIENTRY noopFlushMappedBufferRangeEXT(GLenum target, GLintptr offset, GLsizeiptr length)
{
   (void) target; (void) offset; (void) length;
   noop_warn("glFlushMappedBufferRangeEXT");
}

static void APIENTRY noopFlushMappedNamedBufferRange(GLuint buffer, GLintptr offset, GLsizeiptr length)
{
   (void) buffer; (void) offset; (void) length;
   noop_warn("glFlushMappedNamedBufferRange");
}

static void APIENTRY noopFlushMappedNamedBufferRangeEXT(GLuint buffer, GLintptr offset, GLsizeiptr length)
{
   (void) buffer; (void) offset; (void) length;
   noop_warn("glFlushMappedNamedBufferRangeEXT");
}

static void APIENTRY noopFlushPixelDataRangeNV(GLenum target)
{
   (void) target;
   noop_warn("glFlushPixelDataRangeNV");
}

static void APIENTRY noopFlushRasterSGIX(void)
{
   noop_warn("glFlushRasterSGIX");
}

static void APIENTRY noopFlushStaticDataIBM(GLenum target)
{
   (void) target;
   noop_warn("glFlushStaticDataIBM");
}

static void APIENTRY noopFlushVertexArrayRangeAPPLE(GLsizei length, void *pointer)
{
   (void) length; (void) pointer;
   noop_warn("glFlushVertexArrayRangeAPPLE");
}

static void APIENTRY noopFlushVertexArrayRangeNV(void)
{
   noop_warn("glFlushVertexArrayRangeNV");
}

static void APIENTRY noopFogCoordFormatNV(GLenum type, GLsizei stride)
{
   (void) type; (void) stride;
   noop_warn("glFogCoordFormatNV");
}

static void APIENTRY noopFogCoordPointer(GLenum type, GLsizei stride, const void *pointer)
{
   (void) type; (void) stride; (void) pointer;
   noop_warn("glFogCoordPointer");
}

static void APIENTRY noopFogCoordPointerEXT(GLenum type, GLsizei stride, const void *pointer)
{
   (void) type; (void) stride; (void) pointer;
   noop_warn("glFogCoordPointerEXT");
}

static void APIENTRY noopFogCoordPointerListIBM(GLenum type, GLint stride, const void **pointer, GLint ptrstride)
{
   (void) type; (void) stride; (void) pointer; (void) ptrstride;
   noop_warn("glFogCoordPointerListIBM");
}

static void APIENTRY noopFogCoordd(GLdouble coord)
{
   (void) coord;
   noop_warn("glFogCoordd");
}

static void APIENTRY noopFogCoorddEXT(GLdouble coord)
{
   (void) coord;
   noop_warn("glFogCoorddEXT");
}

static void APIENTRY noopFogCoorddv(const GLdouble *coord)
{
   (void) coord;
   noop_warn("glFogCoorddv");
}

static void APIENTRY noopFogCoorddvEXT(const GLdouble *coord)
{
   (void) coord;
   noop_warn("glFogCoorddvEXT");
}

static void APIENTRY noopFogCoordf(GLfloat coord)
{
   (void) coord;
   noop_warn("glFogCoordf");
}

static void APIENTRY noopFogCoordfEXT(GLfloat coord)
{
   (void) coord;
   noop_warn("glFogCoordfEXT");
}

static void APIENTRY noopFogCoordfv(const GLfloat *coord)
{
   (void) coord;
   noop_warn("glFogCoordfv");
}

static void APIENTRY noopFogCoordfvEXT(const GLfloat *coord)
{
   (void) coord;
   noop_warn("glFogCoordfvEXT");
}

static void APIENTRY noopFogCoordhNV(GLhalf fog)
{
   (void) fog;
   noop_warn("glFogCoordhNV");
}

static void APIENTRY noopFogCoordhvNV(const GLhalf *fog)
{
   (void) fog;
   noop_warn("glFogCoordhvNV");
}

static void APIENTRY noopFogFuncSGIS(GLsizei n, const GLfloat *points)
{
   (void) n; (void) points;
   noop_warn("glFogFuncSGIS");
}

static void APIENTRY noopFogf(GLenum pname, GLfloat param)
{
   (void) pname; (void) param;
   noop_warn("glFogf");
}

static void APIENTRY noopFogfv(GLenum pname, const GLfloat *params)
{
   (void) pname; (void) params;
   noop_warn("glFogfv");
}

static void APIENTRY noopFogi(GLenum pname, GLint param)
{
   (void) pname; (void) param;
   noop_warn("glFogi");
}

static void APIENTRY noopFogiv(GLenum pname, const GLint *params)
{
   (void) pname; (void) params;
   noop_warn("glFogiv");
}

static void APIENTRY noopFogx(GLenum pname, GLfixed param)
{
   (void) pname; (void) param;
   noop_warn("glFogx");
}

static void APIENTRY noopFogxOES(GLenum pname, GLfixed param)
{
   (void) pname; (void) param;
   noop_warn("glFogxOES");
}

static void APIENTRY noopFogxv(GLenum pname, const GLfixed *param)
{
   (void) pname; (void) param;
   noop_warn("glFogxv");
}

static void APIENTRY noopFogxvOES(GLenum pname, const GLfixed *param)
{
   (void) pname; (void) param;
   noop_warn("glFogxvOES");
}

static void APIENTRY noopFragmentColorMaterialSGIX(GLenum face, GLenum mode)
{
   (void) face; (void) mode;
   noop_warn("glFragmentColorMaterialSGIX");
}

static void APIENTRY noopFragmentCoverageColorNV(GLuint color)
{
   (void) color;
   noop_warn("glFragmentCoverageColorNV");
}

static void APIENTRY noopFragmentLightModelfSGIX(GLenum pname, GLfloat param)
{
   (void) pname; (void) param;
   noop_warn("glFragmentLightModelfSGIX");
}

static void APIENTRY noopFragmentLightModelfvSGIX(GLenum pname, const GLfloat *params)
{
   (void) pname; (void) params;
   noop_warn("glFragmentLightModelfvSGIX");
}

static void APIENTRY noopFragmentLightModeliSGIX(GLenum pname, GLint param)
{
   (void) pname; (void) param;
   noop_warn("glFragmentLightModeliSGIX");
}

static void APIENTRY noopFragmentLightModelivSGIX(GLenum pname, const GLint *params)
{
   (void) pname; (void) params;
   noop_warn("glFragmentLightModelivSGIX");
}

static void APIENTRY noopFragmentLightfSGIX(GLenum light, GLenum pname, GLfloat param)
{
   (void) light; (void) pname; (void) param;
   noop_warn("glFragmentLightfSGIX");
}

static void APIENTRY noopFragmentLightfvSGIX(GLenum light, GLenum pname, const GLfloat *params)
{
   (void) light; (void) pname; (void) params;
   noop_warn("glFragmentLightfvSGIX");
}

static void APIENTRY noopFragmentLightiSGIX(GLenum light, GLenum pname, GLint param)
{
   (void) light; (void) pname; (void) param;
   noop_warn("glFragmentLightiSGIX");
}

static void APIENTRY noopFragmentLightivSGIX(GLenum light, GLenum pname, const GLint *params)
{
   (void) light; (void) pname; (void) params;
   noop_warn("glFragmentLightivSGIX");
}

static void APIENTRY noopFragmentMaterialfSGIX(GLenum face, GLenum pname, GLfloat param)
{
   (void) face; (void) pname; (void) param;
   noop_warn("glFragmentMaterialfSGIX");
}

static void APIENTRY noopFragmentMaterialfvSGIX(GLenum face, GLenum pname, const GLfloat *params)
{
   (void) face; (void) pname; (void) params;
   noop_warn("glFragmentMaterialfvSGIX");
}

static void APIENTRY noopFragmentMaterialiSGIX(GLenum face, GLenum pname, GLint param)
{
   (void) face; (void) pname; (void) param;
   noop_warn("glFragmentMaterialiSGIX");
}

static void APIENTRY noopFragmentMaterialivSGIX(GLenum face, GLenum pname, const GLint *params)
{
   (void) face; (void) pname; (void) params;
   noop_warn("glFragmentMaterialivSGIX");
}

static void APIENTRY noopFrameTerminatorGREMEDY(void)
{
   noop_warn("glFrameTerminatorGREMEDY");
}

static void APIENTRY noopFrameZoomSGIX(GLint factor)
{
   (void) factor;
   noop_warn("glFrameZoomSGIX");
}

static void APIENTRY noopFramebufferDrawBufferEXT(GLuint framebuffer, GLenum mode)
{
   (void) framebuffer; (void) mode;
   noop_warn("glFramebufferDrawBufferEXT");
}

static void APIENTRY noopFramebufferDrawBuffersEXT(GLuint framebuffer, GLsizei n, const GLenum *bufs)
{
   (void) framebuffer; (void) n; (void) bufs;
   noop_warn("glFramebufferDrawBuffersEXT");
}

static void APIENTRY noopFramebufferFetchBarrierEXT(void)
{
   noop_warn("glFramebufferFetchBarrierEXT");
}

static void APIENTRY noopFramebufferFetchBarrierQCOM(void)
{
   noop_warn("glFramebufferFetchBarrierQCOM");
}

static void APIENTRY noopFramebufferFoveationConfigQCOM(GLuint framebuffer, GLuint numLayers, GLuint focalPointsPerLayer, GLuint requestedFeatures, GLuint *providedFeatures)
{
   (void) framebuffer; (void) numLayers; (void) focalPointsPerLayer; (void) requestedFeatures; (void) providedFeatures;
   noop_warn("glFramebufferFoveationConfigQCOM");
}

static void APIENTRY noopFramebufferFoveationParametersQCOM(GLuint framebuffer, GLuint layer, GLuint focalPoint, GLfloat focalX, GLfloat focalY, GLfloat gainX, GLfloat gainY, GLfloat foveaArea)
{
   (void) framebuffer; (void) layer; (void) focalPoint; (void) focalX; (void) focalY; (void) gainX; (void) gainY; (void) foveaArea;
   noop_warn("glFramebufferFoveationParametersQCOM");
}

static void APIENTRY noopFramebufferParameteri(GLenum target, GLenum pname, GLint param)
{
   (void) target; (void) pname; (void) param;
   noop_warn("glFramebufferParameteri");
}

static void APIENTRY noopFramebufferParameteriMESA(GLenum target, GLenum pname, GLint param)
{
   (void) target; (void) pname; (void) param;
   noop_warn("glFramebufferParameteriMESA");
}

static void APIENTRY noopFramebufferPixelLocalStorageSizeEXT(GLuint target, GLsizei size)
{
   (void) target; (void) size;
   noop_warn("glFramebufferPixelLocalStorageSizeEXT");
}

static void APIENTRY noopFramebufferReadBufferEXT(GLuint framebuffer, GLenum mode)
{
   (void) framebuffer; (void) mode;
   noop_warn("glFramebufferReadBufferEXT");
}

static void APIENTRY noopFramebufferRenderbuffer(GLenum target, GLenum attachment, GLenum renderbuffertarget, GLuint renderbuffer)
{
   (void) target; (void) attachment; (void) renderbuffertarget; (void) renderbuffer;
   noop_warn("glFramebufferRenderbuffer");
}

static void APIENTRY noopFramebufferRenderbufferEXT(GLenum target, GLenum attachment, GLenum renderbuffertarget, GLuint renderbuffer)
{
   (void) target; (void) attachment; (void) renderbuffertarget; (void) renderbuffer;
   noop_warn("glFramebufferRenderbufferEXT");
}

static void APIENTRY noopFramebufferRenderbufferOES(GLenum target, GLenum attachment, GLenum renderbuffertarget, GLuint renderbuffer)
{
   (void) target; (void) attachment; (void) renderbuffertarget; (void) renderbuffer;
   noop_warn("glFramebufferRenderbufferOES");
}

static void APIENTRY noopFramebufferSampleLocationsfvARB(GLenum target, GLuint start, GLsizei count, const GLfloat *v)
{
   (void) target; (void) start; (void) count; (void) v;
   noop_warn("glFramebufferSampleLocationsfvARB");
}

static void APIENTRY noopFramebufferSampleLocationsfvNV(GLenum target, GLuint start, GLsizei count, const GLfloat *v)
{
   (void) target; (void) start; (void) count; (void) v;
   noop_warn("glFramebufferSampleLocationsfvNV");
}

static void APIENTRY noopFramebufferSamplePositionsfvAMD(GLenum target, GLuint numsamples, GLuint pixelindex, const GLfloat *values)
{
   (void) target; (void) numsamples; (void) pixelindex; (void) values;
   noop_warn("glFramebufferSamplePositionsfvAMD");
}

static void APIENTRY noopFramebufferTexture(GLenum target, GLenum attachment, GLuint texture, GLint level)
{
   (void) target; (void) attachment; (void) texture; (void) level;
   noop_warn("glFramebufferTexture");
}

static void APIENTRY noopFramebufferTexture1D(GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level)
{
   (void) target; (void) attachment; (void) textarget; (void) texture; (void) level;
   noop_warn("glFramebufferTexture1D");
}

static void APIENTRY noopFramebufferTexture1DEXT(GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level)
{
   (void) target; (void) attachment; (void) textarget; (void) texture; (void) level;
   noop_warn("glFramebufferTexture1DEXT");
}

static void APIENTRY noopFramebufferTexture2D(GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level)
{
   (void) target; (void) attachment; (void) textarget; (void) texture; (void) level;
   noop_warn("glFramebufferTexture2D");
}

static void APIENTRY noopFramebufferTexture2DDownsampleIMG(GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level, GLint xscale, GLint yscale)
{
   (void) target; (void) attachment; (void) textarget; (void) texture; (void) level; (void) xscale; (void) yscale;
   noop_warn("glFramebufferTexture2DDownsampleIMG");
}

static void APIENTRY noopFramebufferTexture2DEXT(GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level)
{
   (void) target; (void) attachment; (void) textarget; (void) texture; (void) level;
   noop_warn("glFramebufferTexture2DEXT");
}

static void APIENTRY noopFramebufferTexture2DMultisampleEXT(GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level, GLsizei samples)
{
   (void) target; (void) attachment; (void) textarget; (void) texture; (void) level; (void) samples;
   noop_warn("glFramebufferTexture2DMultisampleEXT");
}

static void APIENTRY noopFramebufferTexture2DMultisampleIMG(GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level, GLsizei samples)
{
   (void) target; (void) attachment; (void) textarget; (void) texture; (void) level; (void) samples;
   noop_warn("glFramebufferTexture2DMultisampleIMG");
}

static void APIENTRY noopFramebufferTexture2DOES(GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level)
{
   (void) target; (void) attachment; (void) textarget; (void) texture; (void) level;
   noop_warn("glFramebufferTexture2DOES");
}

static void APIENTRY noopFramebufferTexture3D(GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level, GLint zoffset)
{
   (void) target; (void) attachment; (void) textarget; (void) texture; (void) level; (void) zoffset;
   noop_warn("glFramebufferTexture3D");
}

static void APIENTRY noopFramebufferTexture3DEXT(GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level, GLint zoffset)
{
   (void) target; (void) attachment; (void) textarget; (void) texture; (void) level; (void) zoffset;
   noop_warn("glFramebufferTexture3DEXT");
}

static void APIENTRY noopFramebufferTexture3DOES(GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level, GLint zoffset)
{
   (void) target; (void) attachment; (void) textarget; (void) texture; (void) level; (void) zoffset;
   noop_warn("glFramebufferTexture3DOES");
}

static void APIENTRY noopFramebufferTextureARB(GLenum target, GLenum attachment, GLuint texture, GLint level)
{
   (void) target; (void) attachment; (void) texture; (void) level;
   noop_warn("glFramebufferTextureARB");
}

static void APIENTRY noopFramebufferTextureEXT(GLenum target, GLenum attachment, GLuint texture, GLint level)
{
   (void) target; (void) attachment; (void) texture; (void) level;
   noop_warn("glFramebufferTextureEXT");
}

static void APIENTRY noopFramebufferTextureFaceARB(GLenum target, GLenum attachment, GLuint texture, GLint level, GLenum face)
{
   (void) target; (void) attachment; (void) texture; (void) level; (void) face;
   noop_warn("glFramebufferTextureFaceARB");
}

static void APIENTRY noopFramebufferTextureFaceEXT(GLenum target, GLenum attachment, GLuint texture, GLint level, GLenum face)
{
   (void) target; (void) attachment; (void) texture; (void) level; (void) face;
   noop_warn("glFramebufferTextureFaceEXT");
}

static void APIENTRY noopFramebufferTextureLayer(GLenum target, GLenum attachment, GLuint texture, GLint level, GLint layer)
{
   (void) target; (void) attachment; (void) texture; (void) level; (void) layer;
   noop_warn("glFramebufferTextureLayer");
}

static void APIENTRY noopFramebufferTextureLayerARB(GLenum target, GLenum attachment, GLuint texture, GLint level, GLint layer)
{
   (void) target; (void) attachment; (void) texture; (void) level; (void) layer;
   noop_warn("glFramebufferTextureLayerARB");
}

static void APIENTRY noopFramebufferTextureLayerDownsampleIMG(GLenum target, GLenum attachment, GLuint texture, GLint level, GLint layer, GLint xscale, GLint yscale)
{
   (void) target; (void) attachment; (void) texture; (void) level; (void) layer; (void) xscale; (void) yscale;
   noop_warn("glFramebufferTextureLayerDownsampleIMG");
}

static void APIENTRY noopFramebufferTextureLayerEXT(GLenum target, GLenum attachment, GLuint texture, GLint level, GLint layer)
{
   (void) target; (void) attachment; (void) texture; (void) level; (void) layer;
   noop_warn("glFramebufferTextureLayerEXT");
}

static void APIENTRY noopFramebufferTextureLayerNV(GLenum target, GLenum attachment, GLuint texture, GLint level, GLint layer)
{
   (void) target; (void) attachment; (void) texture; (void) level; (void) layer;
   noop_warn("glFramebufferTextureLayerNV");
}

static void APIENTRY noopFramebufferTextureMultisampleMultiviewOVR(GLenum target, GLenum attachment, GLuint texture, GLint level, GLsizei samples, GLint baseViewIndex, GLsizei numViews)
{
   (void) target; (void) attachment; (void) texture; (void) level; (void) samples; (void) baseViewIndex; (void) numViews;
   noop_warn("glFramebufferTextureMultisampleMultiviewOVR");
}

static void APIENTRY noopFramebufferTextureMultiviewOVR(GLenum target, GLenum attachment, GLuint texture, GLint level, GLint baseViewIndex, GLsizei numViews)
{
   (void) target; (void) attachment; (void) texture; (void) level; (void) baseViewIndex; (void) numViews;
   noop_warn("glFramebufferTextureMultiviewOVR");
}

static void APIENTRY noopFramebufferTextureOES(GLenum target, GLenum attachment, GLuint texture, GLint level)
{
   (void) target; (void) attachment; (void) texture; (void) level;
   noop_warn("glFramebufferTextureOES");
}

static void APIENTRY noopFreeObjectBufferATI(GLuint buffer)
{
   (void) buffer;
   noop_warn("glFreeObjectBufferATI");
}

static void APIENTRY noopFrontFace(GLenum mode)
{
   (void) mode;
   noop_warn("glFrontFace");
}

static void APIENTRY noopFrustum(GLdouble left, GLdouble right, GLdouble bottom, GLdouble top, GLdouble zNear, GLdouble zFar)
{
   (void) left; (void) right; (void) bottom; (void) top; (void) zNear; (void) zFar;
   noop_warn("glFrustum");
}

static void APIENTRY noopFrustumf(GLfloat l, GLfloat r, GLfloat b, GLfloat t, GLfloat n, GLfloat f)
{
   (void) l; (void) r; (void) b; (void) t; (void) n; (void) f;
   noop_warn("glFrustumf");
}

static void APIENTRY noopFrustumfOES(GLfloat l, GLfloat r, GLfloat b, GLfloat t, GLfloat n, GLfloat f)
{
   (void) l; (void) r; (void) b; (void) t; (void) n; (void) f;
   noop_warn("glFrustumfOES");
}

static void APIENTRY noopFrustumx(GLfixed l, GLfixed r, GLfixed b, GLfixed t, GLfixed n, GLfixed f)
{
   (void) l; (void) r; (void) b; (void) t; (void) n; (void) f;
   noop_warn("glFrustumx");
}

static void APIENTRY noopFrustumxOES(GLfixed l, GLfixed r, GLfixed b, GLfixed t, GLfixed n, GLfixed f)
{
   (void) l; (void) r; (void) b; (void) t; (void) n; (void) f;
   noop_warn("glFrustumxOES");
}

static GLuint APIENTRY noopGenAsyncMarkersSGIX(GLsizei range)
{
   (void) range;
   noop_warn("glGenAsyncMarkersSGIX");
   return (GLuint) 0;
}

static void APIENTRY noopGenBuffers(GLsizei n, GLuint *buffers)
{
   (void) n; (void) buffers;
   noop_warn("glGenBuffers");
}

static void APIENTRY noopGenBuffersARB(GLsizei n, GLuint *buffers)
{
   (void) n; (void) buffers;
   noop_warn("glGenBuffersARB");
}

static void APIENTRY noopGenFencesAPPLE(GLsizei n, GLuint *fences)
{
   (void) n; (void) fences;
   noop_warn("glGenFencesAPPLE");
}

static void APIENTRY noopGenFencesNV(GLsizei n, GLuint *fences)
{
   (void) n; (void) fences;
   noop_warn("glGenFencesNV");
}

static GLuint APIENTRY noopGenFragmentShadersATI(GLuint range)
{
   (void) range;
   noop_warn("glGenFragmentShadersATI");
   return (GLuint) 0;
}

static void APIENTRY noopGenFramebuffers(GLsizei n, GLuint *framebuffers)
{
   (void) n; (void) framebuffers;
   noop_warn("glGenFramebuffers");
}

static void APIENTRY noopGenFramebuffersEXT(GLsizei n, GLuint *framebuffers)
{
   (void) n; (void) framebuffers;
   noop_warn("glGenFramebuffersEXT");
}

static void APIENTRY noopGenFramebuffersOES(GLsizei n, GLuint *framebuffers)
{
   (void) n; (void) framebuffers;
   noop_warn("glGenFramebuffersOES");
}

static GLuint APIENTRY noopGenLists(GLsizei range)
{
   (void) range;
   noop_warn("glGenLists");
   return (GLuint) 0;
}

static void APIENTRY noopGenNamesAMD(GLenum identifier, GLuint num, GLuint *names)
{
   (void) identifier; (void) num; (void) names;
   noop_warn("glGenNamesAMD");
}

static void APIENTRY noopGenOcclusionQueriesNV(GLsizei n, GLuint *ids)
{
   (void) n; (void) ids;
   noop_warn("glGenOcclusionQueriesNV");
}

static GLuint APIENTRY noopGenPathsNV(GLsizei range)
{
   (void) range;
   noop_warn("glGenPathsNV");
   return (GLuint) 0;
}

static void APIENTRY noopGenPerfMonitorsAMD(GLsizei n, GLuint *monitors)
{
   (void) n; (void) monitors;
   noop_warn("glGenPerfMonitorsAMD");
}

static void APIENTRY noopGenProgramPipelines(GLsizei n, GLuint *pipelines)
{
   (void) n; (void) pipelines;
   noop_warn("glGenProgramPipelines");
}

static void APIENTRY noopGenProgramPipelinesEXT(GLsizei n, GLuint *pipelines)
{
   (void) n; (void) pipelines;
   noop_warn("glGenProgramPipelinesEXT");
}

static void APIENTRY noopGenProgramsARB(GLsizei n, GLuint *programs)
{
   (void) n; (void) programs;
   noop_warn("glGenProgramsARB");
}

static void APIENTRY noopGenProgramsNV(GLsizei n, GLuint *programs)
{
   (void) n; (void) programs;
   noop_warn("glGenProgramsNV");
}

static void APIENTRY noopGenQueries(GLsizei n, GLuint *ids)
{
   (void) n; (void) ids;
   noop_warn("glGenQueries");
}

static void APIENTRY noopGenQueriesARB(GLsizei n, GLuint *ids)
{
   (void) n; (void) ids;
   noop_warn("glGenQueriesARB");
}

static void APIENTRY noopGenQueriesEXT(GLsizei n, GLuint *ids)
{
   (void) n; (void) ids;
   noop_warn("glGenQueriesEXT");
}

static void APIENTRY noopGenQueryResourceTagNV(GLsizei n, GLint *tagIds)
{
   (void) n; (void) tagIds;
   noop_warn("glGenQueryResourceTagNV");
}

static void APIENTRY noopGenRenderbuffers(GLsizei n, GLuint *renderbuffers)
{
   (void) n; (void) renderbuffers;
   noop_warn("glGenRenderbuffers");
}

static void APIENTRY noopGenRenderbuffersEXT(GLsizei n, GLuint *renderbuffers)
{
   (void) n; (void) renderbuffers;
   noop_warn("glGenRenderbuffersEXT");
}

static void APIENTRY noopGenRenderbuffersOES(GLsizei n, GLuint *renderbuffers)
{
   (void) n; (void) renderbuffers;
   noop_warn("glGenRenderbuffersOES");
}

static void APIENTRY noopGenSamplers(GLsizei count, GLuint *samplers)
{
   (void) count; (void) samplers;
   noop_warn("glGenSamplers");
}

static void APIENTRY noopGenSemaphoresEXT(GLsizei n, GLuint *semaphores)
{
   (void) n; (void) semaphores;
   noop_warn("glGenSemaphoresEXT");
}

static GLuint APIENTRY noopGenSymbolsEXT(GLenum datatype, GLenum storagetype, GLenum range, GLuint components)
{
   (void) datatype; (void) storagetype; (void) range; (void) components;
   noop_warn("glGenSymbolsEXT");
   return (GLuint) 0;
}

static void APIENTRY noopGenTextures(GLsizei n, GLuint *textures)
{
   (void) n; (void) textures;
   noop_warn("glGenTextures");
}

static void APIENTRY noopGenTexturesEXT(GLsizei n, GLuint *textures)
{
   (void) n; (void) textures;
   noop_warn("glGenTexturesEXT");
}

static void APIENTRY noopGenTransformFeedbacks(GLsizei n, GLuint *ids)
{
   (void) n; (void) ids;
   noop_warn("glGenTransformFeedbacks");
}

static void APIENTRY noopGenTransformFeedbacksEXT(GLsizei n, GLuint *ids)
{
   (void) n; (void) ids;
   noop_warn("glGenTransformFeedbacksEXT");
}

static void APIENTRY noopGenTransformFeedbacksNV(GLsizei n, GLuint *ids)
{
   (void) n; (void) ids;
   noop_warn("glGenTransformFeedbacksNV");
}

static void APIENTRY noopGenVertexArrays(GLsizei n, GLuint *arrays)
{
   (void) n; (void) arrays;
   noop_warn("glGenVertexArrays");
}

static void APIENTRY noopGenVertexArraysAPPLE(GLsizei n, GLuint *arrays)
{
   (void) n; (void) arrays;
   noop_warn("glGenVertexArraysAPPLE");
}

static void APIENTRY noopGenVertexArraysOES(GLsizei n, GLuint *arrays)
{
   (void) n; (void) arrays;
   noop_warn("glGenVertexArraysOES");
}

static GLuint APIENTRY noopGenVertexShadersEXT(GLuint range)
{
   (void) range;
   noop_warn("glGenVertexShadersEXT");
   return (GLuint) 0;
}

static void APIENTRY noopGenerateMipmap(GLenum target)
{
   (void) target;
   noop_warn("glGenerateMipmap");
}

static void APIENTRY noopGenerateMipmapEXT(GLenum target)
{
   (void) target;
   noop_warn("glGenerateMipmapEXT");
}

static void APIENTRY noopGenerateMipmapOES(GLenum target)
{
   (void) target;
   noop_warn("glGenerateMipmapOES");
}

static void APIENTRY noopGenerateMultiTexMipmapEXT(GLenum texunit, GLenum target)
{
   (void) texunit; (void) target;
   noop_warn("glGenerateMultiTexMipmapEXT");
}

static void APIENTRY noopGenerateTextureMipmap(GLuint texture)
{
   (void) texture;
   noop_warn("glGenerateTextureMipmap");
}

static void APIENTRY noopGenerateTextureMipmapEXT(GLuint texture, GLenum target)
{
   (void) texture; (void) target;
   noop_warn("glGenerateTextureMipmapEXT");
}

static void APIENTRY noopGetActiveAtomicCounterBufferiv(GLuint program, GLuint bufferIndex, GLenum pname, GLint *params)
{
   (void) program; (void) bufferIndex; (void) pname; (void) params;
   noop_warn("glGetActiveAtomicCounterBufferiv");
}

static void APIENTRY noopGetActiveAttrib(GLuint program, GLuint index, GLsizei bufSize, GLsizei *length, GLint *size, GLenum *type, GLchar *name)
{
   (void) program; (void) index; (void) bufSize; (void) length; (void) size; (void) type; (void) name;
   noop_warn("glGetActiveAttrib");
}

static void APIENTRY noopGetActiveAttribARB(GLhandleARB programObj, GLuint index, GLsizei maxLength, GLsizei *length, GLint *size, GLenum *type, GLcharARB *name)
{
   (void) programObj; (void) index; (void) maxLength; (void) length; (void) size; (void) type; (void) name;
   noop_warn("glGetActiveAttribARB");
}

static void APIENTRY noopGetActiveSubroutineName(GLuint program, GLenum shadertype, GLuint index, GLsizei bufSize, GLsizei *length, GLchar *name)
{
   (void) program; (void) shadertype; (void) index; (void) bufSize; (void) length; (void) name;
   noop_warn("glGetActiveSubroutineName");
}

static void APIENTRY noopGetActiveSubroutineUniformName(GLuint program, GLenum shadertype, GLuint index, GLsizei bufSize, GLsizei *length, GLchar *name)
{
   (void) program; (void) shadertype; (void) index; (void) bufSize; (void) length; (void) name;
   noop_warn("glGetActiveSubroutineUniformName");
}

static void APIENTRY noopGetActiveSubroutineUniformiv(GLuint program, GLenum shadertype, GLuint index, GLenum pname, GLint *values)
{
   (void) program; (void) shadertype; (void) index; (void) pname; (void) values;
   noop_warn("glGetActiveSubroutineUniformiv");
}

static void APIENTRY noopGetActiveUniform(GLuint program, GLuint index, GLsizei bufSize, GLsizei *length, GLint *size, GLenum *type, GLchar *name)
{
   (void) program; (void) index; (void) bufSize; (void) length; (void) size; (void) type; (void) name;
   noop_warn("glGetActiveUniform");
}

static void APIENTRY noopGetActiveUniformARB(GLhandleARB programObj, GLuint index, GLsizei maxLength, GLsizei *length, GLint *size, GLenum *type, GLcharARB *name)
{
   (void) programObj; (void) index; (void) maxLength; (void) length; (void) size; (void) type; (void) name;
   noop_warn("glGetActiveUniformARB");
}

static void APIENTRY noopGetActiveUniformBlockName(GLuint program, GLuint uniformBlockIndex, GLsizei bufSize, GLsizei *length, GLchar *uniformBlockName)
{
   (void) program; (void) uniformBlockIndex; (void) bufSize; (void) length; (void) uniformBlockName;
   noop_warn("glGetActiveUniformBlockName");
}

static void APIENTRY noopGetActiveUniformBlockiv(GLuint program, GLuint uniformBlockIndex, GLenum pname, GLint *params)
{
   (void) program; (void) uniformBlockIndex; (void) pname; (void) params;
   noop_warn("glGetActiveUniformBlockiv");
}

static void APIENTRY noopGetActiveUniformName(GLuint program, GLuint uniformIndex, GLsizei bufSize, GLsizei *length, GLchar *uniformName)
{
   (void) program; (void) uniformIndex; (void) bufSize; (void) length; (void) uniformName;
   noop_warn("glGetActiveUniformName");
}

static void APIENTRY noopGetActiveUniformsiv(GLuint program, GLsizei uniformCount, const GLuint *uniformIndices, GLenum pname, GLint *params)
{
   (void) program; (void) uniformCount; (void) uniformIndices; (void) pname; (void) params;
   noop_warn("glGetActiveUniformsiv");
}

static void APIENTRY noopGetActiveVaryingNV(GLuint program, GLuint index, GLsizei bufSize, GLsizei *length, GLsizei *size, GLenum *type, GLchar *name)
{
   (void) program; (void) index; (void) bufSize; (void) length; (void) size; (void) type; (void) name;
   noop_warn("glGetActiveVaryingNV");
}

static void APIENTRY noopGetArrayObjectfvATI(GLenum array, GLenum pname, GLfloat *params)
{
   (void) array; (void) pname; (void) params;
   noop_warn("glGetArrayObjectfvATI");
}

static void APIENTRY noopGetArrayObjectivATI(GLenum array, GLenum pname, GLint *params)
{
   (void) array; (void) pname; (void) params;
   noop_warn("glGetArrayObjectivATI");
}

static void APIENTRY noopGetAttachedObjectsARB(GLhandleARB containerObj, GLsizei maxCount, GLsizei *count, GLhandleARB *obj)
{
   (void) containerObj; (void) maxCount; (void) count; (void) obj;
   noop_warn("glGetAttachedObjectsARB");
}

static void APIENTRY noopGetAttachedShaders(GLuint program, GLsizei maxCount, GLsizei *count, GLuint *shaders)
{
   (void) program; (void) maxCount; (void) count; (void) shaders;
   noop_warn("glGetAttachedShaders");
}

static GLint APIENTRY noopGetAttribLocation(GLuint program, const GLchar *name)
{
   (void) program; (void) name;
   noop_warn("glGetAttribLocation");
   return (GLint) 0;
}

static GLint APIENTRY noopGetAttribLocationARB(GLhandleARB programObj, const GLcharARB *name)
{
   (void) programObj; (void) name;
   noop_warn("glGetAttribLocationARB");
   return (GLint) 0;
}

static void APIENTRY noopGetBooleanIndexedvEXT(GLenum target, GLuint index, GLboolean *data)
{
   (void) target; (void) index; (void) data;
   noop_warn("glGetBooleanIndexedvEXT");
}

static void APIENTRY noopGetBooleani_v(GLenum target, GLuint index, GLboolean *data)
{
   (void) target; (void) index; (void) data;
   noop_warn("glGetBooleani_v");
}

static void APIENTRY noopGetBooleanv(GLenum pname, GLboolean *data)
{
   (void) pname; (void) data;
   noop_warn("glGetBooleanv");
}

static void APIENTRY noopGetBufferParameteri64v(GLenum target, GLenum pname, GLint64 *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetBufferParameteri64v");
}

static void APIENTRY noopGetBufferParameteriv(GLenum target, GLenum pname, GLint *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetBufferParameteriv");
}

static void APIENTRY noopGetBufferParameterivARB(GLenum target, GLenum pname, GLint *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetBufferParameterivARB");
}

static void APIENTRY noopGetBufferParameterui64vNV(GLenum target, GLenum pname, GLuint64 *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetBufferParameterui64vNV");
}

static void APIENTRY noopGetBufferPointerv(GLenum target, GLenum pname, void **params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetBufferPointerv");
}

static void APIENTRY noopGetBufferPointervARB(GLenum target, GLenum pname, void **params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetBufferPointervARB");
}

static void APIENTRY noopGetBufferPointervOES(GLenum target, GLenum pname, void **params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetBufferPointervOES");
}

static void APIENTRY noopGetBufferSubData(GLenum target, GLintptr offset, GLsizeiptr size, void *data)
{
   (void) target; (void) offset; (void) size; (void) data;
   noop_warn("glGetBufferSubData");
}

static void APIENTRY noopGetBufferSubDataARB(GLenum target, GLintptr offset, GLsizeiptr size, void *data)
{
   (void) target; (void) offset; (void) size; (void) data;
   noop_warn("glGetBufferSubDataARB");
}

static void APIENTRY noopGetClipPlane(GLenum plane, GLdouble *equation)
{
   (void) plane; (void) equation;
   noop_warn("glGetClipPlane");
}

static void APIENTRY noopGetClipPlanef(GLenum plane, GLfloat *equation)
{
   (void) plane; (void) equation;
   noop_warn("glGetClipPlanef");
}

static void APIENTRY noopGetClipPlanefOES(GLenum plane, GLfloat *equation)
{
   (void) plane; (void) equation;
   noop_warn("glGetClipPlanefOES");
}

static void APIENTRY noopGetClipPlanex(GLenum plane, GLfixed *equation)
{
   (void) plane; (void) equation;
   noop_warn("glGetClipPlanex");
}

static void APIENTRY noopGetClipPlanexOES(GLenum plane, GLfixed *equation)
{
   (void) plane; (void) equation;
   noop_warn("glGetClipPlanexOES");
}

static void APIENTRY noopGetColorTable(GLenum target, GLenum format, GLenum type, void *table)
{
   (void) target; (void) format; (void) type; (void) table;
   noop_warn("glGetColorTable");
}

static void APIENTRY noopGetColorTableEXT(GLenum target, GLenum format, GLenum type, void *data)
{
   (void) target; (void) format; (void) type; (void) data;
   noop_warn("glGetColorTableEXT");
}

static void APIENTRY noopGetColorTableParameterfv(GLenum target, GLenum pname, GLfloat *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetColorTableParameterfv");
}

static void APIENTRY noopGetColorTableParameterfvEXT(GLenum target, GLenum pname, GLfloat *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetColorTableParameterfvEXT");
}

static void APIENTRY noopGetColorTableParameterfvSGI(GLenum target, GLenum pname, GLfloat *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetColorTableParameterfvSGI");
}

static void APIENTRY noopGetColorTableParameteriv(GLenum target, GLenum pname, GLint *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetColorTableParameteriv");
}

static void APIENTRY noopGetColorTableParameterivEXT(GLenum target, GLenum pname, GLint *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetColorTableParameterivEXT");
}

static void APIENTRY noopGetColorTableParameterivSGI(GLenum target, GLenum pname, GLint *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetColorTableParameterivSGI");
}

static void APIENTRY noopGetColorTableSGI(GLenum target, GLenum format, GLenum type, void *table)
{
   (void) target; (void) format; (void) type; (void) table;
   noop_warn("glGetColorTableSGI");
}

static void APIENTRY noopGetCombinerInputParameterfvNV(GLenum stage, GLenum portion, GLenum variable, GLenum pname, GLfloat *params)
{
   (void) stage; (void) portion; (void) variable; (void) pname; (void) params;
   noop_warn("glGetCombinerInputParameterfvNV");
}

static void APIENTRY noopGetCombinerInputParameterivNV(GLenum stage, GLenum portion, GLenum variable, GLenum pname, GLint *params)
{
   (void) stage; (void) portion; (void) variable; (void) pname; (void) params;
   noop_warn("glGetCombinerInputParameterivNV");
}

static void APIENTRY noopGetCombinerOutputParameterfvNV(GLenum stage, GLenum portion, GLenum pname, GLfloat *params)
{
   (void) stage; (void) portion; (void) pname; (void) params;
   noop_warn("glGetCombinerOutputParameterfvNV");
}

static void APIENTRY noopGetCombinerOutputParameterivNV(GLenum stage, GLenum portion, GLenum pname, GLint *params)
{
   (void) stage; (void) portion; (void) pname; (void) params;
   noop_warn("glGetCombinerOutputParameterivNV");
}

static void APIENTRY noopGetCombinerStageParameterfvNV(GLenum stage, GLenum pname, GLfloat *params)
{
   (void) stage; (void) pname; (void) params;
   noop_warn("glGetCombinerStageParameterfvNV");
}

static GLuint APIENTRY noopGetCommandHeaderNV(GLenum tokenID, GLuint size)
{
   (void) tokenID; (void) size;
   noop_warn("glGetCommandHeaderNV");
   return (GLuint) 0;
}

static void APIENTRY noopGetCompressedMultiTexImageEXT(GLenum texunit, GLenum target, GLint lod, void *img)
{
   (void) texunit; (void) target; (void) lod; (void) img;
   noop_warn("glGetCompressedMultiTexImageEXT");
}

static void APIENTRY noopGetCompressedTexImage(GLenum target, GLint level, void *img)
{
   (void) target; (void) level; (void) img;
   noop_warn("glGetCompressedTexImage");
}

static void APIENTRY noopGetCompressedTexImageARB(GLenum target, GLint level, void *img)
{
   (void) target; (void) level; (void) img;
   noop_warn("glGetCompressedTexImageARB");
}

static void APIENTRY noopGetCompressedTexImageNV(GLenum target, GLint lod, void *img)
{
   (void) target; (void) lod; (void) img;
   noop_warn("glGetCompressedTexImageNV");
}

static void APIENTRY noopGetCompressedTextureImage(GLuint texture, GLint level, GLsizei bufSize, void *pixels)
{
   (void) texture; (void) level; (void) bufSize; (void) pixels;
   noop_warn("glGetCompressedTextureImage");
}

static void APIENTRY noopGetCompressedTextureImageEXT(GLuint texture, GLenum target, GLint lod, void *img)
{
   (void) texture; (void) target; (void) lod; (void) img;
   noop_warn("glGetCompressedTextureImageEXT");
}

static void APIENTRY noopGetCompressedTextureSubImage(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLsizei bufSize, void *pixels)
{
   (void) texture; (void) level; (void) xoffset; (void) yoffset; (void) zoffset; (void) width; (void) height; (void) depth; (void) bufSize; (void) pixels;
   noop_warn("glGetCompressedTextureSubImage");
}

static void APIENTRY noopGetConvolutionFilter(GLenum target, GLenum format, GLenum type, void *image)
{
   (void) target; (void) format; (void) type; (void) image;
   noop_warn("glGetConvolutionFilter");
}

static void APIENTRY noopGetConvolutionFilterEXT(GLenum target, GLenum format, GLenum type, void *image)
{
   (void) target; (void) format; (void) type; (void) image;
   noop_warn("glGetConvolutionFilterEXT");
}

static void APIENTRY noopGetConvolutionParameterfv(GLenum target, GLenum pname, GLfloat *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetConvolutionParameterfv");
}

static void APIENTRY noopGetConvolutionParameterfvEXT(GLenum target, GLenum pname, GLfloat *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetConvolutionParameterfvEXT");
}

static void APIENTRY noopGetConvolutionParameteriv(GLenum target, GLenum pname, GLint *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetConvolutionParameteriv");
}

static void APIENTRY noopGetConvolutionParameterivEXT(GLenum target, GLenum pname, GLint *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetConvolutionParameterivEXT");
}

static void APIENTRY noopGetConvolutionParameterxvOES(GLenum target, GLenum pname, GLfixed *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetConvolutionParameterxvOES");
}

static void APIENTRY noopGetCoverageModulationTableNV(GLsizei bufSize, GLfloat *v)
{
   (void) bufSize; (void) v;
   noop_warn("glGetCoverageModulationTableNV");
}

static GLuint APIENTRY noopGetDebugMessageLog(GLuint count, GLsizei bufSize, GLenum *sources, GLenum *types, GLuint *ids, GLenum *severities, GLsizei *lengths, GLchar *messageLog)
{
   (void) count; (void) bufSize; (void) sources; (void) types; (void) ids; (void) severities; (void) lengths; (void) messageLog;
   noop_warn("glGetDebugMessageLog");
   return (GLuint) 0;
}

static GLuint APIENTRY noopGetDebugMessageLogAMD(GLuint count, GLsizei bufSize, GLenum *categories, GLenum *severities, GLuint *ids, GLsizei *lengths, GLchar *message)
{
   (void) count; (void) bufSize; (void) categories; (void) severities; (void) ids; (void) lengths; (void) message;
   noop_warn("glGetDebugMessageLogAMD");
   return (GLuint) 0;
}

static GLuint APIENTRY noopGetDebugMessageLogARB(GLuint count, GLsizei bufSize, GLenum *sources, GLenum *types, GLuint *ids, GLenum *severities, GLsizei *lengths, GLchar *messageLog)
{
   (void) count; (void) bufSize; (void) sources; (void) types; (void) ids; (void) severities; (void) lengths; (void) messageLog;
   noop_warn("glGetDebugMessageLogARB");
   return (GLuint) 0;
}

static GLuint APIENTRY noopGetDebugMessageLogKHR(GLuint count, GLsizei bufSize, GLenum *sources, GLenum *types, GLuint *ids, GLenum *severities, GLsizei *lengths, GLchar *messageLog)
{
   (void) count; (void) bufSize; (void) sources; (void) types; (void) ids; (void) severities; (void) lengths; (void) messageLog;
   noop_warn("glGetDebugMessageLogKHR");
   return (GLuint) 0;
}

static GLuint APIENTRY noopGetDebugMessageLogOES(GLuint count, GLsizei bufsize, GLenum *sources, GLenum *types, GLuint *ids, GLenum *severities, GLsizei *lengths, GLchar *messageLog)
{
   (void) count; (void) bufsize; (void) sources; (void) types; (void) ids; (void) severities; (void) lengths; (void) messageLog;
   noop_warn("glGetDebugMessageLogOES");
   return (GLuint) 0;
}

static void APIENTRY noopGetDetailTexFuncSGIS(GLenum target, GLfloat *points)
{
   (void) target; (void) points;
   noop_warn("glGetDetailTexFuncSGIS");
}

static void APIENTRY noopGetDoubleIndexedvEXT(GLenum target, GLuint index, GLdouble *data)
{
   (void) target; (void) index; (void) data;
   noop_warn("glGetDoubleIndexedvEXT");
}

static void APIENTRY noopGetDoublei_v(GLenum target, GLuint index, GLdouble *data)
{
   (void) target; (void) index; (void) data;
   noop_warn("glGetDoublei_v");
}

static void APIENTRY noopGetDoublei_vEXT(GLenum pname, GLuint index, GLdouble *params)
{
   (void) pname; (void) index; (void) params;
   noop_warn("glGetDoublei_vEXT");
}

static void APIENTRY noopGetDoublev(GLenum pname, GLdouble *data)
{
   (void) pname; (void) data;
   noop_warn("glGetDoublev");
}

static void APIENTRY noopGetDriverControlStringQCOM(GLuint driverControl, GLsizei bufSize, GLsizei *length, GLchar *driverControlString)
{
   (void) driverControl; (void) bufSize; (void) length; (void) driverControlString;
   noop_warn("glGetDriverControlStringQCOM");
}

static void APIENTRY noopGetDriverControlsQCOM(GLint *num, GLsizei size, GLuint *driverControls)
{
   (void) num; (void) size; (void) driverControls;
   noop_warn("glGetDriverControlsQCOM");
}

static GLenum APIENTRY noopGetError(void)
{
   noop_warn("glGetError");
   return (GLenum) 0;
}

static void APIENTRY noopGetFenceivNV(GLuint fence, GLenum pname, GLint *params)
{
   (void) fence; (void) pname; (void) params;
   noop_warn("glGetFenceivNV");
}

static void APIENTRY noopGetFinalCombinerInputParameterfvNV(GLenum variable, GLenum pname, GLfloat *params)
{
   (void) variable; (void) pname; (void) params;
   noop_warn("glGetFinalCombinerInputParameterfvNV");
}

static void APIENTRY noopGetFinalCombinerInputParameterivNV(GLenum variable, GLenum pname, GLint *params)
{
   (void) variable; (void) pname; (void) params;
   noop_warn("glGetFinalCombinerInputParameterivNV");
}

static void APIENTRY noopGetFirstPerfQueryIdINTEL(GLuint *queryId)
{
   (void) queryId;
   noop_warn("glGetFirstPerfQueryIdINTEL");
}

static void APIENTRY noopGetFixedv(GLenum pname, GLfixed *params)
{
   (void) pname; (void) params;
   noop_warn("glGetFixedv");
}

static void APIENTRY noopGetFixedvOES(GLenum pname, GLfixed *params)
{
   (void) pname; (void) params;
   noop_warn("glGetFixedvOES");
}

static void APIENTRY noopGetFloatIndexedvEXT(GLenum target, GLuint index, GLfloat *data)
{
   (void) target; (void) index; (void) data;
   noop_warn("glGetFloatIndexedvEXT");
}

static void APIENTRY noopGetFloati_v(GLenum target, GLuint index, GLfloat *data)
{
   (void) target; (void) index; (void) data;
   noop_warn("glGetFloati_v");
}

static void APIENTRY noopGetFloati_vEXT(GLenum pname, GLuint index, GLfloat *params)
{
   (void) pname; (void) index; (void) params;
   noop_warn("glGetFloati_vEXT");
}

static void APIENTRY noopGetFloati_vNV(GLenum target, GLuint index, GLfloat *data)
{
   (void) target; (void) index; (void) data;
   noop_warn("glGetFloati_vNV");
}

static void APIENTRY noopGetFloati_vOES(GLenum target, GLuint index, GLfloat *data)
{
   (void) target; (void) index; (void) data;
   noop_warn("glGetFloati_vOES");
}

static void APIENTRY noopGetFloatv(GLenum pname, GLfloat *data)
{
   (void) pname; (void) data;
   noop_warn("glGetFloatv");
}

static void APIENTRY noopGetFogFuncSGIS(GLfloat *points)
{
   (void) points;
   noop_warn("glGetFogFuncSGIS");
}

static GLint APIENTRY noopGetFragDataIndex(GLuint program, const GLchar *name)
{
   (void) program; (void) name;
   noop_warn("glGetFragDataIndex");
   return (GLint) 0;
}

static GLint APIENTRY noopGetFragDataIndexEXT(GLuint program, const GLchar *name)
{
   (void) program; (void) name;
   noop_warn("glGetFragDataIndexEXT");
   return (GLint) 0;
}

static GLint APIENTRY noopGetFragDataLocation(GLuint program, const GLchar *name)
{
   (void) program; (void) name;
   noop_warn("glGetFragDataLocation");
   return (GLint) 0;
}

static GLint APIENTRY noopGetFragDataLocationEXT(GLuint program, const GLchar *name)
{
   (void) program; (void) name;
   noop_warn("glGetFragDataLocationEXT");
   return (GLint) 0;
}

static void APIENTRY noopGetFragmentLightfvSGIX(GLenum light, GLenum pname, GLfloat *params)
{
   (void) light; (void) pname; (void) params;
   noop_warn("glGetFragmentLightfvSGIX");
}

static void APIENTRY noopGetFragmentLightivSGIX(GLenum light, GLenum pname, GLint *params)
{
   (void) light; (void) pname; (void) params;
   noop_warn("glGetFragmentLightivSGIX");
}

static void APIENTRY noopGetFragmentMaterialfvSGIX(GLenum face, GLenum pname, GLfloat *params)
{
   (void) face; (void) pname; (void) params;
   noop_warn("glGetFragmentMaterialfvSGIX");
}

static void APIENTRY noopGetFragmentMaterialivSGIX(GLenum face, GLenum pname, GLint *params)
{
   (void) face; (void) pname; (void) params;
   noop_warn("glGetFragmentMaterialivSGIX");
}

static void APIENTRY noopGetFramebufferAttachmentParameteriv(GLenum target, GLenum attachment, GLenum pname, GLint *params)
{
   (void) target; (void) attachment; (void) pname; (void) params;
   noop_warn("glGetFramebufferAttachmentParameteriv");
}

static void APIENTRY noopGetFramebufferAttachmentParameterivEXT(GLenum target, GLenum attachment, GLenum pname, GLint *params)
{
   (void) target; (void) attachment; (void) pname; (void) params;
   noop_warn("glGetFramebufferAttachmentParameterivEXT");
}

static void APIENTRY noopGetFramebufferAttachmentParameterivOES(GLenum target, GLenum attachment, GLenum pname, GLint *params)
{
   (void) target; (void) attachment; (void) pname; (void) params;
   noop_warn("glGetFramebufferAttachmentParameterivOES");
}

static void APIENTRY noopGetFramebufferParameterfvAMD(GLenum target, GLenum pname, GLuint numsamples, GLuint pixelindex, GLsizei size, GLfloat *values)
{
   (void) target; (void) pname; (void) numsamples; (void) pixelindex; (void) size; (void) values;
   noop_warn("glGetFramebufferParameterfvAMD");
}

static void APIENTRY noopGetFramebufferParameteriv(GLenum target, GLenum pname, GLint *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetFramebufferParameteriv");
}

static void APIENTRY noopGetFramebufferParameterivEXT(GLuint framebuffer, GLenum pname, GLint *params)
{
   (void) framebuffer; (void) pname; (void) params;
   noop_warn("glGetFramebufferParameterivEXT");
}

static void APIENTRY noopGetFramebufferParameterivMESA(GLenum target, GLenum pname, GLint *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetFramebufferParameterivMESA");
}

static GLsizei APIENTRY noopGetFramebufferPixelLocalStorageSizeEXT(GLuint target)
{
   (void) target;
   noop_warn("glGetFramebufferPixelLocalStorageSizeEXT");
   return (GLsizei) 0;
}

static GLenum APIENTRY noopGetGraphicsResetStatus(void)
{
   noop_warn("glGetGraphicsResetStatus");
   return (GLenum) 0;
}

static GLenum APIENTRY noopGetGraphicsResetStatusARB(void)
{
   noop_warn("glGetGraphicsResetStatusARB");
   return (GLenum) 0;
}

static GLenum APIENTRY noopGetGraphicsResetStatusEXT(void)
{
   noop_warn("glGetGraphicsResetStatusEXT");
   return (GLenum) 0;
}

static GLenum APIENTRY noopGetGraphicsResetStatusKHR(void)
{
   noop_warn("glGetGraphicsResetStatusKHR");
   return (GLenum) 0;
}

static GLhandleARB APIENTRY noopGetHandleARB(GLenum pname)
{
   (void) pname;
   noop_warn("glGetHandleARB");
   return (GLhandleARB) 0;
}

static void APIENTRY noopGetHistogram(GLenum target, GLboolean reset, GLenum format, GLenum type, void *values)
{
   (void) target; (void) reset; (void) format; (void) type; (void) values;
   noop_warn("glGetHistogram");
}

static void APIENTRY noopGetHistogramEXT(GLenum target, GLboolean reset, GLenum format, GLenum type, void *values)
{
   (void) target; (void) reset; (void) format; (void) type; (void) values;
   noop_warn("glGetHistogramEXT");
}

static void APIENTRY noopGetHistogramParameterfv(GLenum target, GLenum pname, GLfloat *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetHistogramParameterfv");
}

static void APIENTRY noopGetHistogramParameterfvEXT(GLenum target, GLenum pname, GLfloat *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetHistogramParameterfvEXT");
}

static void APIENTRY noopGetHistogramParameteriv(GLenum target, GLenum pname, GLint *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetHistogramParameteriv");
}

static void APIENTRY noopGetHistogramParameterivEXT(GLenum target, GLenum pname, GLint *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetHistogramParameterivEXT");
}

static void APIENTRY noopGetHistogramParameterxvOES(GLenum target, GLenum pname, GLfixed *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetHistogramParameterxvOES");
}

static GLuint64 APIENTRY noopGetImageHandleARB(GLuint texture, GLint level, GLboolean layered, GLint layer, GLenum format)
{
   (void) texture; (void) level; (void) layered; (void) layer; (void) format;
   noop_warn("glGetImageHandleARB");
   return (GLuint64) 0;
}

static GLuint64 APIENTRY noopGetImageHandleNV(GLuint texture, GLint level, GLboolean layered, GLint layer, GLenum format)
{
   (void) texture; (void) level; (void) layered; (void) layer; (void) format;
   noop_warn("glGetImageHandleNV");
   return (GLuint64) 0;
}

static void APIENTRY noopGetImageTransformParameterfvHP(GLenum target, GLenum pname, GLfloat *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetImageTransformParameterfvHP");
}

static void APIENTRY noopGetImageTransformParameterivHP(GLenum target, GLenum pname, GLint *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetImageTransformParameterivHP");
}

static void APIENTRY noopGetInfoLogARB(GLhandleARB obj, GLsizei maxLength, GLsizei *length, GLcharARB *infoLog)
{
   (void) obj; (void) maxLength; (void) length; (void) infoLog;
   noop_warn("glGetInfoLogARB");
}

static GLint APIENTRY noopGetInstrumentsSGIX(void)
{
   noop_warn("glGetInstrumentsSGIX");
   return (GLint) 0;
}

static void APIENTRY noopGetInteger64i_v(GLenum target, GLuint index, GLint64 *data)
{
   (void) target; (void) index; (void) data;
   noop_warn("glGetInteger64i_v");
}

static void APIENTRY noopGetInteger64v(GLenum pname, GLint64 *data)
{
   (void) pname; (void) data;
   noop_warn("glGetInteger64v");
}

static void APIENTRY noopGetInteger64vAPPLE(GLenum pname, GLint64 *params)
{
   (void) pname; (void) params;
   noop_warn("glGetInteger64vAPPLE");
}

static void APIENTRY noopGetIntegerIndexedvEXT(GLenum target, GLuint index, GLint *data)
{
   (void) target; (void) index; (void) data;
   noop_warn("glGetIntegerIndexedvEXT");
}

static void APIENTRY noopGetIntegeri_v(GLenum target, GLuint index, GLint *data)
{
   (void) target; (void) index; (void) data;
   noop_warn("glGetIntegeri_v");
}

static void APIENTRY noopGetIntegeri_vEXT(GLenum target, GLuint index, GLint *data)
{
   (void) target; (void) index; (void) data;
   noop_warn("glGetIntegeri_vEXT");
}

static void APIENTRY noopGetIntegerui64i_vNV(GLenum value, GLuint index, GLuint64 *result)
{
   (void) value; (void) index; (void) result;
   noop_warn("glGetIntegerui64i_vNV");
}

static void APIENTRY noopGetIntegerui64vNV(GLenum value, GLuint64 *result)
{
   (void) value; (void) result;
   noop_warn("glGetIntegerui64vNV");
}

static void APIENTRY noopGetIntegerv(GLenum pname, GLint *data)
{
   (void) pname; (void) data;
   noop_warn("glGetIntegerv");
}

static void APIENTRY noopGetInternalformatSampleivNV(GLenum target, GLenum internalformat, GLsizei samples, GLenum pname, GLsizei count, GLint *params)
{
   (void) target; (void) internalformat; (void) samples; (void) pname; (void) count; (void) params;
   noop_warn("glGetInternalformatSampleivNV");
}

static void APIENTRY noopGetInternalformati64v(GLenum target, GLenum internalformat, GLenum pname, GLsizei count, GLint64 *params)
{
   (void) target; (void) internalformat; (void) pname; (void) count; (void) params;
   noop_warn("glGetInternalformati64v");
}

static void APIENTRY noopGetInternalformativ(GLenum target, GLenum internalformat, GLenum pname, GLsizei count, GLint *params)
{
   (void) target; (void) internalformat; (void) pname; (void) count; (void) params;
   noop_warn("glGetInternalformativ");
}

static void APIENTRY noopGetInvariantBooleanvEXT(GLuint id, GLenum value, GLboolean *data)
{
   (void) id; (void) value; (void) data;
   noop_warn("glGetInvariantBooleanvEXT");
}

static void APIENTRY noopGetInvariantFloatvEXT(GLuint id, GLenum value, GLfloat *data)
{
   (void) id; (void) value; (void) data;
   noop_warn("glGetInvariantFloatvEXT");
}

static void APIENTRY noopGetInvariantIntegervEXT(GLuint id, GLenum value, GLint *data)
{
   (void) id; (void) value; (void) data;
   noop_warn("glGetInvariantIntegervEXT");
}

static void APIENTRY noopGetLightfv(GLenum light, GLenum pname, GLfloat *params)
{
   (void) light; (void) pname; (void) params;
   noop_warn("glGetLightfv");
}

static void APIENTRY noopGetLightiv(GLenum light, GLenum pname, GLint *params)
{
   (void) light; (void) pname; (void) params;
   noop_warn("glGetLightiv");
}

static void APIENTRY noopGetLightxOES(GLenum light, GLenum pname, GLfixed *params)
{
   (void) light; (void) pname; (void) params;
   noop_warn("glGetLightxOES");
}

static void APIENTRY noopGetLightxv(GLenum light, GLenum pname, GLfixed *params)
{
   (void) light; (void) pname; (void) params;
   noop_warn("glGetLightxv");
}

static void APIENTRY noopGetLightxvOES(GLenum light, GLenum pname, GLfixed *params)
{
   (void) light; (void) pname; (void) params;
   noop_warn("glGetLightxvOES");
}

static void APIENTRY noopGetListParameterfvSGIX(GLuint list, GLenum pname, GLfloat *params)
{
   (void) list; (void) pname; (void) params;
   noop_warn("glGetListParameterfvSGIX");
}

static void APIENTRY noopGetListParameterivSGIX(GLuint list, GLenum pname, GLint *params)
{
   (void) list; (void) pname; (void) params;
   noop_warn("glGetListParameterivSGIX");
}

static void APIENTRY noopGetLocalConstantBooleanvEXT(GLuint id, GLenum value, GLboolean *data)
{
   (void) id; (void) value; (void) data;
   noop_warn("glGetLocalConstantBooleanvEXT");
}

static void APIENTRY noopGetLocalConstantFloatvEXT(GLuint id, GLenum value, GLfloat *data)
{
   (void) id; (void) value; (void) data;
   noop_warn("glGetLocalConstantFloatvEXT");
}

static void APIENTRY noopGetLocalConstantIntegervEXT(GLuint id, GLenum value, GLint *data)
{
   (void) id; (void) value; (void) data;
   noop_warn("glGetLocalConstantIntegervEXT");
}

static void APIENTRY noopGetMapAttribParameterfvNV(GLenum target, GLuint index, GLenum pname, GLfloat *params)
{
   (void) target; (void) index; (void) pname; (void) params;
   noop_warn("glGetMapAttribParameterfvNV");
}

static void APIENTRY noopGetMapAttribParameterivNV(GLenum target, GLuint index, GLenum pname, GLint *params)
{
   (void) target; (void) index; (void) pname; (void) params;
   noop_warn("glGetMapAttribParameterivNV");
}

static void APIENTRY noopGetMapControlPointsNV(GLenum target, GLuint index, GLenum type, GLsizei ustride, GLsizei vstride, GLboolean packed, void *points)
{
   (void) target; (void) index; (void) type; (void) ustride; (void) vstride; (void) packed; (void) points;
   noop_warn("glGetMapControlPointsNV");
}

static void APIENTRY noopGetMapParameterfvNV(GLenum target, GLenum pname, GLfloat *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetMapParameterfvNV");
}

static void APIENTRY noopGetMapParameterivNV(GLenum target, GLenum pname, GLint *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetMapParameterivNV");
}

static void APIENTRY noopGetMapdv(GLenum target, GLenum query, GLdouble *v)
{
   (void) target; (void) query; (void) v;
   noop_warn("glGetMapdv");
}

static void APIENTRY noopGetMapfv(GLenum target, GLenum query, GLfloat *v)
{
   (void) target; (void) query; (void) v;
   noop_warn("glGetMapfv");
}

static void APIENTRY noopGetMapiv(GLenum target, GLenum query, GLint *v)
{
   (void) target; (void) query; (void) v;
   noop_warn("glGetMapiv");
}

static void APIENTRY noopGetMapxvOES(GLenum target, GLenum query, GLfixed *v)
{
   (void) target; (void) query; (void) v;
   noop_warn("glGetMapxvOES");
}

static void APIENTRY noopGetMaterialfv(GLenum face, GLenum pname, GLfloat *params)
{
   (void) face; (void) pname; (void) params;
   noop_warn("glGetMaterialfv");
}

static void APIENTRY noopGetMaterialiv(GLenum face, GLenum pname, GLint *params)
{
   (void) face; (void) pname; (void) params;
   noop_warn("glGetMaterialiv");
}

static void APIENTRY noopGetMaterialxOES(GLenum face, GLenum pname, GLfixed param)
{
   (void) face; (void) pname; (void) param;
   noop_warn("glGetMaterialxOES");
}

static void APIENTRY noopGetMaterialxv(GLenum face, GLenum pname, GLfixed *params)
{
   (void) face; (void) pname; (void) params;
   noop_warn("glGetMaterialxv");
}

static void APIENTRY noopGetMaterialxvOES(GLenum face, GLenum pname, GLfixed *params)
{
   (void) face; (void) pname; (void) params;
   noop_warn("glGetMaterialxvOES");
}

static void APIENTRY noopGetMemoryObjectDetachedResourcesuivNV(GLuint memory, GLenum pname, GLint first, GLsizei count, GLuint *params)
{
   (void) memory; (void) pname; (void) first; (void) count; (void) params;
   noop_warn("glGetMemoryObjectDetachedResourcesuivNV");
}

static void APIENTRY noopGetMemoryObjectParameterivEXT(GLuint memoryObject, GLenum pname, GLint *params)
{
   (void) memoryObject; (void) pname; (void) params;
   noop_warn("glGetMemoryObjectParameterivEXT");
}

static void APIENTRY noopGetMinmax(GLenum target, GLboolean reset, GLenum format, GLenum type, void *values)
{
   (void) target; (void) reset; (void) format; (void) type; (void) values;
   noop_warn("glGetMinmax");
}

static void APIENTRY noopGetMinmaxEXT(GLenum target, GLboolean reset, GLenum format, GLenum type, void *values)
{
   (void) target; (void) reset; (void) format; (void) type; (void) values;
   noop_warn("glGetMinmaxEXT");
}

static void APIENTRY noopGetMinmaxParameterfv(GLenum target, GLenum pname, GLfloat *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetMinmaxParameterfv");
}

static void APIENTRY noopGetMinmaxParameterfvEXT(GLenum target, GLenum pname, GLfloat *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetMinmaxParameterfvEXT");
}

static void APIENTRY noopGetMinmaxParameteriv(GLenum target, GLenum pname, GLint *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetMinmaxParameteriv");
}

static void APIENTRY noopGetMinmaxParameterivEXT(GLenum target, GLenum pname, GLint *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetMinmaxParameterivEXT");
}

static void APIENTRY noopGetMultiTexEnvfvEXT(GLenum texunit, GLenum target, GLenum pname, GLfloat *params)
{
   (void) texunit; (void) target; (void) pname; (void) params;
   noop_warn("glGetMultiTexEnvfvEXT");
}

static void APIENTRY noopGetMultiTexEnvivEXT(GLenum texunit, GLenum target, GLenum pname, GLint *params)
{
   (void) texunit; (void) target; (void) pname; (void) params;
   noop_warn("glGetMultiTexEnvivEXT");
}

static void APIENTRY noopGetMultiTexGendvEXT(GLenum texunit, GLenum coord, GLenum pname, GLdouble *params)
{
   (void) texunit; (void) coord; (void) pname; (void) params;
   noop_warn("glGetMultiTexGendvEXT");
}

static void APIENTRY noopGetMultiTexGenfvEXT(GLenum texunit, GLenum coord, GLenum pname, GLfloat *params)
{
   (void) texunit; (void) coord; (void) pname; (void) params;
   noop_warn("glGetMultiTexGenfvEXT");
}

static void APIENTRY noopGetMultiTexGenivEXT(GLenum texunit, GLenum coord, GLenum pname, GLint *params)
{
   (void) texunit; (void) coord; (void) pname; (void) params;
   noop_warn("glGetMultiTexGenivEXT");
}

static void APIENTRY noopGetMultiTexImageEXT(GLenum texunit, GLenum target, GLint level, GLenum format, GLenum type, void *pixels)
{
   (void) texunit; (void) target; (void) level; (void) format; (void) type; (void) pixels;
   noop_warn("glGetMultiTexImageEXT");
}

static void APIENTRY noopGetMultiTexLevelParameterfvEXT(GLenum texunit, GLenum target, GLint level, GLenum pname, GLfloat *params)
{
   (void) texunit; (void) target; (void) level; (void) pname; (void) params;
   noop_warn("glGetMultiTexLevelParameterfvEXT");
}

static void APIENTRY noopGetMultiTexLevelParameterivEXT(GLenum texunit, GLenum target, GLint level, GLenum pname, GLint *params)
{
   (void) texunit; (void) target; (void) level; (void) pname; (void) params;
   noop_warn("glGetMultiTexLevelParameterivEXT");
}

static void APIENTRY noopGetMultiTexParameterIivEXT(GLenum texunit, GLenum target, GLenum pname, GLint *params)
{
   (void) texunit; (void) target; (void) pname; (void) params;
   noop_warn("glGetMultiTexParameterIivEXT");
}

static void APIENTRY noopGetMultiTexParameterIuivEXT(GLenum texunit, GLenum target, GLenum pname, GLuint *params)
{
   (void) texunit; (void) target; (void) pname; (void) params;
   noop_warn("glGetMultiTexParameterIuivEXT");
}

static void APIENTRY noopGetMultiTexParameterfvEXT(GLenum texunit, GLenum target, GLenum pname, GLfloat *params)
{
   (void) texunit; (void) target; (void) pname; (void) params;
   noop_warn("glGetMultiTexParameterfvEXT");
}

static void APIENTRY noopGetMultiTexParameterivEXT(GLenum texunit, GLenum target, GLenum pname, GLint *params)
{
   (void) texunit; (void) target; (void) pname; (void) params;
   noop_warn("glGetMultiTexParameterivEXT");
}

static void APIENTRY noopGetMultisamplefv(GLenum pname, GLuint index, GLfloat *val)
{
   (void) pname; (void) index; (void) val;
   noop_warn("glGetMultisamplefv");
}

static void APIENTRY noopGetMultisamplefvNV(GLenum pname, GLuint index, GLfloat *val)
{
   (void) pname; (void) index; (void) val;
   noop_warn("glGetMultisamplefvNV");
}

static void APIENTRY noopGetNamedBufferParameteri64v(GLuint buffer, GLenum pname, GLint64 *params)
{
   (void) buffer; (void) pname; (void) params;
   noop_warn("glGetNamedBufferParameteri64v");
}

static void APIENTRY noopGetNamedBufferParameteri64vEXT(GLuint buffer, GLenum pname, GLint64 *params)
{
   (void) buffer; (void) pname; (void) params;
   noop_warn("glGetNamedBufferParameteri64vEXT");
}

static void APIENTRY noopGetNamedBufferParameteriv(GLuint buffer, GLenum pname, GLint *params)
{
   (void) buffer; (void) pname; (void) params;
   noop_warn("glGetNamedBufferParameteriv");
}

static void APIENTRY noopGetNamedBufferParameterivEXT(GLuint buffer, GLenum pname, GLint *params)
{
   (void) buffer; (void) pname; (void) params;
   noop_warn("glGetNamedBufferParameterivEXT");
}

static void APIENTRY noopGetNamedBufferParameterui64vNV(GLuint buffer, GLenum pname, GLuint64 *params)
{
   (void) buffer; (void) pname; (void) params;
   noop_warn("glGetNamedBufferParameterui64vNV");
}

static void APIENTRY noopGetNamedBufferPointerv(GLuint buffer, GLenum pname, void **params)
{
   (void) buffer; (void) pname; (void) params;
   noop_warn("glGetNamedBufferPointerv");
}

static void APIENTRY noopGetNamedBufferPointervEXT(GLuint buffer, GLenum pname, void **params)
{
   (void) buffer; (void) pname; (void) params;
   noop_warn("glGetNamedBufferPointervEXT");
}

static void APIENTRY noopGetNamedBufferSubData(GLuint buffer, GLintptr offset, GLsizeiptr size, void *data)
{
   (void) buffer; (void) offset; (void) size; (void) data;
   noop_warn("glGetNamedBufferSubData");
}

static void APIENTRY noopGetNamedBufferSubDataEXT(GLuint buffer, GLintptr offset, GLsizeiptr size, void *data)
{
   (void) buffer; (void) offset; (void) size; (void) data;
   noop_warn("glGetNamedBufferSubDataEXT");
}

static void APIENTRY noopGetNamedFramebufferAttachmentParameteriv(GLuint framebuffer, GLenum attachment, GLenum pname, GLint *params)
{
   (void) framebuffer; (void) attachment; (void) pname; (void) params;
   noop_warn("glGetNamedFramebufferAttachmentParameteriv");
}

static void APIENTRY noopGetNamedFramebufferAttachmentParameterivEXT(GLuint framebuffer, GLenum attachment, GLenum pname, GLint *params)
{
   (void) framebuffer; (void) attachment; (void) pname; (void) params;
   noop_warn("glGetNamedFramebufferAttachmentParameterivEXT");
}

static void APIENTRY noopGetNamedFramebufferParameterfvAMD(GLuint framebuffer, GLenum pname, GLuint numsamples, GLuint pixelindex, GLsizei size, GLfloat *values)
{
   (void) framebuffer; (void) pname; (void) numsamples; (void) pixelindex; (void) size; (void) values;
   noop_warn("glGetNamedFramebufferParameterfvAMD");
}

static void APIENTRY noopGetNamedFramebufferParameteriv(GLuint framebuffer, GLenum pname, GLint *param)
{
   (void) framebuffer; (void) pname; (void) param;
   noop_warn("glGetNamedFramebufferParameteriv");
}

static void APIENTRY noopGetNamedFramebufferParameterivEXT(GLuint framebuffer, GLenum pname, GLint *params)
{
   (void) framebuffer; (void) pname; (void) params;
   noop_warn("glGetNamedFramebufferParameterivEXT");
}

static void APIENTRY noopGetNamedProgramLocalParameterIivEXT(GLuint program, GLenum target, GLuint index, GLint *params)
{
   (void) program; (void) target; (void) index; (void) params;
   noop_warn("glGetNamedProgramLocalParameterIivEXT");
}

static void APIENTRY noopGetNamedProgramLocalParameterIuivEXT(GLuint program, GLenum target, GLuint index, GLuint *params)
{
   (void) program; (void) target; (void) index; (void) params;
   noop_warn("glGetNamedProgramLocalParameterIuivEXT");
}

static void APIENTRY noopGetNamedProgramLocalParameterdvEXT(GLuint program, GLenum target, GLuint index, GLdouble *params)
{
   (void) program; (void) target; (void) index; (void) params;
   noop_warn("glGetNamedProgramLocalParameterdvEXT");
}

static void APIENTRY noopGetNamedProgramLocalParameterfvEXT(GLuint program, GLenum target, GLuint index, GLfloat *params)
{
   (void) program; (void) target; (void) index; (void) params;
   noop_warn("glGetNamedProgramLocalParameterfvEXT");
}

static void APIENTRY noopGetNamedProgramStringEXT(GLuint program, GLenum target, GLenum pname, void *string)
{
   (void) program; (void) target; (void) pname; (void) string;
   noop_warn("glGetNamedProgramStringEXT");
}

static void APIENTRY noopGetNamedProgramivEXT(GLuint program, GLenum target, GLenum pname, GLint *params)
{
   (void) program; (void) target; (void) pname; (void) params;
   noop_warn("glGetNamedProgramivEXT");
}

static void APIENTRY noopGetNamedRenderbufferParameteriv(GLuint renderbuffer, GLenum pname, GLint *params)
{
   (void) renderbuffer; (void) pname; (void) params;
   noop_warn("glGetNamedRenderbufferParameteriv");
}

static void APIENTRY noopGetNamedRenderbufferParameterivEXT(GLuint renderbuffer, GLenum pname, GLint *params)
{
   (void) renderbuffer; (void) pname; (void) params;
   noop_warn("glGetNamedRenderbufferParameterivEXT");
}

static void APIENTRY noopGetNamedStringARB(GLint namelen, const GLchar *name, GLsizei bufSize, GLint *stringlen, GLchar *string)
{
   (void) namelen; (void) name; (void) bufSize; (void) stringlen; (void) string;
   noop_warn("glGetNamedStringARB");
}

static void APIENTRY noopGetNamedStringivARB(GLint namelen, const GLchar *name, GLenum pname, GLint *params)
{
   (void) namelen; (void) name; (void) pname; (void) params;
   noop_warn("glGetNamedStringivARB");
}

static void APIENTRY noopGetNextPerfQueryIdINTEL(GLuint queryId, GLuint *nextQueryId)
{
   (void) queryId; (void) nextQueryId;
   noop_warn("glGetNextPerfQueryIdINTEL");
}

static void APIENTRY noopGetObjectBufferfvATI(GLuint buffer, GLenum pname, GLfloat *params)
{
   (void) buffer; (void) pname; (void) params;
   noop_warn("glGetObjectBufferfvATI");
}

static void APIENTRY noopGetObjectBufferivATI(GLuint buffer, GLenum pname, GLint *params)
{
   (void) buffer; (void) pname; (void) params;
   noop_warn("glGetObjectBufferivATI");
}

static void APIENTRY noopGetObjectLabel(GLenum identifier, GLuint name, GLsizei bufSize, GLsizei *length, GLchar *label)
{
   (void) identifier; (void) name; (void) bufSize; (void) length; (void) label;
   noop_warn("glGetObjectLabel");
}

static void APIENTRY noopGetObjectLabelEXT(GLenum type, GLuint object, GLsizei bufSize, GLsizei *length, GLchar *label)
{
   (void) type; (void) object; (void) bufSize; (void) length; (void) label;
   noop_warn("glGetObjectLabelEXT");
}

static void APIENTRY noopGetObjectLabelKHR(GLenum identifier, GLuint name, GLsizei bufSize, GLsizei *length, GLchar *label)
{
   (void) identifier; (void) name; (void) bufSize; (void) length; (void) label;
   noop_warn("glGetObjectLabelKHR");
}

static void APIENTRY noopGetObjectLabelOES(GLenum identifier, GLuint name, GLsizei bufSize, GLsizei *length, GLchar *label)
{
   (void) identifier; (void) name; (void) bufSize; (void) length; (void) label;
   noop_warn("glGetObjectLabelOES");
}

static void APIENTRY noopGetObjectParameterfvARB(GLhandleARB obj, GLenum pname, GLfloat *params)
{
   (void) obj; (void) pname; (void) params;
   noop_warn("glGetObjectParameterfvARB");
}

static void APIENTRY noopGetObjectParameterivAPPLE(GLenum objectType, GLuint name, GLenum pname, GLint *params)
{
   (void) objectType; (void) name; (void) pname; (void) params;
   noop_warn("glGetObjectParameterivAPPLE");
}

static void APIENTRY noopGetObjectParameterivARB(GLhandleARB obj, GLenum pname, GLint *params)
{
   (void) obj; (void) pname; (void) params;
   noop_warn("glGetObjectParameterivARB");
}

static void APIENTRY noopGetObjectPtrLabel(const void *ptr, GLsizei bufSize, GLsizei *length, GLchar *label)
{
   (void) ptr; (void) bufSize; (void) length; (void) label;
   noop_warn("glGetObjectPtrLabel");
}

static void APIENTRY noopGetObjectPtrLabelKHR(const void *ptr, GLsizei bufSize, GLsizei *length, GLchar *label)
{
   (void) ptr; (void) bufSize; (void) length; (void) label;
   noop_warn("glGetObjectPtrLabelKHR");
}

static void APIENTRY noopGetObjectPtrLabelOES(void *ptr, GLsizei bufSize, GLsizei *length, GLchar *label)
{
   (void) ptr; (void) bufSize; (void) length; (void) label;
   noop_warn("glGetObjectPtrLabelOES");
}

static void APIENTRY noopGetOcclusionQueryivNV(GLuint id, GLenum pname, GLint *params)
{
   (void) id; (void) pname; (void) params;
   noop_warn("glGetOcclusionQueryivNV");
}

static void APIENTRY noopGetOcclusionQueryuivNV(GLuint id, GLenum pname, GLuint *params)
{
   (void) id; (void) pname; (void) params;
   noop_warn("glGetOcclusionQueryuivNV");
}

static void APIENTRY noopGetPathColorGenfvNV(GLenum color, GLenum pname, GLfloat *value)
{
   (void) color; (void) pname; (void) value;
   noop_warn("glGetPathColorGenfvNV");
}

static void APIENTRY noopGetPathColorGenivNV(GLenum color, GLenum pname, GLint *value)
{
   (void) color; (void) pname; (void) value;
   noop_warn("glGetPathColorGenivNV");
}

static void APIENTRY noopGetPathCommandsNV(GLuint path, GLubyte *commands)
{
   (void) path; (void) commands;
   noop_warn("glGetPathCommandsNV");
}

static void APIENTRY noopGetPathCoordsNV(GLuint path, GLfloat *coords)
{
   (void) path; (void) coords;
   noop_warn("glGetPathCoordsNV");
}

static void APIENTRY noopGetPathDashArrayNV(GLuint path, GLfloat *dashArray)
{
   (void) path; (void) dashArray;
   noop_warn("glGetPathDashArrayNV");
}

static GLfloat APIENTRY noopGetPathLengthNV(GLuint path, GLsizei startSegment, GLsizei numSegments)
{
   (void) path; (void) startSegment; (void) numSegments;
   noop_warn("glGetPathLengthNV");
   return (GLfloat) 0;
}

static void APIENTRY noopGetPathMetricRangeNV(GLbitfield metricQueryMask, GLuint firstPathName, GLsizei numPaths, GLsizei stride, GLfloat *metrics)
{
   (void) metricQueryMask; (void) firstPathName; (void) numPaths; (void) stride; (void) metrics;
   noop_warn("glGetPathMetricRangeNV");
}

static void APIENTRY noopGetPathMetricsNV(GLbitfield metricQueryMask, GLsizei numPaths, GLenum pathNameType, const void *paths, GLuint pathBase, GLsizei stride, GLfloat *metrics)
{
   (void) metricQueryMask; (void) numPaths; (void) pathNameType; (void) paths; (void) pathBase; (void) stride; (void) metrics;
   noop_warn("glGetPathMetricsNV");
}

static void APIENTRY noopGetPathParameterfvNV(GLuint path, GLenum pname, GLfloat *value)
{
   (void) path; (void) pname; (void) value;
   noop_warn("glGetPathParameterfvNV");
}

static void APIENTRY noopGetPathParameterivNV(GLuint path, GLenum pname, GLint *value)
{
   (void) path; (void) pname; (void) value;
   noop_warn("glGetPathParameterivNV");
}

static void APIENTRY noopGetPathSpacingNV(GLenum pathListMode, GLsizei numPaths, GLenum pathNameType, const void *paths, GLuint pathBase, GLfloat advanceScale, GLfloat kerningScale, GLenum transformType, GLfloat *returnedSpacing)
{
   (void) pathListMode; (void) numPaths; (void) pathNameType; (void) paths; (void) pathBase; (void) advanceScale; (void) kerningScale; (void) transformType; (void) returnedSpacing;
   noop_warn("glGetPathSpacingNV");
}

static void APIENTRY noopGetPathTexGenfvNV(GLenum texCoordSet, GLenum pname, GLfloat *value)
{
   (void) texCoordSet; (void) pname; (void) value;
   noop_warn("glGetPathTexGenfvNV");
}

static void APIENTRY noopGetPathTexGenivNV(GLenum texCoordSet, GLenum pname, GLint *value)
{
   (void) texCoordSet; (void) pname; (void) value;
   noop_warn("glGetPathTexGenivNV");
}

static void APIENTRY noopGetPerfCounterInfoINTEL(GLuint queryId, GLuint counterId, GLuint counterNameLength, GLchar *counterName, GLuint counterDescLength, GLchar *counterDesc, GLuint *counterOffset, GLuint *counterDataSize, GLuint *counterTypeEnum, GLuint *counterDataTypeEnum, GLuint64 *rawCounterMaxValue)
{
   (void) queryId; (void) counterId; (void) counterNameLength; (void) counterName; (void) counterDescLength; (void) counterDesc; (void) counterOffset; (void) counterDataSize; (void) counterTypeEnum; (void) counterDataTypeEnum; (void) rawCounterMaxValue;
   noop_warn("glGetPerfCounterInfoINTEL");
}

static void APIENTRY noopGetPerfMonitorCounterDataAMD(GLuint monitor, GLenum pname, GLsizei dataSize, GLuint *data, GLint *bytesWritten)
{
   (void) monitor; (void) pname; (void) dataSize; (void) data; (void) bytesWritten;
   noop_warn("glGetPerfMonitorCounterDataAMD");
}

static void APIENTRY noopGetPerfMonitorCounterInfoAMD(GLuint group, GLuint counter, GLenum pname, void *data)
{
   (void) group; (void) counter; (void) pname; (void) data;
   noop_warn("glGetPerfMonitorCounterInfoAMD");
}

static void APIENTRY noopGetPerfMonitorCounterStringAMD(GLuint group, GLuint counter, GLsizei bufSize, GLsizei *length, GLchar *counterString)
{
   (void) group; (void) counter; (void) bufSize; (void) length; (void) counterString;
   noop_warn("glGetPerfMonitorCounterStringAMD");
}

static void APIENTRY noopGetPerfMonitorCountersAMD(GLuint group, GLint *numCounters, GLint *maxActiveCounters, GLsizei counterSize, GLuint *counters)
{
   (void) group; (void) numCounters; (void) maxActiveCounters; (void) counterSize; (void) counters;
   noop_warn("glGetPerfMonitorCountersAMD");
}

static void APIENTRY noopGetPerfMonitorGroupStringAMD(GLuint group, GLsizei bufSize, GLsizei *length, GLchar *groupString)
{
   (void) group; (void) bufSize; (void) length; (void) groupString;
   noop_warn("glGetPerfMonitorGroupStringAMD");
}

static void APIENTRY noopGetPerfMonitorGroupsAMD(GLint *numGroups, GLsizei groupsSize, GLuint *groups)
{
   (void) numGroups; (void) groupsSize; (void) groups;
   noop_warn("glGetPerfMonitorGroupsAMD");
}

static void APIENTRY noopGetPerfQueryDataINTEL(GLuint queryHandle, GLuint flags, GLsizei dataSize, void *data, GLuint *bytesWritten)
{
   (void) queryHandle; (void) flags; (void) dataSize; (void) data; (void) bytesWritten;
   noop_warn("glGetPerfQueryDataINTEL");
}

static void APIENTRY noopGetPerfQueryIdByNameINTEL(GLchar *queryName, GLuint *queryId)
{
   (void) queryName; (void) queryId;
   noop_warn("glGetPerfQueryIdByNameINTEL");
}

static void APIENTRY noopGetPerfQueryInfoINTEL(GLuint queryId, GLuint queryNameLength, GLchar *queryName, GLuint *dataSize, GLuint *noCounters, GLuint *noInstances, GLuint *capsMask)
{
   (void) queryId; (void) queryNameLength; (void) queryName; (void) dataSize; (void) noCounters; (void) noInstances; (void) capsMask;
   noop_warn("glGetPerfQueryInfoINTEL");
}

static void APIENTRY noopGetPixelMapfv(GLenum map, GLfloat *values)
{
   (void) map; (void) values;
   noop_warn("glGetPixelMapfv");
}

static void APIENTRY noopGetPixelMapuiv(GLenum map, GLuint *values)
{
   (void) map; (void) values;
   noop_warn("glGetPixelMapuiv");
}

static void APIENTRY noopGetPixelMapusv(GLenum map, GLushort *values)
{
   (void) map; (void) values;
   noop_warn("glGetPixelMapusv");
}

static void APIENTRY noopGetPixelMapxv(GLenum map, GLint size, GLfixed *values)
{
   (void) map; (void) size; (void) values;
   noop_warn("glGetPixelMapxv");
}

static void APIENTRY noopGetPixelTexGenParameterfvSGIS(GLenum pname, GLfloat *params)
{
   (void) pname; (void) params;
   noop_warn("glGetPixelTexGenParameterfvSGIS");
}

static void APIENTRY noopGetPixelTexGenParameterivSGIS(GLenum pname, GLint *params)
{
   (void) pname; (void) params;
   noop_warn("glGetPixelTexGenParameterivSGIS");
}

static void APIENTRY noopGetPixelTransformParameterfvEXT(GLenum target, GLenum pname, GLfloat *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetPixelTransformParameterfvEXT");
}

static void APIENTRY noopGetPixelTransformParameterivEXT(GLenum target, GLenum pname, GLint *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetPixelTransformParameterivEXT");
}

static void APIENTRY noopGetPointerIndexedvEXT(GLenum target, GLuint index, void **data)
{
   (void) target; (void) index; (void) data;
   noop_warn("glGetPointerIndexedvEXT");
}

static void APIENTRY noopGetPointeri_vEXT(GLenum pname, GLuint index, void **params)
{
   (void) pname; (void) index; (void) params;
   noop_warn("glGetPointeri_vEXT");
}

static void APIENTRY noopGetPointerv(GLenum pname, void **params)
{
   (void) pname; (void) params;
   noop_warn("glGetPointerv");
}

static void APIENTRY noopGetPointervEXT(GLenum pname, void **params)
{
   (void) pname; (void) params;
   noop_warn("glGetPointervEXT");
}

static void APIENTRY noopGetPointervKHR(GLenum pname, void **params)
{
   (void) pname; (void) params;
   noop_warn("glGetPointervKHR");
}

static void APIENTRY noopGetPointervOES(GLenum pname, void **params)
{
   (void) pname; (void) params;
   noop_warn("glGetPointervOES");
}

static void APIENTRY noopGetPolygonStipple(GLubyte *mask)
{
   (void) mask;
   noop_warn("glGetPolygonStipple");
}

static void APIENTRY noopGetProgramBinary(GLuint program, GLsizei bufSize, GLsizei *length, GLenum *binaryFormat, void *binary)
{
   (void) program; (void) bufSize; (void) length; (void) binaryFormat; (void) binary;
   noop_warn("glGetProgramBinary");
}

static void APIENTRY noopGetProgramBinaryOES(GLuint program, GLsizei bufSize, GLsizei *length, GLenum *binaryFormat, void *binary)
{
   (void) program; (void) bufSize; (void) length; (void) binaryFormat; (void) binary;
   noop_warn("glGetProgramBinaryOES");
}

static void APIENTRY noopGetProgramEnvParameterIivNV(GLenum target, GLuint index, GLint *params)
{
   (void) target; (void) index; (void) params;
   noop_warn("glGetProgramEnvParameterIivNV");
}

static void APIENTRY noopGetProgramEnvParameterIuivNV(GLenum target, GLuint index, GLuint *params)
{
   (void) target; (void) index; (void) params;
   noop_warn("glGetProgramEnvParameterIuivNV");
}

static void APIENTRY noopGetProgramEnvParameterdvARB(GLenum target, GLuint index, GLdouble *params)
{
   (void) target; (void) index; (void) params;
   noop_warn("glGetProgramEnvParameterdvARB");
}

static void APIENTRY noopGetProgramEnvParameterfvARB(GLenum target, GLuint index, GLfloat *params)
{
   (void) target; (void) index; (void) params;
   noop_warn("glGetProgramEnvParameterfvARB");
}

static void APIENTRY noopGetProgramInfoLog(GLuint program, GLsizei bufSize, GLsizei *length, GLchar *infoLog)
{
   (void) program; (void) bufSize; (void) length; (void) infoLog;
   noop_warn("glGetProgramInfoLog");
}

static void APIENTRY noopGetProgramInterfaceiv(GLuint program, GLenum programInterface, GLenum pname, GLint *params)
{
   (void) program; (void) programInterface; (void) pname; (void) params;
   noop_warn("glGetProgramInterfaceiv");
}

static void APIENTRY noopGetProgramLocalParameterIivNV(GLenum target, GLuint index, GLint *params)
{
   (void) target; (void) index; (void) params;
   noop_warn("glGetProgramLocalParameterIivNV");
}

static void APIENTRY noopGetProgramLocalParameterIuivNV(GLenum target, GLuint index, GLuint *params)
{
   (void) target; (void) index; (void) params;
   noop_warn("glGetProgramLocalParameterIuivNV");
}

static void APIENTRY noopGetProgramLocalParameterdvARB(GLenum target, GLuint index, GLdouble *params)
{
   (void) target; (void) index; (void) params;
   noop_warn("glGetProgramLocalParameterdvARB");
}

static void APIENTRY noopGetProgramLocalParameterfvARB(GLenum target, GLuint index, GLfloat *params)
{
   (void) target; (void) index; (void) params;
   noop_warn("glGetProgramLocalParameterfvARB");
}

static void APIENTRY noopGetProgramNamedParameterdvNV(GLuint id, GLsizei len, const GLubyte *name, GLdouble *params)
{
   (void) id; (void) len; (void) name; (void) params;
   noop_warn("glGetProgramNamedParameterdvNV");
}

static void APIENTRY noopGetProgramNamedParameterfvNV(GLuint id, GLsizei len, const GLubyte *name, GLfloat *params)
{
   (void) id; (void) len; (void) name; (void) params;
   noop_warn("glGetProgramNamedParameterfvNV");
}

static void APIENTRY noopGetProgramParameterdvNV(GLenum target, GLuint index, GLenum pname, GLdouble *params)
{
   (void) target; (void) index; (void) pname; (void) params;
   noop_warn("glGetProgramParameterdvNV");
}

static void APIENTRY noopGetProgramParameterfvNV(GLenum target, GLuint index, GLenum pname, GLfloat *params)
{
   (void) target; (void) index; (void) pname; (void) params;
   noop_warn("glGetProgramParameterfvNV");
}

static void APIENTRY noopGetProgramPipelineInfoLog(GLuint pipeline, GLsizei bufSize, GLsizei *length, GLchar *infoLog)
{
   (void) pipeline; (void) bufSize; (void) length; (void) infoLog;
   noop_warn("glGetProgramPipelineInfoLog");
}

static void APIENTRY noopGetProgramPipelineInfoLogEXT(GLuint pipeline, GLsizei bufSize, GLsizei *length, GLchar *infoLog)
{
   (void) pipeline; (void) bufSize; (void) length; (void) infoLog;
   noop_warn("glGetProgramPipelineInfoLogEXT");
}

static void APIENTRY noopGetProgramPipelineiv(GLuint pipeline, GLenum pname, GLint *params)
{
   (void) pipeline; (void) pname; (void) params;
   noop_warn("glGetProgramPipelineiv");
}

static void APIENTRY noopGetProgramPipelineivEXT(GLuint pipeline, GLenum pname, GLint *params)
{
   (void) pipeline; (void) pname; (void) params;
   noop_warn("glGetProgramPipelineivEXT");
}

static GLuint APIENTRY noopGetProgramResourceIndex(GLuint program, GLenum programInterface, const GLchar *name)
{
   (void) program; (void) programInterface; (void) name;
   noop_warn("glGetProgramResourceIndex");
   return (GLuint) 0;
}

static GLint APIENTRY noopGetProgramResourceLocation(GLuint program, GLenum programInterface, const GLchar *name)
{
   (void) program; (void) programInterface; (void) name;
   noop_warn("glGetProgramResourceLocation");
   return (GLint) 0;
}

static GLint APIENTRY noopGetProgramResourceLocationIndex(GLuint program, GLenum programInterface, const GLchar *name)
{
   (void) program; (void) programInterface; (void) name;
   noop_warn("glGetProgramResourceLocationIndex");
   return (GLint) 0;
}

static GLint APIENTRY noopGetProgramResourceLocationIndexEXT(GLuint program, GLenum programInterface, const GLchar *name)
{
   (void) program; (void) programInterface; (void) name;
   noop_warn("glGetProgramResourceLocationIndexEXT");
   return (GLint) 0;
}

static void APIENTRY noopGetProgramResourceName(GLuint program, GLenum programInterface, GLuint index, GLsizei bufSize, GLsizei *length, GLchar *name)
{
   (void) program; (void) programInterface; (void) index; (void) bufSize; (void) length; (void) name;
   noop_warn("glGetProgramResourceName");
}

static void APIENTRY noopGetProgramResourcefvNV(GLuint program, GLenum programInterface, GLuint index, GLsizei propCount, const GLenum *props, GLsizei count, GLsizei *length, GLfloat *params)
{
   (void) program; (void) programInterface; (void) index; (void) propCount; (void) props; (void) count; (void) length; (void) params;
   noop_warn("glGetProgramResourcefvNV");
}

static void APIENTRY noopGetProgramResourceiv(GLuint program, GLenum programInterface, GLuint index, GLsizei propCount, const GLenum *props, GLsizei count, GLsizei *length, GLint *params)
{
   (void) program; (void) programInterface; (void) index; (void) propCount; (void) props; (void) count; (void) length; (void) params;
   noop_warn("glGetProgramResourceiv");
}

static void APIENTRY noopGetProgramStageiv(GLuint program, GLenum shadertype, GLenum pname, GLint *values)
{
   (void) program; (void) shadertype; (void) pname; (void) values;
   noop_warn("glGetProgramStageiv");
}

static void APIENTRY noopGetProgramStringARB(GLenum target, GLenum pname, void *string)
{
   (void) target; (void) pname; (void) string;
   noop_warn("glGetProgramStringARB");
}

static void APIENTRY noopGetProgramStringNV(GLuint id, GLenum pname, GLubyte *program)
{
   (void) id; (void) pname; (void) program;
   noop_warn("glGetProgramStringNV");
}

static void APIENTRY noopGetProgramSubroutineParameteruivNV(GLenum target, GLuint index, GLuint *param)
{
   (void) target; (void) index; (void) param;
   noop_warn("glGetProgramSubroutineParameteruivNV");
}

static void APIENTRY noopGetProgramiv(GLuint program, GLenum pname, GLint *params)
{
   (void) program; (void) pname; (void) params;
   noop_warn("glGetProgramiv");
}

static void APIENTRY noopGetProgramivARB(GLenum target, GLenum pname, GLint *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetProgramivARB");
}

static void APIENTRY noopGetProgramivNV(GLuint id, GLenum pname, GLint *params)
{
   (void) id; (void) pname; (void) params;
   noop_warn("glGetProgramivNV");
}

static void APIENTRY noopGetQueryBufferObjecti64v(GLuint id, GLuint buffer, GLenum pname, GLintptr offset)
{
   (void) id; (void) buffer; (void) pname; (void) offset;
   noop_warn("glGetQueryBufferObjecti64v");
}

static void APIENTRY noopGetQueryBufferObjectiv(GLuint id, GLuint buffer, GLenum pname, GLintptr offset)
{
   (void) id; (void) buffer; (void) pname; (void) offset;
   noop_warn("glGetQueryBufferObjectiv");
}

static void APIENTRY noopGetQueryBufferObjectui64v(GLuint id, GLuint buffer, GLenum pname, GLintptr offset)
{
   (void) id; (void) buffer; (void) pname; (void) offset;
   noop_warn("glGetQueryBufferObjectui64v");
}

static void APIENTRY noopGetQueryBufferObjectuiv(GLuint id, GLuint buffer, GLenum pname, GLintptr offset)
{
   (void) id; (void) buffer; (void) pname; (void) offset;
   noop_warn("glGetQueryBufferObjectuiv");
}

static void APIENTRY noopGetQueryIndexediv(GLenum target, GLuint index, GLenum pname, GLint *params)
{
   (void) target; (void) index; (void) pname; (void) params;
   noop_warn("glGetQueryIndexediv");
}

static void APIENTRY noopGetQueryObjecti64v(GLuint id, GLenum pname, GLint64 *params)
{
   (void) id; (void) pname; (void) params;
   noop_warn("glGetQueryObjecti64v");
}

static void APIENTRY noopGetQueryObjecti64vEXT(GLuint id, GLenum pname, GLint64 *params)
{
   (void) id; (void) pname; (void) params;
   noop_warn("glGetQueryObjecti64vEXT");
}

static void APIENTRY noopGetQueryObjectiv(GLuint id, GLenum pname, GLint *params)
{
   (void) id; (void) pname; (void) params;
   noop_warn("glGetQueryObjectiv");
}

static void APIENTRY noopGetQueryObjectivARB(GLuint id, GLenum pname, GLint *params)
{
   (void) id; (void) pname; (void) params;
   noop_warn("glGetQueryObjectivARB");
}

static void APIENTRY noopGetQueryObjectivEXT(GLuint id, GLenum pname, GLint *params)
{
   (void) id; (void) pname; (void) params;
   noop_warn("glGetQueryObjectivEXT");
}

static void APIENTRY noopGetQueryObjectui64v(GLuint id, GLenum pname, GLuint64 *params)
{
   (void) id; (void) pname; (void) params;
   noop_warn("glGetQueryObjectui64v");
}

static void APIENTRY noopGetQueryObjectui64vEXT(GLuint id, GLenum pname, GLuint64 *params)
{
   (void) id; (void) pname; (void) params;
   noop_warn("glGetQueryObjectui64vEXT");
}

static void APIENTRY noopGetQueryObjectui64vNV(GLuint id, GLenum pname, GLuint64 *params)
{
   (void) id; (void) pname; (void) params;
   noop_warn("glGetQueryObjectui64vNV");
}

static void APIENTRY noopGetQueryObjectuiv(GLuint id, GLenum pname, GLuint *params)
{
   (void) id; (void) pname; (void) params;
   noop_warn("glGetQueryObjectuiv");
}

static void APIENTRY noopGetQueryObjectuivARB(GLuint id, GLenum pname, GLuint *params)
{
   (void) id; (void) pname; (void) params;
   noop_warn("glGetQueryObjectuivARB");
}

static void APIENTRY noopGetQueryObjectuivEXT(GLuint id, GLenum pname, GLuint *params)
{
   (void) id; (void) pname; (void) params;
   noop_warn("glGetQueryObjectuivEXT");
}

static void APIENTRY noopGetQueryiv(GLenum target, GLenum pname, GLint *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetQueryiv");
}

static void APIENTRY noopGetQueryivARB(GLenum target, GLenum pname, GLint *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetQueryivARB");
}

static void APIENTRY noopGetQueryivEXT(GLenum target, GLenum pname, GLint *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetQueryivEXT");
}

static void APIENTRY noopGetRenderbufferParameteriv(GLenum target, GLenum pname, GLint *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetRenderbufferParameteriv");
}

static void APIENTRY noopGetRenderbufferParameterivEXT(GLenum target, GLenum pname, GLint *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetRenderbufferParameterivEXT");
}

static void APIENTRY noopGetRenderbufferParameterivOES(GLenum target, GLenum pname, GLint *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetRenderbufferParameterivOES");
}

static void APIENTRY noopGetSamplerParameterIiv(GLuint sampler, GLenum pname, GLint *params)
{
   (void) sampler; (void) pname; (void) params;
   noop_warn("glGetSamplerParameterIiv");
}

static void APIENTRY noopGetSamplerParameterIivEXT(GLuint sampler, GLenum pname, GLint *params)
{
   (void) sampler; (void) pname; (void) params;
   noop_warn("glGetSamplerParameterIivEXT");
}

static void APIENTRY noopGetSamplerParameterIivOES(GLuint sampler, GLenum pname, GLint *params)
{
   (void) sampler; (void) pname; (void) params;
   noop_warn("glGetSamplerParameterIivOES");
}

static void APIENTRY noopGetSamplerParameterIuiv(GLuint sampler, GLenum pname, GLuint *params)
{
   (void) sampler; (void) pname; (void) params;
   noop_warn("glGetSamplerParameterIuiv");
}

static void APIENTRY noopGetSamplerParameterIuivEXT(GLuint sampler, GLenum pname, GLuint *params)
{
   (void) sampler; (void) pname; (void) params;
   noop_warn("glGetSamplerParameterIuivEXT");
}

static void APIENTRY noopGetSamplerParameterIuivOES(GLuint sampler, GLenum pname, GLuint *params)
{
   (void) sampler; (void) pname; (void) params;
   noop_warn("glGetSamplerParameterIuivOES");
}

static void APIENTRY noopGetSamplerParameterfv(GLuint sampler, GLenum pname, GLfloat *params)
{
   (void) sampler; (void) pname; (void) params;
   noop_warn("glGetSamplerParameterfv");
}

static void APIENTRY noopGetSamplerParameteriv(GLuint sampler, GLenum pname, GLint *params)
{
   (void) sampler; (void) pname; (void) params;
   noop_warn("glGetSamplerParameteriv");
}

static void APIENTRY noopGetSemaphoreParameterui64vEXT(GLuint semaphore, GLenum pname, GLuint64 *params)
{
   (void) semaphore; (void) pname; (void) params;
   noop_warn("glGetSemaphoreParameterui64vEXT");
}

static void APIENTRY noopGetSeparableFilter(GLenum target, GLenum format, GLenum type, void *row, void *column, void *span)
{
   (void) target; (void) format; (void) type; (void) row; (void) column; (void) span;
   noop_warn("glGetSeparableFilter");
}

static void APIENTRY noopGetSeparableFilterEXT(GLenum target, GLenum format, GLenum type, void *row, void *column, void *span)
{
   (void) target; (void) format; (void) type; (void) row; (void) column; (void) span;
   noop_warn("glGetSeparableFilterEXT");
}

static void APIENTRY noopGetShaderInfoLog(GLuint shader, GLsizei bufSize, GLsizei *length, GLchar *infoLog)
{
   (void) shader; (void) bufSize; (void) length; (void) infoLog;
   noop_warn("glGetShaderInfoLog");
}

static void APIENTRY noopGetShaderPrecisionFormat(GLenum shadertype, GLenum precisiontype, GLint *range, GLint *precision)
{
   (void) shadertype; (void) precisiontype; (void) range; (void) precision;
   noop_warn("glGetShaderPrecisionFormat");
}

static void APIENTRY noopGetShaderSource(GLuint shader, GLsizei bufSize, GLsizei *length, GLchar *source)
{
   (void) shader; (void) bufSize; (void) length; (void) source;
   noop_warn("glGetShaderSource");
}

static void APIENTRY noopGetShaderSourceARB(GLhandleARB obj, GLsizei maxLength, GLsizei *length, GLcharARB *source)
{
   (void) obj; (void) maxLength; (void) length; (void) source;
   noop_warn("glGetShaderSourceARB");
}

static void APIENTRY noopGetShaderiv(GLuint shader, GLenum pname, GLint *params)
{
   (void) shader; (void) pname; (void) params;
   noop_warn("glGetShaderiv");
}

static void APIENTRY noopGetShadingRateImagePaletteNV(GLuint viewport, GLuint entry, GLenum *rate)
{
   (void) viewport; (void) entry; (void) rate;
   noop_warn("glGetShadingRateImagePaletteNV");
}

static void APIENTRY noopGetShadingRateSampleLocationivNV(GLenum rate, GLuint samples, GLuint index, GLint *location)
{
   (void) rate; (void) samples; (void) index; (void) location;
   noop_warn("glGetShadingRateSampleLocationivNV");
}

static void APIENTRY noopGetSharpenTexFuncSGIS(GLenum target, GLfloat *points)
{
   (void) target; (void) points;
   noop_warn("glGetSharpenTexFuncSGIS");
}

static GLushort APIENTRY noopGetStageIndexNV(GLenum shadertype)
{
   (void) shadertype;
   noop_warn("glGetStageIndexNV");
   return (GLushort) 0;
}

static const GLubyte * APIENTRY noopGetString(GLenum name)
{
   (void) name;
   noop_warn("glGetString");
   return (const GLubyte *) 0;
}

static const GLubyte * APIENTRY noopGetStringi(GLenum name, GLuint index)
{
   (void) name; (void) index;
   noop_warn("glGetStringi");
   return (const GLubyte *) 0;
}

static GLuint APIENTRY noopGetSubroutineIndex(GLuint program, GLenum shadertype, const GLchar *name)
{
   (void) program; (void) shadertype; (void) name;
   noop_warn("glGetSubroutineIndex");
   return (GLuint) 0;
}

static GLint APIENTRY noopGetSubroutineUniformLocation(GLuint program, GLenum shadertype, const GLchar *name)
{
   (void) program; (void) shadertype; (void) name;
   noop_warn("glGetSubroutineUniformLocation");
   return (GLint) 0;
}

static void APIENTRY noopGetSynciv(GLsync sync, GLenum pname, GLsizei count, GLsizei *length, GLint *values)
{
   (void) sync; (void) pname; (void) count; (void) length; (void) values;
   noop_warn("glGetSynciv");
}

static void APIENTRY noopGetSyncivAPPLE(GLsync sync, GLenum pname, GLsizei count, GLsizei *length, GLint *values)
{
   (void) sync; (void) pname; (void) count; (void) length; (void) values;
   noop_warn("glGetSyncivAPPLE");
}

static void APIENTRY noopGetSyncv64NVX(GLsync sync, GLenum pname, GLuint64 *value)
{
   (void) sync; (void) pname; (void) value;
   noop_warn("glGetSyncv64NVX");
}

static void APIENTRY noopGetTexBumpParameterfvATI(GLenum pname, GLfloat *param)
{
   (void) pname; (void) param;
   noop_warn("glGetTexBumpParameterfvATI");
}

static void APIENTRY noopGetTexBumpParameterivATI(GLenum pname, GLint *param)
{
   (void) pname; (void) param;
   noop_warn("glGetTexBumpParameterivATI");
}

static void APIENTRY noopGetTexEnvfv(GLenum target, GLenum pname, GLfloat *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetTexEnvfv");
}

static void APIENTRY noopGetTexEnviv(GLenum target, GLenum pname, GLint *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetTexEnviv");
}

static void APIENTRY noopGetTexEnvxv(GLenum target, GLenum pname, GLfixed *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetTexEnvxv");
}

static void APIENTRY noopGetTexEnvxvOES(GLenum target, GLenum pname, GLfixed *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetTexEnvxvOES");
}

static void APIENTRY noopGetTexFilterFuncSGIS(GLenum target, GLenum filter, GLfloat *weights)
{
   (void) target; (void) filter; (void) weights;
   noop_warn("glGetTexFilterFuncSGIS");
}

static void APIENTRY noopGetTexGendv(GLenum coord, GLenum pname, GLdouble *params)
{
   (void) coord; (void) pname; (void) params;
   noop_warn("glGetTexGendv");
}

static void APIENTRY noopGetTexGenfv(GLenum coord, GLenum pname, GLfloat *params)
{
   (void) coord; (void) pname; (void) params;
   noop_warn("glGetTexGenfv");
}

static void APIENTRY noopGetTexGenfvOES(GLenum coord, GLenum pname, GLfloat *params)
{
   (void) coord; (void) pname; (void) params;
   noop_warn("glGetTexGenfvOES");
}

static void APIENTRY noopGetTexGeniv(GLenum coord, GLenum pname, GLint *params)
{
   (void) coord; (void) pname; (void) params;
   noop_warn("glGetTexGeniv");
}

static void APIENTRY noopGetTexGenivOES(GLenum coord, GLenum pname, GLint *params)
{
   (void) coord; (void) pname; (void) params;
   noop_warn("glGetTexGenivOES");
}

static void APIENTRY noopGetTexGenxvOES(GLenum coord, GLenum pname, GLfixed *params)
{
   (void) coord; (void) pname; (void) params;
   noop_warn("glGetTexGenxvOES");
}

static void APIENTRY noopGetTexImage(GLenum target, GLint level, GLenum format, GLenum type, void *pixels)
{
   (void) target; (void) level; (void) format; (void) type; (void) pixels;
   noop_warn("glGetTexImage");
}

static void APIENTRY noopGetTexImageNV(GLenum target, GLint level, GLenum format, GLenum type, void *pixels)
{
   (void) target; (void) level; (void) format; (void) type; (void) pixels;
   noop_warn("glGetTexImageNV");
}

static void APIENTRY noopGetTexLevelParameterfv(GLenum target, GLint level, GLenum pname, GLfloat *params)
{
   (void) target; (void) level; (void) pname; (void) params;
   noop_warn("glGetTexLevelParameterfv");
}

static void APIENTRY noopGetTexLevelParameterfvNV(GLenum target, GLint level, GLenum pname, GLfloat *params)
{
   (void) target; (void) level; (void) pname; (void) params;
   noop_warn("glGetTexLevelParameterfvNV");
}

static void APIENTRY noopGetTexLevelParameteriv(GLenum target, GLint level, GLenum pname, GLint *params)
{
   (void) target; (void) level; (void) pname; (void) params;
   noop_warn("glGetTexLevelParameteriv");
}

static void APIENTRY noopGetTexLevelParameterivNV(GLenum target, GLint level, GLenum pname, GLint *params)
{
   (void) target; (void) level; (void) pname; (void) params;
   noop_warn("glGetTexLevelParameterivNV");
}

static void APIENTRY noopGetTexLevelParameterxvOES(GLenum target, GLint level, GLenum pname, GLfixed *params)
{
   (void) target; (void) level; (void) pname; (void) params;
   noop_warn("glGetTexLevelParameterxvOES");
}

static void APIENTRY noopGetTexParameterIiv(GLenum target, GLenum pname, GLint *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetTexParameterIiv");
}

static void APIENTRY noopGetTexParameterIivEXT(GLenum target, GLenum pname, GLint *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetTexParameterIivEXT");
}

static void APIENTRY noopGetTexParameterIivOES(GLenum target, GLenum pname, GLint *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetTexParameterIivOES");
}

static void APIENTRY noopGetTexParameterIuiv(GLenum target, GLenum pname, GLuint *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetTexParameterIuiv");
}

static void APIENTRY noopGetTexParameterIuivEXT(GLenum target, GLenum pname, GLuint *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetTexParameterIuivEXT");
}

static void APIENTRY noopGetTexParameterIuivOES(GLenum target, GLenum pname, GLuint *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetTexParameterIuivOES");
}

static void APIENTRY noopGetTexParameterPointervAPPLE(GLenum target, GLenum pname, void **params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetTexParameterPointervAPPLE");
}

static void APIENTRY noopGetTexParameterfv(GLenum target, GLenum pname, GLfloat *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetTexParameterfv");
}

static void APIENTRY noopGetTexParameteriv(GLenum target, GLenum pname, GLint *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetTexParameteriv");
}

static void APIENTRY noopGetTexParameterxv(GLenum target, GLenum pname, GLfixed *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetTexParameterxv");
}

static void APIENTRY noopGetTexParameterxvOES(GLenum target, GLenum pname, GLfixed *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glGetTexParameterxvOES");
}

static GLuint64 APIENTRY noopGetTextureHandleARB(GLuint texture)
{
   (void) texture;
   noop_warn("glGetTextureHandleARB");
   return (GLuint64) 0;
}

static GLuint64 APIENTRY noopGetTextureHandleIMG(GLuint texture)
{
   (void) texture;
   noop_warn("glGetTextureHandleIMG");
   return (GLuint64) 0;
}

static GLuint64 APIENTRY noopGetTextureHandleNV(GLuint texture)
{
   (void) texture;
   noop_warn("glGetTextureHandleNV");
   return (GLuint64) 0;
}

static void APIENTRY noopGetTextureImage(GLuint texture, GLint level, GLenum format, GLenum type, GLsizei bufSize, void *pixels)
{
   (void) texture; (void) level; (void) format; (void) type; (void) bufSize; (void) pixels;
   noop_warn("glGetTextureImage");
}

static void APIENTRY noopGetTextureImageEXT(GLuint texture, GLenum target, GLint level, GLenum format, GLenum type, void *pixels)
{
   (void) texture; (void) target; (void) level; (void) format; (void) type; (void) pixels;
   noop_warn("glGetTextureImageEXT");
}

static void APIENTRY noopGetTextureLevelParameterfv(GLuint texture, GLint level, GLenum pname, GLfloat *params)
{
   (void) texture; (void) level; (void) pname; (void) params;
   noop_warn("glGetTextureLevelParameterfv");
}

static void APIENTRY noopGetTextureLevelParameterfvEXT(GLuint texture, GLenum target, GLint level, GLenum pname, GLfloat *params)
{
   (void) texture; (void) target; (void) level; (void) pname; (void) params;
   noop_warn("glGetTextureLevelParameterfvEXT");
}

static void APIENTRY noopGetTextureLevelParameteriv(GLuint texture, GLint level, GLenum pname, GLint *params)
{
   (void) texture; (void) level; (void) pname; (void) params;
   noop_warn("glGetTextureLevelParameteriv");
}

static void APIENTRY noopGetTextureLevelParameterivEXT(GLuint texture, GLenum target, GLint level, GLenum pname, GLint *params)
{
   (void) texture; (void) target; (void) level; (void) pname; (void) params;
   noop_warn("glGetTextureLevelParameterivEXT");
}

static void APIENTRY noopGetTextureParameterIiv(GLuint texture, GLenum pname, GLint *params)
{
   (void) texture; (void) pname; (void) params;
   noop_warn("glGetTextureParameterIiv");
}

static void APIENTRY noopGetTextureParameterIivEXT(GLuint texture, GLenum target, GLenum pname, GLint *params)
{
   (void) texture; (void) target; (void) pname; (void) params;
   noop_warn("glGetTextureParameterIivEXT");
}

static void APIENTRY noopGetTextureParameterIuiv(GLuint texture, GLenum pname, GLuint *params)
{
   (void) texture; (void) pname; (void) params;
   noop_warn("glGetTextureParameterIuiv");
}

static void APIENTRY noopGetTextureParameterIuivEXT(GLuint texture, GLenum target, GLenum pname, GLuint *params)
{
   (void) texture; (void) target; (void) pname; (void) params;
   noop_warn("glGetTextureParameterIuivEXT");
}

static void APIENTRY noopGetTextureParameterfv(GLuint texture, GLenum pname, GLfloat *params)
{
   (void) texture; (void) pname; (void) params;
   noop_warn("glGetTextureParameterfv");
}

static void APIENTRY noopGetTextureParameterfvEXT(GLuint texture, GLenum target, GLenum pname, GLfloat *params)
{
   (void) texture; (void) target; (void) pname; (void) params;
   noop_warn("glGetTextureParameterfvEXT");
}

static void APIENTRY noopGetTextureParameteriv(GLuint texture, GLenum pname, GLint *params)
{
   (void) texture; (void) pname; (void) params;
   noop_warn("glGetTextureParameteriv");
}

static void APIENTRY noopGetTextureParameterivEXT(GLuint texture, GLenum target, GLenum pname, GLint *params)
{
   (void) texture; (void) target; (void) pname; (void) params;
   noop_warn("glGetTextureParameterivEXT");
}

static GLuint64 APIENTRY noopGetTextureSamplerHandleARB(GLuint texture, GLuint sampler)
{
   (void) texture; (void) sampler;
   noop_warn("glGetTextureSamplerHandleARB");
   return (GLuint64) 0;
}

static GLuint64 APIENTRY noopGetTextureSamplerHandleIMG(GLuint texture, GLuint sampler)
{
   (void) texture; (void) sampler;
   noop_warn("glGetTextureSamplerHandleIMG");
   return (GLuint64) 0;
}

static GLuint64 APIENTRY noopGetTextureSamplerHandleNV(GLuint texture, GLuint sampler)
{
   (void) texture; (void) sampler;
   noop_warn("glGetTextureSamplerHandleNV");
   return (GLuint64) 0;
}

static void APIENTRY noopGetTextureSubImage(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, GLsizei bufSize, void *pixels)
{
   (void) texture; (void) level; (void) xoffset; (void) yoffset; (void) zoffset; (void) width; (void) height; (void) depth; (void) format; (void) type; (void) bufSize; (void) pixels;
   noop_warn("glGetTextureSubImage");
}

static void APIENTRY noopGetTrackMatrixivNV(GLenum target, GLuint address, GLenum pname, GLint *params)
{
   (void) target; (void) address; (void) pname; (void) params;
   noop_warn("glGetTrackMatrixivNV");
}

static void APIENTRY noopGetTransformFeedbackVarying(GLuint program, GLuint index, GLsizei bufSize, GLsizei *length, GLsizei *size, GLenum *type, GLchar *name)
{
   (void) program; (void) index; (void) bufSize; (void) length; (void) size; (void) type; (void) name;
   noop_warn("glGetTransformFeedbackVarying");
}

static void APIENTRY noopGetTransformFeedbackVaryingEXT(GLuint program, GLuint index, GLsizei bufSize, GLsizei *length, GLsizei *size, GLenum *type, GLchar *name)
{
   (void) program; (void) index; (void) bufSize; (void) length; (void) size; (void) type; (void) name;
   noop_warn("glGetTransformFeedbackVaryingEXT");
}

static void APIENTRY noopGetTransformFeedbackVaryingNV(GLuint program, GLuint index, GLint *location)
{
   (void) program; (void) index; (void) location;
   noop_warn("glGetTransformFeedbackVaryingNV");
}

static void APIENTRY noopGetTransformFeedbacki64_v(GLuint xfb, GLenum pname, GLuint index, GLint64 *param)
{
   (void) xfb; (void) pname; (void) index; (void) param;
   noop_warn("glGetTransformFeedbacki64_v");
}

static void APIENTRY noopGetTransformFeedbacki_v(GLuint xfb, GLenum pname, GLuint index, GLint *param)
{
   (void) xfb; (void) pname; (void) index; (void) param;
   noop_warn("glGetTransformFeedbacki_v");
}

static void APIENTRY noopGetTransformFeedbackiv(GLuint xfb, GLenum pname, GLint *param)
{
   (void) xfb; (void) pname; (void) param;
   noop_warn("glGetTransformFeedbackiv");
}

static void APIENTRY noopGetTranslatedShaderSourceANGLE(GLuint shader, GLsizei bufSize, GLsizei *length, GLchar *source)
{
   (void) shader; (void) bufSize; (void) length; (void) source;
   noop_warn("glGetTranslatedShaderSourceANGLE");
}

static GLuint APIENTRY noopGetUniformBlockIndex(GLuint program, const GLchar *uniformBlockName)
{
   (void) program; (void) uniformBlockName;
   noop_warn("glGetUniformBlockIndex");
   return (GLuint) 0;
}

static GLint APIENTRY noopGetUniformBufferSizeEXT(GLuint program, GLint location)
{
   (void) program; (void) location;
   noop_warn("glGetUniformBufferSizeEXT");
   return (GLint) 0;
}

static void APIENTRY noopGetUniformIndices(GLuint program, GLsizei uniformCount, const GLchar *const *uniformNames, GLuint *uniformIndices)
{
   (void) program; (void) uniformCount; (void) uniformNames; (void) uniformIndices;
   noop_warn("glGetUniformIndices");
}

static GLint APIENTRY noopGetUniformLocation(GLuint program, const GLchar *name)
{
   (void) program; (void) name;
   noop_warn("glGetUniformLocation");
   return (GLint) 0;
}

static GLint APIENTRY noopGetUniformLocationARB(GLhandleARB programObj, const GLcharARB *name)
{
   (void) programObj; (void) name;
   noop_warn("glGetUniformLocationARB");
   return (GLint) 0;
}

static GLintptr APIENTRY noopGetUniformOffsetEXT(GLuint program, GLint location)
{
   (void) program; (void) location;
   noop_warn("glGetUniformOffsetEXT");
   return (GLintptr) 0;
}

static void APIENTRY noopGetUniformSubroutineuiv(GLenum shadertype, GLint location, GLuint *params)
{
   (void) shadertype; (void) location; (void) params;
   noop_warn("glGetUniformSubroutineuiv");
}

static void APIENTRY noopGetUniformdv(GLuint program, GLint location, GLdouble *params)
{
   (void) program; (void) location; (void) params;
   noop_warn("glGetUniformdv");
}

static void APIENTRY noopGetUniformfv(GLuint program, GLint location, GLfloat *params)
{
   (void) program; (void) location; (void) params;
   noop_warn("glGetUniformfv");
}

static void APIENTRY noopGetUniformfvARB(GLhandleARB programObj, GLint location, GLfloat *params)
{
   (void) programObj; (void) location; (void) params;
   noop_warn("glGetUniformfvARB");
}

static void APIENTRY noopGetUniformi64vARB(GLuint program, GLint location, GLint64 *params)
{
   (void) program; (void) location; (void) params;
   noop_warn("glGetUniformi64vARB");
}

static void APIENTRY noopGetUniformi64vNV(GLuint program, GLint location, GLint64 *params)
{
   (void) program; (void) location; (void) params;
   noop_warn("glGetUniformi64vNV");
}

static void APIENTRY noopGetUniformiv(GLuint program, GLint location, GLint *params)
{
   (void) program; (void) location; (void) params;
   noop_warn("glGetUniformiv");
}

static void APIENTRY noopGetUniformivARB(GLhandleARB programObj, GLint location, GLint *params)
{
   (void) programObj; (void) location; (void) params;
   noop_warn("glGetUniformivARB");
}

static void APIENTRY noopGetUniformui64vARB(GLuint program, GLint location, GLuint64 *params)
{
   (void) program; (void) location; (void) params;
   noop_warn("glGetUniformui64vARB");
}

static void APIENTRY noopGetUniformui64vNV(GLuint program, GLint location, GLuint64 *params)
{
   (void) program; (void) location; (void) params;
   noop_warn("glGetUniformui64vNV");
}

static void APIENTRY noopGetUniformuiv(GLuint program, GLint location, GLuint *params)
{
   (void) program; (void) location; (void) params;
   noop_warn("glGetUniformuiv");
}

static void APIENTRY noopGetUniformuivEXT(GLuint program, GLint location, GLuint *params)
{
   (void) program; (void) location; (void) params;
   noop_warn("glGetUniformuivEXT");
}

static void APIENTRY noopGetUnsignedBytei_vEXT(GLenum target, GLuint index, GLubyte *data)
{
   (void) target; (void) index; (void) data;
   noop_warn("glGetUnsignedBytei_vEXT");
}

static void APIENTRY noopGetUnsignedBytevEXT(GLenum pname, GLubyte *data)
{
   (void) pname; (void) data;
   noop_warn("glGetUnsignedBytevEXT");
}

static void APIENTRY noopGetVariantArrayObjectfvATI(GLuint id, GLenum pname, GLfloat *params)
{
   (void) id; (void) pname; (void) params;
   noop_warn("glGetVariantArrayObjectfvATI");
}

static void APIENTRY noopGetVariantArrayObjectivATI(GLuint id, GLenum pname, GLint *params)
{
   (void) id; (void) pname; (void) params;
   noop_warn("glGetVariantArrayObjectivATI");
}

static void APIENTRY noopGetVariantBooleanvEXT(GLuint id, GLenum value, GLboolean *data)
{
   (void) id; (void) value; (void) data;
   noop_warn("glGetVariantBooleanvEXT");
}

static void APIENTRY noopGetVariantFloatvEXT(GLuint id, GLenum value, GLfloat *data)
{
   (void) id; (void) value; (void) data;
   noop_warn("glGetVariantFloatvEXT");
}

static void APIENTRY noopGetVariantIntegervEXT(GLuint id, GLenum value, GLint *data)
{
   (void) id; (void) value; (void) data;
   noop_warn("glGetVariantIntegervEXT");
}

static void APIENTRY noopGetVariantPointervEXT(GLuint id, GLenum value, void **data)
{
   (void) id; (void) value; (void) data;
   noop_warn("glGetVariantPointervEXT");
}

static GLint APIENTRY noopGetVaryingLocationNV(GLuint program, const GLchar *name)
{
   (void) program; (void) name;
   noop_warn("glGetVaryingLocationNV");
   return (GLint) 0;
}

static void APIENTRY noopGetVertexArrayIndexed64iv(GLuint vaobj, GLuint index, GLenum pname, GLint64 *param)
{
   (void) vaobj; (void) index; (void) pname; (void) param;
   noop_warn("glGetVertexArrayIndexed64iv");
}

static void APIENTRY noopGetVertexArrayIndexediv(GLuint vaobj, GLuint index, GLenum pname, GLint *param)
{
   (void) vaobj; (void) index; (void) pname; (void) param;
   noop_warn("glGetVertexArrayIndexediv");
}

static void APIENTRY noopGetVertexArrayIntegeri_vEXT(GLuint vaobj, GLuint index, GLenum pname, GLint *param)
{
   (void) vaobj; (void) index; (void) pname; (void) param;
   noop_warn("glGetVertexArrayIntegeri_vEXT");
}

static void APIENTRY noopGetVertexArrayIntegervEXT(GLuint vaobj, GLenum pname, GLint *param)
{
   (void) vaobj; (void) pname; (void) param;
   noop_warn("glGetVertexArrayIntegervEXT");
}

static void APIENTRY noopGetVertexArrayPointeri_vEXT(GLuint vaobj, GLuint index, GLenum pname, void **param)
{
   (void) vaobj; (void) index; (void) pname; (void) param;
   noop_warn("glGetVertexArrayPointeri_vEXT");
}

static void APIENTRY noopGetVertexArrayPointervEXT(GLuint vaobj, GLenum pname, void **param)
{
   (void) vaobj; (void) pname; (void) param;
   noop_warn("glGetVertexArrayPointervEXT");
}

static void APIENTRY noopGetVertexArrayiv(GLuint vaobj, GLenum pname, GLint *param)
{
   (void) vaobj; (void) pname; (void) param;
   noop_warn("glGetVertexArrayiv");
}

static void APIENTRY noopGetVertexAttribArrayObjectfvATI(GLuint index, GLenum pname, GLfloat *params)
{
   (void) index; (void) pname; (void) params;
   noop_warn("glGetVertexAttribArrayObjectfvATI");
}

static void APIENTRY noopGetVertexAttribArrayObjectivATI(GLuint index, GLenum pname, GLint *params)
{
   (void) index; (void) pname; (void) params;
   noop_warn("glGetVertexAttribArrayObjectivATI");
}

static void APIENTRY noopGetVertexAttribIiv(GLuint index, GLenum pname, GLint *params)
{
   (void) index; (void) pname; (void) params;
   noop_warn("glGetVertexAttribIiv");
}

static void APIENTRY noopGetVertexAttribIivEXT(GLuint index, GLenum pname, GLint *params)
{
   (void) index; (void) pname; (void) params;
   noop_warn("glGetVertexAttribIivEXT");
}

static void APIENTRY noopGetVertexAttribIuiv(GLuint index, GLenum pname, GLuint *params)
{
   (void) index; (void) pname; (void) params;
   noop_warn("glGetVertexAttribIuiv");
}

static void APIENTRY noopGetVertexAttribIuivEXT(GLuint index, GLenum pname, GLuint *params)
{
   (void) index; (void) pname; (void) params;
   noop_warn("glGetVertexAttribIuivEXT");
}

static void APIENTRY noopGetVertexAttribLdv(GLuint index, GLenum pname, GLdouble *params)
{
   (void) index; (void) pname; (void) params;
   noop_warn("glGetVertexAttribLdv");
}

static void APIENTRY noopGetVertexAttribLdvEXT(GLuint index, GLenum pname, GLdouble *params)
{
   (void) index; (void) pname; (void) params;
   noop_warn("glGetVertexAttribLdvEXT");
}

static void APIENTRY noopGetVertexAttribLi64vNV(GLuint index, GLenum pname, GLint64 *params)
{
   (void) index; (void) pname; (void) params;
   noop_warn("glGetVertexAttribLi64vNV");
}

static void APIENTRY noopGetVertexAttribLui64vARB(GLuint index, GLenum pname, GLuint64 *params)
{
   (void) index; (void) pname; (void) params;
   noop_warn("glGetVertexAttribLui64vARB");
}

static void APIENTRY noopGetVertexAttribLui64vNV(GLuint index, GLenum pname, GLuint64 *params)
{
   (void) index; (void) pname; (void) params;
   noop_warn("glGetVertexAttribLui64vNV");
}

static void APIENTRY noopGetVertexAttribPointerv(GLuint index, GLenum pname, void **pointer)
{
   (void) index; (void) pname; (void) pointer;
   noop_warn("glGetVertexAttribPointerv");
}

static void APIENTRY noopGetVertexAttribPointervARB(GLuint index, GLenum pname, void **pointer)
{
   (void) index; (void) pname; (void) pointer;
   noop_warn("glGetVertexAttribPointervARB");
}

static void APIENTRY noopGetVertexAttribPointervNV(GLuint index, GLenum pname, void **pointer)
{
   (void) index; (void) pname; (void) pointer;
   noop_warn("glGetVertexAttribPointervNV");
}

static void APIENTRY noopGetVertexAttribdv(GLuint index, GLenum pname, GLdouble *params)
{
   (void) index; (void) pname; (void) params;
   noop_warn("glGetVertexAttribdv");
}

static void APIENTRY noopGetVertexAttribdvARB(GLuint index, GLenum pname, GLdouble *params)
{
   (void) index; (void) pname; (void) params;
   noop_warn("glGetVertexAttribdvARB");
}

static void APIENTRY noopGetVertexAttribdvNV(GLuint index, GLenum pname, GLdouble *params)
{
   (void) index; (void) pname; (void) params;
   noop_warn("glGetVertexAttribdvNV");
}

static void APIENTRY noopGetVertexAttribfv(GLuint index, GLenum pname, GLfloat *params)
{
   (void) index; (void) pname; (void) params;
   noop_warn("glGetVertexAttribfv");
}

static void APIENTRY noopGetVertexAttribfvARB(GLuint index, GLenum pname, GLfloat *params)
{
   (void) index; (void) pname; (void) params;
   noop_warn("glGetVertexAttribfvARB");
}

static void APIENTRY noopGetVertexAttribfvNV(GLuint index, GLenum pname, GLfloat *params)
{
   (void) index; (void) pname; (void) params;
   noop_warn("glGetVertexAttribfvNV");
}

static void APIENTRY noopGetVertexAttribiv(GLuint index, GLenum pname, GLint *params)
{
   (void) index; (void) pname; (void) params;
   noop_warn("glGetVertexAttribiv");
}

static void APIENTRY noopGetVertexAttribivARB(GLuint index, GLenum pname, GLint *params)
{
   (void) index; (void) pname; (void) params;
   noop_warn("glGetVertexAttribivARB");
}

static void APIENTRY noopGetVertexAttribivNV(GLuint index, GLenum pname, GLint *params)
{
   (void) index; (void) pname; (void) params;
   noop_warn("glGetVertexAttribivNV");
}

static void APIENTRY noopGetVideoCaptureANCStreamivNVX(GLuint video_capture_slot, GLuint stream, GLenum pname, GLenum frame_region, GLenum anc_region, GLint *params)
{
   (void) video_capture_slot; (void) stream; (void) pname; (void) frame_region; (void) anc_region; (void) params;
   noop_warn("glGetVideoCaptureANCStreamivNVX");
}

static void APIENTRY noopGetVideoCaptureStreamdvNV(GLuint video_capture_slot, GLuint stream, GLenum pname, GLdouble *params)
{
   (void) video_capture_slot; (void) stream; (void) pname; (void) params;
   noop_warn("glGetVideoCaptureStreamdvNV");
}

static void APIENTRY noopGetVideoCaptureStreamfvNV(GLuint video_capture_slot, GLuint stream, GLenum pname, GLfloat *params)
{
   (void) video_capture_slot; (void) stream; (void) pname; (void) params;
   noop_warn("glGetVideoCaptureStreamfvNV");
}

static void APIENTRY noopGetVideoCaptureStreamivNV(GLuint video_capture_slot, GLuint stream, GLenum pname, GLint *params)
{
   (void) video_capture_slot; (void) stream; (void) pname; (void) params;
   noop_warn("glGetVideoCaptureStreamivNV");
}

static void APIENTRY noopGetVideoCaptureivNV(GLuint video_capture_slot, GLenum pname, GLint *params)
{
   (void) video_capture_slot; (void) pname; (void) params;
   noop_warn("glGetVideoCaptureivNV");
}

static void APIENTRY noopGetVideoi64vNV(GLuint video_slot, GLenum pname, GLint64 *params)
{
   (void) video_slot; (void) pname; (void) params;
   noop_warn("glGetVideoi64vNV");
}

static void APIENTRY noopGetVideoivNV(GLuint video_slot, GLenum pname, GLint *params)
{
   (void) video_slot; (void) pname; (void) params;
   noop_warn("glGetVideoivNV");
}

static void APIENTRY noopGetVideoui64vNV(GLuint video_slot, GLenum pname, GLuint64 *params)
{
   (void) video_slot; (void) pname; (void) params;
   noop_warn("glGetVideoui64vNV");
}

static void APIENTRY noopGetVideouivNV(GLuint video_slot, GLenum pname, GLuint *params)
{
   (void) video_slot; (void) pname; (void) params;
   noop_warn("glGetVideouivNV");
}

static GLVULKANPROCNV APIENTRY noopGetVkProcAddrNV(const GLchar *name)
{
   (void) name;
   noop_warn("glGetVkProcAddrNV");
   return (GLVULKANPROCNV) 0;
}

static void APIENTRY noopGetnColorTable(GLenum target, GLenum format, GLenum type, GLsizei bufSize, void *table)
{
   (void) target; (void) format; (void) type; (void) bufSize; (void) table;
   noop_warn("glGetnColorTable");
}

static void APIENTRY noopGetnColorTableARB(GLenum target, GLenum format, GLenum type, GLsizei bufSize, void *table)
{
   (void) target; (void) format; (void) type; (void) bufSize; (void) table;
   noop_warn("glGetnColorTableARB");
}

static void APIENTRY noopGetnCompressedTexImage(GLenum target, GLint lod, GLsizei bufSize, void *pixels)
{
   (void) target; (void) lod; (void) bufSize; (void) pixels;
   noop_warn("glGetnCompressedTexImage");
}

static void APIENTRY noopGetnCompressedTexImageARB(GLenum target, GLint lod, GLsizei bufSize, void *img)
{
   (void) target; (void) lod; (void) bufSize; (void) img;
   noop_warn("glGetnCompressedTexImageARB");
}

static void APIENTRY noopGetnConvolutionFilter(GLenum target, GLenum format, GLenum type, GLsizei bufSize, void *image)
{
   (void) target; (void) format; (void) type; (void) bufSize; (void) image;
   noop_warn("glGetnConvolutionFilter");
}

static void APIENTRY noopGetnConvolutionFilterARB(GLenum target, GLenum format, GLenum type, GLsizei bufSize, void *image)
{
   (void) target; (void) format; (void) type; (void) bufSize; (void) image;
   noop_warn("glGetnConvolutionFilterARB");
}

static void APIENTRY noopGetnHistogram(GLenum target, GLboolean reset, GLenum format, GLenum type, GLsizei bufSize, void *values)
{
   (void) target; (void) reset; (void) format; (void) type; (void) bufSize; (void) values;
   noop_warn("glGetnHistogram");
}

static void APIENTRY noopGetnHistogramARB(GLenum target, GLboolean reset, GLenum format, GLenum type, GLsizei bufSize, void *values)
{
   (void) target; (void) reset; (void) format; (void) type; (void) bufSize; (void) values;
   noop_warn("glGetnHistogramARB");
}

static void APIENTRY noopGetnMapdv(GLenum target, GLenum query, GLsizei bufSize, GLdouble *v)
{
   (void) target; (void) query; (void) bufSize; (void) v;
   noop_warn("glGetnMapdv");
}

static void APIENTRY noopGetnMapdvARB(GLenum target, GLenum query, GLsizei bufSize, GLdouble *v)
{
   (void) target; (void) query; (void) bufSize; (void) v;
   noop_warn("glGetnMapdvARB");
}

static void APIENTRY noopGetnMapfv(GLenum target, GLenum query, GLsizei bufSize, GLfloat *v)
{
   (void) target; (void) query; (void) bufSize; (void) v;
   noop_warn("glGetnMapfv");
}

static void APIENTRY noopGetnMapfvARB(GLenum target, GLenum query, GLsizei bufSize, GLfloat *v)
{
   (void) target; (void) query; (void) bufSize; (void) v;
   noop_warn("glGetnMapfvARB");
}

static void APIENTRY noopGetnMapiv(GLenum target, GLenum query, GLsizei bufSize, GLint *v)
{
   (void) target; (void) query; (void) bufSize; (void) v;
   noop_warn("glGetnMapiv");
}

static void APIENTRY noopGetnMapivARB(GLenum target, GLenum query, GLsizei bufSize, GLint *v)
{
   (void) target; (void) query; (void) bufSize; (void) v;
   noop_warn("glGetnMapivARB");
}

static void APIENTRY noopGetnMinmax(GLenum target, GLboolean reset, GLenum format, GLenum type, GLsizei bufSize, void *values)
{
   (void) target; (void) reset; (void) format; (void) type; (void) bufSize; (void) values;
   noop_warn("glGetnMinmax");
}

static void APIENTRY noopGetnMinmaxARB(GLenum target, GLboolean reset, GLenum format, GLenum type, GLsizei bufSize, void *values)
{
   (void) target; (void) reset; (void) format; (void) type; (void) bufSize; (void) values;
   noop_warn("glGetnMinmaxARB");
}

static void APIENTRY noopGetnPixelMapfv(GLenum map, GLsizei bufSize, GLfloat *values)
{
   (void) map; (void) bufSize; (void) values;
   noop_warn("glGetnPixelMapfv");
}

static void APIENTRY noopGetnPixelMapfvARB(GLenum map, GLsizei bufSize, GLfloat *values)
{
   (void) map; (void) bufSize; (void) values;
   noop_warn("glGetnPixelMapfvARB");
}

static void APIENTRY noopGetnPixelMapuiv(GLenum map, GLsizei bufSize, GLuint *values)
{
   (void) map; (void) bufSize; (void) values;
   noop_warn("glGetnPixelMapuiv");
}

static void APIENTRY noopGetnPixelMapuivARB(GLenum map, GLsizei bufSize, GLuint *values)
{
   (void) map; (void) bufSize; (void) values;
   noop_warn("glGetnPixelMapuivARB");
}

static void APIENTRY noopGetnPixelMapusv(GLenum map, GLsizei bufSize, GLushort *values)
{
   (void) map; (void) bufSize; (void) values;
   noop_warn("glGetnPixelMapusv");
}

static void APIENTRY noopGetnPixelMapusvARB(GLenum map, GLsizei bufSize, GLushort *values)
{
   (void) map; (void) bufSize; (void) values;
   noop_warn("glGetnPixelMapusvARB");
}

static void APIENTRY noopGetnPolygonStipple(GLsizei bufSize, GLubyte *pattern)
{
   (void) bufSize; (void) pattern;
   noop_warn("glGetnPolygonStipple");
}

static void APIENTRY noopGetnPolygonStippleARB(GLsizei bufSize, GLubyte *pattern)
{
   (void) bufSize; (void) pattern;
   noop_warn("glGetnPolygonStippleARB");
}

static void APIENTRY noopGetnSeparableFilter(GLenum target, GLenum format, GLenum type, GLsizei rowBufSize, void *row, GLsizei columnBufSize, void *column, void *span)
{
   (void) target; (void) format; (void) type; (void) rowBufSize; (void) row; (void) columnBufSize; (void) column; (void) span;
   noop_warn("glGetnSeparableFilter");
}

static void APIENTRY noopGetnSeparableFilterARB(GLenum target, GLenum format, GLenum type, GLsizei rowBufSize, void *row, GLsizei columnBufSize, void *column, void *span)
{
   (void) target; (void) format; (void) type; (void) rowBufSize; (void) row; (void) columnBufSize; (void) column; (void) span;
   noop_warn("glGetnSeparableFilterARB");
}

static void APIENTRY noopGetnTexImage(GLenum target, GLint level, GLenum format, GLenum type, GLsizei bufSize, void *pixels)
{
   (void) target; (void) level; (void) format; (void) type; (void) bufSize; (void) pixels;
   noop_warn("glGetnTexImage");
}

static void APIENTRY noopGetnTexImageARB(GLenum target, GLint level, GLenum format, GLenum type, GLsizei bufSize, void *img)
{
   (void) target; (void) level; (void) format; (void) type; (void) bufSize; (void) img;
   noop_warn("glGetnTexImageARB");
}

static void APIENTRY noopGetnUniformdv(GLuint program, GLint location, GLsizei bufSize, GLdouble *params)
{
   (void) program; (void) location; (void) bufSize; (void) params;
   noop_warn("glGetnUniformdv");
}

static void APIENTRY noopGetnUniformdvARB(GLuint program, GLint location, GLsizei bufSize, GLdouble *params)
{
   (void) program; (void) location; (void) bufSize; (void) params;
   noop_warn("glGetnUniformdvARB");
}

static void APIENTRY noopGetnUniformfv(GLuint program, GLint location, GLsizei bufSize, GLfloat *params)
{
   (void) program; (void) location; (void) bufSize; (void) params;
   noop_warn("glGetnUniformfv");
}

static void APIENTRY noopGetnUniformfvARB(GLuint program, GLint location, GLsizei bufSize, GLfloat *params)
{
   (void) program; (void) location; (void) bufSize; (void) params;
   noop_warn("glGetnUniformfvARB");
}

static void APIENTRY noopGetnUniformfvEXT(GLuint program, GLint location, GLsizei bufSize, GLfloat *params)
{
   (void) program; (void) location; (void) bufSize; (void) params;
   noop_warn("glGetnUniformfvEXT");
}

static void APIENTRY noopGetnUniformfvKHR(GLuint program, GLint location, GLsizei bufSize, GLfloat *params)
{
   (void) program; (void) location; (void) bufSize; (void) params;
   noop_warn("glGetnUniformfvKHR");
}

static void APIENTRY noopGetnUniformi64vARB(GLuint program, GLint location, GLsizei bufSize, GLint64 *params)
{
   (void) program; (void) location; (void) bufSize; (void) params;
   noop_warn("glGetnUniformi64vARB");
}

static void APIENTRY noopGetnUniformiv(GLuint program, GLint location, GLsizei bufSize, GLint *params)
{
   (void) program; (void) location; (void) bufSize; (void) params;
   noop_warn("glGetnUniformiv");
}

static void APIENTRY noopGetnUniformivARB(GLuint program, GLint location, GLsizei bufSize, GLint *params)
{
   (void) program; (void) location; (void) bufSize; (void) params;
   noop_warn("glGetnUniformivARB");
}

static void APIENTRY noopGetnUniformivEXT(GLuint program, GLint location, GLsizei bufSize, GLint *params)
{
   (void) program; (void) location; (void) bufSize; (void) params;
   noop_warn("glGetnUniformivEXT");
}

static void APIENTRY noopGetnUniformivKHR(GLuint program, GLint location, GLsizei bufSize, GLint *params)
{
   (void) program; (void) location; (void) bufSize; (void) params;
   noop_warn("glGetnUniformivKHR");
}

static void APIENTRY noopGetnUniformui64vARB(GLuint program, GLint location, GLsizei bufSize, GLuint64 *params)
{
   (void) program; (void) location; (void) bufSize; (void) params;
   noop_warn("glGetnUniformui64vARB");
}

static void APIENTRY noopGetnUniformuiv(GLuint program, GLint location, GLsizei bufSize, GLuint *params)
{
   (void) program; (void) location; (void) bufSize; (void) params;
   noop_warn("glGetnUniformuiv");
}

static void APIENTRY noopGetnUniformuivARB(GLuint program, GLint location, GLsizei bufSize, GLuint *params)
{
   (void) program; (void) location; (void) bufSize; (void) params;
   noop_warn("glGetnUniformuivARB");
}

static void APIENTRY noopGetnUniformuivKHR(GLuint program, GLint location, GLsizei bufSize, GLuint *params)
{
   (void) program; (void) location; (void) bufSize; (void) params;
   noop_warn("glGetnUniformuivKHR");
}

static void APIENTRY noopGlobalAlphaFactorbSUN(GLbyte factor)
{
   (void) factor;
   noop_warn("glGlobalAlphaFactorbSUN");
}

static void APIENTRY noopGlobalAlphaFactordSUN(GLdouble factor)
{
   (void) factor;
   noop_warn("glGlobalAlphaFactordSUN");
}

static void APIENTRY noopGlobalAlphaFactorfSUN(GLfloat factor)
{
   (void) factor;
   noop_warn("glGlobalAlphaFactorfSUN");
}

static void APIENTRY noopGlobalAlphaFactoriSUN(GLint factor)
{
   (void) factor;
   noop_warn("glGlobalAlphaFactoriSUN");
}

static void APIENTRY noopGlobalAlphaFactorsSUN(GLshort factor)
{
   (void) factor;
   noop_warn("glGlobalAlphaFactorsSUN");
}

static void APIENTRY noopGlobalAlphaFactorubSUN(GLubyte factor)
{
   (void) factor;
   noop_warn("glGlobalAlphaFactorubSUN");
}

static void APIENTRY noopGlobalAlphaFactoruiSUN(GLuint factor)
{
   (void) factor;
   noop_warn("glGlobalAlphaFactoruiSUN");
}

static void APIENTRY noopGlobalAlphaFactorusSUN(GLushort factor)
{
   (void) factor;
   noop_warn("glGlobalAlphaFactorusSUN");
}

static void APIENTRY noopGpuSyncAcquireNVX(GLintptr sync)
{
   (void) sync;
   noop_warn("glGpuSyncAcquireNVX");
}

static GLintptr APIENTRY noopGpuSyncCreateNVX(void)
{
   noop_warn("glGpuSyncCreateNVX");
   return (GLintptr) 0;
}

static void APIENTRY noopGpuSyncDestroyNVX(GLintptr sync)
{
   (void) sync;
   noop_warn("glGpuSyncDestroyNVX");
}

static void APIENTRY noopGpuSyncReleaseNVX(GLintptr sync)
{
   (void) sync;
   noop_warn("glGpuSyncReleaseNVX");
}

static void APIENTRY noopHint(GLenum target, GLenum mode)
{
   (void) target; (void) mode;
   noop_warn("glHint");
}

static void APIENTRY noopHintPGI(GLenum target, GLint mode)
{
   (void) target; (void) mode;
   noop_warn("glHintPGI");
}

static void APIENTRY noopHistogram(GLenum target, GLsizei width, GLenum internalformat, GLboolean sink)
{
   (void) target; (void) width; (void) internalformat; (void) sink;
   noop_warn("glHistogram");
}

static void APIENTRY noopHistogramEXT(GLenum target, GLsizei width, GLenum internalformat, GLboolean sink)
{
   (void) target; (void) width; (void) internalformat; (void) sink;
   noop_warn("glHistogramEXT");
}

static void APIENTRY noopIglooInterfaceSGIX(GLenum pname, const void *params)
{
   (void) pname; (void) params;
   noop_warn("glIglooInterfaceSGIX");
}

static void APIENTRY noopImageTransformParameterfHP(GLenum target, GLenum pname, GLfloat param)
{
   (void) target; (void) pname; (void) param;
   noop_warn("glImageTransformParameterfHP");
}

static void APIENTRY noopImageTransformParameterfvHP(GLenum target, GLenum pname, const GLfloat *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glImageTransformParameterfvHP");
}

static void APIENTRY noopImageTransformParameteriHP(GLenum target, GLenum pname, GLint param)
{
   (void) target; (void) pname; (void) param;
   noop_warn("glImageTransformParameteriHP");
}

static void APIENTRY noopImageTransformParameterivHP(GLenum target, GLenum pname, const GLint *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glImageTransformParameterivHP");
}

static void APIENTRY noopImportMemoryFdEXT(GLuint memory, GLuint64 size, GLenum handleType, GLint fd)
{
   (void) memory; (void) size; (void) handleType; (void) fd;
   noop_warn("glImportMemoryFdEXT");
}

static void APIENTRY noopImportMemoryWin32HandleEXT(GLuint memory, GLuint64 size, GLenum handleType, void *handle)
{
   (void) memory; (void) size; (void) handleType; (void) handle;
   noop_warn("glImportMemoryWin32HandleEXT");
}

static void APIENTRY noopImportMemoryWin32NameEXT(GLuint memory, GLuint64 size, GLenum handleType, const void *name)
{
   (void) memory; (void) size; (void) handleType; (void) name;
   noop_warn("glImportMemoryWin32NameEXT");
}

static void APIENTRY noopImportSemaphoreFdEXT(GLuint semaphore, GLenum handleType, GLint fd)
{
   (void) semaphore; (void) handleType; (void) fd;
   noop_warn("glImportSemaphoreFdEXT");
}

static void APIENTRY noopImportSemaphoreWin32HandleEXT(GLuint semaphore, GLenum handleType, void *handle)
{
   (void) semaphore; (void) handleType; (void) handle;
   noop_warn("glImportSemaphoreWin32HandleEXT");
}

static void APIENTRY noopImportSemaphoreWin32NameEXT(GLuint semaphore, GLenum handleType, const void *name)
{
   (void) semaphore; (void) handleType; (void) name;
   noop_warn("glImportSemaphoreWin32NameEXT");
}

static GLsync APIENTRY noopImportSyncEXT(GLenum external_sync_type, GLintptr external_sync, GLbitfield flags)
{
   (void) external_sync_type; (void) external_sync; (void) flags;
   noop_warn("glImportSyncEXT");
   return (GLsync) 0;
}

static void APIENTRY noopIndexFormatNV(GLenum type, GLsizei stride)
{
   (void) type; (void) stride;
   noop_warn("glIndexFormatNV");
}

static void APIENTRY noopIndexFuncEXT(GLenum func, GLclampf ref)
{
   (void) func; (void) ref;
   noop_warn("glIndexFuncEXT");
}

static void APIENTRY noopIndexMask(GLuint mask)
{
   (void) mask;
   noop_warn("glIndexMask");
}

static void APIENTRY noopIndexMaterialEXT(GLenum face, GLenum mode)
{
   (void) face; (void) mode;
   noop_warn("glIndexMaterialEXT");
}

static void APIENTRY noopIndexPointer(GLenum type, GLsizei stride, const void *pointer)
{
   (void) type; (void) stride; (void) pointer;
   noop_warn("glIndexPointer");
}

static void APIENTRY noopIndexPointerEXT(GLenum type, GLsizei stride, GLsizei count, const void *pointer)
{
   (void) type; (void) stride; (void) count; (void) pointer;
   noop_warn("glIndexPointerEXT");
}

static void APIENTRY noopIndexPointerListIBM(GLenum type, GLint stride, const void **pointer, GLint ptrstride)
{
   (void) type; (void) stride; (void) pointer; (void) ptrstride;
   noop_warn("glIndexPointerListIBM");
}

static void APIENTRY noopIndexd(GLdouble c)
{
   (void) c;
   noop_warn("glIndexd");
}

static void APIENTRY noopIndexdv(const GLdouble *c)
{
   (void) c;
   noop_warn("glIndexdv");
}

static void APIENTRY noopIndexf(GLfloat c)
{
   (void) c;
   noop_warn("glIndexf");
}

static void APIENTRY noopIndexfv(const GLfloat *c)
{
   (void) c;
   noop_warn("glIndexfv");
}

static void APIENTRY noopIndexi(GLint c)
{
   (void) c;
   noop_warn("glIndexi");
}

static void APIENTRY noopIndexiv(const GLint *c)
{
   (void) c;
   noop_warn("glIndexiv");
}

static void APIENTRY noopIndexs(GLshort c)
{
   (void) c;
   noop_warn("glIndexs");
}

static void APIENTRY noopIndexsv(const GLshort *c)
{
   (void) c;
   noop_warn("glIndexsv");
}

static void APIENTRY noopIndexub(GLubyte c)
{
   (void) c;
   noop_warn("glIndexub");
}

static void APIENTRY noopIndexubv(const GLubyte *c)
{
   (void) c;
   noop_warn("glIndexubv");
}

static void APIENTRY noopIndexxOES(GLfixed component)
{
   (void) component;
   noop_warn("glIndexxOES");
}

static void APIENTRY noopIndexxvOES(const GLfixed *component)
{
   (void) component;
   noop_warn("glIndexxvOES");
}

static void APIENTRY noopInitNames(void)
{
   noop_warn("glInitNames");
}

static void APIENTRY noopInsertComponentEXT(GLuint res, GLuint src, GLuint num)
{
   (void) res; (void) src; (void) num;
   noop_warn("glInsertComponentEXT");
}

static void APIENTRY noopInsertEventMarkerEXT(GLsizei length, const GLchar *marker)
{
   (void) length; (void) marker;
   noop_warn("glInsertEventMarkerEXT");
}

static void APIENTRY noopInstrumentsBufferSGIX(GLsizei size, GLint *buffer)
{
   (void) size; (void) buffer;
   noop_warn("glInstrumentsBufferSGIX");
}

static void APIENTRY noopInterleavedArrays(GLenum format, GLsizei stride, const void *pointer)
{
   (void) format; (void) stride; (void) pointer;
   noop_warn("glInterleavedArrays");
}

static void APIENTRY noopInterpolatePathsNV(GLuint resultPath, GLuint pathA, GLuint pathB, GLfloat weight)
{
   (void) resultPath; (void) pathA; (void) pathB; (void) weight;
   noop_warn("glInterpolatePathsNV");
}

static void APIENTRY noopInvalidateBufferData(GLuint buffer)
{
   (void) buffer;
   noop_warn("glInvalidateBufferData");
}

static void APIENTRY noopInvalidateBufferSubData(GLuint buffer, GLintptr offset, GLsizeiptr length)
{
   (void) buffer; (void) offset; (void) length;
   noop_warn("glInvalidateBufferSubData");
}

static void APIENTRY noopInvalidateFramebuffer(GLenum target, GLsizei numAttachments, const GLenum *attachments)
{
   (void) target; (void) numAttachments; (void) attachments;
   noop_warn("glInvalidateFramebuffer");
}

static void APIENTRY noopInvalidateNamedFramebufferData(GLuint framebuffer, GLsizei numAttachments, const GLenum *attachments)
{
   (void) framebuffer; (void) numAttachments; (void) attachments;
   noop_warn("glInvalidateNamedFramebufferData");
}

static void APIENTRY noopInvalidateNamedFramebufferSubData(GLuint framebuffer, GLsizei numAttachments, const GLenum *attachments, GLint x, GLint y, GLsizei width, GLsizei height)
{
   (void) framebuffer; (void) numAttachments; (void) attachments; (void) x; (void) y; (void) width; (void) height;
   noop_warn("glInvalidateNamedFramebufferSubData");
}

static void APIENTRY noopInvalidateSubFramebuffer(GLenum target, GLsizei numAttachments, const GLenum *attachments, GLint x, GLint y, GLsizei width, GLsizei height)
{
   (void) target; (void) numAttachments; (void) attachments; (void) x; (void) y; (void) width; (void) height;
   noop_warn("glInvalidateSubFramebuffer");
}

static void APIENTRY noopInvalidateTexImage(GLuint texture, GLint level)
{
   (void) texture; (void) level;
   noop_warn("glInvalidateTexImage");
}

static void APIENTRY noopInvalidateTexSubImage(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth)
{
   (void) texture; (void) level; (void) xoffset; (void) yoffset; (void) zoffset; (void) width; (void) height; (void) depth;
   noop_warn("glInvalidateTexSubImage");
}

static GLboolean APIENTRY noopIsAsyncMarkerSGIX(GLuint marker)
{
   (void) marker;
   noop_warn("glIsAsyncMarkerSGIX");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsBuffer(GLuint buffer)
{
   (void) buffer;
   noop_warn("glIsBuffer");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsBufferARB(GLuint buffer)
{
   (void) buffer;
   noop_warn("glIsBufferARB");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsBufferResidentNV(GLenum target)
{
   (void) target;
   noop_warn("glIsBufferResidentNV");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsCommandListNV(GLuint list)
{
   (void) list;
   noop_warn("glIsCommandListNV");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsEnabled(GLenum cap)
{
   (void) cap;
   noop_warn("glIsEnabled");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsEnabledIndexedEXT(GLenum target, GLuint index)
{
   (void) target; (void) index;
   noop_warn("glIsEnabledIndexedEXT");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsEnabledi(GLenum target, GLuint index)
{
   (void) target; (void) index;
   noop_warn("glIsEnabledi");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsEnablediEXT(GLenum target, GLuint index)
{
   (void) target; (void) index;
   noop_warn("glIsEnablediEXT");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsEnablediNV(GLenum target, GLuint index)
{
   (void) target; (void) index;
   noop_warn("glIsEnablediNV");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsEnablediOES(GLenum target, GLuint index)
{
   (void) target; (void) index;
   noop_warn("glIsEnablediOES");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsFenceAPPLE(GLuint fence)
{
   (void) fence;
   noop_warn("glIsFenceAPPLE");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsFenceNV(GLuint fence)
{
   (void) fence;
   noop_warn("glIsFenceNV");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsFramebuffer(GLuint framebuffer)
{
   (void) framebuffer;
   noop_warn("glIsFramebuffer");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsFramebufferEXT(GLuint framebuffer)
{
   (void) framebuffer;
   noop_warn("glIsFramebufferEXT");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsFramebufferOES(GLuint framebuffer)
{
   (void) framebuffer;
   noop_warn("glIsFramebufferOES");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsImageHandleResidentARB(GLuint64 handle)
{
   (void) handle;
   noop_warn("glIsImageHandleResidentARB");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsImageHandleResidentNV(GLuint64 handle)
{
   (void) handle;
   noop_warn("glIsImageHandleResidentNV");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsList(GLuint list)
{
   (void) list;
   noop_warn("glIsList");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsMemoryObjectEXT(GLuint memoryObject)
{
   (void) memoryObject;
   noop_warn("glIsMemoryObjectEXT");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsNameAMD(GLenum identifier, GLuint name)
{
   (void) identifier; (void) name;
   noop_warn("glIsNameAMD");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsNamedBufferResidentNV(GLuint buffer)
{
   (void) buffer;
   noop_warn("glIsNamedBufferResidentNV");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsNamedStringARB(GLint namelen, const GLchar *name)
{
   (void) namelen; (void) name;
   noop_warn("glIsNamedStringARB");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsObjectBufferATI(GLuint buffer)
{
   (void) buffer;
   noop_warn("glIsObjectBufferATI");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsOcclusionQueryNV(GLuint id)
{
   (void) id;
   noop_warn("glIsOcclusionQueryNV");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsPathNV(GLuint path)
{
   (void) path;
   noop_warn("glIsPathNV");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsPointInFillPathNV(GLuint path, GLuint mask, GLfloat x, GLfloat y)
{
   (void) path; (void) mask; (void) x; (void) y;
   noop_warn("glIsPointInFillPathNV");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsPointInStrokePathNV(GLuint path, GLfloat x, GLfloat y)
{
   (void) path; (void) x; (void) y;
   noop_warn("glIsPointInStrokePathNV");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsProgram(GLuint program)
{
   (void) program;
   noop_warn("glIsProgram");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsProgramARB(GLuint program)
{
   (void) program;
   noop_warn("glIsProgramARB");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsProgramNV(GLuint id)
{
   (void) id;
   noop_warn("glIsProgramNV");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsProgramPipeline(GLuint pipeline)
{
   (void) pipeline;
   noop_warn("glIsProgramPipeline");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsProgramPipelineEXT(GLuint pipeline)
{
   (void) pipeline;
   noop_warn("glIsProgramPipelineEXT");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsQuery(GLuint id)
{
   (void) id;
   noop_warn("glIsQuery");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsQueryARB(GLuint id)
{
   (void) id;
   noop_warn("glIsQueryARB");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsQueryEXT(GLuint id)
{
   (void) id;
   noop_warn("glIsQueryEXT");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsRenderbuffer(GLuint renderbuffer)
{
   (void) renderbuffer;
   noop_warn("glIsRenderbuffer");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsRenderbufferEXT(GLuint renderbuffer)
{
   (void) renderbuffer;
   noop_warn("glIsRenderbufferEXT");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsRenderbufferOES(GLuint renderbuffer)
{
   (void) renderbuffer;
   noop_warn("glIsRenderbufferOES");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsSampler(GLuint sampler)
{
   (void) sampler;
   noop_warn("glIsSampler");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsSemaphoreEXT(GLuint semaphore)
{
   (void) semaphore;
   noop_warn("glIsSemaphoreEXT");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsShader(GLuint shader)
{
   (void) shader;
   noop_warn("glIsShader");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsStateNV(GLuint state)
{
   (void) state;
   noop_warn("glIsStateNV");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsSync(GLsync sync)
{
   (void) sync;
   noop_warn("glIsSync");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsSyncAPPLE(GLsync sync)
{
   (void) sync;
   noop_warn("glIsSyncAPPLE");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsTexture(GLuint texture)
{
   (void) texture;
   noop_warn("glIsTexture");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsTextureEXT(GLuint texture)
{
   (void) texture;
   noop_warn("glIsTextureEXT");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsTextureHandleResidentARB(GLuint64 handle)
{
   (void) handle;
   noop_warn("glIsTextureHandleResidentARB");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsTextureHandleResidentNV(GLuint64 handle)
{
   (void) handle;
   noop_warn("glIsTextureHandleResidentNV");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsTransformFeedback(GLuint id)
{
   (void) id;
   noop_warn("glIsTransformFeedback");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsTransformFeedbackEXT(GLuint id)
{
   (void) id;
   noop_warn("glIsTransformFeedbackEXT");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsTransformFeedbackNV(GLuint id)
{
   (void) id;
   noop_warn("glIsTransformFeedbackNV");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsVariantEnabledEXT(GLuint id, GLenum cap)
{
   (void) id; (void) cap;
   noop_warn("glIsVariantEnabledEXT");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsVertexArray(GLuint array)
{
   (void) array;
   noop_warn("glIsVertexArray");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsVertexArrayAPPLE(GLuint array)
{
   (void) array;
   noop_warn("glIsVertexArrayAPPLE");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsVertexArrayOES(GLuint array)
{
   (void) array;
   noop_warn("glIsVertexArrayOES");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopIsVertexAttribEnabledAPPLE(GLuint index, GLenum pname)
{
   (void) index; (void) pname;
   noop_warn("glIsVertexAttribEnabledAPPLE");
   return (GLboolean) 0;
}

static void APIENTRY noopLGPUCopyImageSubDataNVX(GLuint sourceGpu, GLbitfield destinationGpuMask, GLuint srcName, GLenum srcTarget, GLint srcLevel, GLint srcX, GLint srxY, GLint srcZ, GLuint dstName, GLenum dstTarget, GLint dstLevel, GLint dstX, GLint dstY, GLint dstZ, GLsizei width, GLsizei height, GLsizei depth)
{
   (void) sourceGpu; (void) destinationGpuMask; (void) srcName; (void) srcTarget; (void) srcLevel; (void) srcX; (void) srxY; (void) srcZ; (void) dstName; (void) dstTarget; (void) dstLevel; (void) dstX; (void) dstY; (void) dstZ; (void) width; (void) height; (void) depth;
   noop_warn("glLGPUCopyImageSubDataNVX");
}

static void APIENTRY noopLGPUInterlockNVX(void)
{
   noop_warn("glLGPUInterlockNVX");
}

static void APIENTRY noopLGPUNamedBufferSubDataNVX(GLbitfield gpuMask, GLuint buffer, GLintptr offset, GLsizeiptr size, const void *data)
{
   (void) gpuMask; (void) buffer; (void) offset; (void) size; (void) data;
   noop_warn("glLGPUNamedBufferSubDataNVX");
}

static void APIENTRY noopLabelObjectEXT(GLenum type, GLuint object, GLsizei length, const GLchar *label)
{
   (void) type; (void) object; (void) length; (void) label;
   noop_warn("glLabelObjectEXT");
}

static void APIENTRY noopLightEnviSGIX(GLenum pname, GLint param)
{
   (void) pname; (void) param;
   noop_warn("glLightEnviSGIX");
}

static void APIENTRY noopLightModelf(GLenum pname, GLfloat param)
{
   (void) pname; (void) param;
   noop_warn("glLightModelf");
}

static void APIENTRY noopLightModelfv(GLenum pname, const GLfloat *params)
{
   (void) pname; (void) params;
   noop_warn("glLightModelfv");
}

static void APIENTRY noopLightModeli(GLenum pname, GLint param)
{
   (void) pname; (void) param;
   noop_warn("glLightModeli");
}

static void APIENTRY noopLightModeliv(GLenum pname, const GLint *params)
{
   (void) pname; (void) params;
   noop_warn("glLightModeliv");
}

static void APIENTRY noopLightModelx(GLenum pname, GLfixed param)
{
   (void) pname; (void) param;
   noop_warn("glLightModelx");
}

static void APIENTRY noopLightModelxOES(GLenum pname, GLfixed param)
{
   (void) pname; (void) param;
   noop_warn("glLightModelxOES");
}

static void APIENTRY noopLightModelxv(GLenum pname, const GLfixed *param)
{
   (void) pname; (void) param;
   noop_warn("glLightModelxv");
}

static void APIENTRY noopLightModelxvOES(GLenum pname, const GLfixed *param)
{
   (void) pname; (void) param;
   noop_warn("glLightModelxvOES");
}

static void APIENTRY noopLightf(GLenum light, GLenum pname, GLfloat param)
{
   (void) light; (void) pname; (void) param;
   noop_warn("glLightf");
}

static void APIENTRY noopLightfv(GLenum light, GLenum pname, const GLfloat *params)
{
   (void) light; (void) pname; (void) params;
   noop_warn("glLightfv");
}

static void APIENTRY noopLighti(GLenum light, GLenum pname, GLint param)
{
   (void) light; (void) pname; (void) param;
   noop_warn("glLighti");
}

static void APIENTRY noopLightiv(GLenum light, GLenum pname, const GLint *params)
{
   (void) light; (void) pname; (void) params;
   noop_warn("glLightiv");
}

static void APIENTRY noopLightx(GLenum light, GLenum pname, GLfixed param)
{
   (void) light; (void) pname; (void) param;
   noop_warn("glLightx");
}

static void APIENTRY noopLightxOES(GLenum light, GLenum pname, GLfixed param)
{
   (void) light; (void) pname; (void) param;
   noop_warn("glLightxOES");
}

static void APIENTRY noopLightxv(GLenum light, GLenum pname, const GLfixed *params)
{
   (void) light; (void) pname; (void) params;
   noop_warn("glLightxv");
}

static void APIENTRY noopLightxvOES(GLenum light, GLenum pname, const GLfixed *params)
{
   (void) light; (void) pname; (void) params;
   noop_warn("glLightxvOES");
}

static void APIENTRY noopLineStipple(GLint factor, GLushort pattern)
{
   (void) factor; (void) pattern;
   noop_warn("glLineStipple");
}

static void APIENTRY noopLineWidth(GLfloat width)
{
   (void) width;
   noop_warn("glLineWidth");
}

static void APIENTRY noopLineWidthx(GLfixed width)
{
   (void) width;
   noop_warn("glLineWidthx");
}

static void APIENTRY noopLineWidthxOES(GLfixed width)
{
   (void) width;
   noop_warn("glLineWidthxOES");
}

static void APIENTRY noopLinkProgram(GLuint program)
{
   (void) program;
   noop_warn("glLinkProgram");
}

static void APIENTRY noopLinkProgramARB(GLhandleARB programObj)
{
   (void) programObj;
   noop_warn("glLinkProgramARB");
}

static void APIENTRY noopListBase(GLuint base)
{
   (void) base;
   noop_warn("glListBase");
}

static void APIENTRY noopListDrawCommandsStatesClientNV(GLuint list, GLuint segment, const void **indirects, const GLsizei *sizes, const GLuint *states, const GLuint *fbos, GLuint count)
{
   (void) list; (void) segment; (void) indirects; (void) sizes; (void) states; (void) fbos; (void) count;
   noop_warn("glListDrawCommandsStatesClientNV");
}

static void APIENTRY noopListParameterfSGIX(GLuint list, GLenum pname, GLfloat param)
{
   (void) list; (void) pname; (void) param;
   noop_warn("glListParameterfSGIX");
}

static void APIENTRY noopListParameterfvSGIX(GLuint list, GLenum pname, const GLfloat *params)
{
   (void) list; (void) pname; (void) params;
   noop_warn("glListParameterfvSGIX");
}

static void APIENTRY noopListParameteriSGIX(GLuint list, GLenum pname, GLint param)
{
   (void) list; (void) pname; (void) param;
   noop_warn("glListParameteriSGIX");
}

static void APIENTRY noopListParameterivSGIX(GLuint list, GLenum pname, const GLint *params)
{
   (void) list; (void) pname; (void) params;
   noop_warn("glListParameterivSGIX");
}

static void APIENTRY noopLoadIdentity(void)
{
   noop_warn("glLoadIdentity");
}

static void APIENTRY noopLoadIdentityDeformationMapSGIX(GLbitfield mask)
{
   (void) mask;
   noop_warn("glLoadIdentityDeformationMapSGIX");
}

static void APIENTRY noopLoadMatrixd(const GLdouble *m)
{
   (void) m;
   noop_warn("glLoadMatrixd");
}

static void APIENTRY noopLoadMatrixf(const GLfloat *m)
{
   (void) m;
   noop_warn("glLoadMatrixf");
}

static void APIENTRY noopLoadMatrixx(const GLfixed *m)
{
   (void) m;
   noop_warn("glLoadMatrixx");
}

static void APIENTRY noopLoadMatrixxOES(const GLfixed *m)
{
   (void) m;
   noop_warn("glLoadMatrixxOES");
}

static void APIENTRY noopLoadName(GLuint name)
{
   (void) name;
   noop_warn("glLoadName");
}

static void APIENTRY noopLoadPaletteFromModelViewMatrixOES(void)
{
   noop_warn("glLoadPaletteFromModelViewMatrixOES");
}

static void APIENTRY noopLoadProgramNV(GLenum target, GLuint id, GLsizei len, const GLubyte *program)
{
   (void) target; (void) id; (void) len; (void) program;
   noop_warn("glLoadProgramNV");
}

static void APIENTRY noopLoadTransformEXT(GLenum transform)
{
   (void) transform;
   noop_warn("glLoadTransformEXT");
}

static void APIENTRY noopLoadTransposeMatrixd(const GLdouble *m)
{
   (void) m;
   noop_warn("glLoadTransposeMatrixd");
}

static void APIENTRY noopLoadTransposeMatrixdARB(const GLdouble *m)
{
   (void) m;
   noop_warn("glLoadTransposeMatrixdARB");
}

static void APIENTRY noopLoadTransposeMatrixf(const GLfloat *m)
{
   (void) m;
   noop_warn("glLoadTransposeMatrixf");
}

static void APIENTRY noopLoadTransposeMatrixfARB(const GLfloat *m)
{
   (void) m;
   noop_warn("glLoadTransposeMatrixfARB");
}

static void APIENTRY noopLoadTransposeMatrixxOES(const GLfixed *m)
{
   (void) m;
   noop_warn("glLoadTransposeMatrixxOES");
}

static void APIENTRY noopLockArraysEXT(GLint first, GLsizei count)
{
   (void) first; (void) count;
   noop_warn("glLockArraysEXT");
}

static void APIENTRY noopLogicOp(GLenum opcode)
{
   (void) opcode;
   noop_warn("glLogicOp");
}

static void APIENTRY noopMakeBufferNonResidentNV(GLenum target)
{
   (void) target;
   noop_warn("glMakeBufferNonResidentNV");
}

static void APIENTRY noopMakeBufferResidentNV(GLenum target, GLenum access)
{
   (void) target; (void) access;
   noop_warn("glMakeBufferResidentNV");
}

static void APIENTRY noopMakeImageHandleNonResidentARB(GLuint64 handle)
{
   (void) handle;
   noop_warn("glMakeImageHandleNonResidentARB");
}

static void APIENTRY noopMakeImageHandleNonResidentNV(GLuint64 handle)
{
   (void) handle;
   noop_warn("glMakeImageHandleNonResidentNV");
}

static void APIENTRY noopMakeImageHandleResidentARB(GLuint64 handle, GLenum access)
{
   (void) handle; (void) access;
   noop_warn("glMakeImageHandleResidentARB");
}

static void APIENTRY noopMakeImageHandleResidentNV(GLuint64 handle, GLenum access)
{
   (void) handle; (void) access;
   noop_warn("glMakeImageHandleResidentNV");
}

static void APIENTRY noopMakeNamedBufferNonResidentNV(GLuint buffer)
{
   (void) buffer;
   noop_warn("glMakeNamedBufferNonResidentNV");
}

static void APIENTRY noopMakeNamedBufferResidentNV(GLuint buffer, GLenum access)
{
   (void) buffer; (void) access;
   noop_warn("glMakeNamedBufferResidentNV");
}

static void APIENTRY noopMakeTextureHandleNonResidentARB(GLuint64 handle)
{
   (void) handle;
   noop_warn("glMakeTextureHandleNonResidentARB");
}

static void APIENTRY noopMakeTextureHandleNonResidentNV(GLuint64 handle)
{
   (void) handle;
   noop_warn("glMakeTextureHandleNonResidentNV");
}

static void APIENTRY noopMakeTextureHandleResidentARB(GLuint64 handle)
{
   (void) handle;
   noop_warn("glMakeTextureHandleResidentARB");
}

static void APIENTRY noopMakeTextureHandleResidentNV(GLuint64 handle)
{
   (void) handle;
   noop_warn("glMakeTextureHandleResidentNV");
}

static void APIENTRY noopMap1d(GLenum target, GLdouble u1, GLdouble u2, GLint stride, GLint order, const GLdouble *points)
{
   (void) target; (void) u1; (void) u2; (void) stride; (void) order; (void) points;
   noop_warn("glMap1d");
}

static void APIENTRY noopMap1f(GLenum target, GLfloat u1, GLfloat u2, GLint stride, GLint order, const GLfloat *points)
{
   (void) target; (void) u1; (void) u2; (void) stride; (void) order; (void) points;
   noop_warn("glMap1f");
}

static void APIENTRY noopMap1xOES(GLenum target, GLfixed u1, GLfixed u2, GLint stride, GLint order, GLfixed points)
{
   (void) target; (void) u1; (void) u2; (void) stride; (void) order; (void) points;
   noop_warn("glMap1xOES");
}

static void APIENTRY noopMap2d(GLenum target, GLdouble u1, GLdouble u2, GLint ustride, GLint uorder, GLdouble v1, GLdouble v2, GLint vstride, GLint vorder, const GLdouble *points)
{
   (void) target; (void) u1; (void) u2; (void) ustride; (void) uorder; (void) v1; (void) v2; (void) vstride; (void) vorder; (void) points;
   noop_warn("glMap2d");
}

static void APIENTRY noopMap2f(GLenum target, GLfloat u1, GLfloat u2, GLint ustride, GLint uorder, GLfloat v1, GLfloat v2, GLint vstride, GLint vorder, const GLfloat *points)
{
   (void) target; (void) u1; (void) u2; (void) ustride; (void) uorder; (void) v1; (void) v2; (void) vstride; (void) vorder; (void) points;
   noop_warn("glMap2f");
}

static void APIENTRY noopMap2xOES(GLenum target, GLfixed u1, GLfixed u2, GLint ustride, GLint uorder, GLfixed v1, GLfixed v2, GLint vstride, GLint vorder, GLfixed points)
{
   (void) target; (void) u1; (void) u2; (void) ustride; (void) uorder; (void) v1; (void) v2; (void) vstride; (void) vorder; (void) points;
   noop_warn("glMap2xOES");
}

static void * APIENTRY noopMapBuffer(GLenum target, GLenum access)
{
   (void) target; (void) access;
   noop_warn("glMapBuffer");
   return (void *) 0;
}

static void * APIENTRY noopMapBufferARB(GLenum target, GLenum access)
{
   (void) target; (void) access;
   noop_warn("glMapBufferARB");
   return (void *) 0;
}

static void * APIENTRY noopMapBufferOES(GLenum target, GLenum access)
{
   (void) target; (void) access;
   noop_warn("glMapBufferOES");
   return (void *) 0;
}

static void * APIENTRY noopMapBufferRange(GLenum target, GLintptr offset, GLsizeiptr length, GLbitfield access)
{
   (void) target; (void) offset; (void) length; (void) access;
   noop_warn("glMapBufferRange");
   return (void *) 0;
}

static void * APIENTRY noopMapBufferRangeEXT(GLenum target, GLintptr offset, GLsizeiptr length, GLbitfield access)
{
   (void) target; (void) offset; (void) length; (void) access;
   noop_warn("glMapBufferRangeEXT");
   return (void *) 0;
}

static void APIENTRY noopMapControlPointsNV(GLenum target, GLuint index, GLenum type, GLsizei ustride, GLsizei vstride, GLint uorder, GLint vorder, GLboolean packed, const void *points)
{
   (void) target; (void) index; (void) type; (void) ustride; (void) vstride; (void) uorder; (void) vorder; (void) packed; (void) points;
   noop_warn("glMapControlPointsNV");
}

static void APIENTRY noopMapGrid1d(GLint un, GLdouble u1, GLdouble u2)
{
   (void) un; (void) u1; (void) u2;
   noop_warn("glMapGrid1d");
}

static void APIENTRY noopMapGrid1f(GLint un, GLfloat u1, GLfloat u2)
{
   (void) un; (void) u1; (void) u2;
   noop_warn("glMapGrid1f");
}

static void APIENTRY noopMapGrid1xOES(GLint n, GLfixed u1, GLfixed u2)
{
   (void) n; (void) u1; (void) u2;
   noop_warn("glMapGrid1xOES");
}

static void APIENTRY noopMapGrid2d(GLint un, GLdouble u1, GLdouble u2, GLint vn, GLdouble v1, GLdouble v2)
{
   (void) un; (void) u1; (void) u2; (void) vn; (void) v1; (void) v2;
   noop_warn("glMapGrid2d");
}

static void APIENTRY noopMapGrid2f(GLint un, GLfloat u1, GLfloat u2, GLint vn, GLfloat v1, GLfloat v2)
{
   (void) un; (void) u1; (void) u2; (void) vn; (void) v1; (void) v2;
   noop_warn("glMapGrid2f");
}

static void APIENTRY noopMapGrid2xOES(GLint n, GLfixed u1, GLfixed u2, GLfixed v1, GLfixed v2)
{
   (void) n; (void) u1; (void) u2; (void) v1; (void) v2;
   noop_warn("glMapGrid2xOES");
}

static void * APIENTRY noopMapNamedBuffer(GLuint buffer, GLenum access)
{
   (void) buffer; (void) access;
   noop_warn("glMapNamedBuffer");
   return (void *) 0;
}

static void * APIENTRY noopMapNamedBufferEXT(GLuint buffer, GLenum access)
{
   (void) buffer; (void) access;
   noop_warn("glMapNamedBufferEXT");
   return (void *) 0;
}

static void * APIENTRY noopMapNamedBufferRange(GLuint buffer, GLintptr offset, GLsizeiptr length, GLbitfield access)
{
   (void) buffer; (void) offset; (void) length; (void) access;
   noop_warn("glMapNamedBufferRange");
   return (void *) 0;
}

static void * APIENTRY noopMapNamedBufferRangeEXT(GLuint buffer, GLintptr offset, GLsizeiptr length, GLbitfield access)
{
   (void) buffer; (void) offset; (void) length; (void) access;
   noop_warn("glMapNamedBufferRangeEXT");
   return (void *) 0;
}

static void * APIENTRY noopMapObjectBufferATI(GLuint buffer)
{
   (void) buffer;
   noop_warn("glMapObjectBufferATI");
   return (void *) 0;
}

static void APIENTRY noopMapParameterfvNV(GLenum target, GLenum pname, const GLfloat *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glMapParameterfvNV");
}

static void APIENTRY noopMapParameterivNV(GLenum target, GLenum pname, const GLint *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glMapParameterivNV");
}

static void * APIENTRY noopMapTexture2DINTEL(GLuint texture, GLint level, GLbitfield access, GLint *stride, GLenum *layout)
{
   (void) texture; (void) level; (void) access; (void) stride; (void) layout;
   noop_warn("glMapTexture2DINTEL");
   return (void *) 0;
}

static void APIENTRY noopMapVertexAttrib1dAPPLE(GLuint index, GLuint size, GLdouble u1, GLdouble u2, GLint stride, GLint order, const GLdouble *points)
{
   (void) index; (void) size; (void) u1; (void) u2; (void) stride; (void) order; (void) points;
   noop_warn("glMapVertexAttrib1dAPPLE");
}

static void APIENTRY noopMapVertexAttrib1fAPPLE(GLuint index, GLuint size, GLfloat u1, GLfloat u2, GLint stride, GLint order, const GLfloat *points)
{
   (void) index; (void) size; (void) u1; (void) u2; (void) stride; (void) order; (void) points;
   noop_warn("glMapVertexAttrib1fAPPLE");
}

static void APIENTRY noopMapVertexAttrib2dAPPLE(GLuint index, GLuint size, GLdouble u1, GLdouble u2, GLint ustride, GLint uorder, GLdouble v1, GLdouble v2, GLint vstride, GLint vorder, const GLdouble *points)
{
   (void) index; (void) size; (void) u1; (void) u2; (void) ustride; (void) uorder; (void) v1; (void) v2; (void) vstride; (void) vorder; (void) points;
   noop_warn("glMapVertexAttrib2dAPPLE");
}

static void APIENTRY noopMapVertexAttrib2fAPPLE(GLuint index, GLuint size, GLfloat u1, GLfloat u2, GLint ustride, GLint uorder, GLfloat v1, GLfloat v2, GLint vstride, GLint vorder, const GLfloat *points)
{
   (void) index; (void) size; (void) u1; (void) u2; (void) ustride; (void) uorder; (void) v1; (void) v2; (void) vstride; (void) vorder; (void) points;
   noop_warn("glMapVertexAttrib2fAPPLE");
}

static void APIENTRY noopMaterialf(GLenum face, GLenum pname, GLfloat param)
{
   (void) face; (void) pname; (void) param;
   noop_warn("glMaterialf");
}

static void APIENTRY noopMaterialfv(GLenum face, GLenum pname, const GLfloat *params)
{
   (void) face; (void) pname; (void) params;
   noop_warn("glMaterialfv");
}

static void APIENTRY noopMateriali(GLenum face, GLenum pname, GLint param)
{
   (void) face; (void) pname; (void) param;
   noop_warn("glMateriali");
}

static void APIENTRY noopMaterialiv(GLenum face, GLenum pname, const GLint *params)
{
   (void) face; (void) pname; (void) params;
   noop_warn("glMaterialiv");
}

static void APIENTRY noopMaterialx(GLenum face, GLenum pname, GLfixed param)
{
   (void) face; (void) pname; (void) param;
   noop_warn("glMaterialx");
}

static void APIENTRY noopMaterialxOES(GLenum face, GLenum pname, GLfixed param)
{
   (void) face; (void) pname; (void) param;
   noop_warn("glMaterialxOES");
}

static void APIENTRY noopMaterialxv(GLenum face, GLenum pname, const GLfixed *param)
{
   (void) face; (void) pname; (void) param;
   noop_warn("glMaterialxv");
}

static void APIENTRY noopMaterialxvOES(GLenum face, GLenum pname, const GLfixed *param)
{
   (void) face; (void) pname; (void) param;
   noop_warn("glMaterialxvOES");
}

static void APIENTRY noopMatrixFrustumEXT(GLenum mode, GLdouble left, GLdouble right, GLdouble bottom, GLdouble top, GLdouble zNear, GLdouble zFar)
{
   (void) mode; (void) left; (void) right; (void) bottom; (void) top; (void) zNear; (void) zFar;
   noop_warn("glMatrixFrustumEXT");
}

static void APIENTRY noopMatrixIndexPointerARB(GLint size, GLenum type, GLsizei stride, const void *pointer)
{
   (void) size; (void) type; (void) stride; (void) pointer;
   noop_warn("glMatrixIndexPointerARB");
}

static void APIENTRY noopMatrixIndexPointerOES(GLint size, GLenum type, GLsizei stride, const void *pointer)
{
   (void) size; (void) type; (void) stride; (void) pointer;
   noop_warn("glMatrixIndexPointerOES");
}

static void APIENTRY noopMatrixIndexubvARB(GLint size, const GLubyte *indices)
{
   (void) size; (void) indices;
   noop_warn("glMatrixIndexubvARB");
}

static void APIENTRY noopMatrixIndexuivARB(GLint size, const GLuint *indices)
{
   (void) size; (void) indices;
   noop_warn("glMatrixIndexuivARB");
}

static void APIENTRY noopMatrixIndexusvARB(GLint size, const GLushort *indices)
{
   (void) size; (void) indices;
   noop_warn("glMatrixIndexusvARB");
}

static void APIENTRY noopMatrixLoad3x2fNV(GLenum matrixMode, const GLfloat *m)
{
   (void) matrixMode; (void) m;
   noop_warn("glMatrixLoad3x2fNV");
}

static void APIENTRY noopMatrixLoad3x3fNV(GLenum matrixMode, const GLfloat *m)
{
   (void) matrixMode; (void) m;
   noop_warn("glMatrixLoad3x3fNV");
}

static void APIENTRY noopMatrixLoadIdentityEXT(GLenum mode)
{
   (void) mode;
   noop_warn("glMatrixLoadIdentityEXT");
}

static void APIENTRY noopMatrixLoadTranspose3x3fNV(GLenum matrixMode, const GLfloat *m)
{
   (void) matrixMode; (void) m;
   noop_warn("glMatrixLoadTranspose3x3fNV");
}

static void APIENTRY noopMatrixLoadTransposedEXT(GLenum mode, const GLdouble *m)
{
   (void) mode; (void) m;
   noop_warn("glMatrixLoadTransposedEXT");
}

static void APIENTRY noopMatrixLoadTransposefEXT(GLenum mode, const GLfloat *m)
{
   (void) mode; (void) m;
   noop_warn("glMatrixLoadTransposefEXT");
}

static void APIENTRY noopMatrixLoaddEXT(GLenum mode, const GLdouble *m)
{
   (void) mode; (void) m;
   noop_warn("glMatrixLoaddEXT");
}

static void APIENTRY noopMatrixLoadfEXT(GLenum mode, const GLfloat *m)
{
   (void) mode; (void) m;
   noop_warn("glMatrixLoadfEXT");
}

static void APIENTRY noopMatrixMode(GLenum mode)
{
   (void) mode;
   noop_warn("glMatrixMode");
}

static void APIENTRY noopMatrixMult3x2fNV(GLenum matrixMode, const GLfloat *m)
{
   (void) matrixMode; (void) m;
   noop_warn("glMatrixMult3x2fNV");
}

static void APIENTRY noopMatrixMult3x3fNV(GLenum matrixMode, const GLfloat *m)
{
   (void) matrixMode; (void) m;
   noop_warn("glMatrixMult3x3fNV");
}

static void APIENTRY noopMatrixMultTranspose3x3fNV(GLenum matrixMode, const GLfloat *m)
{
   (void) matrixMode; (void) m;
   noop_warn("glMatrixMultTranspose3x3fNV");
}

static void APIENTRY noopMatrixMultTransposedEXT(GLenum mode, const GLdouble *m)
{
   (void) mode; (void) m;
   noop_warn("glMatrixMultTransposedEXT");
}

static void APIENTRY noopMatrixMultTransposefEXT(GLenum mode, const GLfloat *m)
{
   (void) mode; (void) m;
   noop_warn("glMatrixMultTransposefEXT");
}

static void APIENTRY noopMatrixMultdEXT(GLenum mode, const GLdouble *m)
{
   (void) mode; (void) m;
   noop_warn("glMatrixMultdEXT");
}

static void APIENTRY noopMatrixMultfEXT(GLenum mode, const GLfloat *m)
{
   (void) mode; (void) m;
   noop_warn("glMatrixMultfEXT");
}

static void APIENTRY noopMatrixOrthoEXT(GLenum mode, GLdouble left, GLdouble right, GLdouble bottom, GLdouble top, GLdouble zNear, GLdouble zFar)
{
   (void) mode; (void) left; (void) right; (void) bottom; (void) top; (void) zNear; (void) zFar;
   noop_warn("glMatrixOrthoEXT");
}

static void APIENTRY noopMatrixPopEXT(GLenum mode)
{
   (void) mode;
   noop_warn("glMatrixPopEXT");
}

static void APIENTRY noopMatrixPushEXT(GLenum mode)
{
   (void) mode;
   noop_warn("glMatrixPushEXT");
}

static void APIENTRY noopMatrixRotatedEXT(GLenum mode, GLdouble angle, GLdouble x, GLdouble y, GLdouble z)
{
   (void) mode; (void) angle; (void) x; (void) y; (void) z;
   noop_warn("glMatrixRotatedEXT");
}

static void APIENTRY noopMatrixRotatefEXT(GLenum mode, GLfloat angle, GLfloat x, GLfloat y, GLfloat z)
{
   (void) mode; (void) angle; (void) x; (void) y; (void) z;
   noop_warn("glMatrixRotatefEXT");
}

static void APIENTRY noopMatrixScaledEXT(GLenum mode, GLdouble x, GLdouble y, GLdouble z)
{
   (void) mode; (void) x; (void) y; (void) z;
   noop_warn("glMatrixScaledEXT");
}

static void APIENTRY noopMatrixScalefEXT(GLenum mode, GLfloat x, GLfloat y, GLfloat z)
{
   (void) mode; (void) x; (void) y; (void) z;
   noop_warn("glMatrixScalefEXT");
}

static void APIENTRY noopMatrixTranslatedEXT(GLenum mode, GLdouble x, GLdouble y, GLdouble z)
{
   (void) mode; (void) x; (void) y; (void) z;
   noop_warn("glMatrixTranslatedEXT");
}

static void APIENTRY noopMatrixTranslatefEXT(GLenum mode, GLfloat x, GLfloat y, GLfloat z)
{
   (void) mode; (void) x; (void) y; (void) z;
   noop_warn("glMatrixTranslatefEXT");
}

static void APIENTRY noopMaxShaderCompilerThreadsARB(GLuint count)
{
   (void) count;
   noop_warn("glMaxShaderCompilerThreadsARB");
}

static void APIENTRY noopMaxShaderCompilerThreadsKHR(GLuint count)
{
   (void) count;
   noop_warn("glMaxShaderCompilerThreadsKHR");
}

static void APIENTRY noopMemoryBarrier(GLbitfield barriers)
{
   (void) barriers;
   noop_warn("glMemoryBarrier");
}

static void APIENTRY noopMemoryBarrierByRegion(GLbitfield barriers)
{
   (void) barriers;
   noop_warn("glMemoryBarrierByRegion");
}

static void APIENTRY noopMemoryBarrierEXT(GLbitfield barriers)
{
   (void) barriers;
   noop_warn("glMemoryBarrierEXT");
}

static void APIENTRY noopMemoryObjectParameterivEXT(GLuint memoryObject, GLenum pname, const GLint *params)
{
   (void) memoryObject; (void) pname; (void) params;
   noop_warn("glMemoryObjectParameterivEXT");
}

static void APIENTRY noopMinSampleShading(GLfloat value)
{
   (void) value;
   noop_warn("glMinSampleShading");
}

static void APIENTRY noopMinSampleShadingARB(GLfloat value)
{
   (void) value;
   noop_warn("glMinSampleShadingARB");
}

static void APIENTRY noopMinSampleShadingOES(GLfloat value)
{
   (void) value;
   noop_warn("glMinSampleShadingOES");
}

static void APIENTRY noopMinmax(GLenum target, GLenum internalformat, GLboolean sink)
{
   (void) target; (void) internalformat; (void) sink;
   noop_warn("glMinmax");
}

static void APIENTRY noopMinmaxEXT(GLenum target, GLenum internalformat, GLboolean sink)
{
   (void) target; (void) internalformat; (void) sink;
   noop_warn("glMinmaxEXT");
}

static void APIENTRY noopMultMatrixd(const GLdouble *m)
{
   (void) m;
   noop_warn("glMultMatrixd");
}

static void APIENTRY noopMultMatrixf(const GLfloat *m)
{
   (void) m;
   noop_warn("glMultMatrixf");
}

static void APIENTRY noopMultMatrixx(const GLfixed *m)
{
   (void) m;
   noop_warn("glMultMatrixx");
}

static void APIENTRY noopMultMatrixxOES(const GLfixed *m)
{
   (void) m;
   noop_warn("glMultMatrixxOES");
}

static void APIENTRY noopMultTransformEXT(GLenum transform)
{
   (void) transform;
   noop_warn("glMultTransformEXT");
}

static void APIENTRY noopMultTransposeMatrixd(const GLdouble *m)
{
   (void) m;
   noop_warn("glMultTransposeMatrixd");
}

static void APIENTRY noopMultTransposeMatrixdARB(const GLdouble *m)
{
   (void) m;
   noop_warn("glMultTransposeMatrixdARB");
}

static void APIENTRY noopMultTransposeMatrixf(const GLfloat *m)
{
   (void) m;
   noop_warn("glMultTransposeMatrixf");
}

static void APIENTRY noopMultTransposeMatrixfARB(const GLfloat *m)
{
   (void) m;
   noop_warn("glMultTransposeMatrixfARB");
}

static void APIENTRY noopMultTransposeMatrixxOES(const GLfixed *m)
{
   (void) m;
   noop_warn("glMultTransposeMatrixxOES");
}

static void APIENTRY noopMultiDrawArrays(GLenum mode, const GLint *first, const GLsizei *count, GLsizei drawcount)
{
   (void) mode; (void) first; (void) count; (void) drawcount;
   noop_warn("glMultiDrawArrays");
}

static void APIENTRY noopMultiDrawArraysEXT(GLenum mode, const GLint *first, const GLsizei *count, GLsizei primcount)
{
   (void) mode; (void) first; (void) count; (void) primcount;
   noop_warn("glMultiDrawArraysEXT");
}

static void APIENTRY noopMultiDrawArraysIndirect(GLenum mode, const void *indirect, GLsizei drawcount, GLsizei stride)
{
   (void) mode; (void) indirect; (void) drawcount; (void) stride;
   noop_warn("glMultiDrawArraysIndirect");
}

static void APIENTRY noopMultiDrawArraysIndirectAMD(GLenum mode, const void *indirect, GLsizei primcount, GLsizei stride)
{
   (void) mode; (void) indirect; (void) primcount; (void) stride;
   noop_warn("glMultiDrawArraysIndirectAMD");
}

static void APIENTRY noopMultiDrawArraysIndirectBindlessCountNV(GLenum mode, const void *indirect, GLsizei drawCount, GLsizei maxDrawCount, GLsizei stride, GLint vertexBufferCount)
{
   (void) mode; (void) indirect; (void) drawCount; (void) maxDrawCount; (void) stride; (void) vertexBufferCount;
   noop_warn("glMultiDrawArraysIndirectBindlessCountNV");
}

static void APIENTRY noopMultiDrawArraysIndirectBindlessNV(GLenum mode, const void *indirect, GLsizei drawCount, GLsizei stride, GLint vertexBufferCount)
{
   (void) mode; (void) indirect; (void) drawCount; (void) stride; (void) vertexBufferCount;
   noop_warn("glMultiDrawArraysIndirectBindlessNV");
}

static void APIENTRY noopMultiDrawArraysIndirectCount(GLenum mode, const void *indirect, GLintptr drawcount, GLsizei maxdrawcount, GLsizei stride)
{
   (void) mode; (void) indirect; (void) drawcount; (void) maxdrawcount; (void) stride;
   noop_warn("glMultiDrawArraysIndirectCount");
}

static void APIENTRY noopMultiDrawArraysIndirectCountARB(GLenum mode, const void *indirect, GLintptr drawcount, GLsizei maxdrawcount, GLsizei stride)
{
   (void) mode; (void) indirect; (void) drawcount; (void) maxdrawcount; (void) stride;
   noop_warn("glMultiDrawArraysIndirectCountARB");
}

static void APIENTRY noopMultiDrawArraysIndirectEXT(GLenum mode, const void *indirect, GLsizei drawcount, GLsizei stride)
{
   (void) mode; (void) indirect; (void) drawcount; (void) stride;
   noop_warn("glMultiDrawArraysIndirectEXT");
}

static void APIENTRY noopMultiDrawElementArrayAPPLE(GLenum mode, const GLint *first, const GLsizei *count, GLsizei primcount)
{
   (void) mode; (void) first; (void) count; (void) primcount;
   noop_warn("glMultiDrawElementArrayAPPLE");
}

static void APIENTRY noopMultiDrawElements(GLenum mode, const GLsizei *count, GLenum type, const void *const *indices, GLsizei drawcount)
{
   (void) mode; (void) count; (void) type; (void) indices; (void) drawcount;
   noop_warn("glMultiDrawElements");
}

static void APIENTRY noopMultiDrawElementsBaseVertex(GLenum mode, const GLsizei *count, GLenum type, const void *const *indices, GLsizei drawcount, const GLint *basevertex)
{
   (void) mode; (void) count; (void) type; (void) indices; (void) drawcount; (void) basevertex;
   noop_warn("glMultiDrawElementsBaseVertex");
}

static void APIENTRY noopMultiDrawElementsBaseVertexEXT(GLenum mode, const GLsizei *count, GLenum type, const void *const *indices, GLsizei drawcount, const GLint *basevertex)
{
   (void) mode; (void) count; (void) type; (void) indices; (void) drawcount; (void) basevertex;
   noop_warn("glMultiDrawElementsBaseVertexEXT");
}

static void APIENTRY noopMultiDrawElementsEXT(GLenum mode, const GLsizei *count, GLenum type, const void *const *indices, GLsizei primcount)
{
   (void) mode; (void) count; (void) type; (void) indices; (void) primcount;
   noop_warn("glMultiDrawElementsEXT");
}

static void APIENTRY noopMultiDrawElementsIndirect(GLenum mode, GLenum type, const void *indirect, GLsizei drawcount, GLsizei stride)
{
   (void) mode; (void) type; (void) indirect; (void) drawcount; (void) stride;
   noop_warn("glMultiDrawElementsIndirect");
}

static void APIENTRY noopMultiDrawElementsIndirectAMD(GLenum mode, GLenum type, const void *indirect, GLsizei primcount, GLsizei stride)
{
   (void) mode; (void) type; (void) indirect; (void) primcount; (void) stride;
   noop_warn("glMultiDrawElementsIndirectAMD");
}

static void APIENTRY noopMultiDrawElementsIndirectBindlessCountNV(GLenum mode, GLenum type, const void *indirect, GLsizei drawCount, GLsizei maxDrawCount, GLsizei stride, GLint vertexBufferCount)
{
   (void) mode; (void) type; (void) indirect; (void) drawCount; (void) maxDrawCount; (void) stride; (void) vertexBufferCount;
   noop_warn("glMultiDrawElementsIndirectBindlessCountNV");
}

static void APIENTRY noopMultiDrawElementsIndirectBindlessNV(GLenum mode, GLenum type, const void *indirect, GLsizei drawCount, GLsizei stride, GLint vertexBufferCount)
{
   (void) mode; (void) type; (void) indirect; (void) drawCount; (void) stride; (void) vertexBufferCount;
   noop_warn("glMultiDrawElementsIndirectBindlessNV");
}

static void APIENTRY noopMultiDrawElementsIndirectCount(GLenum mode, GLenum type, const void *indirect, GLintptr drawcount, GLsizei maxdrawcount, GLsizei stride)
{
   (void) mode; (void) type; (void) indirect; (void) drawcount; (void) maxdrawcount; (void) stride;
   noop_warn("glMultiDrawElementsIndirectCount");
}

static void APIENTRY noopMultiDrawElementsIndirectCountARB(GLenum mode, GLenum type, const void *indirect, GLintptr drawcount, GLsizei maxdrawcount, GLsizei stride)
{
   (void) mode; (void) type; (void) indirect; (void) drawcount; (void) maxdrawcount; (void) stride;
   noop_warn("glMultiDrawElementsIndirectCountARB");
}

static void APIENTRY noopMultiDrawElementsIndirectEXT(GLenum mode, GLenum type, const void *indirect, GLsizei drawcount, GLsizei stride)
{
   (void) mode; (void) type; (void) indirect; (void) drawcount; (void) stride;
   noop_warn("glMultiDrawElementsIndirectEXT");
}

static void APIENTRY noopMultiDrawMeshTasksIndirectCountNV(GLintptr indirect, GLintptr drawcount, GLsizei maxdrawcount, GLsizei stride)
{
   (void) indirect; (void) drawcount; (void) maxdrawcount; (void) stride;
   noop_warn("glMultiDrawMeshTasksIndirectCountNV");
}

static void APIENTRY noopMultiDrawMeshTasksIndirectNV(GLintptr indirect, GLsizei drawcount, GLsizei stride)
{
   (void) indirect; (void) drawcount; (void) stride;
   noop_warn("glMultiDrawMeshTasksIndirectNV");
}

static void APIENTRY noopMultiDrawRangeElementArrayAPPLE(GLenum mode, GLuint start, GLuint end, const GLint *first, const GLsizei *count, GLsizei primcount)
{
   (void) mode; (void) start; (void) end; (void) first; (void) count; (void) primcount;
   noop_warn("glMultiDrawRangeElementArrayAPPLE");
}

static void APIENTRY noopMultiModeDrawArraysIBM(const GLenum *mode, const GLint *first, const GLsizei *count, GLsizei primcount, GLint modestride)
{
   (void) mode; (void) first; (void) count; (void) primcount; (void) modestride;
   noop_warn("glMultiModeDrawArraysIBM");
}

static void APIENTRY noopMultiModeDrawElementsIBM(const GLenum *mode, const GLsizei *count, GLenum type, const void *const *indices, GLsizei primcount, GLint modestride)
{
   (void) mode; (void) count; (void) type; (void) indices; (void) primcount; (void) modestride;
   noop_warn("glMultiModeDrawElementsIBM");
}

static void APIENTRY noopMultiTexBufferEXT(GLenum texunit, GLenum target, GLenum internalformat, GLuint buffer)
{
   (void) texunit; (void) target; (void) internalformat; (void) buffer;
   noop_warn("glMultiTexBufferEXT");
}

static void APIENTRY noopMultiTexCoord1bOES(GLenum texture, GLbyte s)
{
   (void) texture; (void) s;
   noop_warn("glMultiTexCoord1bOES");
}

static void APIENTRY noopMultiTexCoord1bvOES(GLenum texture, const GLbyte *coords)
{
   (void) texture; (void) coords;
   noop_warn("glMultiTexCoord1bvOES");
}

static void APIENTRY noopMultiTexCoord1d(GLenum target, GLdouble s)
{
   (void) target; (void) s;
   noop_warn("glMultiTexCoord1d");
}

static void APIENTRY noopMultiTexCoord1dARB(GLenum target, GLdouble s)
{
   (void) target; (void) s;
   noop_warn("glMultiTexCoord1dARB");
}

static void APIENTRY noopMultiTexCoord1dv(GLenum target, const GLdouble *v)
{
   (void) target; (void) v;
   noop_warn("glMultiTexCoord1dv");
}

static void APIENTRY noopMultiTexCoord1dvARB(GLenum target, const GLdouble *v)
{
   (void) target; (void) v;
   noop_warn("glMultiTexCoord1dvARB");
}

static void APIENTRY noopMultiTexCoord1f(GLenum target, GLfloat s)
{
   (void) target; (void) s;
   noop_warn("glMultiTexCoord1f");
}

static void APIENTRY noopMultiTexCoord1fARB(GLenum target, GLfloat s)
{
   (void) target; (void) s;
   noop_warn("glMultiTexCoord1fARB");
}

static void APIENTRY noopMultiTexCoord1fv(GLenum target, const GLfloat *v)
{
   (void) target; (void) v;
   noop_warn("glMultiTexCoord1fv");
}

static void APIENTRY noopMultiTexCoord1fvARB(GLenum target, const GLfloat *v)
{
   (void) target; (void) v;
   noop_warn("glMultiTexCoord1fvARB");
}

static void APIENTRY noopMultiTexCoord1hNV(GLenum target, GLhalf s)
{
   (void) target; (void) s;
   noop_warn("glMultiTexCoord1hNV");
}

static void APIENTRY noopMultiTexCoord1hvNV(GLenum target, const GLhalf *v)
{
   (void) target; (void) v;
   noop_warn("glMultiTexCoord1hvNV");
}

static void APIENTRY noopMultiTexCoord1i(GLenum target, GLint s)
{
   (void) target; (void) s;
   noop_warn("glMultiTexCoord1i");
}

static void APIENTRY noopMultiTexCoord1iARB(GLenum target, GLint s)
{
   (void) target; (void) s;
   noop_warn("glMultiTexCoord1iARB");
}

static void APIENTRY noopMultiTexCoord1iv(GLenum target, const GLint *v)
{
   (void) target; (void) v;
   noop_warn("glMultiTexCoord1iv");
}

static void APIENTRY noopMultiTexCoord1ivARB(GLenum target, const GLint *v)
{
   (void) target; (void) v;
   noop_warn("glMultiTexCoord1ivARB");
}

static void APIENTRY noopMultiTexCoord1s(GLenum target, GLshort s)
{
   (void) target; (void) s;
   noop_warn("glMultiTexCoord1s");
}

static void APIENTRY noopMultiTexCoord1sARB(GLenum target, GLshort s)
{
   (void) target; (void) s;
   noop_warn("glMultiTexCoord1sARB");
}

static void APIENTRY noopMultiTexCoord1sv(GLenum target, const GLshort *v)
{
   (void) target; (void) v;
   noop_warn("glMultiTexCoord1sv");
}

static void APIENTRY noopMultiTexCoord1svARB(GLenum target, const GLshort *v)
{
   (void) target; (void) v;
   noop_warn("glMultiTexCoord1svARB");
}

static void APIENTRY noopMultiTexCoord1x(GLenum target, GLfixed s)
{
   (void) target; (void) s;
   noop_warn("glMultiTexCoord1x");
}

static void APIENTRY noopMultiTexCoord1xOES(GLenum texture, GLfixed s)
{
   (void) texture; (void) s;
   noop_warn("glMultiTexCoord1xOES");
}

static void APIENTRY noopMultiTexCoord1xv(GLenum target, const GLfixed *v)
{
   (void) target; (void) v;
   noop_warn("glMultiTexCoord1xv");
}

static void APIENTRY noopMultiTexCoord1xvOES(GLenum texture, const GLfixed *coords)
{
   (void) texture; (void) coords;
   noop_warn("glMultiTexCoord1xvOES");
}

static void APIENTRY noopMultiTexCoord2bOES(GLenum texture, GLbyte s, GLbyte t)
{
   (void) texture; (void) s; (void) t;
   noop_warn("glMultiTexCoord2bOES");
}

static void APIENTRY noopMultiTexCoord2bvOES(GLenum texture, const GLbyte *coords)
{
   (void) texture; (void) coords;
   noop_warn("glMultiTexCoord2bvOES");
}

static void APIENTRY noopMultiTexCoord2d(GLenum target, GLdouble s, GLdouble t)
{
   (void) target; (void) s; (void) t;
   noop_warn("glMultiTexCoord2d");
}

static void APIENTRY noopMultiTexCoord2dARB(GLenum target, GLdouble s, GLdouble t)
{
   (void) target; (void) s; (void) t;
   noop_warn("glMultiTexCoord2dARB");
}

static void APIENTRY noopMultiTexCoord2dv(GLenum target, const GLdouble *v)
{
   (void) target; (void) v;
   noop_warn("glMultiTexCoord2dv");
}

static void APIENTRY noopMultiTexCoord2dvARB(GLenum target, const GLdouble *v)
{
   (void) target; (void) v;
   noop_warn("glMultiTexCoord2dvARB");
}

static void APIENTRY noopMultiTexCoord2f(GLenum target, GLfloat s, GLfloat t)
{
   (void) target; (void) s; (void) t;
   noop_warn("glMultiTexCoord2f");
}

static void APIENTRY noopMultiTexCoord2fARB(GLenum target, GLfloat s, GLfloat t)
{
   (void) target; (void) s; (void) t;
   noop_warn("glMultiTexCoord2fARB");
}

static void APIENTRY noopMultiTexCoord2fv(GLenum target, const GLfloat *v)
{
   (void) target; (void) v;
   noop_warn("glMultiTexCoord2fv");
}

static void APIENTRY noopMultiTexCoord2fvARB(GLenum target, const GLfloat *v)
{
   (void) target; (void) v;
   noop_warn("glMultiTexCoord2fvARB");
}

static void APIENTRY noopMultiTexCoord2hNV(GLenum target, GLhalf s, GLhalf t)
{
   (void) target; (void) s; (void) t;
   noop_warn("glMultiTexCoord2hNV");
}

static void APIENTRY noopMultiTexCoord2hvNV(GLenum target, const GLhalf *v)
{
   (void) target; (void) v;
   noop_warn("glMultiTexCoord2hvNV");
}

static void APIENTRY noopMultiTexCoord2i(GLenum target, GLint s, GLint t)
{
   (void) target; (void) s; (void) t;
   noop_warn("glMultiTexCoord2i");
}

static void APIENTRY noopMultiTexCoord2iARB(GLenum target, GLint s, GLint t)
{
   (void) target; (void) s; (void) t;
   noop_warn("glMultiTexCoord2iARB");
}

static void APIENTRY noopMultiTexCoord2iv(GLenum target, const GLint *v)
{
   (void) target; (void) v;
   noop_warn("glMultiTexCoord2iv");
}

static void APIENTRY noopMultiTexCoord2ivARB(GLenum target, const GLint *v)
{
   (void) target; (void) v;
   noop_warn("glMultiTexCoord2ivARB");
}

static void APIENTRY noopMultiTexCoord2s(GLenum target, GLshort s, GLshort t)
{
   (void) target; (void) s; (void) t;
   noop_warn("glMultiTexCoord2s");
}

static void APIENTRY noopMultiTexCoord2sARB(GLenum target, GLshort s, GLshort t)
{
   (void) target; (void) s; (void) t;
   noop_warn("glMultiTexCoord2sARB");
}

static void APIENTRY noopMultiTexCoord2sv(GLenum target, const GLshort *v)
{
   (void) target; (void) v;
   noop_warn("glMultiTexCoord2sv");
}

static void APIENTRY noopMultiTexCoord2svARB(GLenum target, const GLshort *v)
{
   (void) target; (void) v;
   noop_warn("glMultiTexCoord2svARB");
}

static void APIENTRY noopMultiTexCoord2x(GLenum target, GLfixed s, GLfixed t)
{
   (void) target; (void) s; (void) t;
   noop_warn("glMultiTexCoord2x");
}

static void APIENTRY noopMultiTexCoord2xOES(GLenum texture, GLfixed s, GLfixed t)
{
   (void) texture; (void) s; (void) t;
   noop_warn("glMultiTexCoord2xOES");
}

static void APIENTRY noopMultiTexCoord2xv(GLenum target, const GLfixed *v)
{
   (void) target; (void) v;
   noop_warn("glMultiTexCoord2xv");
}

static void APIENTRY noopMultiTexCoord2xvOES(GLenum texture, const GLfixed *coords)
{
   (void) texture; (void) coords;
   noop_warn("glMultiTexCoord2xvOES");
}

static void APIENTRY noopMultiTexCoord3bOES(GLenum texture, GLbyte s, GLbyte t, GLbyte r)
{
   (void) texture; (void) s; (void) t; (void) r;
   noop_warn("glMultiTexCoord3bOES");
}

static void APIENTRY noopMultiTexCoord3bvOES(GLenum texture, const GLbyte *coords)
{
   (void) texture; (void) coords;
   noop_warn("glMultiTexCoord3bvOES");
}

static void APIENTRY noopMultiTexCoord3d(GLenum target, GLdouble s, GLdouble t, GLdouble r)
{
   (void) target; (void) s; (void) t; (void) r;
   noop_warn("glMultiTexCoord3d");
}

static void APIENTRY noopMultiTexCoord3dARB(GLenum target, GLdouble s, GLdouble t, GLdouble r)
{
   (void) target; (void) s; (void) t; (void) r;
   noop_warn("glMultiTexCoord3dARB");
}

static void APIENTRY noopMultiTexCoord3dv(GLenum target, const GLdouble *v)
{
   (void) target; (void) v;
   noop_warn("glMultiTexCoord3dv");
}

static void APIENTRY noopMultiTexCoord3dvARB(GLenum target, const GLdouble *v)
{
   (void) target; (void) v;
   noop_warn("glMultiTexCoord3dvARB");
}

static void APIENTRY noopMultiTexCoord3f(GLenum target, GLfloat s, GLfloat t, GLfloat r)
{
   (void) target; (void) s; (void) t; (void) r;
   noop_warn("glMultiTexCoord3f");
}

static void APIENTRY noopMultiTexCoord3fARB(GLenum target, GLfloat s, GLfloat t, GLfloat r)
{
   (void) target; (void) s; (void) t; (void) r;
   noop_warn("glMultiTexCoord3fARB");
}

static void APIENTRY noopMultiTexCoord3fv(GLenum target, const GLfloat *v)
{
   (void) target; (void) v;
   noop_warn("glMultiTexCoord3fv");
}

static void APIENTRY noopMultiTexCoord3fvARB(GLenum target, const GLfloat *v)
{
   (void) target; (void) v;
   noop_warn("glMultiTexCoord3fvARB");
}

static void APIENTRY noopMultiTexCoord3hNV(GLenum target, GLhalf s, GLhalf t, GLhalf r)
{
   (void) target; (void) s; (void) t; (void) r;
   noop_warn("glMultiTexCoord3hNV");
}

static void APIENTRY noopMultiTexCoord3hvNV(GLenum target, const GLhalf *v)
{
   (void) target; (void) v;
   noop_warn("glMultiTexCoord3hvNV");
}

static void APIENTRY noopMultiTexCoord3i(GLenum target, GLint s, GLint t, GLint r)
{
   (void) target; (void) s; (void) t; (void) r;
   noop_warn("glMultiTexCoord3i");
}

static void APIENTRY noopMultiTexCoord3iARB(GLenum target, GLint s, GLint t, GLint r)
{
   (void) target; (void) s; (void) t; (void) r;
   noop_warn("glMultiTexCoord3iARB");
}

static void APIENTRY noopMultiTexCoord3iv(GLenum target, const GLint *v)
{
   (void) target; (void) v;
   noop_warn("glMultiTexCoord3iv");
}

static void APIENTRY noopMultiTexCoord3ivARB(GLenum target, const GLint *v)
{
   (void) target; (void) v;
   noop_warn("glMultiTexCoord3ivARB");
}

static void APIENTRY noopMultiTexCoord3s(GLenum target, GLshort s, GLshort t, GLshort r)
{
   (void) target; (void) s; (void) t; (void) r;
   noop_warn("glMultiTexCoord3s");
}

static void APIENTRY noopMultiTexCoord3sARB(GLenum target, GLshort s, GLshort t, GLshort r)
{
   (void) target; (void) s; (void) t; (void) r;
   noop_warn("glMultiTexCoord3sARB");
}

static void APIENTRY noopMultiTexCoord3sv(GLenum target, const GLshort *v)
{
   (void) target; (void) v;
   noop_warn("glMultiTexCoord3sv");
}

static void APIENTRY noopMultiTexCoord3svARB(GLenum target, const GLshort *v)
{
   (void) target; (void) v;
   noop_warn("glMultiTexCoord3svARB");
}

static void APIENTRY noopMultiTexCoord3x(GLenum target, GLfixed s, GLfixed t, GLfixed r)
{
   (void) target; (void) s; (void) t; (void) r;
   noop_warn("glMultiTexCoord3x");
}

static void APIENTRY noopMultiTexCoord3xOES(GLenum texture, GLfixed s, GLfixed t, GLfixed r)
{
   (void) texture; (void) s; (void) t; (void) r;
   noop_warn("glMultiTexCoord3xOES");
}

static void APIENTRY noopMultiTexCoord3xv(GLenum target, const GLfixed *v)
{
   (void) target; (void) v;
   noop_warn("glMultiTexCoord3xv");
}

static void APIENTRY noopMultiTexCoord3xvOES(GLenum texture, const GLfixed *coords)
{
   (void) texture; (void) coords;
   noop_warn("glMultiTexCoord3xvOES");
}

static void APIENTRY noopMultiTexCoord4bOES(GLenum texture, GLbyte s, GLbyte t, GLbyte r, GLbyte q)
{
   (void) texture; (void) s; (void) t; (void) r; (void) q;
   noop_warn("glMultiTexCoord4bOES");
}

static void APIENTRY noopMultiTexCoord4bvOES(GLenum texture, const GLbyte *coords)
{
   (void) texture; (void) coords;
   noop_warn("glMultiTexCoord4bvOES");
}

static void APIENTRY noopMultiTexCoord4d(GLenum target, GLdouble s, GLdouble t, GLdouble r, GLdouble q)
{
   (void) target; (void) s; (void) t; (void) r; (void) q;
   noop_warn("glMultiTexCoord4d");
}

static void APIENTRY noopMultiTexCoord4dARB(GLenum target, GLdouble s, GLdouble t, GLdouble r, GLdouble q)
{
   (void) target; (void) s; (void) t; (void) r; (void) q;
   noop_warn("glMultiTexCoord4dARB");
}

static void APIENTRY noopMultiTexCoord4dv(GLenum target, const GLdouble *v)
{
   (void) target; (void) v;
   noop_warn("glMultiTexCoord4dv");
}

static void APIENTRY noopMultiTexCoord4dvARB(GLenum target, const GLdouble *v)
{
   (void) target; (void) v;
   noop_warn("glMultiTexCoord4dvARB");
}

static void APIENTRY noopMultiTexCoord4f(GLenum target, GLfloat s, GLfloat t, GLfloat r, GLfloat q)
{
   (void) target; (void) s; (void) t; (void) r; (void) q;
   noop_warn("glMultiTexCoord4f");
}

static void APIENTRY noopMultiTexCoord4fARB(GLenum target, GLfloat s, GLfloat t, GLfloat r, GLfloat q)
{
   (void) target; (void) s; (void) t; (void) r; (void) q;
   noop_warn("glMultiTexCoord4fARB");
}

static void APIENTRY noopMultiTexCoord4fv(GLenum target, const GLfloat *v)
{
   (void) target; (void) v;
   noop_warn("glMultiTexCoord4fv");
}

static void APIENTRY noopMultiTexCoord4fvARB(GLenum target, const GLfloat *v)
{
   (void) target; (void) v;
   noop_warn("glMultiTexCoord4fvARB");
}

static void APIENTRY noopMultiTexCoord4hNV(GLenum target, GLhalf s, GLhalf t, GLhalf r, GLhalf q)
{
   (void) target; (void) s; (void) t; (void) r; (void) q;
   noop_warn("glMultiTexCoord4hNV");
}

static void APIENTRY noopMultiTexCoord4hvNV(GLenum target, const GLhalf *v)
{
   (void) target; (void) v;
   noop_warn("glMultiTexCoord4hvNV");
}

static void APIENTRY noopMultiTexCoord4i(GLenum target, GLint s, GLint t, GLint r, GLint q)
{
   (void) target; (void) s; (void) t; (void) r; (void) q;
   noop_warn("glMultiTexCoord4i");
}

static void APIENTRY noopMultiTexCoord4iARB(GLenum target, GLint s, GLint t, GLint r, GLint q)
{
   (void) target; (void) s; (void) t; (void) r; (void) q;
   noop_warn("glMultiTexCoord4iARB");
}

static void APIENTRY noopMultiTexCoord4iv(GLenum target, const GLint *v)
{
   (void) target; (void) v;
   noop_warn("glMultiTexCoord4iv");
}

static void APIENTRY noopMultiTexCoord4ivARB(GLenum target, const GLint *v)
{
   (void) target; (void) v;
   noop_warn("glMultiTexCoord4ivARB");
}

static void APIENTRY noopMultiTexCoord4s(GLenum target, GLshort s, GLshort t, GLshort r, GLshort q)
{
   (void) target; (void) s; (void) t; (void) r; (void) q;
   noop_warn("glMultiTexCoord4s");
}

static void APIENTRY noopMultiTexCoord4sARB(GLenum target, GLshort s, GLshort t, GLshort r, GLshort q)
{
   (void) target; (void) s; (void) t; (void) r; (void) q;
   noop_warn("glMultiTexCoord4sARB");
}

static void APIENTRY noopMultiTexCoord4sv(GLenum target, const GLshort *v)
{
   (void) target; (void) v;
   noop_warn("glMultiTexCoord4sv");
}

static void APIENTRY noopMultiTexCoord4svARB(GLenum target, const GLshort *v)
{
   (void) target; (void) v;
   noop_warn("glMultiTexCoord4svARB");
}

static void APIENTRY noopMultiTexCoord4x(GLenum texture, GLfixed s, GLfixed t, GLfixed r, GLfixed q)
{
   (void) texture; (void) s; (void) t; (void) r; (void) q;
   noop_warn("glMultiTexCoord4x");
}

static void APIENTRY noopMultiTexCoord4xOES(GLenum texture, GLfixed s, GLfixed t, GLfixed r, GLfixed q)
{
   (void) texture; (void) s; (void) t; (void) r; (void) q;
   noop_warn("glMultiTexCoord4xOES");
}

static void APIENTRY noopMultiTexCoord4xv(GLenum target, const GLfixed *v)
{
   (void) target; (void) v;
   noop_warn("glMultiTexCoord4xv");
}

static void APIENTRY noopMultiTexCoord4xvOES(GLenum texture, const GLfixed *coords)
{
   (void) texture; (void) coords;
   noop_warn("glMultiTexCoord4xvOES");
}

static void APIENTRY noopMultiTexCoordP1ui(GLenum texture, GLenum type, GLuint coords)
{
   (void) texture; (void) type; (void) coords;
   noop_warn("glMultiTexCoordP1ui");
}

static void APIENTRY noopMultiTexCoordP1uiv(GLenum texture, GLenum type, const GLuint *coords)
{
   (void) texture; (void) type; (void) coords;
   noop_warn("glMultiTexCoordP1uiv");
}

static void APIENTRY noopMultiTexCoordP2ui(GLenum texture, GLenum type, GLuint coords)
{
   (void) texture; (void) type; (void) coords;
   noop_warn("glMultiTexCoordP2ui");
}

static void APIENTRY noopMultiTexCoordP2uiv(GLenum texture, GLenum type, const GLuint *coords)
{
   (void) texture; (void) type; (void) coords;
   noop_warn("glMultiTexCoordP2uiv");
}

static void APIENTRY noopMultiTexCoordP3ui(GLenum texture, GLenum type, GLuint coords)
{
   (void) texture; (void) type; (void) coords;
   noop_warn("glMultiTexCoordP3ui");
}

static void APIENTRY noopMultiTexCoordP3uiv(GLenum texture, GLenum type, const GLuint *coords)
{
   (void) texture; (void) type; (void) coords;
   noop_warn("glMultiTexCoordP3uiv");
}

static void APIENTRY noopMultiTexCoordP4ui(GLenum texture, GLenum type, GLuint coords)
{
   (void) texture; (void) type; (void) coords;
   noop_warn("glMultiTexCoordP4ui");
}

static void APIENTRY noopMultiTexCoordP4uiv(GLenum texture, GLenum type, const GLuint *coords)
{
   (void) texture; (void) type; (void) coords;
   noop_warn("glMultiTexCoordP4uiv");
}

static void APIENTRY noopMultiTexCoordPointerEXT(GLenum texunit, GLint size, GLenum type, GLsizei stride, const void *pointer)
{
   (void) texunit; (void) size; (void) type; (void) stride; (void) pointer;
   noop_warn("glMultiTexCoordPointerEXT");
}

static void APIENTRY noopMultiTexEnvfEXT(GLenum texunit, GLenum target, GLenum pname, GLfloat param)
{
   (void) texunit; (void) target; (void) pname; (void) param;
   noop_warn("glMultiTexEnvfEXT");
}

static void APIENTRY noopMultiTexEnvfvEXT(GLenum texunit, GLenum target, GLenum pname, const GLfloat *params)
{
   (void) texunit; (void) target; (void) pname; (void) params;
   noop_warn("glMultiTexEnvfvEXT");
}

static void APIENTRY noopMultiTexEnviEXT(GLenum texunit, GLenum target, GLenum pname, GLint param)
{
   (void) texunit; (void) target; (void) pname; (void) param;
   noop_warn("glMultiTexEnviEXT");
}

static void APIENTRY noopMultiTexEnvivEXT(GLenum texunit, GLenum target, GLenum pname, const GLint *params)
{
   (void) texunit; (void) target; (void) pname; (void) params;
   noop_warn("glMultiTexEnvivEXT");
}

static void APIENTRY noopMultiTexGendEXT(GLenum texunit, GLenum coord, GLenum pname, GLdouble param)
{
   (void) texunit; (void) coord; (void) pname; (void) param;
   noop_warn("glMultiTexGendEXT");
}

static void APIENTRY noopMultiTexGendvEXT(GLenum texunit, GLenum coord, GLenum pname, const GLdouble *params)
{
   (void) texunit; (void) coord; (void) pname; (void) params;
   noop_warn("glMultiTexGendvEXT");
}

static void APIENTRY noopMultiTexGenfEXT(GLenum texunit, GLenum coord, GLenum pname, GLfloat param)
{
   (void) texunit; (void) coord; (void) pname; (void) param;
   noop_warn("glMultiTexGenfEXT");
}

static void APIENTRY noopMultiTexGenfvEXT(GLenum texunit, GLenum coord, GLenum pname, const GLfloat *params)
{
   (void) texunit; (void) coord; (void) pname; (void) params;
   noop_warn("glMultiTexGenfvEXT");
}

static void APIENTRY noopMultiTexGeniEXT(GLenum texunit, GLenum coord, GLenum pname, GLint param)
{
   (void) texunit; (void) coord; (void) pname; (void) param;
   noop_warn("glMultiTexGeniEXT");
}

static void APIENTRY noopMultiTexGenivEXT(GLenum texunit, GLenum coord, GLenum pname, const GLint *params)
{
   (void) texunit; (void) coord; (void) pname; (void) params;
   noop_warn("glMultiTexGenivEXT");
}

static void APIENTRY noopMultiTexImage1DEXT(GLenum texunit, GLenum target, GLint level, GLint internalformat, GLsizei width, GLint border, GLenum format, GLenum type, const void *pixels)
{
   (void) texunit; (void) target; (void) level; (void) internalformat; (void) width; (void) border; (void) format; (void) type; (void) pixels;
   noop_warn("glMultiTexImage1DEXT");
}

static void APIENTRY noopMultiTexImage2DEXT(GLenum texunit, GLenum target, GLint level, GLint internalformat, GLsizei width, GLsizei height, GLint border, GLenum format, GLenum type, const void *pixels)
{
   (void) texunit; (void) target; (void) level; (void) internalformat; (void) width; (void) height; (void) border; (void) format; (void) type; (void) pixels;
   noop_warn("glMultiTexImage2DEXT");
}

static void APIENTRY noopMultiTexImage3DEXT(GLenum texunit, GLenum target, GLint level, GLint internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLenum format, GLenum type, const void *pixels)
{
   (void) texunit; (void) target; (void) level; (void) internalformat; (void) width; (void) height; (void) depth; (void) border; (void) format; (void) type; (void) pixels;
   noop_warn("glMultiTexImage3DEXT");
}

static void APIENTRY noopMultiTexParameterIivEXT(GLenum texunit, GLenum target, GLenum pname, const GLint *params)
{
   (void) texunit; (void) target; (void) pname; (void) params;
   noop_warn("glMultiTexParameterIivEXT");
}

static void APIENTRY noopMultiTexParameterIuivEXT(GLenum texunit, GLenum target, GLenum pname, const GLuint *params)
{
   (void) texunit; (void) target; (void) pname; (void) params;
   noop_warn("glMultiTexParameterIuivEXT");
}

static void APIENTRY noopMultiTexParameterfEXT(GLenum texunit, GLenum target, GLenum pname, GLfloat param)
{
   (void) texunit; (void) target; (void) pname; (void) param;
   noop_warn("glMultiTexParameterfEXT");
}

static void APIENTRY noopMultiTexParameterfvEXT(GLenum texunit, GLenum target, GLenum pname, const GLfloat *params)
{
   (void) texunit; (void) target; (void) pname; (void) params;
   noop_warn("glMultiTexParameterfvEXT");
}

static void APIENTRY noopMultiTexParameteriEXT(GLenum texunit, GLenum target, GLenum pname, GLint param)
{
   (void) texunit; (void) target; (void) pname; (void) param;
   noop_warn("glMultiTexParameteriEXT");
}

static void APIENTRY noopMultiTexParameterivEXT(GLenum texunit, GLenum target, GLenum pname, const GLint *params)
{
   (void) texunit; (void) target; (void) pname; (void) params;
   noop_warn("glMultiTexParameterivEXT");
}

static void APIENTRY noopMultiTexRenderbufferEXT(GLenum texunit, GLenum target, GLuint renderbuffer)
{
   (void) texunit; (void) target; (void) renderbuffer;
   noop_warn("glMultiTexRenderbufferEXT");
}

static void APIENTRY noopMultiTexSubImage1DEXT(GLenum texunit, GLenum target, GLint level, GLint xoffset, GLsizei width, GLenum format, GLenum type, const void *pixels)
{
   (void) texunit; (void) target; (void) level; (void) xoffset; (void) width; (void) format; (void) type; (void) pixels;
   noop_warn("glMultiTexSubImage1DEXT");
}

static void APIENTRY noopMultiTexSubImage2DEXT(GLenum texunit, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLenum type, const void *pixels)
{
   (void) texunit; (void) target; (void) level; (void) xoffset; (void) yoffset; (void) width; (void) height; (void) format; (void) type; (void) pixels;
   noop_warn("glMultiTexSubImage2DEXT");
}

static void APIENTRY noopMultiTexSubImage3DEXT(GLenum texunit, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void *pixels)
{
   (void) texunit; (void) target; (void) level; (void) xoffset; (void) yoffset; (void) zoffset; (void) width; (void) height; (void) depth; (void) format; (void) type; (void) pixels;
   noop_warn("glMultiTexSubImage3DEXT");
}

static void APIENTRY noopMulticastBarrierNV(void)
{
   noop_warn("glMulticastBarrierNV");
}

static void APIENTRY noopMulticastBlitFramebufferNV(GLuint srcGpu, GLuint dstGpu, GLint srcX0, GLint srcY0, GLint srcX1, GLint srcY1, GLint dstX0, GLint dstY0, GLint dstX1, GLint dstY1, GLbitfield mask, GLenum filter)
{
   (void) srcGpu; (void) dstGpu; (void) srcX0; (void) srcY0; (void) srcX1; (void) srcY1; (void) dstX0; (void) dstY0; (void) dstX1; (void) dstY1; (void) mask; (void) filter;
   noop_warn("glMulticastBlitFramebufferNV");
}

static void APIENTRY noopMulticastBufferSubDataNV(GLbitfield gpuMask, GLuint buffer, GLintptr offset, GLsizeiptr size, const void *data)
{
   (void) gpuMask; (void) buffer; (void) offset; (void) size; (void) data;
   noop_warn("glMulticastBufferSubDataNV");
}

static void APIENTRY noopMulticastCopyBufferSubDataNV(GLuint readGpu, GLbitfield writeGpuMask, GLuint readBuffer, GLuint writeBuffer, GLintptr readOffset, GLintptr writeOffset, GLsizeiptr size)
{
   (void) readGpu; (void) writeGpuMask; (void) readBuffer; (void) writeBuffer; (void) readOffset; (void) writeOffset; (void) size;
   noop_warn("glMulticastCopyBufferSubDataNV");
}

static void APIENTRY noopMulticastCopyImageSubDataNV(GLuint srcGpu, GLbitfield dstGpuMask, GLuint srcName, GLenum srcTarget, GLint srcLevel, GLint srcX, GLint srcY, GLint srcZ, GLuint dstName, GLenum dstTarget, GLint dstLevel, GLint dstX, GLint dstY, GLint dstZ, GLsizei srcWidth, GLsizei srcHeight, GLsizei srcDepth)
{
   (void) srcGpu; (void) dstGpuMask; (void) srcName; (void) srcTarget; (void) srcLevel; (void) srcX; (void) srcY; (void) srcZ; (void) dstName; (void) dstTarget; (void) dstLevel; (void) dstX; (void) dstY; (void) dstZ; (void) srcWidth; (void) srcHeight; (void) srcDepth;
   noop_warn("glMulticastCopyImageSubDataNV");
}

static void APIENTRY noopMulticastFramebufferSampleLocationsfvNV(GLuint gpu, GLuint framebuffer, GLuint start, GLsizei count, const GLfloat *v)
{
   (void) gpu; (void) framebuffer; (void) start; (void) count; (void) v;
   noop_warn("glMulticastFramebufferSampleLocationsfvNV");
}

static void APIENTRY noopMulticastGetQueryObjecti64vNV(GLuint gpu, GLuint id, GLenum pname, GLint64 *params)
{
   (void) gpu; (void) id; (void) pname; (void) params;
   noop_warn("glMulticastGetQueryObjecti64vNV");
}

static void APIENTRY noopMulticastGetQueryObjectivNV(GLuint gpu, GLuint id, GLenum pname, GLint *params)
{
   (void) gpu; (void) id; (void) pname; (void) params;
   noop_warn("glMulticastGetQueryObjectivNV");
}

static void APIENTRY noopMulticastGetQueryObjectui64vNV(GLuint gpu, GLuint id, GLenum pname, GLuint64 *params)
{
   (void) gpu; (void) id; (void) pname; (void) params;
   noop_warn("glMulticastGetQueryObjectui64vNV");
}

static void APIENTRY noopMulticastGetQueryObjectuivNV(GLuint gpu, GLuint id, GLenum pname, GLuint *params)
{
   (void) gpu; (void) id; (void) pname; (void) params;
   noop_warn("glMulticastGetQueryObjectuivNV");
}

static void APIENTRY noopMulticastScissorArrayvNVX(GLuint gpu, GLuint first, GLsizei count, const GLint *v)
{
   (void) gpu; (void) first; (void) count; (void) v;
   noop_warn("glMulticastScissorArrayvNVX");
}

static void APIENTRY noopMulticastViewportArrayvNVX(GLuint gpu, GLuint first, GLsizei count, const GLfloat *v)
{
   (void) gpu; (void) first; (void) count; (void) v;
   noop_warn("glMulticastViewportArrayvNVX");
}

static void APIENTRY noopMulticastViewportPositionWScaleNVX(GLuint gpu, GLuint index, GLfloat xcoeff, GLfloat ycoeff)
{
   (void) gpu; (void) index; (void) xcoeff; (void) ycoeff;
   noop_warn("glMulticastViewportPositionWScaleNVX");
}

static void APIENTRY noopMulticastWaitSyncNV(GLuint signalGpu, GLbitfield waitGpuMask)
{
   (void) signalGpu; (void) waitGpuMask;
   noop_warn("glMulticastWaitSyncNV");
}

static void APIENTRY noopNVENCInterOpFunctionNVX(void *dataPtr)
{
   (void) dataPtr;
   noop_warn("glNVENCInterOpFunctionNVX");
}

static void APIENTRY noopNamedBufferAttachMemoryNV(GLuint buffer, GLuint memory, GLuint64 offset)
{
   (void) buffer; (void) memory; (void) offset;
   noop_warn("glNamedBufferAttachMemoryNV");
}

static void APIENTRY noopNamedBufferData(GLuint buffer, GLsizeiptr size, const void *data, GLenum usage)
{
   (void) buffer; (void) size; (void) data; (void) usage;
   noop_warn("glNamedBufferData");
}

static void APIENTRY noopNamedBufferDataEXT(GLuint buffer, GLsizeiptr size, const void *data, GLenum usage)
{
   (void) buffer; (void) size; (void) data; (void) usage;
   noop_warn("glNamedBufferDataEXT");
}

static void APIENTRY noopNamedBufferPageCommitmentARB(GLuint buffer, GLintptr offset, GLsizeiptr size, GLboolean commit)
{
   (void) buffer; (void) offset; (void) size; (void) commit;
   noop_warn("glNamedBufferPageCommitmentARB");
}

static void APIENTRY noopNamedBufferPageCommitmentEXT(GLuint buffer, GLintptr offset, GLsizeiptr size, GLboolean commit)
{
   (void) buffer; (void) offset; (void) size; (void) commit;
   noop_warn("glNamedBufferPageCommitmentEXT");
}

static void APIENTRY noopNamedBufferStorage(GLuint buffer, GLsizeiptr size, const void *data, GLbitfield flags)
{
   (void) buffer; (void) size; (void) data; (void) flags;
   noop_warn("glNamedBufferStorage");
}

static void APIENTRY noopNamedBufferStorageEXT(GLuint buffer, GLsizeiptr size, const void *data, GLbitfield flags)
{
   (void) buffer; (void) size; (void) data; (void) flags;
   noop_warn("glNamedBufferStorageEXT");
}

static void APIENTRY noopNamedBufferStorageExternalEXT(GLuint buffer, GLintptr offset, GLsizeiptr size, GLeglClientBufferEXT clientBuffer, GLbitfield flags)
{
   (void) buffer; (void) offset; (void) size; (void) clientBuffer; (void) flags;
   noop_warn("glNamedBufferStorageExternalEXT");
}

static void APIENTRY noopNamedBufferStorageMemEXT(GLuint buffer, GLsizeiptr size, GLuint memory, GLuint64 offset)
{
   (void) buffer; (void) size; (void) memory; (void) offset;
   noop_warn("glNamedBufferStorageMemEXT");
}

static void APIENTRY noopNamedBufferSubData(GLuint buffer, GLintptr offset, GLsizeiptr size, const void *data)
{
   (void) buffer; (void) offset; (void) size; (void) data;
   noop_warn("glNamedBufferSubData");
}

static void APIENTRY noopNamedBufferSubDataEXT(GLuint buffer, GLintptr offset, GLsizeiptr size, const void *data)
{
   (void) buffer; (void) offset; (void) size; (void) data;
   noop_warn("glNamedBufferSubDataEXT");
}

static void APIENTRY noopNamedCopyBufferSubDataEXT(GLuint readBuffer, GLuint writeBuffer, GLintptr readOffset, GLintptr writeOffset, GLsizeiptr size)
{
   (void) readBuffer; (void) writeBuffer; (void) readOffset; (void) writeOffset; (void) size;
   noop_warn("glNamedCopyBufferSubDataEXT");
}

static void APIENTRY noopNamedFramebufferDrawBuffer(GLuint framebuffer, GLenum buf)
{
   (void) framebuffer; (void) buf;
   noop_warn("glNamedFramebufferDrawBuffer");
}

static void APIENTRY noopNamedFramebufferDrawBuffers(GLuint framebuffer, GLsizei n, const GLenum *bufs)
{
   (void) framebuffer; (void) n; (void) bufs;
   noop_warn("glNamedFramebufferDrawBuffers");
}

static void APIENTRY noopNamedFramebufferParameteri(GLuint framebuffer, GLenum pname, GLint param)
{
   (void) framebuffer; (void) pname; (void) param;
   noop_warn("glNamedFramebufferParameteri");
}

static void APIENTRY noopNamedFramebufferParameteriEXT(GLuint framebuffer, GLenum pname, GLint param)
{
   (void) framebuffer; (void) pname; (void) param;
   noop_warn("glNamedFramebufferParameteriEXT");
}

static void APIENTRY noopNamedFramebufferReadBuffer(GLuint framebuffer, GLenum src)
{
   (void) framebuffer; (void) src;
   noop_warn("glNamedFramebufferReadBuffer");
}

static void APIENTRY noopNamedFramebufferRenderbuffer(GLuint framebuffer, GLenum attachment, GLenum renderbuffertarget, GLuint renderbuffer)
{
   (void) framebuffer; (void) attachment; (void) renderbuffertarget; (void) renderbuffer;
   noop_warn("glNamedFramebufferRenderbuffer");
}

static void APIENTRY noopNamedFramebufferRenderbufferEXT(GLuint framebuffer, GLenum attachment, GLenum renderbuffertarget, GLuint renderbuffer)
{
   (void) framebuffer; (void) attachment; (void) renderbuffertarget; (void) renderbuffer;
   noop_warn("glNamedFramebufferRenderbufferEXT");
}

static void APIENTRY noopNamedFramebufferSampleLocationsfvARB(GLuint framebuffer, GLuint start, GLsizei count, const GLfloat *v)
{
   (void) framebuffer; (void) start; (void) count; (void) v;
   noop_warn("glNamedFramebufferSampleLocationsfvARB");
}

static void APIENTRY noopNamedFramebufferSampleLocationsfvNV(GLuint framebuffer, GLuint start, GLsizei count, const GLfloat *v)
{
   (void) framebuffer; (void) start; (void) count; (void) v;
   noop_warn("glNamedFramebufferSampleLocationsfvNV");
}

static void APIENTRY noopNamedFramebufferSamplePositionsfvAMD(GLuint framebuffer, GLuint numsamples, GLuint pixelindex, const GLfloat *values)
{
   (void) framebuffer; (void) numsamples; (void) pixelindex; (void) values;
   noop_warn("glNamedFramebufferSamplePositionsfvAMD");
}

static void APIENTRY noopNamedFramebufferTexture(GLuint framebuffer, GLenum attachment, GLuint texture, GLint level)
{
   (void) framebuffer; (void) attachment; (void) texture; (void) level;
   noop_warn("glNamedFramebufferTexture");
}

static void APIENTRY noopNamedFramebufferTexture1DEXT(GLuint framebuffer, GLenum attachment, GLenum textarget, GLuint texture, GLint level)
{
   (void) framebuffer; (void) attachment; (void) textarget; (void) texture; (void) level;
   noop_warn("glNamedFramebufferTexture1DEXT");
}

static void APIENTRY noopNamedFramebufferTexture2DEXT(GLuint framebuffer, GLenum attachment, GLenum textarget, GLuint texture, GLint level)
{
   (void) framebuffer; (void) attachment; (void) textarget; (void) texture; (void) level;
   noop_warn("glNamedFramebufferTexture2DEXT");
}

static void APIENTRY noopNamedFramebufferTexture3DEXT(GLuint framebuffer, GLenum attachment, GLenum textarget, GLuint texture, GLint level, GLint zoffset)
{
   (void) framebuffer; (void) attachment; (void) textarget; (void) texture; (void) level; (void) zoffset;
   noop_warn("glNamedFramebufferTexture3DEXT");
}

static void APIENTRY noopNamedFramebufferTextureEXT(GLuint framebuffer, GLenum attachment, GLuint texture, GLint level)
{
   (void) framebuffer; (void) attachment; (void) texture; (void) level;
   noop_warn("glNamedFramebufferTextureEXT");
}

static void APIENTRY noopNamedFramebufferTextureFaceEXT(GLuint framebuffer, GLenum attachment, GLuint texture, GLint level, GLenum face)
{
   (void) framebuffer; (void) attachment; (void) texture; (void) level; (void) face;
   noop_warn("glNamedFramebufferTextureFaceEXT");
}

static void APIENTRY noopNamedFramebufferTextureLayer(GLuint framebuffer, GLenum attachment, GLuint texture, GLint level, GLint layer)
{
   (void) framebuffer; (void) attachment; (void) texture; (void) level; (void) layer;
   noop_warn("glNamedFramebufferTextureLayer");
}

static void APIENTRY noopNamedFramebufferTextureLayerEXT(GLuint framebuffer, GLenum attachment, GLuint texture, GLint level, GLint layer)
{
   (void) framebuffer; (void) attachment; (void) texture; (void) level; (void) layer;
   noop_warn("glNamedFramebufferTextureLayerEXT");
}

static void APIENTRY noopNamedProgramLocalParameter4dEXT(GLuint program, GLenum target, GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w)
{
   (void) program; (void) target; (void) index; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glNamedProgramLocalParameter4dEXT");
}

static void APIENTRY noopNamedProgramLocalParameter4dvEXT(GLuint program, GLenum target, GLuint index, const GLdouble *params)
{
   (void) program; (void) target; (void) index; (void) params;
   noop_warn("glNamedProgramLocalParameter4dvEXT");
}

static void APIENTRY noopNamedProgramLocalParameter4fEXT(GLuint program, GLenum target, GLuint index, GLfloat x, GLfloat y, GLfloat z, GLfloat w)
{
   (void) program; (void) target; (void) index; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glNamedProgramLocalParameter4fEXT");
}

static void APIENTRY noopNamedProgramLocalParameter4fvEXT(GLuint program, GLenum target, GLuint index, const GLfloat *params)
{
   (void) program; (void) target; (void) index; (void) params;
   noop_warn("glNamedProgramLocalParameter4fvEXT");
}

static void APIENTRY noopNamedProgramLocalParameterI4iEXT(GLuint program, GLenum target, GLuint index, GLint x, GLint y, GLint z, GLint w)
{
   (void) program; (void) target; (void) index; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glNamedProgramLocalParameterI4iEXT");
}

static void APIENTRY noopNamedProgramLocalParameterI4ivEXT(GLuint program, GLenum target, GLuint index, const GLint *params)
{
   (void) program; (void) target; (void) index; (void) params;
   noop_warn("glNamedProgramLocalParameterI4ivEXT");
}

static void APIENTRY noopNamedProgramLocalParameterI4uiEXT(GLuint program, GLenum target, GLuint index, GLuint x, GLuint y, GLuint z, GLuint w)
{
   (void) program; (void) target; (void) index; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glNamedProgramLocalParameterI4uiEXT");
}

static void APIENTRY noopNamedProgramLocalParameterI4uivEXT(GLuint program, GLenum target, GLuint index, const GLuint *params)
{
   (void) program; (void) target; (void) index; (void) params;
   noop_warn("glNamedProgramLocalParameterI4uivEXT");
}

static void APIENTRY noopNamedProgramLocalParameters4fvEXT(GLuint program, GLenum target, GLuint index, GLsizei count, const GLfloat *params)
{
   (void) program; (void) target; (void) index; (void) count; (void) params;
   noop_warn("glNamedProgramLocalParameters4fvEXT");
}

static void APIENTRY noopNamedProgramLocalParametersI4ivEXT(GLuint program, GLenum target, GLuint index, GLsizei count, const GLint *params)
{
   (void) program; (void) target; (void) index; (void) count; (void) params;
   noop_warn("glNamedProgramLocalParametersI4ivEXT");
}

static void APIENTRY noopNamedProgramLocalParametersI4uivEXT(GLuint program, GLenum target, GLuint index, GLsizei count, const GLuint *params)
{
   (void) program; (void) target; (void) index; (void) count; (void) params;
   noop_warn("glNamedProgramLocalParametersI4uivEXT");
}

static void APIENTRY noopNamedProgramStringEXT(GLuint program, GLenum target, GLenum format, GLsizei len, const void *string)
{
   (void) program; (void) target; (void) format; (void) len; (void) string;
   noop_warn("glNamedProgramStringEXT");
}

static void APIENTRY noopNamedRenderbufferStorage(GLuint renderbuffer, GLenum internalformat, GLsizei width, GLsizei height)
{
   (void) renderbuffer; (void) internalformat; (void) width; (void) height;
   noop_warn("glNamedRenderbufferStorage");
}

static void APIENTRY noopNamedRenderbufferStorageEXT(GLuint renderbuffer, GLenum internalformat, GLsizei width, GLsizei height)
{
   (void) renderbuffer; (void) internalformat; (void) width; (void) height;
   noop_warn("glNamedRenderbufferStorageEXT");
}

static void APIENTRY noopNamedRenderbufferStorageMultisample(GLuint renderbuffer, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height)
{
   (void) renderbuffer; (void) samples; (void) internalformat; (void) width; (void) height;
   noop_warn("glNamedRenderbufferStorageMultisample");
}

static void APIENTRY noopNamedRenderbufferStorageMultisampleAdvancedAMD(GLuint renderbuffer, GLsizei samples, GLsizei storageSamples, GLenum internalformat, GLsizei width, GLsizei height)
{
   (void) renderbuffer; (void) samples; (void) storageSamples; (void) internalformat; (void) width; (void) height;
   noop_warn("glNamedRenderbufferStorageMultisampleAdvancedAMD");
}

static void APIENTRY noopNamedRenderbufferStorageMultisampleCoverageEXT(GLuint renderbuffer, GLsizei coverageSamples, GLsizei colorSamples, GLenum internalformat, GLsizei width, GLsizei height)
{
   (void) renderbuffer; (void) coverageSamples; (void) colorSamples; (void) internalformat; (void) width; (void) height;
   noop_warn("glNamedRenderbufferStorageMultisampleCoverageEXT");
}

static void APIENTRY noopNamedRenderbufferStorageMultisampleEXT(GLuint renderbuffer, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height)
{
   (void) renderbuffer; (void) samples; (void) internalformat; (void) width; (void) height;
   noop_warn("glNamedRenderbufferStorageMultisampleEXT");
}

static void APIENTRY noopNamedStringARB(GLenum type, GLint namelen, const GLchar *name, GLint stringlen, const GLchar *string)
{
   (void) type; (void) namelen; (void) name; (void) stringlen; (void) string;
   noop_warn("glNamedStringARB");
}

static void APIENTRY noopNewList(GLuint list, GLenum mode)
{
   (void) list; (void) mode;
   noop_warn("glNewList");
}

static GLuint APIENTRY noopNewObjectBufferATI(GLsizei size, const void *pointer, GLenum usage)
{
   (void) size; (void) pointer; (void) usage;
   noop_warn("glNewObjectBufferATI");
   return (GLuint) 0;
}

static void APIENTRY noopNormal3b(GLbyte nx, GLbyte ny, GLbyte nz)
{
   (void) nx; (void) ny; (void) nz;
   noop_warn("glNormal3b");
}

static void APIENTRY noopNormal3bv(const GLbyte *v)
{
   (void) v;
   noop_warn("glNormal3bv");
}

static void APIENTRY noopNormal3d(GLdouble nx, GLdouble ny, GLdouble nz)
{
   (void) nx; (void) ny; (void) nz;
   noop_warn("glNormal3d");
}

static void APIENTRY noopNormal3dv(const GLdouble *v)
{
   (void) v;
   noop_warn("glNormal3dv");
}

static void APIENTRY noopNormal3f(GLfloat nx, GLfloat ny, GLfloat nz)
{
   (void) nx; (void) ny; (void) nz;
   noop_warn("glNormal3f");
}

static void APIENTRY noopNormal3fVertex3fSUN(GLfloat nx, GLfloat ny, GLfloat nz, GLfloat x, GLfloat y, GLfloat z)
{
   (void) nx; (void) ny; (void) nz; (void) x; (void) y; (void) z;
   noop_warn("glNormal3fVertex3fSUN");
}

static void APIENTRY noopNormal3fVertex3fvSUN(const GLfloat *n, const GLfloat *v)
{
   (void) n; (void) v;
   noop_warn("glNormal3fVertex3fvSUN");
}

static void APIENTRY noopNormal3fv(const GLfloat *v)
{
   (void) v;
   noop_warn("glNormal3fv");
}

static void APIENTRY noopNormal3hNV(GLhalf nx, GLhalf ny, GLhalf nz)
{
   (void) nx; (void) ny; (void) nz;
   noop_warn("glNormal3hNV");
}

static void APIENTRY noopNormal3hvNV(const GLhalf *v)
{
   (void) v;
   noop_warn("glNormal3hvNV");
}

static void APIENTRY noopNormal3i(GLint nx, GLint ny, GLint nz)
{
   (void) nx; (void) ny; (void) nz;
   noop_warn("glNormal3i");
}

static void APIENTRY noopNormal3iv(const GLint *v)
{
   (void) v;
   noop_warn("glNormal3iv");
}

static void APIENTRY noopNormal3s(GLshort nx, GLshort ny, GLshort nz)
{
   (void) nx; (void) ny; (void) nz;
   noop_warn("glNormal3s");
}

static void APIENTRY noopNormal3sv(const GLshort *v)
{
   (void) v;
   noop_warn("glNormal3sv");
}

static void APIENTRY noopNormal3x(GLfixed nx, GLfixed ny, GLfixed nz)
{
   (void) nx; (void) ny; (void) nz;
   noop_warn("glNormal3x");
}

static void APIENTRY noopNormal3xOES(GLfixed nx, GLfixed ny, GLfixed nz)
{
   (void) nx; (void) ny; (void) nz;
   noop_warn("glNormal3xOES");
}

static void APIENTRY noopNormal3xvOES(const GLfixed *coords)
{
   (void) coords;
   noop_warn("glNormal3xvOES");
}

static void APIENTRY noopNormalFormatNV(GLenum type, GLsizei stride)
{
   (void) type; (void) stride;
   noop_warn("glNormalFormatNV");
}

static void APIENTRY noopNormalP3ui(GLenum type, GLuint coords)
{
   (void) type; (void) coords;
   noop_warn("glNormalP3ui");
}

static void APIENTRY noopNormalP3uiv(GLenum type, const GLuint *coords)
{
   (void) type; (void) coords;
   noop_warn("glNormalP3uiv");
}

static void APIENTRY noopNormalPointer(GLenum type, GLsizei stride, const void *pointer)
{
   (void) type; (void) stride; (void) pointer;
   noop_warn("glNormalPointer");
}

static void APIENTRY noopNormalPointerEXT(GLenum type, GLsizei stride, GLsizei count, const void *pointer)
{
   (void) type; (void) stride; (void) count; (void) pointer;
   noop_warn("glNormalPointerEXT");
}

static void APIENTRY noopNormalPointerListIBM(GLenum type, GLint stride, const void **pointer, GLint ptrstride)
{
   (void) type; (void) stride; (void) pointer; (void) ptrstride;
   noop_warn("glNormalPointerListIBM");
}

static void APIENTRY noopNormalPointervINTEL(GLenum type, const void **pointer)
{
   (void) type; (void) pointer;
   noop_warn("glNormalPointervINTEL");
}

static void APIENTRY noopNormalStream3bATI(GLenum stream, GLbyte nx, GLbyte ny, GLbyte nz)
{
   (void) stream; (void) nx; (void) ny; (void) nz;
   noop_warn("glNormalStream3bATI");
}

static void APIENTRY noopNormalStream3bvATI(GLenum stream, const GLbyte *coords)
{
   (void) stream; (void) coords;
   noop_warn("glNormalStream3bvATI");
}

static void APIENTRY noopNormalStream3dATI(GLenum stream, GLdouble nx, GLdouble ny, GLdouble nz)
{
   (void) stream; (void) nx; (void) ny; (void) nz;
   noop_warn("glNormalStream3dATI");
}

static void APIENTRY noopNormalStream3dvATI(GLenum stream, const GLdouble *coords)
{
   (void) stream; (void) coords;
   noop_warn("glNormalStream3dvATI");
}

static void APIENTRY noopNormalStream3fATI(GLenum stream, GLfloat nx, GLfloat ny, GLfloat nz)
{
   (void) stream; (void) nx; (void) ny; (void) nz;
   noop_warn("glNormalStream3fATI");
}

static void APIENTRY noopNormalStream3fvATI(GLenum stream, const GLfloat *coords)
{
   (void) stream; (void) coords;
   noop_warn("glNormalStream3fvATI");
}

static void APIENTRY noopNormalStream3iATI(GLenum stream, GLint nx, GLint ny, GLint nz)
{
   (void) stream; (void) nx; (void) ny; (void) nz;
   noop_warn("glNormalStream3iATI");
}

static void APIENTRY noopNormalStream3ivATI(GLenum stream, const GLint *coords)
{
   (void) stream; (void) coords;
   noop_warn("glNormalStream3ivATI");
}

static void APIENTRY noopNormalStream3sATI(GLenum stream, GLshort nx, GLshort ny, GLshort nz)
{
   (void) stream; (void) nx; (void) ny; (void) nz;
   noop_warn("glNormalStream3sATI");
}

static void APIENTRY noopNormalStream3svATI(GLenum stream, const GLshort *coords)
{
   (void) stream; (void) coords;
   noop_warn("glNormalStream3svATI");
}

static void APIENTRY noopObjectLabel(GLenum identifier, GLuint name, GLsizei length, const GLchar *label)
{
   (void) identifier; (void) name; (void) length; (void) label;
   noop_warn("glObjectLabel");
}

static void APIENTRY noopObjectLabelKHR(GLenum identifier, GLuint name, GLsizei length, const GLchar *label)
{
   (void) identifier; (void) name; (void) length; (void) label;
   noop_warn("glObjectLabelKHR");
}

static void APIENTRY noopObjectLabelOES(GLenum identifier, GLuint name, GLsizei length, const GLchar *label)
{
   (void) identifier; (void) name; (void) length; (void) label;
   noop_warn("glObjectLabelOES");
}

static void APIENTRY noopObjectPtrLabel(const void *ptr, GLsizei length, const GLchar *label)
{
   (void) ptr; (void) length; (void) label;
   noop_warn("glObjectPtrLabel");
}

static void APIENTRY noopObjectPtrLabelKHR(const void *ptr, GLsizei length, const GLchar *label)
{
   (void) ptr; (void) length; (void) label;
   noop_warn("glObjectPtrLabelKHR");
}

static void APIENTRY noopObjectPtrLabelOES(void *ptr, GLsizei length, const GLchar *label)
{
   (void) ptr; (void) length; (void) label;
   noop_warn("glObjectPtrLabelOES");
}

static GLenum APIENTRY noopObjectPurgeableAPPLE(GLenum objectType, GLuint name, GLenum option)
{
   (void) objectType; (void) name; (void) option;
   noop_warn("glObjectPurgeableAPPLE");
   return (GLenum) 0;
}

static GLenum APIENTRY noopObjectUnpurgeableAPPLE(GLenum objectType, GLuint name, GLenum option)
{
   (void) objectType; (void) name; (void) option;
   noop_warn("glObjectUnpurgeableAPPLE");
   return (GLenum) 0;
}

static void APIENTRY noopOrtho(GLdouble left, GLdouble right, GLdouble bottom, GLdouble top, GLdouble zNear, GLdouble zFar)
{
   (void) left; (void) right; (void) bottom; (void) top; (void) zNear; (void) zFar;
   noop_warn("glOrtho");
}

static void APIENTRY noopOrthof(GLfloat l, GLfloat r, GLfloat b, GLfloat t, GLfloat n, GLfloat f)
{
   (void) l; (void) r; (void) b; (void) t; (void) n; (void) f;
   noop_warn("glOrthof");
}

static void APIENTRY noopOrthofOES(GLfloat l, GLfloat r, GLfloat b, GLfloat t, GLfloat n, GLfloat f)
{
   (void) l; (void) r; (void) b; (void) t; (void) n; (void) f;
   noop_warn("glOrthofOES");
}

static void APIENTRY noopOrthox(GLfixed l, GLfixed r, GLfixed b, GLfixed t, GLfixed n, GLfixed f)
{
   (void) l; (void) r; (void) b; (void) t; (void) n; (void) f;
   noop_warn("glOrthox");
}

static void APIENTRY noopOrthoxOES(GLfixed l, GLfixed r, GLfixed b, GLfixed t, GLfixed n, GLfixed f)
{
   (void) l; (void) r; (void) b; (void) t; (void) n; (void) f;
   noop_warn("glOrthoxOES");
}

static void APIENTRY noopPNTrianglesfATI(GLenum pname, GLfloat param)
{
   (void) pname; (void) param;
   noop_warn("glPNTrianglesfATI");
}

static void APIENTRY noopPNTrianglesiATI(GLenum pname, GLint param)
{
   (void) pname; (void) param;
   noop_warn("glPNTrianglesiATI");
}

static void APIENTRY noopPassTexCoordATI(GLuint dst, GLuint coord, GLenum swizzle)
{
   (void) dst; (void) coord; (void) swizzle;
   noop_warn("glPassTexCoordATI");
}

static void APIENTRY noopPassThrough(GLfloat token)
{
   (void) token;
   noop_warn("glPassThrough");
}

static void APIENTRY noopPassThroughxOES(GLfixed token)
{
   (void) token;
   noop_warn("glPassThroughxOES");
}

static void APIENTRY noopPatchParameterfv(GLenum pname, const GLfloat *values)
{
   (void) pname; (void) values;
   noop_warn("glPatchParameterfv");
}

static void APIENTRY noopPatchParameterfvEXT(GLenum pname, const GLfloat *values)
{
   (void) pname; (void) values;
   noop_warn("glPatchParameterfvEXT");
}

static void APIENTRY noopPatchParameterfvNV(GLenum pname, const GLfloat *values)
{
   (void) pname; (void) values;
   noop_warn("glPatchParameterfvNV");
}

static void APIENTRY noopPatchParameteri(GLenum pname, GLint value)
{
   (void) pname; (void) value;
   noop_warn("glPatchParameteri");
}

static void APIENTRY noopPatchParameteriEXT(GLenum pname, GLint value)
{
   (void) pname; (void) value;
   noop_warn("glPatchParameteriEXT");
}

static void APIENTRY noopPatchParameteriNV(GLenum pname, GLint value)
{
   (void) pname; (void) value;
   noop_warn("glPatchParameteriNV");
}

static void APIENTRY noopPatchParameteriOES(GLenum pname, GLint value)
{
   (void) pname; (void) value;
   noop_warn("glPatchParameteriOES");
}

static void APIENTRY noopPathColorGenNV(GLenum color, GLenum genMode, GLenum colorFormat, const GLfloat *coeffs)
{
   (void) color; (void) genMode; (void) colorFormat; (void) coeffs;
   noop_warn("glPathColorGenNV");
}

static void APIENTRY noopPathCommandsNV(GLuint path, GLsizei numCommands, const GLubyte *commands, GLsizei numCoords, GLenum coordType, const void *coords)
{
   (void) path; (void) numCommands; (void) commands; (void) numCoords; (void) coordType; (void) coords;
   noop_warn("glPathCommandsNV");
}

static void APIENTRY noopPathCoordsNV(GLuint path, GLsizei numCoords, GLenum coordType, const void *coords)
{
   (void) path; (void) numCoords; (void) coordType; (void) coords;
   noop_warn("glPathCoordsNV");
}

static void APIENTRY noopPathCoverDepthFuncNV(GLenum func)
{
   (void) func;
   noop_warn("glPathCoverDepthFuncNV");
}

static void APIENTRY noopPathDashArrayNV(GLuint path, GLsizei dashCount, const GLfloat *dashArray)
{
   (void) path; (void) dashCount; (void) dashArray;
   noop_warn("glPathDashArrayNV");
}

static void APIENTRY noopPathFogGenNV(GLenum genMode)
{
   (void) genMode;
   noop_warn("glPathFogGenNV");
}

static GLenum APIENTRY noopPathGlyphIndexArrayNV(GLuint firstPathName, GLenum fontTarget, const void *fontName, GLbitfield fontStyle, GLuint firstGlyphIndex, GLsizei numGlyphs, GLuint pathParameterTemplate, GLfloat emScale)
{
   (void) firstPathName; (void) fontTarget; (void) fontName; (void) fontStyle; (void) firstGlyphIndex; (void) numGlyphs; (void) pathParameterTemplate; (void) emScale;
   noop_warn("glPathGlyphIndexArrayNV");
   return (GLenum) 0;
}

static GLenum APIENTRY noopPathGlyphIndexRangeNV(GLenum fontTarget, const void *fontName, GLbitfield fontStyle, GLuint pathParameterTemplate, GLfloat emScale, GLuint *baseAndCount)
{
   (void) fontTarget; (void) fontName; (void) fontStyle; (void) pathParameterTemplate; (void) emScale; (void) baseAndCount;
   noop_warn("glPathGlyphIndexRangeNV");
   return (GLenum) 0;
}

static void APIENTRY noopPathGlyphRangeNV(GLuint firstPathName, GLenum fontTarget, const void *fontName, GLbitfield fontStyle, GLuint firstGlyph, GLsizei numGlyphs, GLenum handleMissingGlyphs, GLuint pathParameterTemplate, GLfloat emScale)
{
   (void) firstPathName; (void) fontTarget; (void) fontName; (void) fontStyle; (void) firstGlyph; (void) numGlyphs; (void) handleMissingGlyphs; (void) pathParameterTemplate; (void) emScale;
   noop_warn("glPathGlyphRangeNV");
}

static void APIENTRY noopPathGlyphsNV(GLuint firstPathName, GLenum fontTarget, const void *fontName, GLbitfield fontStyle, GLsizei numGlyphs, GLenum type, const void *charcodes, GLenum handleMissingGlyphs, GLuint pathParameterTemplate, GLfloat emScale)
{
   (void) firstPathName; (void) fontTarget; (void) fontName; (void) fontStyle; (void) numGlyphs; (void) type; (void) charcodes; (void) handleMissingGlyphs; (void) pathParameterTemplate; (void) emScale;
   noop_warn("glPathGlyphsNV");
}

static GLenum APIENTRY noopPathMemoryGlyphIndexArrayNV(GLuint firstPathName, GLenum fontTarget, GLsizeiptr fontSize, const void *fontData, GLsizei faceIndex, GLuint firstGlyphIndex, GLsizei numGlyphs, GLuint pathParameterTemplate, GLfloat emScale)
{
   (void) firstPathName; (void) fontTarget; (void) fontSize; (void) fontData; (void) faceIndex; (void) firstGlyphIndex; (void) numGlyphs; (void) pathParameterTemplate; (void) emScale;
   noop_warn("glPathMemoryGlyphIndexArrayNV");
   return (GLenum) 0;
}

static void APIENTRY noopPathParameterfNV(GLuint path, GLenum pname, GLfloat value)
{
   (void) path; (void) pname; (void) value;
   noop_warn("glPathParameterfNV");
}

static void APIENTRY noopPathParameterfvNV(GLuint path, GLenum pname, const GLfloat *value)
{
   (void) path; (void) pname; (void) value;
   noop_warn("glPathParameterfvNV");
}

static void APIENTRY noopPathParameteriNV(GLuint path, GLenum pname, GLint value)
{
   (void) path; (void) pname; (void) value;
   noop_warn("glPathParameteriNV");
}

static void APIENTRY noopPathParameterivNV(GLuint path, GLenum pname, const GLint *value)
{
   (void) path; (void) pname; (void) value;
   noop_warn("glPathParameterivNV");
}

static void APIENTRY noopPathStencilDepthOffsetNV(GLfloat factor, GLfloat units)
{
   (void) factor; (void) units;
   noop_warn("glPathStencilDepthOffsetNV");
}

static void APIENTRY noopPathStencilFuncNV(GLenum func, GLint ref, GLuint mask)
{
   (void) func; (void) ref; (void) mask;
   noop_warn("glPathStencilFuncNV");
}

static void APIENTRY noopPathStringNV(GLuint path, GLenum format, GLsizei length, const void *pathString)
{
   (void) path; (void) format; (void) length; (void) pathString;
   noop_warn("glPathStringNV");
}

static void APIENTRY noopPathSubCommandsNV(GLuint path, GLsizei commandStart, GLsizei commandsToDelete, GLsizei numCommands, const GLubyte *commands, GLsizei numCoords, GLenum coordType, const void *coords)
{
   (void) path; (void) commandStart; (void) commandsToDelete; (void) numCommands; (void) commands; (void) numCoords; (void) coordType; (void) coords;
   noop_warn("glPathSubCommandsNV");
}

static void APIENTRY noopPathSubCoordsNV(GLuint path, GLsizei coordStart, GLsizei numCoords, GLenum coordType, const void *coords)
{
   (void) path; (void) coordStart; (void) numCoords; (void) coordType; (void) coords;
   noop_warn("glPathSubCoordsNV");
}

static void APIENTRY noopPathTexGenNV(GLenum texCoordSet, GLenum genMode, GLint components, const GLfloat *coeffs)
{
   (void) texCoordSet; (void) genMode; (void) components; (void) coeffs;
   noop_warn("glPathTexGenNV");
}

static void APIENTRY noopPauseTransformFeedback(void)
{
   noop_warn("glPauseTransformFeedback");
}

static void APIENTRY noopPauseTransformFeedbackEXT(void)
{
   noop_warn("glPauseTransformFeedbackEXT");
}

static void APIENTRY noopPauseTransformFeedbackNV(void)
{
   noop_warn("glPauseTransformFeedbackNV");
}

static void APIENTRY noopPixelDataRangeNV(GLenum target, GLsizei length, const void *pointer)
{
   (void) target; (void) length; (void) pointer;
   noop_warn("glPixelDataRangeNV");
}

static void APIENTRY noopPixelMapfv(GLenum map, GLsizei mapsize, const GLfloat *values)
{
   (void) map; (void) mapsize; (void) values;
   noop_warn("glPixelMapfv");
}

static void APIENTRY noopPixelMapuiv(GLenum map, GLsizei mapsize, const GLuint *values)
{
   (void) map; (void) mapsize; (void) values;
   noop_warn("glPixelMapuiv");
}

static void APIENTRY noopPixelMapusv(GLenum map, GLsizei mapsize, const GLushort *values)
{
   (void) map; (void) mapsize; (void) values;
   noop_warn("glPixelMapusv");
}

static void APIENTRY noopPixelMapx(GLenum map, GLint size, const GLfixed *values)
{
   (void) map; (void) size; (void) values;
   noop_warn("glPixelMapx");
}

static void APIENTRY noopPixelStoref(GLenum pname, GLfloat param)
{
   (void) pname; (void) param;
   noop_warn("glPixelStoref");
}

static void APIENTRY noopPixelStorei(GLenum pname, GLint param)
{
   (void) pname; (void) param;
   noop_warn("glPixelStorei");
}

static void APIENTRY noopPixelStorex(GLenum pname, GLfixed param)
{
   (void) pname; (void) param;
   noop_warn("glPixelStorex");
}

static void APIENTRY noopPixelTexGenParameterfSGIS(GLenum pname, GLfloat param)
{
   (void) pname; (void) param;
   noop_warn("glPixelTexGenParameterfSGIS");
}

static void APIENTRY noopPixelTexGenParameterfvSGIS(GLenum pname, const GLfloat *params)
{
   (void) pname; (void) params;
   noop_warn("glPixelTexGenParameterfvSGIS");
}

static void APIENTRY noopPixelTexGenParameteriSGIS(GLenum pname, GLint param)
{
   (void) pname; (void) param;
   noop_warn("glPixelTexGenParameteriSGIS");
}

static void APIENTRY noopPixelTexGenParameterivSGIS(GLenum pname, const GLint *params)
{
   (void) pname; (void) params;
   noop_warn("glPixelTexGenParameterivSGIS");
}

static void APIENTRY noopPixelTexGenSGIX(GLenum mode)
{
   (void) mode;
   noop_warn("glPixelTexGenSGIX");
}

static void APIENTRY noopPixelTransferf(GLenum pname, GLfloat param)
{
   (void) pname; (void) param;
   noop_warn("glPixelTransferf");
}

static void APIENTRY noopPixelTransferi(GLenum pname, GLint param)
{
   (void) pname; (void) param;
   noop_warn("glPixelTransferi");
}

static void APIENTRY noopPixelTransferxOES(GLenum pname, GLfixed param)
{
   (void) pname; (void) param;
   noop_warn("glPixelTransferxOES");
}

static void APIENTRY noopPixelTransformParameterfEXT(GLenum target, GLenum pname, GLfloat param)
{
   (void) target; (void) pname; (void) param;
   noop_warn("glPixelTransformParameterfEXT");
}

static void APIENTRY noopPixelTransformParameterfvEXT(GLenum target, GLenum pname, const GLfloat *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glPixelTransformParameterfvEXT");
}

static void APIENTRY noopPixelTransformParameteriEXT(GLenum target, GLenum pname, GLint param)
{
   (void) target; (void) pname; (void) param;
   noop_warn("glPixelTransformParameteriEXT");
}

static void APIENTRY noopPixelTransformParameterivEXT(GLenum target, GLenum pname, const GLint *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glPixelTransformParameterivEXT");
}

static void APIENTRY noopPixelZoom(GLfloat xfactor, GLfloat yfactor)
{
   (void) xfactor; (void) yfactor;
   noop_warn("glPixelZoom");
}

static void APIENTRY noopPixelZoomxOES(GLfixed xfactor, GLfixed yfactor)
{
   (void) xfactor; (void) yfactor;
   noop_warn("glPixelZoomxOES");
}

static GLboolean APIENTRY noopPointAlongPathNV(GLuint path, GLsizei startSegment, GLsizei numSegments, GLfloat distance, GLfloat *x, GLfloat *y, GLfloat *tangentX, GLfloat *tangentY)
{
   (void) path; (void) startSegment; (void) numSegments; (void) distance; (void) x; (void) y; (void) tangentX; (void) tangentY;
   noop_warn("glPointAlongPathNV");
   return (GLboolean) 0;
}

static void APIENTRY noopPointParameterf(GLenum pname, GLfloat param)
{
   (void) pname; (void) param;
   noop_warn("glPointParameterf");
}

static void APIENTRY noopPointParameterfARB(GLenum pname, GLfloat param)
{
   (void) pname; (void) param;
   noop_warn("glPointParameterfARB");
}

static void APIENTRY noopPointParameterfEXT(GLenum pname, GLfloat param)
{
   (void) pname; (void) param;
   noop_warn("glPointParameterfEXT");
}

static void APIENTRY noopPointParameterfSGIS(GLenum pname, GLfloat param)
{
   (void) pname; (void) param;
   noop_warn("glPointParameterfSGIS");
}

static void APIENTRY noopPointParameterfv(GLenum pname, const GLfloat *params)
{
   (void) pname; (void) params;
   noop_warn("glPointParameterfv");
}

static void APIENTRY noopPointParameterfvARB(GLenum pname, const GLfloat *params)
{
   (void) pname; (void) params;
   noop_warn("glPointParameterfvARB");
}

static void APIENTRY noopPointParameterfvEXT(GLenum pname, const GLfloat *params)
{
   (void) pname; (void) params;
   noop_warn("glPointParameterfvEXT");
}

static void APIENTRY noopPointParameterfvSGIS(GLenum pname, const GLfloat *params)
{
   (void) pname; (void) params;
   noop_warn("glPointParameterfvSGIS");
}

static void APIENTRY noopPointParameteri(GLenum pname, GLint param)
{
   (void) pname; (void) param;
   noop_warn("glPointParameteri");
}

static void APIENTRY noopPointParameteriNV(GLenum pname, GLint param)
{
   (void) pname; (void) param;
   noop_warn("glPointParameteriNV");
}

static void APIENTRY noopPointParameteriv(GLenum pname, const GLint *params)
{
   (void) pname; (void) params;
   noop_warn("glPointParameteriv");
}

static void APIENTRY noopPointParameterivNV(GLenum pname, const GLint *params)
{
   (void) pname; (void) params;
   noop_warn("glPointParameterivNV");
}

static void APIENTRY noopPointParameterx(GLenum pname, GLfixed param)
{
   (void) pname; (void) param;
   noop_warn("glPointParameterx");
}

static void APIENTRY noopPointParameterxOES(GLenum pname, GLfixed param)
{
   (void) pname; (void) param;
   noop_warn("glPointParameterxOES");
}

static void APIENTRY noopPointParameterxv(GLenum pname, const GLfixed *params)
{
   (void) pname; (void) params;
   noop_warn("glPointParameterxv");
}

static void APIENTRY noopPointParameterxvOES(GLenum pname, const GLfixed *params)
{
   (void) pname; (void) params;
   noop_warn("glPointParameterxvOES");
}

static void APIENTRY noopPointSize(GLfloat size)
{
   (void) size;
   noop_warn("glPointSize");
}

static void APIENTRY noopPointSizePointerOES(GLenum type, GLsizei stride, const void *pointer)
{
   (void) type; (void) stride; (void) pointer;
   noop_warn("glPointSizePointerOES");
}

static void APIENTRY noopPointSizex(GLfixed size)
{
   (void) size;
   noop_warn("glPointSizex");
}

static void APIENTRY noopPointSizexOES(GLfixed size)
{
   (void) size;
   noop_warn("glPointSizexOES");
}

static GLint APIENTRY noopPollAsyncSGIX(GLuint *markerp)
{
   (void) markerp;
   noop_warn("glPollAsyncSGIX");
   return (GLint) 0;
}

static GLint APIENTRY noopPollInstrumentsSGIX(GLint *marker_p)
{
   (void) marker_p;
   noop_warn("glPollInstrumentsSGIX");
   return (GLint) 0;
}

static void APIENTRY noopPolygonMode(GLenum face, GLenum mode)
{
   (void) face; (void) mode;
   noop_warn("glPolygonMode");
}

static void APIENTRY noopPolygonModeNV(GLenum face, GLenum mode)
{
   (void) face; (void) mode;
   noop_warn("glPolygonModeNV");
}

static void APIENTRY noopPolygonOffset(GLfloat factor, GLfloat units)
{
   (void) factor; (void) units;
   noop_warn("glPolygonOffset");
}

static void APIENTRY noopPolygonOffsetClamp(GLfloat factor, GLfloat units, GLfloat clamp)
{
   (void) factor; (void) units; (void) clamp;
   noop_warn("glPolygonOffsetClamp");
}

static void APIENTRY noopPolygonOffsetClampEXT(GLfloat factor, GLfloat units, GLfloat clamp)
{
   (void) factor; (void) units; (void) clamp;
   noop_warn("glPolygonOffsetClampEXT");
}

static void APIENTRY noopPolygonOffsetEXT(GLfloat factor, GLfloat bias)
{
   (void) factor; (void) bias;
   noop_warn("glPolygonOffsetEXT");
}

static void APIENTRY noopPolygonOffsetx(GLfixed factor, GLfixed units)
{
   (void) factor; (void) units;
   noop_warn("glPolygonOffsetx");
}

static void APIENTRY noopPolygonOffsetxOES(GLfixed factor, GLfixed units)
{
   (void) factor; (void) units;
   noop_warn("glPolygonOffsetxOES");
}

static void APIENTRY noopPolygonStipple(const GLubyte *mask)
{
   (void) mask;
   noop_warn("glPolygonStipple");
}

static void APIENTRY noopPopAttrib(void)
{
   noop_warn("glPopAttrib");
}

static void APIENTRY noopPopClientAttrib(void)
{
   noop_warn("glPopClientAttrib");
}

static void APIENTRY noopPopDebugGroup(void)
{
   noop_warn("glPopDebugGroup");
}

static void APIENTRY noopPopDebugGroupKHR(void)
{
   noop_warn("glPopDebugGroupKHR");
}

static void APIENTRY noopPopDebugGroupOES(void)
{
   noop_warn("glPopDebugGroupOES");
}

static void APIENTRY noopPopGroupMarkerEXT(void)
{
   noop_warn("glPopGroupMarkerEXT");
}

static void APIENTRY noopPopMatrix(void)
{
   noop_warn("glPopMatrix");
}

static void APIENTRY noopPopName(void)
{
   noop_warn("glPopName");
}

static void APIENTRY noopPresentFrameDualFillNV(GLuint video_slot, GLuint64 minPresentTime, GLuint beginPresentTimeId, GLuint presentDurationId, GLenum type, GLenum target0, GLuint fill0, GLenum target1, GLuint fill1, GLenum target2, GLuint fill2, GLenum target3, GLuint fill3)
{
   (void) video_slot; (void) minPresentTime; (void) beginPresentTimeId; (void) presentDurationId; (void) type; (void) target0; (void) fill0; (void) target1; (void) fill1; (void) target2; (void) fill2; (void) target3; (void) fill3;
   noop_warn("glPresentFrameDualFillNV");
}

static void APIENTRY noopPresentFrameKeyedNV(GLuint video_slot, GLuint64 minPresentTime, GLuint beginPresentTimeId, GLuint presentDurationId, GLenum type, GLenum target0, GLuint fill0, GLuint key0, GLenum target1, GLuint fill1, GLuint key1)
{
   (void) video_slot; (void) minPresentTime; (void) beginPresentTimeId; (void) presentDurationId; (void) type; (void) target0; (void) fill0; (void) key0; (void) target1; (void) fill1; (void) key1;
   noop_warn("glPresentFrameKeyedNV");
}

static void APIENTRY noopPrimitiveBoundingBox(GLfloat minX, GLfloat minY, GLfloat minZ, GLfloat minW, GLfloat maxX, GLfloat maxY, GLfloat maxZ, GLfloat maxW)
{
   (void) minX; (void) minY; (void) minZ; (void) minW; (void) maxX; (void) maxY; (void) maxZ; (void) maxW;
   noop_warn("glPrimitiveBoundingBox");
}

static void APIENTRY noopPrimitiveBoundingBoxARB(GLfloat minX, GLfloat minY, GLfloat minZ, GLfloat minW, GLfloat maxX, GLfloat maxY, GLfloat maxZ, GLfloat maxW)
{
   (void) minX; (void) minY; (void) minZ; (void) minW; (void) maxX; (void) maxY; (void) maxZ; (void) maxW;
   noop_warn("glPrimitiveBoundingBoxARB");
}

static void APIENTRY noopPrimitiveBoundingBoxEXT(GLfloat minX, GLfloat minY, GLfloat minZ, GLfloat minW, GLfloat maxX, GLfloat maxY, GLfloat maxZ, GLfloat maxW)
{
   (void) minX; (void) minY; (void) minZ; (void) minW; (void) maxX; (void) maxY; (void) maxZ; (void) maxW;
   noop_warn("glPrimitiveBoundingBoxEXT");
}

static void APIENTRY noopPrimitiveBoundingBoxOES(GLfloat minX, GLfloat minY, GLfloat minZ, GLfloat minW, GLfloat maxX, GLfloat maxY, GLfloat maxZ, GLfloat maxW)
{
   (void) minX; (void) minY; (void) minZ; (void) minW; (void) maxX; (void) maxY; (void) maxZ; (void) maxW;
   noop_warn("glPrimitiveBoundingBoxOES");
}

static void APIENTRY noopPrimitiveRestart(void)
{
   noop_warn("glPrimitiveRestart");
}

static void APIENTRY noopPrimitiveRestartIndex(GLuint index)
{
   (void) index;
   noop_warn("glPrimitiveRestartIndex");
}

static void APIENTRY noopPrimitiveRestartIndexNV(GLuint index)
{
   (void) index;
   noop_warn("glPrimitiveRestartIndexNV");
}

static void APIENTRY noopPrimitiveRestartNV(void)
{
   noop_warn("glPrimitiveRestartNV");
}

static void APIENTRY noopPrioritizeTextures(GLsizei n, const GLuint *textures, const GLfloat *priorities)
{
   (void) n; (void) textures; (void) priorities;
   noop_warn("glPrioritizeTextures");
}

static void APIENTRY noopPrioritizeTexturesEXT(GLsizei n, const GLuint *textures, const GLclampf *priorities)
{
   (void) n; (void) textures; (void) priorities;
   noop_warn("glPrioritizeTexturesEXT");
}

static void APIENTRY noopPrioritizeTexturesxOES(GLsizei n, const GLuint *textures, const GLfixed *priorities)
{
   (void) n; (void) textures; (void) priorities;
   noop_warn("glPrioritizeTexturesxOES");
}

static void APIENTRY noopProgramBinary(GLuint program, GLenum binaryFormat, const void *binary, GLsizei length)
{
   (void) program; (void) binaryFormat; (void) binary; (void) length;
   noop_warn("glProgramBinary");
}

static void APIENTRY noopProgramBinaryOES(GLuint program, GLenum binaryFormat, const void *binary, GLint length)
{
   (void) program; (void) binaryFormat; (void) binary; (void) length;
   noop_warn("glProgramBinaryOES");
}

static void APIENTRY noopProgramBufferParametersIivNV(GLenum target, GLuint bindingIndex, GLuint wordIndex, GLsizei count, const GLint *params)
{
   (void) target; (void) bindingIndex; (void) wordIndex; (void) count; (void) params;
   noop_warn("glProgramBufferParametersIivNV");
}

static void APIENTRY noopProgramBufferParametersIuivNV(GLenum target, GLuint bindingIndex, GLuint wordIndex, GLsizei count, const GLuint *params)
{
   (void) target; (void) bindingIndex; (void) wordIndex; (void) count; (void) params;
   noop_warn("glProgramBufferParametersIuivNV");
}

static void APIENTRY noopProgramBufferParametersfvNV(GLenum target, GLuint bindingIndex, GLuint wordIndex, GLsizei count, const GLfloat *params)
{
   (void) target; (void) bindingIndex; (void) wordIndex; (void) count; (void) params;
   noop_warn("glProgramBufferParametersfvNV");
}

static void APIENTRY noopProgramEnvParameter4dARB(GLenum target, GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w)
{
   (void) target; (void) index; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glProgramEnvParameter4dARB");
}

static void APIENTRY noopProgramEnvParameter4dvARB(GLenum target, GLuint index, const GLdouble *params)
{
   (void) target; (void) index; (void) params;
   noop_warn("glProgramEnvParameter4dvARB");
}

static void APIENTRY noopProgramEnvParameter4fARB(GLenum target, GLuint index, GLfloat x, GLfloat y, GLfloat z, GLfloat w)
{
   (void) target; (void) index; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glProgramEnvParameter4fARB");
}

static void APIENTRY noopProgramEnvParameter4fvARB(GLenum target, GLuint index, const GLfloat *params)
{
   (void) target; (void) index; (void) params;
   noop_warn("glProgramEnvParameter4fvARB");
}

static void APIENTRY noopProgramEnvParameterI4iNV(GLenum target, GLuint index, GLint x, GLint y, GLint z, GLint w)
{
   (void) target; (void) index; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glProgramEnvParameterI4iNV");
}

static void APIENTRY noopProgramEnvParameterI4ivNV(GLenum target, GLuint index, const GLint *params)
{
   (void) target; (void) index; (void) params;
   noop_warn("glProgramEnvParameterI4ivNV");
}

static void APIENTRY noopProgramEnvParameterI4uiNV(GLenum target, GLuint index, GLuint x, GLuint y, GLuint z, GLuint w)
{
   (void) target; (void) index; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glProgramEnvParameterI4uiNV");
}

static void APIENTRY noopProgramEnvParameterI4uivNV(GLenum target, GLuint index, const GLuint *params)
{
   (void) target; (void) index; (void) params;
   noop_warn("glProgramEnvParameterI4uivNV");
}

static void APIENTRY noopProgramEnvParameters4fvEXT(GLenum target, GLuint index, GLsizei count, const GLfloat *params)
{
   (void) target; (void) index; (void) count; (void) params;
   noop_warn("glProgramEnvParameters4fvEXT");
}

static void APIENTRY noopProgramEnvParametersI4ivNV(GLenum target, GLuint index, GLsizei count, const GLint *params)
{
   (void) target; (void) index; (void) count; (void) params;
   noop_warn("glProgramEnvParametersI4ivNV");
}

static void APIENTRY noopProgramEnvParametersI4uivNV(GLenum target, GLuint index, GLsizei count, const GLuint *params)
{
   (void) target; (void) index; (void) count; (void) params;
   noop_warn("glProgramEnvParametersI4uivNV");
}

static void APIENTRY noopProgramLocalParameter4dARB(GLenum target, GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w)
{
   (void) target; (void) index; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glProgramLocalParameter4dARB");
}

static void APIENTRY noopProgramLocalParameter4dvARB(GLenum target, GLuint index, const GLdouble *params)
{
   (void) target; (void) index; (void) params;
   noop_warn("glProgramLocalParameter4dvARB");
}

static void APIENTRY noopProgramLocalParameter4fARB(GLenum target, GLuint index, GLfloat x, GLfloat y, GLfloat z, GLfloat w)
{
   (void) target; (void) index; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glProgramLocalParameter4fARB");
}

static void APIENTRY noopProgramLocalParameter4fvARB(GLenum target, GLuint index, const GLfloat *params)
{
   (void) target; (void) index; (void) params;
   noop_warn("glProgramLocalParameter4fvARB");
}

static void APIENTRY noopProgramLocalParameterI4iNV(GLenum target, GLuint index, GLint x, GLint y, GLint z, GLint w)
{
   (void) target; (void) index; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glProgramLocalParameterI4iNV");
}

static void APIENTRY noopProgramLocalParameterI4ivNV(GLenum target, GLuint index, const GLint *params)
{
   (void) target; (void) index; (void) params;
   noop_warn("glProgramLocalParameterI4ivNV");
}

static void APIENTRY noopProgramLocalParameterI4uiNV(GLenum target, GLuint index, GLuint x, GLuint y, GLuint z, GLuint w)
{
   (void) target; (void) index; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glProgramLocalParameterI4uiNV");
}

static void APIENTRY noopProgramLocalParameterI4uivNV(GLenum target, GLuint index, const GLuint *params)
{
   (void) target; (void) index; (void) params;
   noop_warn("glProgramLocalParameterI4uivNV");
}

static void APIENTRY noopProgramLocalParameters4fvEXT(GLenum target, GLuint index, GLsizei count, const GLfloat *params)
{
   (void) target; (void) index; (void) count; (void) params;
   noop_warn("glProgramLocalParameters4fvEXT");
}

static void APIENTRY noopProgramLocalParametersI4ivNV(GLenum target, GLuint index, GLsizei count, const GLint *params)
{
   (void) target; (void) index; (void) count; (void) params;
   noop_warn("glProgramLocalParametersI4ivNV");
}

static void APIENTRY noopProgramLocalParametersI4uivNV(GLenum target, GLuint index, GLsizei count, const GLuint *params)
{
   (void) target; (void) index; (void) count; (void) params;
   noop_warn("glProgramLocalParametersI4uivNV");
}

static void APIENTRY noopProgramNamedParameter4dNV(GLuint id, GLsizei len, const GLubyte *name, GLdouble x, GLdouble y, GLdouble z, GLdouble w)
{
   (void) id; (void) len; (void) name; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glProgramNamedParameter4dNV");
}

static void APIENTRY noopProgramNamedParameter4dvNV(GLuint id, GLsizei len, const GLubyte *name, const GLdouble *v)
{
   (void) id; (void) len; (void) name; (void) v;
   noop_warn("glProgramNamedParameter4dvNV");
}

static void APIENTRY noopProgramNamedParameter4fNV(GLuint id, GLsizei len, const GLubyte *name, GLfloat x, GLfloat y, GLfloat z, GLfloat w)
{
   (void) id; (void) len; (void) name; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glProgramNamedParameter4fNV");
}

static void APIENTRY noopProgramNamedParameter4fvNV(GLuint id, GLsizei len, const GLubyte *name, const GLfloat *v)
{
   (void) id; (void) len; (void) name; (void) v;
   noop_warn("glProgramNamedParameter4fvNV");
}

static void APIENTRY noopProgramParameter4dNV(GLenum target, GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w)
{
   (void) target; (void) index; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glProgramParameter4dNV");
}

static void APIENTRY noopProgramParameter4dvNV(GLenum target, GLuint index, const GLdouble *v)
{
   (void) target; (void) index; (void) v;
   noop_warn("glProgramParameter4dvNV");
}

static void APIENTRY noopProgramParameter4fNV(GLenum target, GLuint index, GLfloat x, GLfloat y, GLfloat z, GLfloat w)
{
   (void) target; (void) index; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glProgramParameter4fNV");
}

static void APIENTRY noopProgramParameter4fvNV(GLenum target, GLuint index, const GLfloat *v)
{
   (void) target; (void) index; (void) v;
   noop_warn("glProgramParameter4fvNV");
}

static void APIENTRY noopProgramParameteri(GLuint program, GLenum pname, GLint value)
{
   (void) program; (void) pname; (void) value;
   noop_warn("glProgramParameteri");
}

static void APIENTRY noopProgramParameteriARB(GLuint program, GLenum pname, GLint value)
{
   (void) program; (void) pname; (void) value;
   noop_warn("glProgramParameteriARB");
}

static void APIENTRY noopProgramParameteriEXT(GLuint program, GLenum pname, GLint value)
{
   (void) program; (void) pname; (void) value;
   noop_warn("glProgramParameteriEXT");
}

static void APIENTRY noopProgramParameters4dvNV(GLenum target, GLuint index, GLsizei count, const GLdouble *v)
{
   (void) target; (void) index; (void) count; (void) v;
   noop_warn("glProgramParameters4dvNV");
}

static void APIENTRY noopProgramParameters4fvNV(GLenum target, GLuint index, GLsizei count, const GLfloat *v)
{
   (void) target; (void) index; (void) count; (void) v;
   noop_warn("glProgramParameters4fvNV");
}

static void APIENTRY noopProgramPathFragmentInputGenNV(GLuint program, GLint location, GLenum genMode, GLint components, const GLfloat *coeffs)
{
   (void) program; (void) location; (void) genMode; (void) components; (void) coeffs;
   noop_warn("glProgramPathFragmentInputGenNV");
}

static void APIENTRY noopProgramStringARB(GLenum target, GLenum format, GLsizei len, const void *string)
{
   (void) target; (void) format; (void) len; (void) string;
   noop_warn("glProgramStringARB");
}

static void APIENTRY noopProgramSubroutineParametersuivNV(GLenum target, GLsizei count, const GLuint *params)
{
   (void) target; (void) count; (void) params;
   noop_warn("glProgramSubroutineParametersuivNV");
}

static void APIENTRY noopProgramUniform1d(GLuint program, GLint location, GLdouble v0)
{
   (void) program; (void) location; (void) v0;
   noop_warn("glProgramUniform1d");
}

static void APIENTRY noopProgramUniform1dEXT(GLuint program, GLint location, GLdouble x)
{
   (void) program; (void) location; (void) x;
   noop_warn("glProgramUniform1dEXT");
}

static void APIENTRY noopProgramUniform1dv(GLuint program, GLint location, GLsizei count, const GLdouble *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform1dv");
}

static void APIENTRY noopProgramUniform1dvEXT(GLuint program, GLint location, GLsizei count, const GLdouble *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform1dvEXT");
}

static void APIENTRY noopProgramUniform1f(GLuint program, GLint location, GLfloat v0)
{
   (void) program; (void) location; (void) v0;
   noop_warn("glProgramUniform1f");
}

static void APIENTRY noopProgramUniform1fEXT(GLuint program, GLint location, GLfloat v0)
{
   (void) program; (void) location; (void) v0;
   noop_warn("glProgramUniform1fEXT");
}

static void APIENTRY noopProgramUniform1fv(GLuint program, GLint location, GLsizei count, const GLfloat *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform1fv");
}

static void APIENTRY noopProgramUniform1fvEXT(GLuint program, GLint location, GLsizei count, const GLfloat *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform1fvEXT");
}

static void APIENTRY noopProgramUniform1i(GLuint program, GLint location, GLint v0)
{
   (void) program; (void) location; (void) v0;
   noop_warn("glProgramUniform1i");
}

static void APIENTRY noopProgramUniform1i64ARB(GLuint program, GLint location, GLint64 x)
{
   (void) program; (void) location; (void) x;
   noop_warn("glProgramUniform1i64ARB");
}

static void APIENTRY noopProgramUniform1i64NV(GLuint program, GLint location, GLint64 x)
{
   (void) program; (void) location; (void) x;
   noop_warn("glProgramUniform1i64NV");
}

static void APIENTRY noopProgramUniform1i64vARB(GLuint program, GLint location, GLsizei count, const GLint64 *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform1i64vARB");
}

static void APIENTRY noopProgramUniform1i64vNV(GLuint program, GLint location, GLsizei count, const GLint64 *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform1i64vNV");
}

static void APIENTRY noopProgramUniform1iEXT(GLuint program, GLint location, GLint v0)
{
   (void) program; (void) location; (void) v0;
   noop_warn("glProgramUniform1iEXT");
}

static void APIENTRY noopProgramUniform1iv(GLuint program, GLint location, GLsizei count, const GLint *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform1iv");
}

static void APIENTRY noopProgramUniform1ivEXT(GLuint program, GLint location, GLsizei count, const GLint *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform1ivEXT");
}

static void APIENTRY noopProgramUniform1ui(GLuint program, GLint location, GLuint v0)
{
   (void) program; (void) location; (void) v0;
   noop_warn("glProgramUniform1ui");
}

static void APIENTRY noopProgramUniform1ui64ARB(GLuint program, GLint location, GLuint64 x)
{
   (void) program; (void) location; (void) x;
   noop_warn("glProgramUniform1ui64ARB");
}

static void APIENTRY noopProgramUniform1ui64NV(GLuint program, GLint location, GLuint64 x)
{
   (void) program; (void) location; (void) x;
   noop_warn("glProgramUniform1ui64NV");
}

static void APIENTRY noopProgramUniform1ui64vARB(GLuint program, GLint location, GLsizei count, const GLuint64 *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform1ui64vARB");
}

static void APIENTRY noopProgramUniform1ui64vNV(GLuint program, GLint location, GLsizei count, const GLuint64 *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform1ui64vNV");
}

static void APIENTRY noopProgramUniform1uiEXT(GLuint program, GLint location, GLuint v0)
{
   (void) program; (void) location; (void) v0;
   noop_warn("glProgramUniform1uiEXT");
}

static void APIENTRY noopProgramUniform1uiv(GLuint program, GLint location, GLsizei count, const GLuint *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform1uiv");
}

static void APIENTRY noopProgramUniform1uivEXT(GLuint program, GLint location, GLsizei count, const GLuint *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform1uivEXT");
}

static void APIENTRY noopProgramUniform2d(GLuint program, GLint location, GLdouble v0, GLdouble v1)
{
   (void) program; (void) location; (void) v0; (void) v1;
   noop_warn("glProgramUniform2d");
}

static void APIENTRY noopProgramUniform2dEXT(GLuint program, GLint location, GLdouble x, GLdouble y)
{
   (void) program; (void) location; (void) x; (void) y;
   noop_warn("glProgramUniform2dEXT");
}

static void APIENTRY noopProgramUniform2dv(GLuint program, GLint location, GLsizei count, const GLdouble *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform2dv");
}

static void APIENTRY noopProgramUniform2dvEXT(GLuint program, GLint location, GLsizei count, const GLdouble *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform2dvEXT");
}

static void APIENTRY noopProgramUniform2f(GLuint program, GLint location, GLfloat v0, GLfloat v1)
{
   (void) program; (void) location; (void) v0; (void) v1;
   noop_warn("glProgramUniform2f");
}

static void APIENTRY noopProgramUniform2fEXT(GLuint program, GLint location, GLfloat v0, GLfloat v1)
{
   (void) program; (void) location; (void) v0; (void) v1;
   noop_warn("glProgramUniform2fEXT");
}

static void APIENTRY noopProgramUniform2fv(GLuint program, GLint location, GLsizei count, const GLfloat *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform2fv");
}

static void APIENTRY noopProgramUniform2fvEXT(GLuint program, GLint location, GLsizei count, const GLfloat *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform2fvEXT");
}

static void APIENTRY noopProgramUniform2i(GLuint program, GLint location, GLint v0, GLint v1)
{
   (void) program; (void) location; (void) v0; (void) v1;
   noop_warn("glProgramUniform2i");
}

static void APIENTRY noopProgramUniform2i64ARB(GLuint program, GLint location, GLint64 x, GLint64 y)
{
   (void) program; (void) location; (void) x; (void) y;
   noop_warn("glProgramUniform2i64ARB");
}

static void APIENTRY noopProgramUniform2i64NV(GLuint program, GLint location, GLint64 x, GLint64 y)
{
   (void) program; (void) location; (void) x; (void) y;
   noop_warn("glProgramUniform2i64NV");
}

static void APIENTRY noopProgramUniform2i64vARB(GLuint program, GLint location, GLsizei count, const GLint64 *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform2i64vARB");
}

static void APIENTRY noopProgramUniform2i64vNV(GLuint program, GLint location, GLsizei count, const GLint64 *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform2i64vNV");
}

static void APIENTRY noopProgramUniform2iEXT(GLuint program, GLint location, GLint v0, GLint v1)
{
   (void) program; (void) location; (void) v0; (void) v1;
   noop_warn("glProgramUniform2iEXT");
}

static void APIENTRY noopProgramUniform2iv(GLuint program, GLint location, GLsizei count, const GLint *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform2iv");
}

static void APIENTRY noopProgramUniform2ivEXT(GLuint program, GLint location, GLsizei count, const GLint *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform2ivEXT");
}

static void APIENTRY noopProgramUniform2ui(GLuint program, GLint location, GLuint v0, GLuint v1)
{
   (void) program; (void) location; (void) v0; (void) v1;
   noop_warn("glProgramUniform2ui");
}

static void APIENTRY noopProgramUniform2ui64ARB(GLuint program, GLint location, GLuint64 x, GLuint64 y)
{
   (void) program; (void) location; (void) x; (void) y;
   noop_warn("glProgramUniform2ui64ARB");
}

static void APIENTRY noopProgramUniform2ui64NV(GLuint program, GLint location, GLuint64 x, GLuint64 y)
{
   (void) program; (void) location; (void) x; (void) y;
   noop_warn("glProgramUniform2ui64NV");
}

static void APIENTRY noopProgramUniform2ui64vARB(GLuint program, GLint location, GLsizei count, const GLuint64 *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform2ui64vARB");
}

static void APIENTRY noopProgramUniform2ui64vNV(GLuint program, GLint location, GLsizei count, const GLuint64 *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform2ui64vNV");
}

static void APIENTRY noopProgramUniform2uiEXT(GLuint program, GLint location, GLuint v0, GLuint v1)
{
   (void) program; (void) location; (void) v0; (void) v1;
   noop_warn("glProgramUniform2uiEXT");
}

static void APIENTRY noopProgramUniform2uiv(GLuint program, GLint location, GLsizei count, const GLuint *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform2uiv");
}

static void APIENTRY noopProgramUniform2uivEXT(GLuint program, GLint location, GLsizei count, const GLuint *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform2uivEXT");
}

static void APIENTRY noopProgramUniform3d(GLuint program, GLint location, GLdouble v0, GLdouble v1, GLdouble v2)
{
   (void) program; (void) location; (void) v0; (void) v1; (void) v2;
   noop_warn("glProgramUniform3d");
}

static void APIENTRY noopProgramUniform3dEXT(GLuint program, GLint location, GLdouble x, GLdouble y, GLdouble z)
{
   (void) program; (void) location; (void) x; (void) y; (void) z;
   noop_warn("glProgramUniform3dEXT");
}

static void APIENTRY noopProgramUniform3dv(GLuint program, GLint location, GLsizei count, const GLdouble *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform3dv");
}

static void APIENTRY noopProgramUniform3dvEXT(GLuint program, GLint location, GLsizei count, const GLdouble *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform3dvEXT");
}

static void APIENTRY noopProgramUniform3f(GLuint program, GLint location, GLfloat v0, GLfloat v1, GLfloat v2)
{
   (void) program; (void) location; (void) v0; (void) v1; (void) v2;
   noop_warn("glProgramUniform3f");
}

static void APIENTRY noopProgramUniform3fEXT(GLuint program, GLint location, GLfloat v0, GLfloat v1, GLfloat v2)
{
   (void) program; (void) location; (void) v0; (void) v1; (void) v2;
   noop_warn("glProgramUniform3fEXT");
}

static void APIENTRY noopProgramUniform3fv(GLuint program, GLint location, GLsizei count, const GLfloat *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform3fv");
}

static void APIENTRY noopProgramUniform3fvEXT(GLuint program, GLint location, GLsizei count, const GLfloat *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform3fvEXT");
}

static void APIENTRY noopProgramUniform3i(GLuint program, GLint location, GLint v0, GLint v1, GLint v2)
{
   (void) program; (void) location; (void) v0; (void) v1; (void) v2;
   noop_warn("glProgramUniform3i");
}

static void APIENTRY noopProgramUniform3i64ARB(GLuint program, GLint location, GLint64 x, GLint64 y, GLint64 z)
{
   (void) program; (void) location; (void) x; (void) y; (void) z;
   noop_warn("glProgramUniform3i64ARB");
}

static void APIENTRY noopProgramUniform3i64NV(GLuint program, GLint location, GLint64 x, GLint64 y, GLint64 z)
{
   (void) program; (void) location; (void) x; (void) y; (void) z;
   noop_warn("glProgramUniform3i64NV");
}

static void APIENTRY noopProgramUniform3i64vARB(GLuint program, GLint location, GLsizei count, const GLint64 *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform3i64vARB");
}

static void APIENTRY noopProgramUniform3i64vNV(GLuint program, GLint location, GLsizei count, const GLint64 *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform3i64vNV");
}

static void APIENTRY noopProgramUniform3iEXT(GLuint program, GLint location, GLint v0, GLint v1, GLint v2)
{
   (void) program; (void) location; (void) v0; (void) v1; (void) v2;
   noop_warn("glProgramUniform3iEXT");
}

static void APIENTRY noopProgramUniform3iv(GLuint program, GLint location, GLsizei count, const GLint *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform3iv");
}

static void APIENTRY noopProgramUniform3ivEXT(GLuint program, GLint location, GLsizei count, const GLint *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform3ivEXT");
}

static void APIENTRY noopProgramUniform3ui(GLuint program, GLint location, GLuint v0, GLuint v1, GLuint v2)
{
   (void) program; (void) location; (void) v0; (void) v1; (void) v2;
   noop_warn("glProgramUniform3ui");
}

static void APIENTRY noopProgramUniform3ui64ARB(GLuint program, GLint location, GLuint64 x, GLuint64 y, GLuint64 z)
{
   (void) program; (void) location; (void) x; (void) y; (void) z;
   noop_warn("glProgramUniform3ui64ARB");
}

static void APIENTRY noopProgramUniform3ui64NV(GLuint program, GLint location, GLuint64 x, GLuint64 y, GLuint64 z)
{
   (void) program; (void) location; (void) x; (void) y; (void) z;
   noop_warn("glProgramUniform3ui64NV");
}

static void APIENTRY noopProgramUniform3ui64vARB(GLuint program, GLint location, GLsizei count, const GLuint64 *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform3ui64vARB");
}

static void APIENTRY noopProgramUniform3ui64vNV(GLuint program, GLint location, GLsizei count, const GLuint64 *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform3ui64vNV");
}

static void APIENTRY noopProgramUniform3uiEXT(GLuint program, GLint location, GLuint v0, GLuint v1, GLuint v2)
{
   (void) program; (void) location; (void) v0; (void) v1; (void) v2;
   noop_warn("glProgramUniform3uiEXT");
}

static void APIENTRY noopProgramUniform3uiv(GLuint program, GLint location, GLsizei count, const GLuint *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform3uiv");
}

static void APIENTRY noopProgramUniform3uivEXT(GLuint program, GLint location, GLsizei count, const GLuint *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform3uivEXT");
}

static void APIENTRY noopProgramUniform4d(GLuint program, GLint location, GLdouble v0, GLdouble v1, GLdouble v2, GLdouble v3)
{
   (void) program; (void) location; (void) v0; (void) v1; (void) v2; (void) v3;
   noop_warn("glProgramUniform4d");
}

static void APIENTRY noopProgramUniform4dEXT(GLuint program, GLint location, GLdouble x, GLdouble y, GLdouble z, GLdouble w)
{
   (void) program; (void) location; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glProgramUniform4dEXT");
}

static void APIENTRY noopProgramUniform4dv(GLuint program, GLint location, GLsizei count, const GLdouble *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform4dv");
}

static void APIENTRY noopProgramUniform4dvEXT(GLuint program, GLint location, GLsizei count, const GLdouble *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform4dvEXT");
}

static void APIENTRY noopProgramUniform4f(GLuint program, GLint location, GLfloat v0, GLfloat v1, GLfloat v2, GLfloat v3)
{
   (void) program; (void) location; (void) v0; (void) v1; (void) v2; (void) v3;
   noop_warn("glProgramUniform4f");
}

static void APIENTRY noopProgramUniform4fEXT(GLuint program, GLint location, GLfloat v0, GLfloat v1, GLfloat v2, GLfloat v3)
{
   (void) program; (void) location; (void) v0; (void) v1; (void) v2; (void) v3;
   noop_warn("glProgramUniform4fEXT");
}

static void APIENTRY noopProgramUniform4fv(GLuint program, GLint location, GLsizei count, const GLfloat *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform4fv");
}

static void APIENTRY noopProgramUniform4fvEXT(GLuint program, GLint location, GLsizei count, const GLfloat *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform4fvEXT");
}

static void APIENTRY noopProgramUniform4i(GLuint program, GLint location, GLint v0, GLint v1, GLint v2, GLint v3)
{
   (void) program; (void) location; (void) v0; (void) v1; (void) v2; (void) v3;
   noop_warn("glProgramUniform4i");
}

static void APIENTRY noopProgramUniform4i64ARB(GLuint program, GLint location, GLint64 x, GLint64 y, GLint64 z, GLint64 w)
{
   (void) program; (void) location; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glProgramUniform4i64ARB");
}

static void APIENTRY noopProgramUniform4i64NV(GLuint program, GLint location, GLint64 x, GLint64 y, GLint64 z, GLint64 w)
{
   (void) program; (void) location; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glProgramUniform4i64NV");
}

static void APIENTRY noopProgramUniform4i64vARB(GLuint program, GLint location, GLsizei count, const GLint64 *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform4i64vARB");
}

static void APIENTRY noopProgramUniform4i64vNV(GLuint program, GLint location, GLsizei count, const GLint64 *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform4i64vNV");
}

static void APIENTRY noopProgramUniform4iEXT(GLuint program, GLint location, GLint v0, GLint v1, GLint v2, GLint v3)
{
   (void) program; (void) location; (void) v0; (void) v1; (void) v2; (void) v3;
   noop_warn("glProgramUniform4iEXT");
}

static void APIENTRY noopProgramUniform4iv(GLuint program, GLint location, GLsizei count, const GLint *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform4iv");
}

static void APIENTRY noopProgramUniform4ivEXT(GLuint program, GLint location, GLsizei count, const GLint *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform4ivEXT");
}

static void APIENTRY noopProgramUniform4ui(GLuint program, GLint location, GLuint v0, GLuint v1, GLuint v2, GLuint v3)
{
   (void) program; (void) location; (void) v0; (void) v1; (void) v2; (void) v3;
   noop_warn("glProgramUniform4ui");
}

static void APIENTRY noopProgramUniform4ui64ARB(GLuint program, GLint location, GLuint64 x, GLuint64 y, GLuint64 z, GLuint64 w)
{
   (void) program; (void) location; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glProgramUniform4ui64ARB");
}

static void APIENTRY noopProgramUniform4ui64NV(GLuint program, GLint location, GLuint64 x, GLuint64 y, GLuint64 z, GLuint64 w)
{
   (void) program; (void) location; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glProgramUniform4ui64NV");
}

static void APIENTRY noopProgramUniform4ui64vARB(GLuint program, GLint location, GLsizei count, const GLuint64 *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform4ui64vARB");
}

static void APIENTRY noopProgramUniform4ui64vNV(GLuint program, GLint location, GLsizei count, const GLuint64 *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform4ui64vNV");
}

static void APIENTRY noopProgramUniform4uiEXT(GLuint program, GLint location, GLuint v0, GLuint v1, GLuint v2, GLuint v3)
{
   (void) program; (void) location; (void) v0; (void) v1; (void) v2; (void) v3;
   noop_warn("glProgramUniform4uiEXT");
}

static void APIENTRY noopProgramUniform4uiv(GLuint program, GLint location, GLsizei count, const GLuint *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform4uiv");
}

static void APIENTRY noopProgramUniform4uivEXT(GLuint program, GLint location, GLsizei count, const GLuint *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniform4uivEXT");
}

static void APIENTRY noopProgramUniformHandleui64ARB(GLuint program, GLint location, GLuint64 value)
{
   (void) program; (void) location; (void) value;
   noop_warn("glProgramUniformHandleui64ARB");
}

static void APIENTRY noopProgramUniformHandleui64IMG(GLuint program, GLint location, GLuint64 value)
{
   (void) program; (void) location; (void) value;
   noop_warn("glProgramUniformHandleui64IMG");
}

static void APIENTRY noopProgramUniformHandleui64NV(GLuint program, GLint location, GLuint64 value)
{
   (void) program; (void) location; (void) value;
   noop_warn("glProgramUniformHandleui64NV");
}

static void APIENTRY noopProgramUniformHandleui64vARB(GLuint program, GLint location, GLsizei count, const GLuint64 *values)
{
   (void) program; (void) location; (void) count; (void) values;
   noop_warn("glProgramUniformHandleui64vARB");
}

static void APIENTRY noopProgramUniformHandleui64vIMG(GLuint program, GLint location, GLsizei count, const GLuint64 *values)
{
   (void) program; (void) location; (void) count; (void) values;
   noop_warn("glProgramUniformHandleui64vIMG");
}

static void APIENTRY noopProgramUniformHandleui64vNV(GLuint program, GLint location, GLsizei count, const GLuint64 *values)
{
   (void) program; (void) location; (void) count; (void) values;
   noop_warn("glProgramUniformHandleui64vNV");
}

static void APIENTRY noopProgramUniformMatrix2dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   (void) program; (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glProgramUniformMatrix2dv");
}

static void APIENTRY noopProgramUniformMatrix2dvEXT(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   (void) program; (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glProgramUniformMatrix2dvEXT");
}

static void APIENTRY noopProgramUniformMatrix2fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   (void) program; (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glProgramUniformMatrix2fv");
}

static void APIENTRY noopProgramUniformMatrix2fvEXT(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   (void) program; (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glProgramUniformMatrix2fvEXT");
}

static void APIENTRY noopProgramUniformMatrix2x3dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   (void) program; (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glProgramUniformMatrix2x3dv");
}

static void APIENTRY noopProgramUniformMatrix2x3dvEXT(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   (void) program; (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glProgramUniformMatrix2x3dvEXT");
}

static void APIENTRY noopProgramUniformMatrix2x3fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   (void) program; (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glProgramUniformMatrix2x3fv");
}

static void APIENTRY noopProgramUniformMatrix2x3fvEXT(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   (void) program; (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glProgramUniformMatrix2x3fvEXT");
}

static void APIENTRY noopProgramUniformMatrix2x4dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   (void) program; (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glProgramUniformMatrix2x4dv");
}

static void APIENTRY noopProgramUniformMatrix2x4dvEXT(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   (void) program; (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glProgramUniformMatrix2x4dvEXT");
}

static void APIENTRY noopProgramUniformMatrix2x4fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   (void) program; (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glProgramUniformMatrix2x4fv");
}

static void APIENTRY noopProgramUniformMatrix2x4fvEXT(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   (void) program; (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glProgramUniformMatrix2x4fvEXT");
}

static void APIENTRY noopProgramUniformMatrix3dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   (void) program; (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glProgramUniformMatrix3dv");
}

static void APIENTRY noopProgramUniformMatrix3dvEXT(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   (void) program; (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glProgramUniformMatrix3dvEXT");
}

static void APIENTRY noopProgramUniformMatrix3fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   (void) program; (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glProgramUniformMatrix3fv");
}

static void APIENTRY noopProgramUniformMatrix3fvEXT(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   (void) program; (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glProgramUniformMatrix3fvEXT");
}

static void APIENTRY noopProgramUniformMatrix3x2dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   (void) program; (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glProgramUniformMatrix3x2dv");
}

static void APIENTRY noopProgramUniformMatrix3x2dvEXT(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   (void) program; (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glProgramUniformMatrix3x2dvEXT");
}

static void APIENTRY noopProgramUniformMatrix3x2fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   (void) program; (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glProgramUniformMatrix3x2fv");
}

static void APIENTRY noopProgramUniformMatrix3x2fvEXT(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   (void) program; (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glProgramUniformMatrix3x2fvEXT");
}

static void APIENTRY noopProgramUniformMatrix3x4dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   (void) program; (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glProgramUniformMatrix3x4dv");
}

static void APIENTRY noopProgramUniformMatrix3x4dvEXT(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   (void) program; (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glProgramUniformMatrix3x4dvEXT");
}

static void APIENTRY noopProgramUniformMatrix3x4fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   (void) program; (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glProgramUniformMatrix3x4fv");
}

static void APIENTRY noopProgramUniformMatrix3x4fvEXT(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   (void) program; (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glProgramUniformMatrix3x4fvEXT");
}

static void APIENTRY noopProgramUniformMatrix4dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   (void) program; (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glProgramUniformMatrix4dv");
}

static void APIENTRY noopProgramUniformMatrix4dvEXT(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   (void) program; (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glProgramUniformMatrix4dvEXT");
}

static void APIENTRY noopProgramUniformMatrix4fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   (void) program; (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glProgramUniformMatrix4fv");
}

static void APIENTRY noopProgramUniformMatrix4fvEXT(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   (void) program; (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glProgramUniformMatrix4fvEXT");
}

static void APIENTRY noopProgramUniformMatrix4x2dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   (void) program; (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glProgramUniformMatrix4x2dv");
}

static void APIENTRY noopProgramUniformMatrix4x2dvEXT(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   (void) program; (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glProgramUniformMatrix4x2dvEXT");
}

static void APIENTRY noopProgramUniformMatrix4x2fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   (void) program; (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glProgramUniformMatrix4x2fv");
}

static void APIENTRY noopProgramUniformMatrix4x2fvEXT(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   (void) program; (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glProgramUniformMatrix4x2fvEXT");
}

static void APIENTRY noopProgramUniformMatrix4x3dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   (void) program; (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glProgramUniformMatrix4x3dv");
}

static void APIENTRY noopProgramUniformMatrix4x3dvEXT(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   (void) program; (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glProgramUniformMatrix4x3dvEXT");
}

static void APIENTRY noopProgramUniformMatrix4x3fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   (void) program; (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glProgramUniformMatrix4x3fv");
}

static void APIENTRY noopProgramUniformMatrix4x3fvEXT(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   (void) program; (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glProgramUniformMatrix4x3fvEXT");
}

static void APIENTRY noopProgramUniformui64NV(GLuint program, GLint location, GLuint64 value)
{
   (void) program; (void) location; (void) value;
   noop_warn("glProgramUniformui64NV");
}

static void APIENTRY noopProgramUniformui64vNV(GLuint program, GLint location, GLsizei count, const GLuint64 *value)
{
   (void) program; (void) location; (void) count; (void) value;
   noop_warn("glProgramUniformui64vNV");
}

static void APIENTRY noopProgramVertexLimitNV(GLenum target, GLint limit)
{
   (void) target; (void) limit;
   noop_warn("glProgramVertexLimitNV");
}

static void APIENTRY noopProvokingVertex(GLenum mode)
{
   (void) mode;
   noop_warn("glProvokingVertex");
}

static void APIENTRY noopProvokingVertexEXT(GLenum mode)
{
   (void) mode;
   noop_warn("glProvokingVertexEXT");
}

static void APIENTRY noopPushAttrib(GLbitfield mask)
{
   (void) mask;
   noop_warn("glPushAttrib");
}

static void APIENTRY noopPushClientAttrib(GLbitfield mask)
{
   (void) mask;
   noop_warn("glPushClientAttrib");
}

static void APIENTRY noopPushClientAttribDefaultEXT(GLbitfield mask)
{
   (void) mask;
   noop_warn("glPushClientAttribDefaultEXT");
}

static void APIENTRY noopPushDebugGroup(GLenum source, GLuint id, GLsizei length, const GLchar *message)
{
   (void) source; (void) id; (void) length; (void) message;
   noop_warn("glPushDebugGroup");
}

static void APIENTRY noopPushDebugGroupKHR(GLenum source, GLuint id, GLsizei length, const GLchar *message)
{
   (void) source; (void) id; (void) length; (void) message;
   noop_warn("glPushDebugGroupKHR");
}

static void APIENTRY noopPushDebugGroupOES(GLenum source, GLuint id, GLsizei length, const GLchar *message)
{
   (void) source; (void) id; (void) length; (void) message;
   noop_warn("glPushDebugGroupOES");
}

static void APIENTRY noopPushGroupMarkerEXT(GLsizei length, const GLchar *marker)
{
   (void) length; (void) marker;
   noop_warn("glPushGroupMarkerEXT");
}

static void APIENTRY noopPushMatrix(void)
{
   noop_warn("glPushMatrix");
}

static void APIENTRY noopPushName(GLuint name)
{
   (void) name;
   noop_warn("glPushName");
}

static void APIENTRY noopQueryCounter(GLuint id, GLenum target)
{
   (void) id; (void) target;
   noop_warn("glQueryCounter");
}

static void APIENTRY noopQueryCounterEXT(GLuint id, GLenum target)
{
   (void) id; (void) target;
   noop_warn("glQueryCounterEXT");
}

static void APIENTRY noopQueryCounterNV(GLuint id, GLenum target)
{
   (void) id; (void) target;
   noop_warn("glQueryCounterNV");
}

static GLbitfield APIENTRY noopQueryMatrixxOES(GLfixed *mantissa, GLint *exponent)
{
   (void) mantissa; (void) exponent;
   noop_warn("glQueryMatrixxOES");
   return (GLbitfield) 0;
}

static void APIENTRY noopQueryObjectParameteruiAMD(GLenum target, GLuint id, GLenum pname, GLuint param)
{
   (void) target; (void) id; (void) pname; (void) param;
   noop_warn("glQueryObjectParameteruiAMD");
}

static GLint APIENTRY noopQueryResourceNV(GLenum queryType, GLint tagId, GLuint count, GLint *buffer)
{
   (void) queryType; (void) tagId; (void) count; (void) buffer;
   noop_warn("glQueryResourceNV");
   return (GLint) 0;
}

static void APIENTRY noopQueryResourceTagNV(GLint tagId, const GLchar *tagString)
{
   (void) tagId; (void) tagString;
   noop_warn("glQueryResourceTagNV");
}

static void APIENTRY noopRasterPos2d(GLdouble x, GLdouble y)
{
   (void) x; (void) y;
   noop_warn("glRasterPos2d");
}

static void APIENTRY noopRasterPos2dv(const GLdouble *v)
{
   (void) v;
   noop_warn("glRasterPos2dv");
}

static void APIENTRY noopRasterPos2f(GLfloat x, GLfloat y)
{
   (void) x; (void) y;
   noop_warn("glRasterPos2f");
}

static void APIENTRY noopRasterPos2fv(const GLfloat *v)
{
   (void) v;
   noop_warn("glRasterPos2fv");
}

static void APIENTRY noopRasterPos2i(GLint x, GLint y)
{
   (void) x; (void) y;
   noop_warn("glRasterPos2i");
}

static void APIENTRY noopRasterPos2iv(const GLint *v)
{
   (void) v;
   noop_warn("glRasterPos2iv");
}

static void APIENTRY noopRasterPos2s(GLshort x, GLshort y)
{
   (void) x; (void) y;
   noop_warn("glRasterPos2s");
}

static void APIENTRY noopRasterPos2sv(const GLshort *v)
{
   (void) v;
   noop_warn("glRasterPos2sv");
}

static void APIENTRY noopRasterPos2xOES(GLfixed x, GLfixed y)
{
   (void) x; (void) y;
   noop_warn("glRasterPos2xOES");
}

static void APIENTRY noopRasterPos2xvOES(const GLfixed *coords)
{
   (void) coords;
   noop_warn("glRasterPos2xvOES");
}

static void APIENTRY noopRasterPos3d(GLdouble x, GLdouble y, GLdouble z)
{
   (void) x; (void) y; (void) z;
   noop_warn("glRasterPos3d");
}

static void APIENTRY noopRasterPos3dv(const GLdouble *v)
{
   (void) v;
   noop_warn("glRasterPos3dv");
}

static void APIENTRY noopRasterPos3f(GLfloat x, GLfloat y, GLfloat z)
{
   (void) x; (void) y; (void) z;
   noop_warn("glRasterPos3f");
}

static void APIENTRY noopRasterPos3fv(const GLfloat *v)
{
   (void) v;
   noop_warn("glRasterPos3fv");
}

static void APIENTRY noopRasterPos3i(GLint x, GLint y, GLint z)
{
   (void) x; (void) y; (void) z;
   noop_warn("glRasterPos3i");
}

static void APIENTRY noopRasterPos3iv(const GLint *v)
{
   (void) v;
   noop_warn("glRasterPos3iv");
}

static void APIENTRY noopRasterPos3s(GLshort x, GLshort y, GLshort z)
{
   (void) x; (void) y; (void) z;
   noop_warn("glRasterPos3s");
}

static void APIENTRY noopRasterPos3sv(const GLshort *v)
{
   (void) v;
   noop_warn("glRasterPos3sv");
}

static void APIENTRY noopRasterPos3xOES(GLfixed x, GLfixed y, GLfixed z)
{
   (void) x; (void) y; (void) z;
   noop_warn("glRasterPos3xOES");
}

static void APIENTRY noopRasterPos3xvOES(const GLfixed *coords)
{
   (void) coords;
   noop_warn("glRasterPos3xvOES");
}

static void APIENTRY noopRasterPos4d(GLdouble x, GLdouble y, GLdouble z, GLdouble w)
{
   (void) x; (void) y; (void) z; (void) w;
   noop_warn("glRasterPos4d");
}

static void APIENTRY noopRasterPos4dv(const GLdouble *v)
{
   (void) v;
   noop_warn("glRasterPos4dv");
}

static void APIENTRY noopRasterPos4f(GLfloat x, GLfloat y, GLfloat z, GLfloat w)
{
   (void) x; (void) y; (void) z; (void) w;
   noop_warn("glRasterPos4f");
}

static void APIENTRY noopRasterPos4fv(const GLfloat *v)
{
   (void) v;
   noop_warn("glRasterPos4fv");
}

static void APIENTRY noopRasterPos4i(GLint x, GLint y, GLint z, GLint w)
{
   (void) x; (void) y; (void) z; (void) w;
   noop_warn("glRasterPos4i");
}

static void APIENTRY noopRasterPos4iv(const GLint *v)
{
   (void) v;
   noop_warn("glRasterPos4iv");
}

static void APIENTRY noopRasterPos4s(GLshort x, GLshort y, GLshort z, GLshort w)
{
   (void) x; (void) y; (void) z; (void) w;
   noop_warn("glRasterPos4s");
}

static void APIENTRY noopRasterPos4sv(const GLshort *v)
{
   (void) v;
   noop_warn("glRasterPos4sv");
}

static void APIENTRY noopRasterPos4xOES(GLfixed x, GLfixed y, GLfixed z, GLfixed w)
{
   (void) x; (void) y; (void) z; (void) w;
   noop_warn("glRasterPos4xOES");
}

static void APIENTRY noopRasterPos4xvOES(const GLfixed *coords)
{
   (void) coords;
   noop_warn("glRasterPos4xvOES");
}

static void APIENTRY noopRasterSamplesEXT(GLuint samples, GLboolean fixedsamplelocations)
{
   (void) samples; (void) fixedsamplelocations;
   noop_warn("glRasterSamplesEXT");
}

static void APIENTRY noopReadBuffer(GLenum src)
{
   (void) src;
   noop_warn("glReadBuffer");
}

static void APIENTRY noopReadBufferIndexedEXT(GLenum src, GLint index)
{
   (void) src; (void) index;
   noop_warn("glReadBufferIndexedEXT");
}

static void APIENTRY noopReadBufferNV(GLenum mode)
{
   (void) mode;
   noop_warn("glReadBufferNV");
}

static void APIENTRY noopReadInstrumentsSGIX(GLint marker)
{
   (void) marker;
   noop_warn("glReadInstrumentsSGIX");
}

static void APIENTRY noopReadPixels(GLint x, GLint y, GLsizei width, GLsizei height, GLenum format, GLenum type, void *pixels)
{
   (void) x; (void) y; (void) width; (void) height; (void) format; (void) type; (void) pixels;
   noop_warn("glReadPixels");
}

static void APIENTRY noopReadnPixels(GLint x, GLint y, GLsizei width, GLsizei height, GLenum format, GLenum type, GLsizei bufSize, void *data)
{
   (void) x; (void) y; (void) width; (void) height; (void) format; (void) type; (void) bufSize; (void) data;
   noop_warn("glReadnPixels");
}

static void APIENTRY noopReadnPixelsARB(GLint x, GLint y, GLsizei width, GLsizei height, GLenum format, GLenum type, GLsizei bufSize, void *data)
{
   (void) x; (void) y; (void) width; (void) height; (void) format; (void) type; (void) bufSize; (void) data;
   noop_warn("glReadnPixelsARB");
}

static void APIENTRY noopReadnPixelsEXT(GLint x, GLint y, GLsizei width, GLsizei height, GLenum format, GLenum type, GLsizei bufSize, void *data)
{
   (void) x; (void) y; (void) width; (void) height; (void) format; (void) type; (void) bufSize; (void) data;
   noop_warn("glReadnPixelsEXT");
}

static void APIENTRY noopReadnPixelsKHR(GLint x, GLint y, GLsizei width, GLsizei height, GLenum format, GLenum type, GLsizei bufSize, void *data)
{
   (void) x; (void) y; (void) width; (void) height; (void) format; (void) type; (void) bufSize; (void) data;
   noop_warn("glReadnPixelsKHR");
}

static void APIENTRY noopRectd(GLdouble x1, GLdouble y1, GLdouble x2, GLdouble y2)
{
   (void) x1; (void) y1; (void) x2; (void) y2;
   noop_warn("glRectd");
}

static void APIENTRY noopRectdv(const GLdouble *v1, const GLdouble *v2)
{
   (void) v1; (void) v2;
   noop_warn("glRectdv");
}

static void APIENTRY noopRectf(GLfloat x1, GLfloat y1, GLfloat x2, GLfloat y2)
{
   (void) x1; (void) y1; (void) x2; (void) y2;
   noop_warn("glRectf");
}

static void APIENTRY noopRectfv(const GLfloat *v1, const GLfloat *v2)
{
   (void) v1; (void) v2;
   noop_warn("glRectfv");
}

static void APIENTRY noopRecti(GLint x1, GLint y1, GLint x2, GLint y2)
{
   (void) x1; (void) y1; (void) x2; (void) y2;
   noop_warn("glRecti");
}

static void APIENTRY noopRectiv(const GLint *v1, const GLint *v2)
{
   (void) v1; (void) v2;
   noop_warn("glRectiv");
}

static void APIENTRY noopRects(GLshort x1, GLshort y1, GLshort x2, GLshort y2)
{
   (void) x1; (void) y1; (void) x2; (void) y2;
   noop_warn("glRects");
}

static void APIENTRY noopRectsv(const GLshort *v1, const GLshort *v2)
{
   (void) v1; (void) v2;
   noop_warn("glRectsv");
}

static void APIENTRY noopRectxOES(GLfixed x1, GLfixed y1, GLfixed x2, GLfixed y2)
{
   (void) x1; (void) y1; (void) x2; (void) y2;
   noop_warn("glRectxOES");
}

static void APIENTRY noopRectxvOES(const GLfixed *v1, const GLfixed *v2)
{
   (void) v1; (void) v2;
   noop_warn("glRectxvOES");
}

static void APIENTRY noopReferencePlaneSGIX(const GLdouble *equation)
{
   (void) equation;
   noop_warn("glReferencePlaneSGIX");
}

static GLboolean APIENTRY noopReleaseKeyedMutexWin32EXT(GLuint memory, GLuint64 key)
{
   (void) memory; (void) key;
   noop_warn("glReleaseKeyedMutexWin32EXT");
   return (GLboolean) 0;
}

static void APIENTRY noopReleaseShaderCompiler(void)
{
   noop_warn("glReleaseShaderCompiler");
}

static void APIENTRY noopRenderGpuMaskNV(GLbitfield mask)
{
   (void) mask;
   noop_warn("glRenderGpuMaskNV");
}

static GLint APIENTRY noopRenderMode(GLenum mode)
{
   (void) mode;
   noop_warn("glRenderMode");
   return (GLint) 0;
}

static void APIENTRY noopRenderbufferStorage(GLenum target, GLenum internalformat, GLsizei width, GLsizei height)
{
   (void) target; (void) internalformat; (void) width; (void) height;
   noop_warn("glRenderbufferStorage");
}

static void APIENTRY noopRenderbufferStorageEXT(GLenum target, GLenum internalformat, GLsizei width, GLsizei height)
{
   (void) target; (void) internalformat; (void) width; (void) height;
   noop_warn("glRenderbufferStorageEXT");
}

static void APIENTRY noopRenderbufferStorageMultisample(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height)
{
   (void) target; (void) samples; (void) internalformat; (void) width; (void) height;
   noop_warn("glRenderbufferStorageMultisample");
}

static void APIENTRY noopRenderbufferStorageMultisampleANGLE(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height)
{
   (void) target; (void) samples; (void) internalformat; (void) width; (void) height;
   noop_warn("glRenderbufferStorageMultisampleANGLE");
}

static void APIENTRY noopRenderbufferStorageMultisampleAPPLE(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height)
{
   (void) target; (void) samples; (void) internalformat; (void) width; (void) height;
   noop_warn("glRenderbufferStorageMultisampleAPPLE");
}

static void APIENTRY noopRenderbufferStorageMultisampleAdvancedAMD(GLenum target, GLsizei samples, GLsizei storageSamples, GLenum internalformat, GLsizei width, GLsizei height)
{
   (void) target; (void) samples; (void) storageSamples; (void) internalformat; (void) width; (void) height;
   noop_warn("glRenderbufferStorageMultisampleAdvancedAMD");
}

static void APIENTRY noopRenderbufferStorageMultisampleCoverageNV(GLenum target, GLsizei coverageSamples, GLsizei colorSamples, GLenum internalformat, GLsizei width, GLsizei height)
{
   (void) target; (void) coverageSamples; (void) colorSamples; (void) internalformat; (void) width; (void) height;
   noop_warn("glRenderbufferStorageMultisampleCoverageNV");
}

static void APIENTRY noopRenderbufferStorageMultisampleEXT(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height)
{
   (void) target; (void) samples; (void) internalformat; (void) width; (void) height;
   noop_warn("glRenderbufferStorageMultisampleEXT");
}

static void APIENTRY noopRenderbufferStorageMultisampleIMG(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height)
{
   (void) target; (void) samples; (void) internalformat; (void) width; (void) height;
   noop_warn("glRenderbufferStorageMultisampleIMG");
}

static void APIENTRY noopRenderbufferStorageMultisampleNV(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height)
{
   (void) target; (void) samples; (void) internalformat; (void) width; (void) height;
   noop_warn("glRenderbufferStorageMultisampleNV");
}

static void APIENTRY noopRenderbufferStorageOES(GLenum target, GLenum internalformat, GLsizei width, GLsizei height)
{
   (void) target; (void) internalformat; (void) width; (void) height;
   noop_warn("glRenderbufferStorageOES");
}

static void APIENTRY noopReplacementCodePointerSUN(GLenum type, GLsizei stride, const void **pointer)
{
   (void) type; (void) stride; (void) pointer;
   noop_warn("glReplacementCodePointerSUN");
}

static void APIENTRY noopReplacementCodeubSUN(GLubyte code)
{
   (void) code;
   noop_warn("glReplacementCodeubSUN");
}

static void APIENTRY noopReplacementCodeubvSUN(const GLubyte *code)
{
   (void) code;
   noop_warn("glReplacementCodeubvSUN");
}

static void APIENTRY noopReplacementCodeuiColor3fVertex3fSUN(GLuint rc, GLfloat r, GLfloat g, GLfloat b, GLfloat x, GLfloat y, GLfloat z)
{
   (void) rc; (void) r; (void) g; (void) b; (void) x; (void) y; (void) z;
   noop_warn("glReplacementCodeuiColor3fVertex3fSUN");
}

static void APIENTRY noopReplacementCodeuiColor3fVertex3fvSUN(const GLuint *rc, const GLfloat *c, const GLfloat *v)
{
   (void) rc; (void) c; (void) v;
   noop_warn("glReplacementCodeuiColor3fVertex3fvSUN");
}

static void APIENTRY noopReplacementCodeuiColor4fNormal3fVertex3fSUN(GLuint rc, GLfloat r, GLfloat g, GLfloat b, GLfloat a, GLfloat nx, GLfloat ny, GLfloat nz, GLfloat x, GLfloat y, GLfloat z)
{
   (void) rc; (void) r; (void) g; (void) b; (void) a; (void) nx; (void) ny; (void) nz; (void) x; (void) y; (void) z;
   noop_warn("glReplacementCodeuiColor4fNormal3fVertex3fSUN");
}

static void APIENTRY noopReplacementCodeuiColor4fNormal3fVertex3fvSUN(const GLuint *rc, const GLfloat *c, const GLfloat *n, const GLfloat *v)
{
   (void) rc; (void) c; (void) n; (void) v;
   noop_warn("glReplacementCodeuiColor4fNormal3fVertex3fvSUN");
}

static void APIENTRY noopReplacementCodeuiColor4ubVertex3fSUN(GLuint rc, GLubyte r, GLubyte g, GLubyte b, GLubyte a, GLfloat x, GLfloat y, GLfloat z)
{
   (void) rc; (void) r; (void) g; (void) b; (void) a; (void) x; (void) y; (void) z;
   noop_warn("glReplacementCodeuiColor4ubVertex3fSUN");
}

static void APIENTRY noopReplacementCodeuiColor4ubVertex3fvSUN(const GLuint *rc, const GLubyte *c, const GLfloat *v)
{
   (void) rc; (void) c; (void) v;
   noop_warn("glReplacementCodeuiColor4ubVertex3fvSUN");
}

static void APIENTRY noopReplacementCodeuiNormal3fVertex3fSUN(GLuint rc, GLfloat nx, GLfloat ny, GLfloat nz, GLfloat x, GLfloat y, GLfloat z)
{
   (void) rc; (void) nx; (void) ny; (void) nz; (void) x; (void) y; (void) z;
   noop_warn("glReplacementCodeuiNormal3fVertex3fSUN");
}

static void APIENTRY noopReplacementCodeuiNormal3fVertex3fvSUN(const GLuint *rc, const GLfloat *n, const GLfloat *v)
{
   (void) rc; (void) n; (void) v;
   noop_warn("glReplacementCodeuiNormal3fVertex3fvSUN");
}

static void APIENTRY noopReplacementCodeuiSUN(GLuint code)
{
   (void) code;
   noop_warn("glReplacementCodeuiSUN");
}

static void APIENTRY noopReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fSUN(GLuint rc, GLfloat s, GLfloat t, GLfloat r, GLfloat g, GLfloat b, GLfloat a, GLfloat nx, GLfloat ny, GLfloat nz, GLfloat x, GLfloat y, GLfloat z)
{
   (void) rc; (void) s; (void) t; (void) r; (void) g; (void) b; (void) a; (void) nx; (void) ny; (void) nz; (void) x; (void) y; (void) z;
   noop_warn("glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fSUN");
}

static void APIENTRY noopReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fvSUN(const GLuint *rc, const GLfloat *tc, const GLfloat *c, const GLfloat *n, const GLfloat *v)
{
   (void) rc; (void) tc; (void) c; (void) n; (void) v;
   noop_warn("glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fvSUN");
}

static void APIENTRY noopReplacementCodeuiTexCoord2fNormal3fVertex3fSUN(GLuint rc, GLfloat s, GLfloat t, GLfloat nx, GLfloat ny, GLfloat nz, GLfloat x, GLfloat y, GLfloat z)
{
   (void) rc; (void) s; (void) t; (void) nx; (void) ny; (void) nz; (void) x; (void) y; (void) z;
   noop_warn("glReplacementCodeuiTexCoord2fNormal3fVertex3fSUN");
}

static void APIENTRY noopReplacementCodeuiTexCoord2fNormal3fVertex3fvSUN(const GLuint *rc, const GLfloat *tc, const GLfloat *n, const GLfloat *v)
{
   (void) rc; (void) tc; (void) n; (void) v;
   noop_warn("glReplacementCodeuiTexCoord2fNormal3fVertex3fvSUN");
}

static void APIENTRY noopReplacementCodeuiTexCoord2fVertex3fSUN(GLuint rc, GLfloat s, GLfloat t, GLfloat x, GLfloat y, GLfloat z)
{
   (void) rc; (void) s; (void) t; (void) x; (void) y; (void) z;
   noop_warn("glReplacementCodeuiTexCoord2fVertex3fSUN");
}

static void APIENTRY noopReplacementCodeuiTexCoord2fVertex3fvSUN(const GLuint *rc, const GLfloat *tc, const GLfloat *v)
{
   (void) rc; (void) tc; (void) v;
   noop_warn("glReplacementCodeuiTexCoord2fVertex3fvSUN");
}

static void APIENTRY noopReplacementCodeuiVertex3fSUN(GLuint rc, GLfloat x, GLfloat y, GLfloat z)
{
   (void) rc; (void) x; (void) y; (void) z;
   noop_warn("glReplacementCodeuiVertex3fSUN");
}

static void APIENTRY noopReplacementCodeuiVertex3fvSUN(const GLuint *rc, const GLfloat *v)
{
   (void) rc; (void) v;
   noop_warn("glReplacementCodeuiVertex3fvSUN");
}

static void APIENTRY noopReplacementCodeuivSUN(const GLuint *code)
{
   (void) code;
   noop_warn("glReplacementCodeuivSUN");
}

static void APIENTRY noopReplacementCodeusSUN(GLushort code)
{
   (void) code;
   noop_warn("glReplacementCodeusSUN");
}

static void APIENTRY noopReplacementCodeusvSUN(const GLushort *code)
{
   (void) code;
   noop_warn("glReplacementCodeusvSUN");
}

static void APIENTRY noopRequestResidentProgramsNV(GLsizei n, const GLuint *programs)
{
   (void) n; (void) programs;
   noop_warn("glRequestResidentProgramsNV");
}

static void APIENTRY noopResetHistogram(GLenum target)
{
   (void) target;
   noop_warn("glResetHistogram");
}

static void APIENTRY noopResetHistogramEXT(GLenum target)
{
   (void) target;
   noop_warn("glResetHistogramEXT");
}

static void APIENTRY noopResetMemoryObjectParameterNV(GLuint memory, GLenum pname)
{
   (void) memory; (void) pname;
   noop_warn("glResetMemoryObjectParameterNV");
}

static void APIENTRY noopResetMinmax(GLenum target)
{
   (void) target;
   noop_warn("glResetMinmax");
}

static void APIENTRY noopResetMinmaxEXT(GLenum target)
{
   (void) target;
   noop_warn("glResetMinmaxEXT");
}

static void APIENTRY noopResizeBuffersMESA(void)
{
   noop_warn("glResizeBuffersMESA");
}

static void APIENTRY noopResolveDepthValuesNV(void)
{
   noop_warn("glResolveDepthValuesNV");
}

static void APIENTRY noopResolveMultisampleFramebufferAPPLE(void)
{
   noop_warn("glResolveMultisampleFramebufferAPPLE");
}

static void APIENTRY noopResumeTransformFeedback(void)
{
   noop_warn("glResumeTransformFeedback");
}

static void APIENTRY noopResumeTransformFeedbackEXT(void)
{
   noop_warn("glResumeTransformFeedbackEXT");
}

static void APIENTRY noopResumeTransformFeedbackNV(void)
{
   noop_warn("glResumeTransformFeedbackNV");
}

static void APIENTRY noopRotated(GLdouble angle, GLdouble x, GLdouble y, GLdouble z)
{
   (void) angle; (void) x; (void) y; (void) z;
   noop_warn("glRotated");
}

static void APIENTRY noopRotatef(GLfloat angle, GLfloat x, GLfloat y, GLfloat z)
{
   (void) angle; (void) x; (void) y; (void) z;
   noop_warn("glRotatef");
}

static void APIENTRY noopRotatex(GLfixed angle, GLfixed x, GLfixed y, GLfixed z)
{
   (void) angle; (void) x; (void) y; (void) z;
   noop_warn("glRotatex");
}

static void APIENTRY noopRotatexOES(GLfixed angle, GLfixed x, GLfixed y, GLfixed z)
{
   (void) angle; (void) x; (void) y; (void) z;
   noop_warn("glRotatexOES");
}

static void APIENTRY noopSampleCoverage(GLfloat value, GLboolean invert)
{
   (void) value; (void) invert;
   noop_warn("glSampleCoverage");
}

static void APIENTRY noopSampleCoverageARB(GLfloat value, GLboolean invert)
{
   (void) value; (void) invert;
   noop_warn("glSampleCoverageARB");
}

static void APIENTRY noopSampleCoveragex(GLclampx value, GLboolean invert)
{
   (void) value; (void) invert;
   noop_warn("glSampleCoveragex");
}

static void APIENTRY noopSampleCoveragexOES(GLclampx value, GLboolean invert)
{
   (void) value; (void) invert;
   noop_warn("glSampleCoveragexOES");
}

static void APIENTRY noopSampleMapATI(GLuint dst, GLuint interp, GLenum swizzle)
{
   (void) dst; (void) interp; (void) swizzle;
   noop_warn("glSampleMapATI");
}

static void APIENTRY noopSampleMaskEXT(GLclampf value, GLboolean invert)
{
   (void) value; (void) invert;
   noop_warn("glSampleMaskEXT");
}

static void APIENTRY noopSampleMaskIndexedNV(GLuint index, GLbitfield mask)
{
   (void) index; (void) mask;
   noop_warn("glSampleMaskIndexedNV");
}

static void APIENTRY noopSampleMaskSGIS(GLclampf value, GLboolean invert)
{
   (void) value; (void) invert;
   noop_warn("glSampleMaskSGIS");
}

static void APIENTRY noopSampleMaski(GLuint maskNumber, GLbitfield mask)
{
   (void) maskNumber; (void) mask;
   noop_warn("glSampleMaski");
}

static void APIENTRY noopSamplePatternEXT(GLenum pattern)
{
   (void) pattern;
   noop_warn("glSamplePatternEXT");
}

static void APIENTRY noopSamplePatternSGIS(GLenum pattern)
{
   (void) pattern;
   noop_warn("glSamplePatternSGIS");
}

static void APIENTRY noopSamplerParameterIiv(GLuint sampler, GLenum pname, const GLint *param)
{
   (void) sampler; (void) pname; (void) param;
   noop_warn("glSamplerParameterIiv");
}

static void APIENTRY noopSamplerParameterIivEXT(GLuint sampler, GLenum pname, const GLint *param)
{
   (void) sampler; (void) pname; (void) param;
   noop_warn("glSamplerParameterIivEXT");
}

static void APIENTRY noopSamplerParameterIivOES(GLuint sampler, GLenum pname, const GLint *param)
{
   (void) sampler; (void) pname; (void) param;
   noop_warn("glSamplerParameterIivOES");
}

static void APIENTRY noopSamplerParameterIuiv(GLuint sampler, GLenum pname, const GLuint *param)
{
   (void) sampler; (void) pname; (void) param;
   noop_warn("glSamplerParameterIuiv");
}

static void APIENTRY noopSamplerParameterIuivEXT(GLuint sampler, GLenum pname, const GLuint *param)
{
   (void) sampler; (void) pname; (void) param;
   noop_warn("glSamplerParameterIuivEXT");
}

static void APIENTRY noopSamplerParameterIuivOES(GLuint sampler, GLenum pname, const GLuint *param)
{
   (void) sampler; (void) pname; (void) param;
   noop_warn("glSamplerParameterIuivOES");
}

static void APIENTRY noopSamplerParameterf(GLuint sampler, GLenum pname, GLfloat param)
{
   (void) sampler; (void) pname; (void) param;
   noop_warn("glSamplerParameterf");
}

static void APIENTRY noopSamplerParameterfv(GLuint sampler, GLenum pname, const GLfloat *param)
{
   (void) sampler; (void) pname; (void) param;
   noop_warn("glSamplerParameterfv");
}

static void APIENTRY noopSamplerParameteri(GLuint sampler, GLenum pname, GLint param)
{
   (void) sampler; (void) pname; (void) param;
   noop_warn("glSamplerParameteri");
}

static void APIENTRY noopSamplerParameteriv(GLuint sampler, GLenum pname, const GLint *param)
{
   (void) sampler; (void) pname; (void) param;
   noop_warn("glSamplerParameteriv");
}

static void APIENTRY noopScaled(GLdouble x, GLdouble y, GLdouble z)
{
   (void) x; (void) y; (void) z;
   noop_warn("glScaled");
}

static void APIENTRY noopScalef(GLfloat x, GLfloat y, GLfloat z)
{
   (void) x; (void) y; (void) z;
   noop_warn("glScalef");
}

static void APIENTRY noopScalex(GLfixed x, GLfixed y, GLfixed z)
{
   (void) x; (void) y; (void) z;
   noop_warn("glScalex");
}

static void APIENTRY noopScalexOES(GLfixed x, GLfixed y, GLfixed z)
{
   (void) x; (void) y; (void) z;
   noop_warn("glScalexOES");
}

static void APIENTRY noopScissor(GLint x, GLint y, GLsizei width, GLsizei height)
{
   (void) x; (void) y; (void) width; (void) height;
   noop_warn("glScissor");
}

static void APIENTRY noopScissorArrayv(GLuint first, GLsizei count, const GLint *v)
{
   (void) first; (void) count; (void) v;
   noop_warn("glScissorArrayv");
}

static void APIENTRY noopScissorArrayvNV(GLuint first, GLsizei count, const GLint *v)
{
   (void) first; (void) count; (void) v;
   noop_warn("glScissorArrayvNV");
}

static void APIENTRY noopScissorArrayvOES(GLuint first, GLsizei count, const GLint *v)
{
   (void) first; (void) count; (void) v;
   noop_warn("glScissorArrayvOES");
}

static void APIENTRY noopScissorExclusiveArrayvNV(GLuint first, GLsizei count, const GLint *v)
{
   (void) first; (void) count; (void) v;
   noop_warn("glScissorExclusiveArrayvNV");
}

static void APIENTRY noopScissorExclusiveNV(GLint x, GLint y, GLsizei width, GLsizei height)
{
   (void) x; (void) y; (void) width; (void) height;
   noop_warn("glScissorExclusiveNV");
}

static void APIENTRY noopScissorIndexed(GLuint index, GLint left, GLint bottom, GLsizei width, GLsizei height)
{
   (void) index; (void) left; (void) bottom; (void) width; (void) height;
   noop_warn("glScissorIndexed");
}

static void APIENTRY noopScissorIndexedNV(GLuint index, GLint left, GLint bottom, GLsizei width, GLsizei height)
{
   (void) index; (void) left; (void) bottom; (void) width; (void) height;
   noop_warn("glScissorIndexedNV");
}

static void APIENTRY noopScissorIndexedOES(GLuint index, GLint left, GLint bottom, GLsizei width, GLsizei height)
{
   (void) index; (void) left; (void) bottom; (void) width; (void) height;
   noop_warn("glScissorIndexedOES");
}

static void APIENTRY noopScissorIndexedv(GLuint index, const GLint *v)
{
   (void) index; (void) v;
   noop_warn("glScissorIndexedv");
}

static void APIENTRY noopScissorIndexedvNV(GLuint index, const GLint *v)
{
   (void) index; (void) v;
   noop_warn("glScissorIndexedvNV");
}

static void APIENTRY noopScissorIndexedvOES(GLuint index, const GLint *v)
{
   (void) index; (void) v;
   noop_warn("glScissorIndexedvOES");
}

static void APIENTRY noopSecondaryColor3b(GLbyte red, GLbyte green, GLbyte blue)
{
   (void) red; (void) green; (void) blue;
   noop_warn("glSecondaryColor3b");
}

static void APIENTRY noopSecondaryColor3bEXT(GLbyte red, GLbyte green, GLbyte blue)
{
   (void) red; (void) green; (void) blue;
   noop_warn("glSecondaryColor3bEXT");
}

static void APIENTRY noopSecondaryColor3bv(const GLbyte *v)
{
   (void) v;
   noop_warn("glSecondaryColor3bv");
}

static void APIENTRY noopSecondaryColor3bvEXT(const GLbyte *v)
{
   (void) v;
   noop_warn("glSecondaryColor3bvEXT");
}

static void APIENTRY noopSecondaryColor3d(GLdouble red, GLdouble green, GLdouble blue)
{
   (void) red; (void) green; (void) blue;
   noop_warn("glSecondaryColor3d");
}

static void APIENTRY noopSecondaryColor3dEXT(GLdouble red, GLdouble green, GLdouble blue)
{
   (void) red; (void) green; (void) blue;
   noop_warn("glSecondaryColor3dEXT");
}

static void APIENTRY noopSecondaryColor3dv(const GLdouble *v)
{
   (void) v;
   noop_warn("glSecondaryColor3dv");
}

static void APIENTRY noopSecondaryColor3dvEXT(const GLdouble *v)
{
   (void) v;
   noop_warn("glSecondaryColor3dvEXT");
}

static void APIENTRY noopSecondaryColor3f(GLfloat red, GLfloat green, GLfloat blue)
{
   (void) red; (void) green; (void) blue;
   noop_warn("glSecondaryColor3f");
}

static void APIENTRY noopSecondaryColor3fEXT(GLfloat red, GLfloat green, GLfloat blue)
{
   (void) red; (void) green; (void) blue;
   noop_warn("glSecondaryColor3fEXT");
}

static void APIENTRY noopSecondaryColor3fv(const GLfloat *v)
{
   (void) v;
   noop_warn("glSecondaryColor3fv");
}

static void APIENTRY noopSecondaryColor3fvEXT(const GLfloat *v)
{
   (void) v;
   noop_warn("glSecondaryColor3fvEXT");
}

static void APIENTRY noopSecondaryColor3hNV(GLhalf red, GLhalf green, GLhalf blue)
{
   (void) red; (void) green; (void) blue;
   noop_warn("glSecondaryColor3hNV");
}

static void APIENTRY noopSecondaryColor3hvNV(const GLhalf *v)
{
   (void) v;
   noop_warn("glSecondaryColor3hvNV");
}

static void APIENTRY noopSecondaryColor3i(GLint red, GLint green, GLint blue)
{
   (void) red; (void) green; (void) blue;
   noop_warn("glSecondaryColor3i");
}

static void APIENTRY noopSecondaryColor3iEXT(GLint red, GLint green, GLint blue)
{
   (void) red; (void) green; (void) blue;
   noop_warn("glSecondaryColor3iEXT");
}

static void APIENTRY noopSecondaryColor3iv(const GLint *v)
{
   (void) v;
   noop_warn("glSecondaryColor3iv");
}

static void APIENTRY noopSecondaryColor3ivEXT(const GLint *v)
{
   (void) v;
   noop_warn("glSecondaryColor3ivEXT");
}

static void APIENTRY noopSecondaryColor3s(GLshort red, GLshort green, GLshort blue)
{
   (void) red; (void) green; (void) blue;
   noop_warn("glSecondaryColor3s");
}

static void APIENTRY noopSecondaryColor3sEXT(GLshort red, GLshort green, GLshort blue)
{
   (void) red; (void) green; (void) blue;
   noop_warn("glSecondaryColor3sEXT");
}

static void APIENTRY noopSecondaryColor3sv(const GLshort *v)
{
   (void) v;
   noop_warn("glSecondaryColor3sv");
}

static void APIENTRY noopSecondaryColor3svEXT(const GLshort *v)
{
   (void) v;
   noop_warn("glSecondaryColor3svEXT");
}

static void APIENTRY noopSecondaryColor3ub(GLubyte red, GLubyte green, GLubyte blue)
{
   (void) red; (void) green; (void) blue;
   noop_warn("glSecondaryColor3ub");
}

static void APIENTRY noopSecondaryColor3ubEXT(GLubyte red, GLubyte green, GLubyte blue)
{
   (void) red; (void) green; (void) blue;
   noop_warn("glSecondaryColor3ubEXT");
}

static void APIENTRY noopSecondaryColor3ubv(const GLubyte *v)
{
   (void) v;
   noop_warn("glSecondaryColor3ubv");
}

static void APIENTRY noopSecondaryColor3ubvEXT(const GLubyte *v)
{
   (void) v;
   noop_warn("glSecondaryColor3ubvEXT");
}

static void APIENTRY noopSecondaryColor3ui(GLuint red, GLuint green, GLuint blue)
{
   (void) red; (void) green; (void) blue;
   noop_warn("glSecondaryColor3ui");
}

static void APIENTRY noopSecondaryColor3uiEXT(GLuint red, GLuint green, GLuint blue)
{
   (void) red; (void) green; (void) blue;
   noop_warn("glSecondaryColor3uiEXT");
}

static void APIENTRY noopSecondaryColor3uiv(const GLuint *v)
{
   (void) v;
   noop_warn("glSecondaryColor3uiv");
}

static void APIENTRY noopSecondaryColor3uivEXT(const GLuint *v)
{
   (void) v;
   noop_warn("glSecondaryColor3uivEXT");
}

static void APIENTRY noopSecondaryColor3us(GLushort red, GLushort green, GLushort blue)
{
   (void) red; (void) green; (void) blue;
   noop_warn("glSecondaryColor3us");
}

static void APIENTRY noopSecondaryColor3usEXT(GLushort red, GLushort green, GLushort blue)
{
   (void) red; (void) green; (void) blue;
   noop_warn("glSecondaryColor3usEXT");
}

static void APIENTRY noopSecondaryColor3usv(const GLushort *v)
{
   (void) v;
   noop_warn("glSecondaryColor3usv");
}

static void APIENTRY noopSecondaryColor3usvEXT(const GLushort *v)
{
   (void) v;
   noop_warn("glSecondaryColor3usvEXT");
}

static void APIENTRY noopSecondaryColorFormatNV(GLint size, GLenum type, GLsizei stride)
{
   (void) size; (void) type; (void) stride;
   noop_warn("glSecondaryColorFormatNV");
}

static void APIENTRY noopSecondaryColorP3ui(GLenum type, GLuint color)
{
   (void) type; (void) color;
   noop_warn("glSecondaryColorP3ui");
}

static void APIENTRY noopSecondaryColorP3uiv(GLenum type, const GLuint *color)
{
   (void) type; (void) color;
   noop_warn("glSecondaryColorP3uiv");
}

static void APIENTRY noopSecondaryColorPointer(GLint size, GLenum type, GLsizei stride, const void *pointer)
{
   (void) size; (void) type; (void) stride; (void) pointer;
   noop_warn("glSecondaryColorPointer");
}

static void APIENTRY noopSecondaryColorPointerEXT(GLint size, GLenum type, GLsizei stride, const void *pointer)
{
   (void) size; (void) type; (void) stride; (void) pointer;
   noop_warn("glSecondaryColorPointerEXT");
}

static void APIENTRY noopSecondaryColorPointerListIBM(GLint size, GLenum type, GLint stride, const void **pointer, GLint ptrstride)
{
   (void) size; (void) type; (void) stride; (void) pointer; (void) ptrstride;
   noop_warn("glSecondaryColorPointerListIBM");
}

static void APIENTRY noopSelectBuffer(GLsizei size, GLuint *buffer)
{
   (void) size; (void) buffer;
   noop_warn("glSelectBuffer");
}

static void APIENTRY noopSelectPerfMonitorCountersAMD(GLuint monitor, GLboolean enable, GLuint group, GLint numCounters, GLuint *counterList)
{
   (void) monitor; (void) enable; (void) group; (void) numCounters; (void) counterList;
   noop_warn("glSelectPerfMonitorCountersAMD");
}

static void APIENTRY noopSemaphoreParameterui64vEXT(GLuint semaphore, GLenum pname, const GLuint64 *params)
{
   (void) semaphore; (void) pname; (void) params;
   noop_warn("glSemaphoreParameterui64vEXT");
}

static void APIENTRY noopSeparableFilter2D(GLenum target, GLenum internalformat, GLsizei width, GLsizei height, GLenum format, GLenum type, const void *row, const void *column)
{
   (void) target; (void) internalformat; (void) width; (void) height; (void) format; (void) type; (void) row; (void) column;
   noop_warn("glSeparableFilter2D");
}

static void APIENTRY noopSeparableFilter2DEXT(GLenum target, GLenum internalformat, GLsizei width, GLsizei height, GLenum format, GLenum type, const void *row, const void *column)
{
   (void) target; (void) internalformat; (void) width; (void) height; (void) format; (void) type; (void) row; (void) column;
   noop_warn("glSeparableFilter2DEXT");
}

static void APIENTRY noopSetFenceAPPLE(GLuint fence)
{
   (void) fence;
   noop_warn("glSetFenceAPPLE");
}

static void APIENTRY noopSetFenceNV(GLuint fence, GLenum condition)
{
   (void) fence; (void) condition;
   noop_warn("glSetFenceNV");
}

static void APIENTRY noopSetFragmentShaderConstantATI(GLuint dst, const GLfloat *value)
{
   (void) dst; (void) value;
   noop_warn("glSetFragmentShaderConstantATI");
}

static void APIENTRY noopSetInvariantEXT(GLuint id, GLenum type, const void *addr)
{
   (void) id; (void) type; (void) addr;
   noop_warn("glSetInvariantEXT");
}

static void APIENTRY noopSetLocalConstantEXT(GLuint id, GLenum type, const void *addr)
{
   (void) id; (void) type; (void) addr;
   noop_warn("glSetLocalConstantEXT");
}

static void APIENTRY noopSetMultisamplefvAMD(GLenum pname, GLuint index, const GLfloat *val)
{
   (void) pname; (void) index; (void) val;
   noop_warn("glSetMultisamplefvAMD");
}

static void APIENTRY noopShadeModel(GLenum mode)
{
   (void) mode;
   noop_warn("glShadeModel");
}

static void APIENTRY noopShaderBinary(GLsizei count, const GLuint *shaders, GLenum binaryFormat, const void *binary, GLsizei length)
{
   (void) count; (void) shaders; (void) binaryFormat; (void) binary; (void) length;
   noop_warn("glShaderBinary");
}

static void APIENTRY noopShaderOp1EXT(GLenum op, GLuint res, GLuint arg1)
{
   (void) op; (void) res; (void) arg1;
   noop_warn("glShaderOp1EXT");
}

static void APIENTRY noopShaderOp2EXT(GLenum op, GLuint res, GLuint arg1, GLuint arg2)
{
   (void) op; (void) res; (void) arg1; (void) arg2;
   noop_warn("glShaderOp2EXT");
}

static void APIENTRY noopShaderOp3EXT(GLenum op, GLuint res, GLuint arg1, GLuint arg2, GLuint arg3)
{
   (void) op; (void) res; (void) arg1; (void) arg2; (void) arg3;
   noop_warn("glShaderOp3EXT");
}

static void APIENTRY noopShaderSource(GLuint shader, GLsizei count, const GLchar *const *string, const GLint *length)
{
   (void) shader; (void) count; (void) string; (void) length;
   noop_warn("glShaderSource");
}

static void APIENTRY noopShaderSourceARB(GLhandleARB shaderObj, GLsizei count, const GLcharARB **string, const GLint *length)
{
   (void) shaderObj; (void) count; (void) string; (void) length;
   noop_warn("glShaderSourceARB");
}

static void APIENTRY noopShaderStorageBlockBinding(GLuint program, GLuint storageBlockIndex, GLuint storageBlockBinding)
{
   (void) program; (void) storageBlockIndex; (void) storageBlockBinding;
   noop_warn("glShaderStorageBlockBinding");
}

static void APIENTRY noopShadingRateImageBarrierNV(GLboolean synchronize)
{
   (void) synchronize;
   noop_warn("glShadingRateImageBarrierNV");
}

static void APIENTRY noopShadingRateImagePaletteNV(GLuint viewport, GLuint first, GLsizei count, const GLenum *rates)
{
   (void) viewport; (void) first; (void) count; (void) rates;
   noop_warn("glShadingRateImagePaletteNV");
}

static void APIENTRY noopShadingRateSampleOrderCustomNV(GLenum rate, GLuint samples, const GLint *locations)
{
   (void) rate; (void) samples; (void) locations;
   noop_warn("glShadingRateSampleOrderCustomNV");
}

static void APIENTRY noopShadingRateSampleOrderNV(GLenum order)
{
   (void) order;
   noop_warn("glShadingRateSampleOrderNV");
}

static void APIENTRY noopSharpenTexFuncSGIS(GLenum target, GLsizei n, const GLfloat *points)
{
   (void) target; (void) n; (void) points;
   noop_warn("glSharpenTexFuncSGIS");
}

static void APIENTRY noopSignalSemaphoreEXT(GLuint semaphore, GLuint numBufferBarriers, const GLuint *buffers, GLuint numTextureBarriers, const GLuint *textures, const GLenum *dstLayouts)
{
   (void) semaphore; (void) numBufferBarriers; (void) buffers; (void) numTextureBarriers; (void) textures; (void) dstLayouts;
   noop_warn("glSignalSemaphoreEXT");
}

static void APIENTRY noopSignalSemaphoreui64NVX(GLuint signalGpu, GLsizei fenceObjectCount, const GLuint *semaphoreArray, const GLuint64 *fenceValueArray)
{
   (void) signalGpu; (void) fenceObjectCount; (void) semaphoreArray; (void) fenceValueArray;
   noop_warn("glSignalSemaphoreui64NVX");
}

static void APIENTRY noopSignalVkFenceNV(GLuint64 vkFence)
{
   (void) vkFence;
   noop_warn("glSignalVkFenceNV");
}

static void APIENTRY noopSignalVkSemaphoreNV(GLuint64 vkSemaphore)
{
   (void) vkSemaphore;
   noop_warn("glSignalVkSemaphoreNV");
}

static void APIENTRY noopSpecializeShader(GLuint shader, const GLchar *pEntryPoint, GLuint numSpecializationConstants, const GLuint *pConstantIndex, const GLuint *pConstantValue)
{
   (void) shader; (void) pEntryPoint; (void) numSpecializationConstants; (void) pConstantIndex; (void) pConstantValue;
   noop_warn("glSpecializeShader");
}

static void APIENTRY noopSpecializeShaderARB(GLuint shader, const GLchar *pEntryPoint, GLuint numSpecializationConstants, const GLuint *pConstantIndex, const GLuint *pConstantValue)
{
   (void) shader; (void) pEntryPoint; (void) numSpecializationConstants; (void) pConstantIndex; (void) pConstantValue;
   noop_warn("glSpecializeShaderARB");
}

static void APIENTRY noopSpriteParameterfSGIX(GLenum pname, GLfloat param)
{
   (void) pname; (void) param;
   noop_warn("glSpriteParameterfSGIX");
}

static void APIENTRY noopSpriteParameterfvSGIX(GLenum pname, const GLfloat *params)
{
   (void) pname; (void) params;
   noop_warn("glSpriteParameterfvSGIX");
}

static void APIENTRY noopSpriteParameteriSGIX(GLenum pname, GLint param)
{
   (void) pname; (void) param;
   noop_warn("glSpriteParameteriSGIX");
}

static void APIENTRY noopSpriteParameterivSGIX(GLenum pname, const GLint *params)
{
   (void) pname; (void) params;
   noop_warn("glSpriteParameterivSGIX");
}

static void APIENTRY noopStartInstrumentsSGIX(void)
{
   noop_warn("glStartInstrumentsSGIX");
}

static void APIENTRY noopStartTilingQCOM(GLuint x, GLuint y, GLuint width, GLuint height, GLbitfield preserveMask)
{
   (void) x; (void) y; (void) width; (void) height; (void) preserveMask;
   noop_warn("glStartTilingQCOM");
}

static void APIENTRY noopStateCaptureNV(GLuint state, GLenum mode)
{
   (void) state; (void) mode;
   noop_warn("glStateCaptureNV");
}

static void APIENTRY noopStencilClearTagEXT(GLsizei stencilTagBits, GLuint stencilClearTag)
{
   (void) stencilTagBits; (void) stencilClearTag;
   noop_warn("glStencilClearTagEXT");
}

static void APIENTRY noopStencilFillPathInstancedNV(GLsizei numPaths, GLenum pathNameType, const void *paths, GLuint pathBase, GLenum fillMode, GLuint mask, GLenum transformType, const GLfloat *transformValues)
{
   (void) numPaths; (void) pathNameType; (void) paths; (void) pathBase; (void) fillMode; (void) mask; (void) transformType; (void) transformValues;
   noop_warn("glStencilFillPathInstancedNV");
}

static void APIENTRY noopStencilFillPathNV(GLuint path, GLenum fillMode, GLuint mask)
{
   (void) path; (void) fillMode; (void) mask;
   noop_warn("glStencilFillPathNV");
}

static void APIENTRY noopStencilFunc(GLenum func, GLint ref, GLuint mask)
{
   (void) func; (void) ref; (void) mask;
   noop_warn("glStencilFunc");
}

static void APIENTRY noopStencilFuncSeparate(GLenum face, GLenum func, GLint ref, GLuint mask)
{
   (void) face; (void) func; (void) ref; (void) mask;
   noop_warn("glStencilFuncSeparate");
}

static void APIENTRY noopStencilFuncSeparateATI(GLenum frontfunc, GLenum backfunc, GLint ref, GLuint mask)
{
   (void) frontfunc; (void) backfunc; (void) ref; (void) mask;
   noop_warn("glStencilFuncSeparateATI");
}

static void APIENTRY noopStencilMask(GLuint mask)
{
   (void) mask;
   noop_warn("glStencilMask");
}

static void APIENTRY noopStencilMaskSeparate(GLenum face, GLuint mask)
{
   (void) face; (void) mask;
   noop_warn("glStencilMaskSeparate");
}

static void APIENTRY noopStencilOp(GLenum fail, GLenum zfail, GLenum zpass)
{
   (void) fail; (void) zfail; (void) zpass;
   noop_warn("glStencilOp");
}

static void APIENTRY noopStencilOpSeparate(GLenum face, GLenum sfail, GLenum dpfail, GLenum dppass)
{
   (void) face; (void) sfail; (void) dpfail; (void) dppass;
   noop_warn("glStencilOpSeparate");
}

static void APIENTRY noopStencilOpSeparateATI(GLenum face, GLenum sfail, GLenum dpfail, GLenum dppass)
{
   (void) face; (void) sfail; (void) dpfail; (void) dppass;
   noop_warn("glStencilOpSeparateATI");
}

static void APIENTRY noopStencilOpValueAMD(GLenum face, GLuint value)
{
   (void) face; (void) value;
   noop_warn("glStencilOpValueAMD");
}

static void APIENTRY noopStencilStrokePathInstancedNV(GLsizei numPaths, GLenum pathNameType, const void *paths, GLuint pathBase, GLint reference, GLuint mask, GLenum transformType, const GLfloat *transformValues)
{
   (void) numPaths; (void) pathNameType; (void) paths; (void) pathBase; (void) reference; (void) mask; (void) transformType; (void) transformValues;
   noop_warn("glStencilStrokePathInstancedNV");
}

static void APIENTRY noopStencilStrokePathNV(GLuint path, GLint reference, GLuint mask)
{
   (void) path; (void) reference; (void) mask;
   noop_warn("glStencilStrokePathNV");
}

static void APIENTRY noopStencilThenCoverFillPathInstancedNV(GLsizei numPaths, GLenum pathNameType, const void *paths, GLuint pathBase, GLenum fillMode, GLuint mask, GLenum coverMode, GLenum transformType, const GLfloat *transformValues)
{
   (void) numPaths; (void) pathNameType; (void) paths; (void) pathBase; (void) fillMode; (void) mask; (void) coverMode; (void) transformType; (void) transformValues;
   noop_warn("glStencilThenCoverFillPathInstancedNV");
}

static void APIENTRY noopStencilThenCoverFillPathNV(GLuint path, GLenum fillMode, GLuint mask, GLenum coverMode)
{
   (void) path; (void) fillMode; (void) mask; (void) coverMode;
   noop_warn("glStencilThenCoverFillPathNV");
}

static void APIENTRY noopStencilThenCoverStrokePathInstancedNV(GLsizei numPaths, GLenum pathNameType, const void *paths, GLuint pathBase, GLint reference, GLuint mask, GLenum coverMode, GLenum transformType, const GLfloat *transformValues)
{
   (void) numPaths; (void) pathNameType; (void) paths; (void) pathBase; (void) reference; (void) mask; (void) coverMode; (void) transformType; (void) transformValues;
   noop_warn("glStencilThenCoverStrokePathInstancedNV");
}

static void APIENTRY noopStencilThenCoverStrokePathNV(GLuint path, GLint reference, GLuint mask, GLenum coverMode)
{
   (void) path; (void) reference; (void) mask; (void) coverMode;
   noop_warn("glStencilThenCoverStrokePathNV");
}

static void APIENTRY noopStopInstrumentsSGIX(GLint marker)
{
   (void) marker;
   noop_warn("glStopInstrumentsSGIX");
}

static void APIENTRY noopStringMarkerGREMEDY(GLsizei len, const void *string)
{
   (void) len; (void) string;
   noop_warn("glStringMarkerGREMEDY");
}

static void APIENTRY noopSubpixelPrecisionBiasNV(GLuint xbits, GLuint ybits)
{
   (void) xbits; (void) ybits;
   noop_warn("glSubpixelPrecisionBiasNV");
}

static void APIENTRY noopSwizzleEXT(GLuint res, GLuint in, GLenum outX, GLenum outY, GLenum outZ, GLenum outW)
{
   (void) res; (void) in; (void) outX; (void) outY; (void) outZ; (void) outW;
   noop_warn("glSwizzleEXT");
}

static void APIENTRY noopSyncTextureINTEL(GLuint texture)
{
   (void) texture;
   noop_warn("glSyncTextureINTEL");
}

static void APIENTRY noopTagSampleBufferSGIX(void)
{
   noop_warn("glTagSampleBufferSGIX");
}

static void APIENTRY noopTangent3bEXT(GLbyte tx, GLbyte ty, GLbyte tz)
{
   (void) tx; (void) ty; (void) tz;
   noop_warn("glTangent3bEXT");
}

static void APIENTRY noopTangent3bvEXT(const GLbyte *v)
{
   (void) v;
   noop_warn("glTangent3bvEXT");
}

static void APIENTRY noopTangent3dEXT(GLdouble tx, GLdouble ty, GLdouble tz)
{
   (void) tx; (void) ty; (void) tz;
   noop_warn("glTangent3dEXT");
}

static void APIENTRY noopTangent3dvEXT(const GLdouble *v)
{
   (void) v;
   noop_warn("glTangent3dvEXT");
}

static void APIENTRY noopTangent3fEXT(GLfloat tx, GLfloat ty, GLfloat tz)
{
   (void) tx; (void) ty; (void) tz;
   noop_warn("glTangent3fEXT");
}

static void APIENTRY noopTangent3fvEXT(const GLfloat *v)
{
   (void) v;
   noop_warn("glTangent3fvEXT");
}

static void APIENTRY noopTangent3iEXT(GLint tx, GLint ty, GLint tz)
{
   (void) tx; (void) ty; (void) tz;
   noop_warn("glTangent3iEXT");
}

static void APIENTRY noopTangent3ivEXT(const GLint *v)
{
   (void) v;
   noop_warn("glTangent3ivEXT");
}

static void APIENTRY noopTangent3sEXT(GLshort tx, GLshort ty, GLshort tz)
{
   (void) tx; (void) ty; (void) tz;
   noop_warn("glTangent3sEXT");
}

static void APIENTRY noopTangent3svEXT(const GLshort *v)
{
   (void) v;
   noop_warn("glTangent3svEXT");
}

static void APIENTRY noopTangentPointerEXT(GLenum type, GLsizei stride, const void *pointer)
{
   (void) type; (void) stride; (void) pointer;
   noop_warn("glTangentPointerEXT");
}

static void APIENTRY noopTbufferMask3DFX(GLuint mask)
{
   (void) mask;
   noop_warn("glTbufferMask3DFX");
}

static void APIENTRY noopTessellationFactorAMD(GLfloat factor)
{
   (void) factor;
   noop_warn("glTessellationFactorAMD");
}

static void APIENTRY noopTessellationModeAMD(GLenum mode)
{
   (void) mode;
   noop_warn("glTessellationModeAMD");
}

static GLboolean APIENTRY noopTestFenceAPPLE(GLuint fence)
{
   (void) fence;
   noop_warn("glTestFenceAPPLE");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopTestFenceNV(GLuint fence)
{
   (void) fence;
   noop_warn("glTestFenceNV");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopTestObjectAPPLE(GLenum object, GLuint name)
{
   (void) object; (void) name;
   noop_warn("glTestObjectAPPLE");
   return (GLboolean) 0;
}

static void APIENTRY noopTexAttachMemoryNV(GLenum target, GLuint memory, GLuint64 offset)
{
   (void) target; (void) memory; (void) offset;
   noop_warn("glTexAttachMemoryNV");
}

static void APIENTRY noopTexBuffer(GLenum target, GLenum internalformat, GLuint buffer)
{
   (void) target; (void) internalformat; (void) buffer;
   noop_warn("glTexBuffer");
}

static void APIENTRY noopTexBufferARB(GLenum target, GLenum internalformat, GLuint buffer)
{
   (void) target; (void) internalformat; (void) buffer;
   noop_warn("glTexBufferARB");
}

static void APIENTRY noopTexBufferEXT(GLenum target, GLenum internalformat, GLuint buffer)
{
   (void) target; (void) internalformat; (void) buffer;
   noop_warn("glTexBufferEXT");
}

static void APIENTRY noopTexBufferOES(GLenum target, GLenum internalformat, GLuint buffer)
{
   (void) target; (void) internalformat; (void) buffer;
   noop_warn("glTexBufferOES");
}

static void APIENTRY noopTexBufferRange(GLenum target, GLenum internalformat, GLuint buffer, GLintptr offset, GLsizeiptr size)
{
   (void) target; (void) internalformat; (void) buffer; (void) offset; (void) size;
   noop_warn("glTexBufferRange");
}

static void APIENTRY noopTexBufferRangeEXT(GLenum target, GLenum internalformat, GLuint buffer, GLintptr offset, GLsizeiptr size)
{
   (void) target; (void) internalformat; (void) buffer; (void) offset; (void) size;
   noop_warn("glTexBufferRangeEXT");
}

static void APIENTRY noopTexBufferRangeOES(GLenum target, GLenum internalformat, GLuint buffer, GLintptr offset, GLsizeiptr size)
{
   (void) target; (void) internalformat; (void) buffer; (void) offset; (void) size;
   noop_warn("glTexBufferRangeOES");
}

static void APIENTRY noopTexBumpParameterfvATI(GLenum pname, const GLfloat *param)
{
   (void) pname; (void) param;
   noop_warn("glTexBumpParameterfvATI");
}

static void APIENTRY noopTexBumpParameterivATI(GLenum pname, const GLint *param)
{
   (void) pname; (void) param;
   noop_warn("glTexBumpParameterivATI");
}

static void APIENTRY noopTexCoord1bOES(GLbyte s)
{
   (void) s;
   noop_warn("glTexCoord1bOES");
}

static void APIENTRY noopTexCoord1bvOES(const GLbyte *coords)
{
   (void) coords;
   noop_warn("glTexCoord1bvOES");
}

static void APIENTRY noopTexCoord1d(GLdouble s)
{
   (void) s;
   noop_warn("glTexCoord1d");
}

static void APIENTRY noopTexCoord1dv(const GLdouble *v)
{
   (void) v;
   noop_warn("glTexCoord1dv");
}

static void APIENTRY noopTexCoord1f(GLfloat s)
{
   (void) s;
   noop_warn("glTexCoord1f");
}

static void APIENTRY noopTexCoord1fv(const GLfloat *v)
{
   (void) v;
   noop_warn("glTexCoord1fv");
}

static void APIENTRY noopTexCoord1hNV(GLhalf s)
{
   (void) s;
   noop_warn("glTexCoord1hNV");
}

static void APIENTRY noopTexCoord1hvNV(const GLhalf *v)
{
   (void) v;
   noop_warn("glTexCoord1hvNV");
}

static void APIENTRY noopTexCoord1i(GLint s)
{
   (void) s;
   noop_warn("glTexCoord1i");
}

static void APIENTRY noopTexCoord1iv(const GLint *v)
{
   (void) v;
   noop_warn("glTexCoord1iv");
}

static void APIENTRY noopTexCoord1s(GLshort s)
{
   (void) s;
   noop_warn("glTexCoord1s");
}

static void APIENTRY noopTexCoord1sv(const GLshort *v)
{
   (void) v;
   noop_warn("glTexCoord1sv");
}

static void APIENTRY noopTexCoord1xOES(GLfixed s)
{
   (void) s;
   noop_warn("glTexCoord1xOES");
}

static void APIENTRY noopTexCoord1xvOES(const GLfixed *coords)
{
   (void) coords;
   noop_warn("glTexCoord1xvOES");
}

static void APIENTRY noopTexCoord2bOES(GLbyte s, GLbyte t)
{
   (void) s; (void) t;
   noop_warn("glTexCoord2bOES");
}

static void APIENTRY noopTexCoord2bvOES(const GLbyte *coords)
{
   (void) coords;
   noop_warn("glTexCoord2bvOES");
}

static void APIENTRY noopTexCoord2d(GLdouble s, GLdouble t)
{
   (void) s; (void) t;
   noop_warn("glTexCoord2d");
}

static void APIENTRY noopTexCoord2dv(const GLdouble *v)
{
   (void) v;
   noop_warn("glTexCoord2dv");
}

static void APIENTRY noopTexCoord2f(GLfloat s, GLfloat t)
{
   (void) s; (void) t;
   noop_warn("glTexCoord2f");
}

static void APIENTRY noopTexCoord2fColor3fVertex3fSUN(GLfloat s, GLfloat t, GLfloat r, GLfloat g, GLfloat b, GLfloat x, GLfloat y, GLfloat z)
{
   (void) s; (void) t; (void) r; (void) g; (void) b; (void) x; (void) y; (void) z;
   noop_warn("glTexCoord2fColor3fVertex3fSUN");
}

static void APIENTRY noopTexCoord2fColor3fVertex3fvSUN(const GLfloat *tc, const GLfloat *c, const GLfloat *v)
{
   (void) tc; (void) c; (void) v;
   noop_warn("glTexCoord2fColor3fVertex3fvSUN");
}

static void APIENTRY noopTexCoord2fColor4fNormal3fVertex3fSUN(GLfloat s, GLfloat t, GLfloat r, GLfloat g, GLfloat b, GLfloat a, GLfloat nx, GLfloat ny, GLfloat nz, GLfloat x, GLfloat y, GLfloat z)
{
   (void) s; (void) t; (void) r; (void) g; (void) b; (void) a; (void) nx; (void) ny; (void) nz; (void) x; (void) y; (void) z;
   noop_warn("glTexCoord2fColor4fNormal3fVertex3fSUN");
}

static void APIENTRY noopTexCoord2fColor4fNormal3fVertex3fvSUN(const GLfloat *tc, const GLfloat *c, const GLfloat *n, const GLfloat *v)
{
   (void) tc; (void) c; (void) n; (void) v;
   noop_warn("glTexCoord2fColor4fNormal3fVertex3fvSUN");
}

static void APIENTRY noopTexCoord2fColor4ubVertex3fSUN(GLfloat s, GLfloat t, GLubyte r, GLubyte g, GLubyte b, GLubyte a, GLfloat x, GLfloat y, GLfloat z)
{
   (void) s; (void) t; (void) r; (void) g; (void) b; (void) a; (void) x; (void) y; (void) z;
   noop_warn("glTexCoord2fColor4ubVertex3fSUN");
}

static void APIENTRY noopTexCoord2fColor4ubVertex3fvSUN(const GLfloat *tc, const GLubyte *c, const GLfloat *v)
{
   (void) tc; (void) c; (void) v;
   noop_warn("glTexCoord2fColor4ubVertex3fvSUN");
}

static void APIENTRY noopTexCoord2fNormal3fVertex3fSUN(GLfloat s, GLfloat t, GLfloat nx, GLfloat ny, GLfloat nz, GLfloat x, GLfloat y, GLfloat z)
{
   (void) s; (void) t; (void) nx; (void) ny; (void) nz; (void) x; (void) y; (void) z;
   noop_warn("glTexCoord2fNormal3fVertex3fSUN");
}

static void APIENTRY noopTexCoord2fNormal3fVertex3fvSUN(const GLfloat *tc, const GLfloat *n, const GLfloat *v)
{
   (void) tc; (void) n; (void) v;
   noop_warn("glTexCoord2fNormal3fVertex3fvSUN");
}

static void APIENTRY noopTexCoord2fVertex3fSUN(GLfloat s, GLfloat t, GLfloat x, GLfloat y, GLfloat z)
{
   (void) s; (void) t; (void) x; (void) y; (void) z;
   noop_warn("glTexCoord2fVertex3fSUN");
}

static void APIENTRY noopTexCoord2fVertex3fvSUN(const GLfloat *tc, const GLfloat *v)
{
   (void) tc; (void) v;
   noop_warn("glTexCoord2fVertex3fvSUN");
}

static void APIENTRY noopTexCoord2fv(const GLfloat *v)
{
   (void) v;
   noop_warn("glTexCoord2fv");
}

static void APIENTRY noopTexCoord2hNV(GLhalf s, GLhalf t)
{
   (void) s; (void) t;
   noop_warn("glTexCoord2hNV");
}

static void APIENTRY noopTexCoord2hvNV(const GLhalf *v)
{
   (void) v;
   noop_warn("glTexCoord2hvNV");
}

static void APIENTRY noopTexCoord2i(GLint s, GLint t)
{
   (void) s; (void) t;
   noop_warn("glTexCoord2i");
}

static void APIENTRY noopTexCoord2iv(const GLint *v)
{
   (void) v;
   noop_warn("glTexCoord2iv");
}

static void APIENTRY noopTexCoord2s(GLshort s, GLshort t)
{
   (void) s; (void) t;
   noop_warn("glTexCoord2s");
}

static void APIENTRY noopTexCoord2sv(const GLshort *v)
{
   (void) v;
   noop_warn("glTexCoord2sv");
}

static void APIENTRY noopTexCoord2xOES(GLfixed s, GLfixed t)
{
   (void) s; (void) t;
   noop_warn("glTexCoord2xOES");
}

static void APIENTRY noopTexCoord2xvOES(const GLfixed *coords)
{
   (void) coords;
   noop_warn("glTexCoord2xvOES");
}

static void APIENTRY noopTexCoord3bOES(GLbyte s, GLbyte t, GLbyte r)
{
   (void) s; (void) t; (void) r;
   noop_warn("glTexCoord3bOES");
}

static void APIENTRY noopTexCoord3bvOES(const GLbyte *coords)
{
   (void) coords;
   noop_warn("glTexCoord3bvOES");
}

static void APIENTRY noopTexCoord3d(GLdouble s, GLdouble t, GLdouble r)
{
   (void) s; (void) t; (void) r;
   noop_warn("glTexCoord3d");
}

static void APIENTRY noopTexCoord3dv(const GLdouble *v)
{
   (void) v;
   noop_warn("glTexCoord3dv");
}

static void APIENTRY noopTexCoord3f(GLfloat s, GLfloat t, GLfloat r)
{
   (void) s; (void) t; (void) r;
   noop_warn("glTexCoord3f");
}

static void APIENTRY noopTexCoord3fv(const GLfloat *v)
{
   (void) v;
   noop_warn("glTexCoord3fv");
}

static void APIENTRY noopTexCoord3hNV(GLhalf s, GLhalf t, GLhalf r)
{
   (void) s; (void) t; (void) r;
   noop_warn("glTexCoord3hNV");
}

static void APIENTRY noopTexCoord3hvNV(const GLhalf *v)
{
   (void) v;
   noop_warn("glTexCoord3hvNV");
}

static void APIENTRY noopTexCoord3i(GLint s, GLint t, GLint r)
{
   (void) s; (void) t; (void) r;
   noop_warn("glTexCoord3i");
}

static void APIENTRY noopTexCoord3iv(const GLint *v)
{
   (void) v;
   noop_warn("glTexCoord3iv");
}

static void APIENTRY noopTexCoord3s(GLshort s, GLshort t, GLshort r)
{
   (void) s; (void) t; (void) r;
   noop_warn("glTexCoord3s");
}

static void APIENTRY noopTexCoord3sv(const GLshort *v)
{
   (void) v;
   noop_warn("glTexCoord3sv");
}

static void APIENTRY noopTexCoord3xOES(GLfixed s, GLfixed t, GLfixed r)
{
   (void) s; (void) t; (void) r;
   noop_warn("glTexCoord3xOES");
}

static void APIENTRY noopTexCoord3xvOES(const GLfixed *coords)
{
   (void) coords;
   noop_warn("glTexCoord3xvOES");
}

static void APIENTRY noopTexCoord4bOES(GLbyte s, GLbyte t, GLbyte r, GLbyte q)
{
   (void) s; (void) t; (void) r; (void) q;
   noop_warn("glTexCoord4bOES");
}

static void APIENTRY noopTexCoord4bvOES(const GLbyte *coords)
{
   (void) coords;
   noop_warn("glTexCoord4bvOES");
}

static void APIENTRY noopTexCoord4d(GLdouble s, GLdouble t, GLdouble r, GLdouble q)
{
   (void) s; (void) t; (void) r; (void) q;
   noop_warn("glTexCoord4d");
}

static void APIENTRY noopTexCoord4dv(const GLdouble *v)
{
   (void) v;
   noop_warn("glTexCoord4dv");
}

static void APIENTRY noopTexCoord4f(GLfloat s, GLfloat t, GLfloat r, GLfloat q)
{
   (void) s; (void) t; (void) r; (void) q;
   noop_warn("glTexCoord4f");
}

static void APIENTRY noopTexCoord4fColor4fNormal3fVertex4fSUN(GLfloat s, GLfloat t, GLfloat p, GLfloat q, GLfloat r, GLfloat g, GLfloat b, GLfloat a, GLfloat nx, GLfloat ny, GLfloat nz, GLfloat x, GLfloat y, GLfloat z, GLfloat w)
{
   (void) s; (void) t; (void) p; (void) q; (void) r; (void) g; (void) b; (void) a; (void) nx; (void) ny; (void) nz; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glTexCoord4fColor4fNormal3fVertex4fSUN");
}

static void APIENTRY noopTexCoord4fColor4fNormal3fVertex4fvSUN(const GLfloat *tc, const GLfloat *c, const GLfloat *n, const GLfloat *v)
{
   (void) tc; (void) c; (void) n; (void) v;
   noop_warn("glTexCoord4fColor4fNormal3fVertex4fvSUN");
}

static void APIENTRY noopTexCoord4fVertex4fSUN(GLfloat s, GLfloat t, GLfloat p, GLfloat q, GLfloat x, GLfloat y, GLfloat z, GLfloat w)
{
   (void) s; (void) t; (void) p; (void) q; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glTexCoord4fVertex4fSUN");
}

static void APIENTRY noopTexCoord4fVertex4fvSUN(const GLfloat *tc, const GLfloat *v)
{
   (void) tc; (void) v;
   noop_warn("glTexCoord4fVertex4fvSUN");
}

static void APIENTRY noopTexCoord4fv(const GLfloat *v)
{
   (void) v;
   noop_warn("glTexCoord4fv");
}

static void APIENTRY noopTexCoord4hNV(GLhalf s, GLhalf t, GLhalf r, GLhalf q)
{
   (void) s; (void) t; (void) r; (void) q;
   noop_warn("glTexCoord4hNV");
}

static void APIENTRY noopTexCoord4hvNV(const GLhalf *v)
{
   (void) v;
   noop_warn("glTexCoord4hvNV");
}

static void APIENTRY noopTexCoord4i(GLint s, GLint t, GLint r, GLint q)
{
   (void) s; (void) t; (void) r; (void) q;
   noop_warn("glTexCoord4i");
}

static void APIENTRY noopTexCoord4iv(const GLint *v)
{
   (void) v;
   noop_warn("glTexCoord4iv");
}

static void APIENTRY noopTexCoord4s(GLshort s, GLshort t, GLshort r, GLshort q)
{
   (void) s; (void) t; (void) r; (void) q;
   noop_warn("glTexCoord4s");
}

static void APIENTRY noopTexCoord4sv(const GLshort *v)
{
   (void) v;
   noop_warn("glTexCoord4sv");
}

static void APIENTRY noopTexCoord4xOES(GLfixed s, GLfixed t, GLfixed r, GLfixed q)
{
   (void) s; (void) t; (void) r; (void) q;
   noop_warn("glTexCoord4xOES");
}

static void APIENTRY noopTexCoord4xvOES(const GLfixed *coords)
{
   (void) coords;
   noop_warn("glTexCoord4xvOES");
}

static void APIENTRY noopTexCoordFormatNV(GLint size, GLenum type, GLsizei stride)
{
   (void) size; (void) type; (void) stride;
   noop_warn("glTexCoordFormatNV");
}

static void APIENTRY noopTexCoordP1ui(GLenum type, GLuint coords)
{
   (void) type; (void) coords;
   noop_warn("glTexCoordP1ui");
}

static void APIENTRY noopTexCoordP1uiv(GLenum type, const GLuint *coords)
{
   (void) type; (void) coords;
   noop_warn("glTexCoordP1uiv");
}

static void APIENTRY noopTexCoordP2ui(GLenum type, GLuint coords)
{
   (void) type; (void) coords;
   noop_warn("glTexCoordP2ui");
}

static void APIENTRY noopTexCoordP2uiv(GLenum type, const GLuint *coords)
{
   (void) type; (void) coords;
   noop_warn("glTexCoordP2uiv");
}

static void APIENTRY noopTexCoordP3ui(GLenum type, GLuint coords)
{
   (void) type; (void) coords;
   noop_warn("glTexCoordP3ui");
}

static void APIENTRY noopTexCoordP3uiv(GLenum type, const GLuint *coords)
{
   (void) type; (void) coords;
   noop_warn("glTexCoordP3uiv");
}

static void APIENTRY noopTexCoordP4ui(GLenum type, GLuint coords)
{
   (void) type; (void) coords;
   noop_warn("glTexCoordP4ui");
}

static void APIENTRY noopTexCoordP4uiv(GLenum type, const GLuint *coords)
{
   (void) type; (void) coords;
   noop_warn("glTexCoordP4uiv");
}

static void APIENTRY noopTexCoordPointer(GLint size, GLenum type, GLsizei stride, const void *pointer)
{
   (void) size; (void) type; (void) stride; (void) pointer;
   noop_warn("glTexCoordPointer");
}

static void APIENTRY noopTexCoordPointerEXT(GLint size, GLenum type, GLsizei stride, GLsizei count, const void *pointer)
{
   (void) size; (void) type; (void) stride; (void) count; (void) pointer;
   noop_warn("glTexCoordPointerEXT");
}

static void APIENTRY noopTexCoordPointerListIBM(GLint size, GLenum type, GLint stride, const void **pointer, GLint ptrstride)
{
   (void) size; (void) type; (void) stride; (void) pointer; (void) ptrstride;
   noop_warn("glTexCoordPointerListIBM");
}

static void APIENTRY noopTexCoordPointervINTEL(GLint size, GLenum type, const void **pointer)
{
   (void) size; (void) type; (void) pointer;
   noop_warn("glTexCoordPointervINTEL");
}

static void APIENTRY noopTexEnvf(GLenum target, GLenum pname, GLfloat param)
{
   (void) target; (void) pname; (void) param;
   noop_warn("glTexEnvf");
}

static void APIENTRY noopTexEnvfv(GLenum target, GLenum pname, const GLfloat *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glTexEnvfv");
}

static void APIENTRY noopTexEnvi(GLenum target, GLenum pname, GLint param)
{
   (void) target; (void) pname; (void) param;
   noop_warn("glTexEnvi");
}

static void APIENTRY noopTexEnviv(GLenum target, GLenum pname, const GLint *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glTexEnviv");
}

static void APIENTRY noopTexEnvx(GLenum target, GLenum pname, GLfixed param)
{
   (void) target; (void) pname; (void) param;
   noop_warn("glTexEnvx");
}

static void APIENTRY noopTexEnvxOES(GLenum target, GLenum pname, GLfixed param)
{
   (void) target; (void) pname; (void) param;
   noop_warn("glTexEnvxOES");
}

static void APIENTRY noopTexEnvxv(GLenum target, GLenum pname, const GLfixed *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glTexEnvxv");
}

static void APIENTRY noopTexEnvxvOES(GLenum target, GLenum pname, const GLfixed *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glTexEnvxvOES");
}

static void APIENTRY noopTexFilterFuncSGIS(GLenum target, GLenum filter, GLsizei n, const GLfloat *weights)
{
   (void) target; (void) filter; (void) n; (void) weights;
   noop_warn("glTexFilterFuncSGIS");
}

static void APIENTRY noopTexGend(GLenum coord, GLenum pname, GLdouble param)
{
   (void) coord; (void) pname; (void) param;
   noop_warn("glTexGend");
}

static void APIENTRY noopTexGendv(GLenum coord, GLenum pname, const GLdouble *params)
{
   (void) coord; (void) pname; (void) params;
   noop_warn("glTexGendv");
}

static void APIENTRY noopTexGenf(GLenum coord, GLenum pname, GLfloat param)
{
   (void) coord; (void) pname; (void) param;
   noop_warn("glTexGenf");
}

static void APIENTRY noopTexGenfOES(GLenum coord, GLenum pname, GLfloat param)
{
   (void) coord; (void) pname; (void) param;
   noop_warn("glTexGenfOES");
}

static void APIENTRY noopTexGenfv(GLenum coord, GLenum pname, const GLfloat *params)
{
   (void) coord; (void) pname; (void) params;
   noop_warn("glTexGenfv");
}

static void APIENTRY noopTexGenfvOES(GLenum coord, GLenum pname, const GLfloat *params)
{
   (void) coord; (void) pname; (void) params;
   noop_warn("glTexGenfvOES");
}

static void APIENTRY noopTexGeni(GLenum coord, GLenum pname, GLint param)
{
   (void) coord; (void) pname; (void) param;
   noop_warn("glTexGeni");
}

static void APIENTRY noopTexGeniOES(GLenum coord, GLenum pname, GLint param)
{
   (void) coord; (void) pname; (void) param;
   noop_warn("glTexGeniOES");
}

static void APIENTRY noopTexGeniv(GLenum coord, GLenum pname, const GLint *params)
{
   (void) coord; (void) pname; (void) params;
   noop_warn("glTexGeniv");
}

static void APIENTRY noopTexGenivOES(GLenum coord, GLenum pname, const GLint *params)
{
   (void) coord; (void) pname; (void) params;
   noop_warn("glTexGenivOES");
}

static void APIENTRY noopTexGenxOES(GLenum coord, GLenum pname, GLfixed param)
{
   (void) coord; (void) pname; (void) param;
   noop_warn("glTexGenxOES");
}

static void APIENTRY noopTexGenxvOES(GLenum coord, GLenum pname, const GLfixed *params)
{
   (void) coord; (void) pname; (void) params;
   noop_warn("glTexGenxvOES");
}

static void APIENTRY noopTexImage1D(GLenum target, GLint level, GLint internalformat, GLsizei width, GLint border, GLenum format, GLenum type, const void *pixels)
{
   (void) target; (void) level; (void) internalformat; (void) width; (void) border; (void) format; (void) type; (void) pixels;
   noop_warn("glTexImage1D");
}

static void APIENTRY noopTexImage2D(GLenum target, GLint level, GLint internalformat, GLsizei width, GLsizei height, GLint border, GLenum format, GLenum type, const void *pixels)
{
   (void) target; (void) level; (void) internalformat; (void) width; (void) height; (void) border; (void) format; (void) type; (void) pixels;
   noop_warn("glTexImage2D");
}

static void APIENTRY noopTexImage2DMultisample(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLboolean fixedsamplelocations)
{
   (void) target; (void) samples; (void) internalformat; (void) width; (void) height; (void) fixedsamplelocations;
   noop_warn("glTexImage2DMultisample");
}

static void APIENTRY noopTexImage2DMultisampleCoverageNV(GLenum target, GLsizei coverageSamples, GLsizei colorSamples, GLint internalFormat, GLsizei width, GLsizei height, GLboolean fixedSampleLocations)
{
   (void) target; (void) coverageSamples; (void) colorSamples; (void) internalFormat; (void) width; (void) height; (void) fixedSampleLocations;
   noop_warn("glTexImage2DMultisampleCoverageNV");
}

static void APIENTRY noopTexImage3D(GLenum target, GLint level, GLint internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLenum format, GLenum type, const void *pixels)
{
   (void) target; (void) level; (void) internalformat; (void) width; (void) height; (void) depth; (void) border; (void) format; (void) type; (void) pixels;
   noop_warn("glTexImage3D");
}

static void APIENTRY noopTexImage3DEXT(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLenum format, GLenum type, const void *pixels)
{
   (void) target; (void) level; (void) internalformat; (void) width; (void) height; (void) depth; (void) border; (void) format; (void) type; (void) pixels;
   noop_warn("glTexImage3DEXT");
}

static void APIENTRY noopTexImage3DMultisample(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedsamplelocations)
{
   (void) target; (void) samples; (void) internalformat; (void) width; (void) height; (void) depth; (void) fixedsamplelocations;
   noop_warn("glTexImage3DMultisample");
}

static void APIENTRY noopTexImage3DMultisampleCoverageNV(GLenum target, GLsizei coverageSamples, GLsizei colorSamples, GLint internalFormat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedSampleLocations)
{
   (void) target; (void) coverageSamples; (void) colorSamples; (void) internalFormat; (void) width; (void) height; (void) depth; (void) fixedSampleLocations;
   noop_warn("glTexImage3DMultisampleCoverageNV");
}

static void APIENTRY noopTexImage3DNV(GLenum target, GLint level, GLint internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLenum format, GLenum type, const void *pixels)
{
   (void) target; (void) level; (void) internalformat; (void) width; (void) height; (void) depth; (void) border; (void) format; (void) type; (void) pixels;
   noop_warn("glTexImage3DNV");
}

static void APIENTRY noopTexImage3DOES(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLenum format, GLenum type, const void *pixels)
{
   (void) target; (void) level; (void) internalformat; (void) width; (void) height; (void) depth; (void) border; (void) format; (void) type; (void) pixels;
   noop_warn("glTexImage3DOES");
}

static void APIENTRY noopTexImage4DSGIS(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLsizei size4d, GLint border, GLenum format, GLenum type, const void *pixels)
{
   (void) target; (void) level; (void) internalformat; (void) width; (void) height; (void) depth; (void) size4d; (void) border; (void) format; (void) type; (void) pixels;
   noop_warn("glTexImage4DSGIS");
}

static void APIENTRY noopTexPageCommitmentARB(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLboolean commit)
{
   (void) target; (void) level; (void) xoffset; (void) yoffset; (void) zoffset; (void) width; (void) height; (void) depth; (void) commit;
   noop_warn("glTexPageCommitmentARB");
}

static void APIENTRY noopTexPageCommitmentEXT(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLboolean commit)
{
   (void) target; (void) level; (void) xoffset; (void) yoffset; (void) zoffset; (void) width; (void) height; (void) depth; (void) commit;
   noop_warn("glTexPageCommitmentEXT");
}

static void APIENTRY noopTexParameterIiv(GLenum target, GLenum pname, const GLint *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glTexParameterIiv");
}

static void APIENTRY noopTexParameterIivEXT(GLenum target, GLenum pname, const GLint *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glTexParameterIivEXT");
}

static void APIENTRY noopTexParameterIivOES(GLenum target, GLenum pname, const GLint *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glTexParameterIivOES");
}

static void APIENTRY noopTexParameterIuiv(GLenum target, GLenum pname, const GLuint *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glTexParameterIuiv");
}

static void APIENTRY noopTexParameterIuivEXT(GLenum target, GLenum pname, const GLuint *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glTexParameterIuivEXT");
}

static void APIENTRY noopTexParameterIuivOES(GLenum target, GLenum pname, const GLuint *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glTexParameterIuivOES");
}

static void APIENTRY noopTexParameterf(GLenum target, GLenum pname, GLfloat param)
{
   (void) target; (void) pname; (void) param;
   noop_warn("glTexParameterf");
}

static void APIENTRY noopTexParameterfv(GLenum target, GLenum pname, const GLfloat *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glTexParameterfv");
}

static void APIENTRY noopTexParameteri(GLenum target, GLenum pname, GLint param)
{
   (void) target; (void) pname; (void) param;
   noop_warn("glTexParameteri");
}

static void APIENTRY noopTexParameteriv(GLenum target, GLenum pname, const GLint *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glTexParameteriv");
}

static void APIENTRY noopTexParameterx(GLenum target, GLenum pname, GLfixed param)
{
   (void) target; (void) pname; (void) param;
   noop_warn("glTexParameterx");
}

static void APIENTRY noopTexParameterxOES(GLenum target, GLenum pname, GLfixed param)
{
   (void) target; (void) pname; (void) param;
   noop_warn("glTexParameterxOES");
}

static void APIENTRY noopTexParameterxv(GLenum target, GLenum pname, const GLfixed *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glTexParameterxv");
}

static void APIENTRY noopTexParameterxvOES(GLenum target, GLenum pname, const GLfixed *params)
{
   (void) target; (void) pname; (void) params;
   noop_warn("glTexParameterxvOES");
}

static void APIENTRY noopTexRenderbufferNV(GLenum target, GLuint renderbuffer)
{
   (void) target; (void) renderbuffer;
   noop_warn("glTexRenderbufferNV");
}

static void APIENTRY noopTexStorage1D(GLenum target, GLsizei levels, GLenum internalformat, GLsizei width)
{
   (void) target; (void) levels; (void) internalformat; (void) width;
   noop_warn("glTexStorage1D");
}

static void APIENTRY noopTexStorage1DEXT(GLenum target, GLsizei levels, GLenum internalformat, GLsizei width)
{
   (void) target; (void) levels; (void) internalformat; (void) width;
   noop_warn("glTexStorage1DEXT");
}

static void APIENTRY noopTexStorage2D(GLenum target, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height)
{
   (void) target; (void) levels; (void) internalformat; (void) width; (void) height;
   noop_warn("glTexStorage2D");
}

static void APIENTRY noopTexStorage2DEXT(GLenum target, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height)
{
   (void) target; (void) levels; (void) internalformat; (void) width; (void) height;
   noop_warn("glTexStorage2DEXT");
}

static void APIENTRY noopTexStorage2DMultisample(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLboolean fixedsamplelocations)
{
   (void) target; (void) samples; (void) internalformat; (void) width; (void) height; (void) fixedsamplelocations;
   noop_warn("glTexStorage2DMultisample");
}

static void APIENTRY noopTexStorage3D(GLenum target, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth)
{
   (void) target; (void) levels; (void) internalformat; (void) width; (void) height; (void) depth;
   noop_warn("glTexStorage3D");
}

static void APIENTRY noopTexStorage3DEXT(GLenum target, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth)
{
   (void) target; (void) levels; (void) internalformat; (void) width; (void) height; (void) depth;
   noop_warn("glTexStorage3DEXT");
}

static void APIENTRY noopTexStorage3DMultisample(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedsamplelocations)
{
   (void) target; (void) samples; (void) internalformat; (void) width; (void) height; (void) depth; (void) fixedsamplelocations;
   noop_warn("glTexStorage3DMultisample");
}

static void APIENTRY noopTexStorage3DMultisampleOES(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedsamplelocations)
{
   (void) target; (void) samples; (void) internalformat; (void) width; (void) height; (void) depth; (void) fixedsamplelocations;
   noop_warn("glTexStorage3DMultisampleOES");
}

static void APIENTRY noopTexStorageMem1DEXT(GLenum target, GLsizei levels, GLenum internalFormat, GLsizei width, GLuint memory, GLuint64 offset)
{
   (void) target; (void) levels; (void) internalFormat; (void) width; (void) memory; (void) offset;
   noop_warn("glTexStorageMem1DEXT");
}

static void APIENTRY noopTexStorageMem2DEXT(GLenum target, GLsizei levels, GLenum internalFormat, GLsizei width, GLsizei height, GLuint memory, GLuint64 offset)
{
   (void) target; (void) levels; (void) internalFormat; (void) width; (void) height; (void) memory; (void) offset;
   noop_warn("glTexStorageMem2DEXT");
}

static void APIENTRY noopTexStorageMem2DMultisampleEXT(GLenum target, GLsizei samples, GLenum internalFormat, GLsizei width, GLsizei height, GLboolean fixedSampleLocations, GLuint memory, GLuint64 offset)
{
   (void) target; (void) samples; (void) internalFormat; (void) width; (void) height; (void) fixedSampleLocations; (void) memory; (void) offset;
   noop_warn("glTexStorageMem2DMultisampleEXT");
}

static void APIENTRY noopTexStorageMem3DEXT(GLenum target, GLsizei levels, GLenum internalFormat, GLsizei width, GLsizei height, GLsizei depth, GLuint memory, GLuint64 offset)
{
   (void) target; (void) levels; (void) internalFormat; (void) width; (void) height; (void) depth; (void) memory; (void) offset;
   noop_warn("glTexStorageMem3DEXT");
}

static void APIENTRY noopTexStorageMem3DMultisampleEXT(GLenum target, GLsizei samples, GLenum internalFormat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedSampleLocations, GLuint memory, GLuint64 offset)
{
   (void) target; (void) samples; (void) internalFormat; (void) width; (void) height; (void) depth; (void) fixedSampleLocations; (void) memory; (void) offset;
   noop_warn("glTexStorageMem3DMultisampleEXT");
}

static void APIENTRY noopTexStorageSparseAMD(GLenum target, GLenum internalFormat, GLsizei width, GLsizei height, GLsizei depth, GLsizei layers, GLbitfield flags)
{
   (void) target; (void) internalFormat; (void) width; (void) height; (void) depth; (void) layers; (void) flags;
   noop_warn("glTexStorageSparseAMD");
}

static void APIENTRY noopTexSubImage1D(GLenum target, GLint level, GLint xoffset, GLsizei width, GLenum format, GLenum type, const void *pixels)
{
   (void) target; (void) level; (void) xoffset; (void) width; (void) format; (void) type; (void) pixels;
   noop_warn("glTexSubImage1D");
}

static void APIENTRY noopTexSubImage1DEXT(GLenum target, GLint level, GLint xoffset, GLsizei width, GLenum format, GLenum type, const void *pixels)
{
   (void) target; (void) level; (void) xoffset; (void) width; (void) format; (void) type; (void) pixels;
   noop_warn("glTexSubImage1DEXT");
}

static void APIENTRY noopTexSubImage2D(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLenum type, const void *pixels)
{
   (void) target; (void) level; (void) xoffset; (void) yoffset; (void) width; (void) height; (void) format; (void) type; (void) pixels;
   noop_warn("glTexSubImage2D");
}

static void APIENTRY noopTexSubImage2DEXT(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLenum type, const void *pixels)
{
   (void) target; (void) level; (void) xoffset; (void) yoffset; (void) width; (void) height; (void) format; (void) type; (void) pixels;
   noop_warn("glTexSubImage2DEXT");
}

static void APIENTRY noopTexSubImage3D(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void *pixels)
{
   (void) target; (void) level; (void) xoffset; (void) yoffset; (void) zoffset; (void) width; (void) height; (void) depth; (void) format; (void) type; (void) pixels;
   noop_warn("glTexSubImage3D");
}

static void APIENTRY noopTexSubImage3DEXT(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void *pixels)
{
   (void) target; (void) level; (void) xoffset; (void) yoffset; (void) zoffset; (void) width; (void) height; (void) depth; (void) format; (void) type; (void) pixels;
   noop_warn("glTexSubImage3DEXT");
}

static void APIENTRY noopTexSubImage3DNV(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void *pixels)
{
   (void) target; (void) level; (void) xoffset; (void) yoffset; (void) zoffset; (void) width; (void) height; (void) depth; (void) format; (void) type; (void) pixels;
   noop_warn("glTexSubImage3DNV");
}

static void APIENTRY noopTexSubImage3DOES(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void *pixels)
{
   (void) target; (void) level; (void) xoffset; (void) yoffset; (void) zoffset; (void) width; (void) height; (void) depth; (void) format; (void) type; (void) pixels;
   noop_warn("glTexSubImage3DOES");
}

static void APIENTRY noopTexSubImage4DSGIS(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLint woffset, GLsizei width, GLsizei height, GLsizei depth, GLsizei size4d, GLenum format, GLenum type, const void *pixels)
{
   (void) target; (void) level; (void) xoffset; (void) yoffset; (void) zoffset; (void) woffset; (void) width; (void) height; (void) depth; (void) size4d; (void) format; (void) type; (void) pixels;
   noop_warn("glTexSubImage4DSGIS");
}

static void APIENTRY noopTextureAttachMemoryNV(GLuint texture, GLuint memory, GLuint64 offset)
{
   (void) texture; (void) memory; (void) offset;
   noop_warn("glTextureAttachMemoryNV");
}

static void APIENTRY noopTextureBarrier(void)
{
   noop_warn("glTextureBarrier");
}

static void APIENTRY noopTextureBarrierNV(void)
{
   noop_warn("glTextureBarrierNV");
}

static void APIENTRY noopTextureBuffer(GLuint texture, GLenum internalformat, GLuint buffer)
{
   (void) texture; (void) internalformat; (void) buffer;
   noop_warn("glTextureBuffer");
}

static void APIENTRY noopTextureBufferEXT(GLuint texture, GLenum target, GLenum internalformat, GLuint buffer)
{
   (void) texture; (void) target; (void) internalformat; (void) buffer;
   noop_warn("glTextureBufferEXT");
}

static void APIENTRY noopTextureBufferRange(GLuint texture, GLenum internalformat, GLuint buffer, GLintptr offset, GLsizeiptr size)
{
   (void) texture; (void) internalformat; (void) buffer; (void) offset; (void) size;
   noop_warn("glTextureBufferRange");
}

static void APIENTRY noopTextureBufferRangeEXT(GLuint texture, GLenum target, GLenum internalformat, GLuint buffer, GLintptr offset, GLsizeiptr size)
{
   (void) texture; (void) target; (void) internalformat; (void) buffer; (void) offset; (void) size;
   noop_warn("glTextureBufferRangeEXT");
}

static void APIENTRY noopTextureColorMaskSGIS(GLboolean red, GLboolean green, GLboolean blue, GLboolean alpha)
{
   (void) red; (void) green; (void) blue; (void) alpha;
   noop_warn("glTextureColorMaskSGIS");
}

static void APIENTRY noopTextureFoveationParametersQCOM(GLuint texture, GLuint layer, GLuint focalPoint, GLfloat focalX, GLfloat focalY, GLfloat gainX, GLfloat gainY, GLfloat foveaArea)
{
   (void) texture; (void) layer; (void) focalPoint; (void) focalX; (void) focalY; (void) gainX; (void) gainY; (void) foveaArea;
   noop_warn("glTextureFoveationParametersQCOM");
}

static void APIENTRY noopTextureImage1DEXT(GLuint texture, GLenum target, GLint level, GLint internalformat, GLsizei width, GLint border, GLenum format, GLenum type, const void *pixels)
{
   (void) texture; (void) target; (void) level; (void) internalformat; (void) width; (void) border; (void) format; (void) type; (void) pixels;
   noop_warn("glTextureImage1DEXT");
}

static void APIENTRY noopTextureImage2DEXT(GLuint texture, GLenum target, GLint level, GLint internalformat, GLsizei width, GLsizei height, GLint border, GLenum format, GLenum type, const void *pixels)
{
   (void) texture; (void) target; (void) level; (void) internalformat; (void) width; (void) height; (void) border; (void) format; (void) type; (void) pixels;
   noop_warn("glTextureImage2DEXT");
}

static void APIENTRY noopTextureImage2DMultisampleCoverageNV(GLuint texture, GLenum target, GLsizei coverageSamples, GLsizei colorSamples, GLint internalFormat, GLsizei width, GLsizei height, GLboolean fixedSampleLocations)
{
   (void) texture; (void) target; (void) coverageSamples; (void) colorSamples; (void) internalFormat; (void) width; (void) height; (void) fixedSampleLocations;
   noop_warn("glTextureImage2DMultisampleCoverageNV");
}

static void APIENTRY noopTextureImage2DMultisampleNV(GLuint texture, GLenum target, GLsizei samples, GLint internalFormat, GLsizei width, GLsizei height, GLboolean fixedSampleLocations)
{
   (void) texture; (void) target; (void) samples; (void) internalFormat; (void) width; (void) height; (void) fixedSampleLocations;
   noop_warn("glTextureImage2DMultisampleNV");
}

static void APIENTRY noopTextureImage3DEXT(GLuint texture, GLenum target, GLint level, GLint internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLenum format, GLenum type, const void *pixels)
{
   (void) texture; (void) target; (void) level; (void) internalformat; (void) width; (void) height; (void) depth; (void) border; (void) format; (void) type; (void) pixels;
   noop_warn("glTextureImage3DEXT");
}

static void APIENTRY noopTextureImage3DMultisampleCoverageNV(GLuint texture, GLenum target, GLsizei coverageSamples, GLsizei colorSamples, GLint internalFormat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedSampleLocations)
{
   (void) texture; (void) target; (void) coverageSamples; (void) colorSamples; (void) internalFormat; (void) width; (void) height; (void) depth; (void) fixedSampleLocations;
   noop_warn("glTextureImage3DMultisampleCoverageNV");
}

static void APIENTRY noopTextureImage3DMultisampleNV(GLuint texture, GLenum target, GLsizei samples, GLint internalFormat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedSampleLocations)
{
   (void) texture; (void) target; (void) samples; (void) internalFormat; (void) width; (void) height; (void) depth; (void) fixedSampleLocations;
   noop_warn("glTextureImage3DMultisampleNV");
}

static void APIENTRY noopTextureLightEXT(GLenum pname)
{
   (void) pname;
   noop_warn("glTextureLightEXT");
}

static void APIENTRY noopTextureMaterialEXT(GLenum face, GLenum mode)
{
   (void) face; (void) mode;
   noop_warn("glTextureMaterialEXT");
}

static void APIENTRY noopTextureNormalEXT(GLenum mode)
{
   (void) mode;
   noop_warn("glTextureNormalEXT");
}

static void APIENTRY noopTexturePageCommitmentEXT(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLboolean commit)
{
   (void) texture; (void) level; (void) xoffset; (void) yoffset; (void) zoffset; (void) width; (void) height; (void) depth; (void) commit;
   noop_warn("glTexturePageCommitmentEXT");
}

static void APIENTRY noopTextureParameterIiv(GLuint texture, GLenum pname, const GLint *params)
{
   (void) texture; (void) pname; (void) params;
   noop_warn("glTextureParameterIiv");
}

static void APIENTRY noopTextureParameterIivEXT(GLuint texture, GLenum target, GLenum pname, const GLint *params)
{
   (void) texture; (void) target; (void) pname; (void) params;
   noop_warn("glTextureParameterIivEXT");
}

static void APIENTRY noopTextureParameterIuiv(GLuint texture, GLenum pname, const GLuint *params)
{
   (void) texture; (void) pname; (void) params;
   noop_warn("glTextureParameterIuiv");
}

static void APIENTRY noopTextureParameterIuivEXT(GLuint texture, GLenum target, GLenum pname, const GLuint *params)
{
   (void) texture; (void) target; (void) pname; (void) params;
   noop_warn("glTextureParameterIuivEXT");
}

static void APIENTRY noopTextureParameterf(GLuint texture, GLenum pname, GLfloat param)
{
   (void) texture; (void) pname; (void) param;
   noop_warn("glTextureParameterf");
}

static void APIENTRY noopTextureParameterfEXT(GLuint texture, GLenum target, GLenum pname, GLfloat param)
{
   (void) texture; (void) target; (void) pname; (void) param;
   noop_warn("glTextureParameterfEXT");
}

static void APIENTRY noopTextureParameterfv(GLuint texture, GLenum pname, const GLfloat *param)
{
   (void) texture; (void) pname; (void) param;
   noop_warn("glTextureParameterfv");
}

static void APIENTRY noopTextureParameterfvEXT(GLuint texture, GLenum target, GLenum pname, const GLfloat *params)
{
   (void) texture; (void) target; (void) pname; (void) params;
   noop_warn("glTextureParameterfvEXT");
}

static void APIENTRY noopTextureParameteri(GLuint texture, GLenum pname, GLint param)
{
   (void) texture; (void) pname; (void) param;
   noop_warn("glTextureParameteri");
}

static void APIENTRY noopTextureParameteriEXT(GLuint texture, GLenum target, GLenum pname, GLint param)
{
   (void) texture; (void) target; (void) pname; (void) param;
   noop_warn("glTextureParameteriEXT");
}

static void APIENTRY noopTextureParameteriv(GLuint texture, GLenum pname, const GLint *param)
{
   (void) texture; (void) pname; (void) param;
   noop_warn("glTextureParameteriv");
}

static void APIENTRY noopTextureParameterivEXT(GLuint texture, GLenum target, GLenum pname, const GLint *params)
{
   (void) texture; (void) target; (void) pname; (void) params;
   noop_warn("glTextureParameterivEXT");
}

static void APIENTRY noopTextureRangeAPPLE(GLenum target, GLsizei length, const void *pointer)
{
   (void) target; (void) length; (void) pointer;
   noop_warn("glTextureRangeAPPLE");
}

static void APIENTRY noopTextureRenderbufferEXT(GLuint texture, GLenum target, GLuint renderbuffer)
{
   (void) texture; (void) target; (void) renderbuffer;
   noop_warn("glTextureRenderbufferEXT");
}

static void APIENTRY noopTextureStorage1D(GLuint texture, GLsizei levels, GLenum internalformat, GLsizei width)
{
   (void) texture; (void) levels; (void) internalformat; (void) width;
   noop_warn("glTextureStorage1D");
}

static void APIENTRY noopTextureStorage1DEXT(GLuint texture, GLenum target, GLsizei levels, GLenum internalformat, GLsizei width)
{
   (void) texture; (void) target; (void) levels; (void) internalformat; (void) width;
   noop_warn("glTextureStorage1DEXT");
}

static void APIENTRY noopTextureStorage2D(GLuint texture, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height)
{
   (void) texture; (void) levels; (void) internalformat; (void) width; (void) height;
   noop_warn("glTextureStorage2D");
}

static void APIENTRY noopTextureStorage2DEXT(GLuint texture, GLenum target, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height)
{
   (void) texture; (void) target; (void) levels; (void) internalformat; (void) width; (void) height;
   noop_warn("glTextureStorage2DEXT");
}

static void APIENTRY noopTextureStorage2DMultisample(GLuint texture, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLboolean fixedsamplelocations)
{
   (void) texture; (void) samples; (void) internalformat; (void) width; (void) height; (void) fixedsamplelocations;
   noop_warn("glTextureStorage2DMultisample");
}

static void APIENTRY noopTextureStorage2DMultisampleEXT(GLuint texture, GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLboolean fixedsamplelocations)
{
   (void) texture; (void) target; (void) samples; (void) internalformat; (void) width; (void) height; (void) fixedsamplelocations;
   noop_warn("glTextureStorage2DMultisampleEXT");
}

static void APIENTRY noopTextureStorage3D(GLuint texture, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth)
{
   (void) texture; (void) levels; (void) internalformat; (void) width; (void) height; (void) depth;
   noop_warn("glTextureStorage3D");
}

static void APIENTRY noopTextureStorage3DEXT(GLuint texture, GLenum target, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth)
{
   (void) texture; (void) target; (void) levels; (void) internalformat; (void) width; (void) height; (void) depth;
   noop_warn("glTextureStorage3DEXT");
}

static void APIENTRY noopTextureStorage3DMultisample(GLuint texture, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedsamplelocations)
{
   (void) texture; (void) samples; (void) internalformat; (void) width; (void) height; (void) depth; (void) fixedsamplelocations;
   noop_warn("glTextureStorage3DMultisample");
}

static void APIENTRY noopTextureStorage3DMultisampleEXT(GLuint texture, GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedsamplelocations)
{
   (void) texture; (void) target; (void) samples; (void) internalformat; (void) width; (void) height; (void) depth; (void) fixedsamplelocations;
   noop_warn("glTextureStorage3DMultisampleEXT");
}

static void APIENTRY noopTextureStorageMem1DEXT(GLuint texture, GLsizei levels, GLenum internalFormat, GLsizei width, GLuint memory, GLuint64 offset)
{
   (void) texture; (void) levels; (void) internalFormat; (void) width; (void) memory; (void) offset;
   noop_warn("glTextureStorageMem1DEXT");
}

static void APIENTRY noopTextureStorageMem2DEXT(GLuint texture, GLsizei levels, GLenum internalFormat, GLsizei width, GLsizei height, GLuint memory, GLuint64 offset)
{
   (void) texture; (void) levels; (void) internalFormat; (void) width; (void) height; (void) memory; (void) offset;
   noop_warn("glTextureStorageMem2DEXT");
}

static void APIENTRY noopTextureStorageMem2DMultisampleEXT(GLuint texture, GLsizei samples, GLenum internalFormat, GLsizei width, GLsizei height, GLboolean fixedSampleLocations, GLuint memory, GLuint64 offset)
{
   (void) texture; (void) samples; (void) internalFormat; (void) width; (void) height; (void) fixedSampleLocations; (void) memory; (void) offset;
   noop_warn("glTextureStorageMem2DMultisampleEXT");
}

static void APIENTRY noopTextureStorageMem3DEXT(GLuint texture, GLsizei levels, GLenum internalFormat, GLsizei width, GLsizei height, GLsizei depth, GLuint memory, GLuint64 offset)
{
   (void) texture; (void) levels; (void) internalFormat; (void) width; (void) height; (void) depth; (void) memory; (void) offset;
   noop_warn("glTextureStorageMem3DEXT");
}

static void APIENTRY noopTextureStorageMem3DMultisampleEXT(GLuint texture, GLsizei samples, GLenum internalFormat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedSampleLocations, GLuint memory, GLuint64 offset)
{
   (void) texture; (void) samples; (void) internalFormat; (void) width; (void) height; (void) depth; (void) fixedSampleLocations; (void) memory; (void) offset;
   noop_warn("glTextureStorageMem3DMultisampleEXT");
}

static void APIENTRY noopTextureStorageSparseAMD(GLuint texture, GLenum target, GLenum internalFormat, GLsizei width, GLsizei height, GLsizei depth, GLsizei layers, GLbitfield flags)
{
   (void) texture; (void) target; (void) internalFormat; (void) width; (void) height; (void) depth; (void) layers; (void) flags;
   noop_warn("glTextureStorageSparseAMD");
}

static void APIENTRY noopTextureSubImage1D(GLuint texture, GLint level, GLint xoffset, GLsizei width, GLenum format, GLenum type, const void *pixels)
{
   (void) texture; (void) level; (void) xoffset; (void) width; (void) format; (void) type; (void) pixels;
   noop_warn("glTextureSubImage1D");
}

static void APIENTRY noopTextureSubImage1DEXT(GLuint texture, GLenum target, GLint level, GLint xoffset, GLsizei width, GLenum format, GLenum type, const void *pixels)
{
   (void) texture; (void) target; (void) level; (void) xoffset; (void) width; (void) format; (void) type; (void) pixels;
   noop_warn("glTextureSubImage1DEXT");
}

static void APIENTRY noopTextureSubImage2D(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLenum type, const void *pixels)
{
   (void) texture; (void) level; (void) xoffset; (void) yoffset; (void) width; (void) height; (void) format; (void) type; (void) pixels;
   noop_warn("glTextureSubImage2D");
}

static void APIENTRY noopTextureSubImage2DEXT(GLuint texture, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLenum type, const void *pixels)
{
   (void) texture; (void) target; (void) level; (void) xoffset; (void) yoffset; (void) width; (void) height; (void) format; (void) type; (void) pixels;
   noop_warn("glTextureSubImage2DEXT");
}

static void APIENTRY noopTextureSubImage3D(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void *pixels)
{
   (void) texture; (void) level; (void) xoffset; (void) yoffset; (void) zoffset; (void) width; (void) height; (void) depth; (void) format; (void) type; (void) pixels;
   noop_warn("glTextureSubImage3D");
}

static void APIENTRY noopTextureSubImage3DEXT(GLuint texture, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void *pixels)
{
   (void) texture; (void) target; (void) level; (void) xoffset; (void) yoffset; (void) zoffset; (void) width; (void) height; (void) depth; (void) format; (void) type; (void) pixels;
   noop_warn("glTextureSubImage3DEXT");
}

static void APIENTRY noopTextureView(GLuint texture, GLenum target, GLuint origtexture, GLenum internalformat, GLuint minlevel, GLuint numlevels, GLuint minlayer, GLuint numlayers)
{
   (void) texture; (void) target; (void) origtexture; (void) internalformat; (void) minlevel; (void) numlevels; (void) minlayer; (void) numlayers;
   noop_warn("glTextureView");
}

static void APIENTRY noopTextureViewEXT(GLuint texture, GLenum target, GLuint origtexture, GLenum internalformat, GLuint minlevel, GLuint numlevels, GLuint minlayer, GLuint numlayers)
{
   (void) texture; (void) target; (void) origtexture; (void) internalformat; (void) minlevel; (void) numlevels; (void) minlayer; (void) numlayers;
   noop_warn("glTextureViewEXT");
}

static void APIENTRY noopTextureViewOES(GLuint texture, GLenum target, GLuint origtexture, GLenum internalformat, GLuint minlevel, GLuint numlevels, GLuint minlayer, GLuint numlayers)
{
   (void) texture; (void) target; (void) origtexture; (void) internalformat; (void) minlevel; (void) numlevels; (void) minlayer; (void) numlayers;
   noop_warn("glTextureViewOES");
}

static void APIENTRY noopTrackMatrixNV(GLenum target, GLuint address, GLenum matrix, GLenum transform)
{
   (void) target; (void) address; (void) matrix; (void) transform;
   noop_warn("glTrackMatrixNV");
}

static void APIENTRY noopTransformFeedbackAttribsNV(GLsizei count, const GLint *attribs, GLenum bufferMode)
{
   (void) count; (void) attribs; (void) bufferMode;
   noop_warn("glTransformFeedbackAttribsNV");
}

static void APIENTRY noopTransformFeedbackBufferBase(GLuint xfb, GLuint index, GLuint buffer)
{
   (void) xfb; (void) index; (void) buffer;
   noop_warn("glTransformFeedbackBufferBase");
}

static void APIENTRY noopTransformFeedbackBufferRange(GLuint xfb, GLuint index, GLuint buffer, GLintptr offset, GLsizeiptr size)
{
   (void) xfb; (void) index; (void) buffer; (void) offset; (void) size;
   noop_warn("glTransformFeedbackBufferRange");
}

static void APIENTRY noopTransformFeedbackStreamAttribsNV(GLsizei count, const GLint *attribs, GLsizei nbuffers, const GLint *bufstreams, GLenum bufferMode)
{
   (void) count; (void) attribs; (void) nbuffers; (void) bufstreams; (void) bufferMode;
   noop_warn("glTransformFeedbackStreamAttribsNV");
}

static void APIENTRY noopTransformFeedbackVaryings(GLuint program, GLsizei count, const GLchar *const *varyings, GLenum bufferMode)
{
   (void) program; (void) count; (void) varyings; (void) bufferMode;
   noop_warn("glTransformFeedbackVaryings");
}

static void APIENTRY noopTransformFeedbackVaryingsEXT(GLuint program, GLsizei count, const GLchar *const *varyings, GLenum bufferMode)
{
   (void) program; (void) count; (void) varyings; (void) bufferMode;
   noop_warn("glTransformFeedbackVaryingsEXT");
}

static void APIENTRY noopTransformFeedbackVaryingsNV(GLuint program, GLsizei count, const GLint *locations, GLenum bufferMode)
{
   (void) program; (void) count; (void) locations; (void) bufferMode;
   noop_warn("glTransformFeedbackVaryingsNV");
}

static void APIENTRY noopTransformPathNV(GLuint resultPath, GLuint srcPath, GLenum transformType, const GLfloat *transformValues)
{
   (void) resultPath; (void) srcPath; (void) transformType; (void) transformValues;
   noop_warn("glTransformPathNV");
}

static void APIENTRY noopTranslated(GLdouble x, GLdouble y, GLdouble z)
{
   (void) x; (void) y; (void) z;
   noop_warn("glTranslated");
}

static void APIENTRY noopTranslatef(GLfloat x, GLfloat y, GLfloat z)
{
   (void) x; (void) y; (void) z;
   noop_warn("glTranslatef");
}

static void APIENTRY noopTranslatex(GLfixed x, GLfixed y, GLfixed z)
{
   (void) x; (void) y; (void) z;
   noop_warn("glTranslatex");
}

static void APIENTRY noopTranslatexOES(GLfixed x, GLfixed y, GLfixed z)
{
   (void) x; (void) y; (void) z;
   noop_warn("glTranslatexOES");
}

static void APIENTRY noopUniform1d(GLint location, GLdouble x)
{
   (void) location; (void) x;
   noop_warn("glUniform1d");
}

static void APIENTRY noopUniform1dv(GLint location, GLsizei count, const GLdouble *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform1dv");
}

static void APIENTRY noopUniform1f(GLint location, GLfloat v0)
{
   (void) location; (void) v0;
   noop_warn("glUniform1f");
}

static void APIENTRY noopUniform1fARB(GLint location, GLfloat v0)
{
   (void) location; (void) v0;
   noop_warn("glUniform1fARB");
}

static void APIENTRY noopUniform1fv(GLint location, GLsizei count, const GLfloat *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform1fv");
}

static void APIENTRY noopUniform1fvARB(GLint location, GLsizei count, const GLfloat *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform1fvARB");
}

static void APIENTRY noopUniform1i(GLint location, GLint v0)
{
   (void) location; (void) v0;
   noop_warn("glUniform1i");
}

static void APIENTRY noopUniform1i64ARB(GLint location, GLint64 x)
{
   (void) location; (void) x;
   noop_warn("glUniform1i64ARB");
}

static void APIENTRY noopUniform1i64NV(GLint location, GLint64 x)
{
   (void) location; (void) x;
   noop_warn("glUniform1i64NV");
}

static void APIENTRY noopUniform1i64vARB(GLint location, GLsizei count, const GLint64 *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform1i64vARB");
}

static void APIENTRY noopUniform1i64vNV(GLint location, GLsizei count, const GLint64 *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform1i64vNV");
}

static void APIENTRY noopUniform1iARB(GLint location, GLint v0)
{
   (void) location; (void) v0;
   noop_warn("glUniform1iARB");
}

static void APIENTRY noopUniform1iv(GLint location, GLsizei count, const GLint *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform1iv");
}

static void APIENTRY noopUniform1ivARB(GLint location, GLsizei count, const GLint *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform1ivARB");
}

static void APIENTRY noopUniform1ui(GLint location, GLuint v0)
{
   (void) location; (void) v0;
   noop_warn("glUniform1ui");
}

static void APIENTRY noopUniform1ui64ARB(GLint location, GLuint64 x)
{
   (void) location; (void) x;
   noop_warn("glUniform1ui64ARB");
}

static void APIENTRY noopUniform1ui64NV(GLint location, GLuint64 x)
{
   (void) location; (void) x;
   noop_warn("glUniform1ui64NV");
}

static void APIENTRY noopUniform1ui64vARB(GLint location, GLsizei count, const GLuint64 *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform1ui64vARB");
}

static void APIENTRY noopUniform1ui64vNV(GLint location, GLsizei count, const GLuint64 *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform1ui64vNV");
}

static void APIENTRY noopUniform1uiEXT(GLint location, GLuint v0)
{
   (void) location; (void) v0;
   noop_warn("glUniform1uiEXT");
}

static void APIENTRY noopUniform1uiv(GLint location, GLsizei count, const GLuint *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform1uiv");
}

static void APIENTRY noopUniform1uivEXT(GLint location, GLsizei count, const GLuint *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform1uivEXT");
}

static void APIENTRY noopUniform2d(GLint location, GLdouble x, GLdouble y)
{
   (void) location; (void) x; (void) y;
   noop_warn("glUniform2d");
}

static void APIENTRY noopUniform2dv(GLint location, GLsizei count, const GLdouble *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform2dv");
}

static void APIENTRY noopUniform2f(GLint location, GLfloat v0, GLfloat v1)
{
   (void) location; (void) v0; (void) v1;
   noop_warn("glUniform2f");
}

static void APIENTRY noopUniform2fARB(GLint location, GLfloat v0, GLfloat v1)
{
   (void) location; (void) v0; (void) v1;
   noop_warn("glUniform2fARB");
}

static void APIENTRY noopUniform2fv(GLint location, GLsizei count, const GLfloat *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform2fv");
}

static void APIENTRY noopUniform2fvARB(GLint location, GLsizei count, const GLfloat *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform2fvARB");
}

static void APIENTRY noopUniform2i(GLint location, GLint v0, GLint v1)
{
   (void) location; (void) v0; (void) v1;
   noop_warn("glUniform2i");
}

static void APIENTRY noopUniform2i64ARB(GLint location, GLint64 x, GLint64 y)
{
   (void) location; (void) x; (void) y;
   noop_warn("glUniform2i64ARB");
}

static void APIENTRY noopUniform2i64NV(GLint location, GLint64 x, GLint64 y)
{
   (void) location; (void) x; (void) y;
   noop_warn("glUniform2i64NV");
}

static void APIENTRY noopUniform2i64vARB(GLint location, GLsizei count, const GLint64 *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform2i64vARB");
}

static void APIENTRY noopUniform2i64vNV(GLint location, GLsizei count, const GLint64 *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform2i64vNV");
}

static void APIENTRY noopUniform2iARB(GLint location, GLint v0, GLint v1)
{
   (void) location; (void) v0; (void) v1;
   noop_warn("glUniform2iARB");
}

static void APIENTRY noopUniform2iv(GLint location, GLsizei count, const GLint *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform2iv");
}

static void APIENTRY noopUniform2ivARB(GLint location, GLsizei count, const GLint *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform2ivARB");
}

static void APIENTRY noopUniform2ui(GLint location, GLuint v0, GLuint v1)
{
   (void) location; (void) v0; (void) v1;
   noop_warn("glUniform2ui");
}

static void APIENTRY noopUniform2ui64ARB(GLint location, GLuint64 x, GLuint64 y)
{
   (void) location; (void) x; (void) y;
   noop_warn("glUniform2ui64ARB");
}

static void APIENTRY noopUniform2ui64NV(GLint location, GLuint64 x, GLuint64 y)
{
   (void) location; (void) x; (void) y;
   noop_warn("glUniform2ui64NV");
}

static void APIENTRY noopUniform2ui64vARB(GLint location, GLsizei count, const GLuint64 *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform2ui64vARB");
}

static void APIENTRY noopUniform2ui64vNV(GLint location, GLsizei count, const GLuint64 *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform2ui64vNV");
}

static void APIENTRY noopUniform2uiEXT(GLint location, GLuint v0, GLuint v1)
{
   (void) location; (void) v0; (void) v1;
   noop_warn("glUniform2uiEXT");
}

static void APIENTRY noopUniform2uiv(GLint location, GLsizei count, const GLuint *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform2uiv");
}

static void APIENTRY noopUniform2uivEXT(GLint location, GLsizei count, const GLuint *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform2uivEXT");
}

static void APIENTRY noopUniform3d(GLint location, GLdouble x, GLdouble y, GLdouble z)
{
   (void) location; (void) x; (void) y; (void) z;
   noop_warn("glUniform3d");
}

static void APIENTRY noopUniform3dv(GLint location, GLsizei count, const GLdouble *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform3dv");
}

static void APIENTRY noopUniform3f(GLint location, GLfloat v0, GLfloat v1, GLfloat v2)
{
   (void) location; (void) v0; (void) v1; (void) v2;
   noop_warn("glUniform3f");
}

static void APIENTRY noopUniform3fARB(GLint location, GLfloat v0, GLfloat v1, GLfloat v2)
{
   (void) location; (void) v0; (void) v1; (void) v2;
   noop_warn("glUniform3fARB");
}

static void APIENTRY noopUniform3fv(GLint location, GLsizei count, const GLfloat *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform3fv");
}

static void APIENTRY noopUniform3fvARB(GLint location, GLsizei count, const GLfloat *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform3fvARB");
}

static void APIENTRY noopUniform3i(GLint location, GLint v0, GLint v1, GLint v2)
{
   (void) location; (void) v0; (void) v1; (void) v2;
   noop_warn("glUniform3i");
}

static void APIENTRY noopUniform3i64ARB(GLint location, GLint64 x, GLint64 y, GLint64 z)
{
   (void) location; (void) x; (void) y; (void) z;
   noop_warn("glUniform3i64ARB");
}

static void APIENTRY noopUniform3i64NV(GLint location, GLint64 x, GLint64 y, GLint64 z)
{
   (void) location; (void) x; (void) y; (void) z;
   noop_warn("glUniform3i64NV");
}

static void APIENTRY noopUniform3i64vARB(GLint location, GLsizei count, const GLint64 *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform3i64vARB");
}

static void APIENTRY noopUniform3i64vNV(GLint location, GLsizei count, const GLint64 *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform3i64vNV");
}

static void APIENTRY noopUniform3iARB(GLint location, GLint v0, GLint v1, GLint v2)
{
   (void) location; (void) v0; (void) v1; (void) v2;
   noop_warn("glUniform3iARB");
}

static void APIENTRY noopUniform3iv(GLint location, GLsizei count, const GLint *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform3iv");
}

static void APIENTRY noopUniform3ivARB(GLint location, GLsizei count, const GLint *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform3ivARB");
}

static void APIENTRY noopUniform3ui(GLint location, GLuint v0, GLuint v1, GLuint v2)
{
   (void) location; (void) v0; (void) v1; (void) v2;
   noop_warn("glUniform3ui");
}

static void APIENTRY noopUniform3ui64ARB(GLint location, GLuint64 x, GLuint64 y, GLuint64 z)
{
   (void) location; (void) x; (void) y; (void) z;
   noop_warn("glUniform3ui64ARB");
}

static void APIENTRY noopUniform3ui64NV(GLint location, GLuint64 x, GLuint64 y, GLuint64 z)
{
   (void) location; (void) x; (void) y; (void) z;
   noop_warn("glUniform3ui64NV");
}

static void APIENTRY noopUniform3ui64vARB(GLint location, GLsizei count, const GLuint64 *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform3ui64vARB");
}

static void APIENTRY noopUniform3ui64vNV(GLint location, GLsizei count, const GLuint64 *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform3ui64vNV");
}

static void APIENTRY noopUniform3uiEXT(GLint location, GLuint v0, GLuint v1, GLuint v2)
{
   (void) location; (void) v0; (void) v1; (void) v2;
   noop_warn("glUniform3uiEXT");
}

static void APIENTRY noopUniform3uiv(GLint location, GLsizei count, const GLuint *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform3uiv");
}

static void APIENTRY noopUniform3uivEXT(GLint location, GLsizei count, const GLuint *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform3uivEXT");
}

static void APIENTRY noopUniform4d(GLint location, GLdouble x, GLdouble y, GLdouble z, GLdouble w)
{
   (void) location; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glUniform4d");
}

static void APIENTRY noopUniform4dv(GLint location, GLsizei count, const GLdouble *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform4dv");
}

static void APIENTRY noopUniform4f(GLint location, GLfloat v0, GLfloat v1, GLfloat v2, GLfloat v3)
{
   (void) location; (void) v0; (void) v1; (void) v2; (void) v3;
   noop_warn("glUniform4f");
}

static void APIENTRY noopUniform4fARB(GLint location, GLfloat v0, GLfloat v1, GLfloat v2, GLfloat v3)
{
   (void) location; (void) v0; (void) v1; (void) v2; (void) v3;
   noop_warn("glUniform4fARB");
}

static void APIENTRY noopUniform4fv(GLint location, GLsizei count, const GLfloat *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform4fv");
}

static void APIENTRY noopUniform4fvARB(GLint location, GLsizei count, const GLfloat *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform4fvARB");
}

static void APIENTRY noopUniform4i(GLint location, GLint v0, GLint v1, GLint v2, GLint v3)
{
   (void) location; (void) v0; (void) v1; (void) v2; (void) v3;
   noop_warn("glUniform4i");
}

static void APIENTRY noopUniform4i64ARB(GLint location, GLint64 x, GLint64 y, GLint64 z, GLint64 w)
{
   (void) location; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glUniform4i64ARB");
}

static void APIENTRY noopUniform4i64NV(GLint location, GLint64 x, GLint64 y, GLint64 z, GLint64 w)
{
   (void) location; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glUniform4i64NV");
}

static void APIENTRY noopUniform4i64vARB(GLint location, GLsizei count, const GLint64 *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform4i64vARB");
}

static void APIENTRY noopUniform4i64vNV(GLint location, GLsizei count, const GLint64 *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform4i64vNV");
}

static void APIENTRY noopUniform4iARB(GLint location, GLint v0, GLint v1, GLint v2, GLint v3)
{
   (void) location; (void) v0; (void) v1; (void) v2; (void) v3;
   noop_warn("glUniform4iARB");
}

static void APIENTRY noopUniform4iv(GLint location, GLsizei count, const GLint *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform4iv");
}

static void APIENTRY noopUniform4ivARB(GLint location, GLsizei count, const GLint *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform4ivARB");
}

static void APIENTRY noopUniform4ui(GLint location, GLuint v0, GLuint v1, GLuint v2, GLuint v3)
{
   (void) location; (void) v0; (void) v1; (void) v2; (void) v3;
   noop_warn("glUniform4ui");
}

static void APIENTRY noopUniform4ui64ARB(GLint location, GLuint64 x, GLuint64 y, GLuint64 z, GLuint64 w)
{
   (void) location; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glUniform4ui64ARB");
}

static void APIENTRY noopUniform4ui64NV(GLint location, GLuint64 x, GLuint64 y, GLuint64 z, GLuint64 w)
{
   (void) location; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glUniform4ui64NV");
}

static void APIENTRY noopUniform4ui64vARB(GLint location, GLsizei count, const GLuint64 *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform4ui64vARB");
}

static void APIENTRY noopUniform4ui64vNV(GLint location, GLsizei count, const GLuint64 *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform4ui64vNV");
}

static void APIENTRY noopUniform4uiEXT(GLint location, GLuint v0, GLuint v1, GLuint v2, GLuint v3)
{
   (void) location; (void) v0; (void) v1; (void) v2; (void) v3;
   noop_warn("glUniform4uiEXT");
}

static void APIENTRY noopUniform4uiv(GLint location, GLsizei count, const GLuint *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform4uiv");
}

static void APIENTRY noopUniform4uivEXT(GLint location, GLsizei count, const GLuint *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniform4uivEXT");
}

static void APIENTRY noopUniformBlockBinding(GLuint program, GLuint uniformBlockIndex, GLuint uniformBlockBinding)
{
   (void) program; (void) uniformBlockIndex; (void) uniformBlockBinding;
   noop_warn("glUniformBlockBinding");
}

static void APIENTRY noopUniformBufferEXT(GLuint program, GLint location, GLuint buffer)
{
   (void) program; (void) location; (void) buffer;
   noop_warn("glUniformBufferEXT");
}

static void APIENTRY noopUniformHandleui64ARB(GLint location, GLuint64 value)
{
   (void) location; (void) value;
   noop_warn("glUniformHandleui64ARB");
}

static void APIENTRY noopUniformHandleui64IMG(GLint location, GLuint64 value)
{
   (void) location; (void) value;
   noop_warn("glUniformHandleui64IMG");
}

static void APIENTRY noopUniformHandleui64NV(GLint location, GLuint64 value)
{
   (void) location; (void) value;
   noop_warn("glUniformHandleui64NV");
}

static void APIENTRY noopUniformHandleui64vARB(GLint location, GLsizei count, const GLuint64 *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniformHandleui64vARB");
}

static void APIENTRY noopUniformHandleui64vIMG(GLint location, GLsizei count, const GLuint64 *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniformHandleui64vIMG");
}

static void APIENTRY noopUniformHandleui64vNV(GLint location, GLsizei count, const GLuint64 *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniformHandleui64vNV");
}

static void APIENTRY noopUniformMatrix2dv(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glUniformMatrix2dv");
}

static void APIENTRY noopUniformMatrix2fv(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glUniformMatrix2fv");
}

static void APIENTRY noopUniformMatrix2fvARB(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glUniformMatrix2fvARB");
}

static void APIENTRY noopUniformMatrix2x3dv(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glUniformMatrix2x3dv");
}

static void APIENTRY noopUniformMatrix2x3fv(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glUniformMatrix2x3fv");
}

static void APIENTRY noopUniformMatrix2x3fvNV(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glUniformMatrix2x3fvNV");
}

static void APIENTRY noopUniformMatrix2x4dv(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glUniformMatrix2x4dv");
}

static void APIENTRY noopUniformMatrix2x4fv(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glUniformMatrix2x4fv");
}

static void APIENTRY noopUniformMatrix2x4fvNV(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glUniformMatrix2x4fvNV");
}

static void APIENTRY noopUniformMatrix3dv(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glUniformMatrix3dv");
}

static void APIENTRY noopUniformMatrix3fv(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glUniformMatrix3fv");
}

static void APIENTRY noopUniformMatrix3fvARB(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glUniformMatrix3fvARB");
}

static void APIENTRY noopUniformMatrix3x2dv(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glUniformMatrix3x2dv");
}

static void APIENTRY noopUniformMatrix3x2fv(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glUniformMatrix3x2fv");
}

static void APIENTRY noopUniformMatrix3x2fvNV(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glUniformMatrix3x2fvNV");
}

static void APIENTRY noopUniformMatrix3x4dv(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glUniformMatrix3x4dv");
}

static void APIENTRY noopUniformMatrix3x4fv(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glUniformMatrix3x4fv");
}

static void APIENTRY noopUniformMatrix3x4fvNV(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glUniformMatrix3x4fvNV");
}

static void APIENTRY noopUniformMatrix4dv(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glUniformMatrix4dv");
}

static void APIENTRY noopUniformMatrix4fv(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glUniformMatrix4fv");
}

static void APIENTRY noopUniformMatrix4fvARB(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glUniformMatrix4fvARB");
}

static void APIENTRY noopUniformMatrix4x2dv(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glUniformMatrix4x2dv");
}

static void APIENTRY noopUniformMatrix4x2fv(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glUniformMatrix4x2fv");
}

static void APIENTRY noopUniformMatrix4x2fvNV(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glUniformMatrix4x2fvNV");
}

static void APIENTRY noopUniformMatrix4x3dv(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glUniformMatrix4x3dv");
}

static void APIENTRY noopUniformMatrix4x3fv(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glUniformMatrix4x3fv");
}

static void APIENTRY noopUniformMatrix4x3fvNV(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   (void) location; (void) count; (void) transpose; (void) value;
   noop_warn("glUniformMatrix4x3fvNV");
}

static void APIENTRY noopUniformSubroutinesuiv(GLenum shadertype, GLsizei count, const GLuint *indices)
{
   (void) shadertype; (void) count; (void) indices;
   noop_warn("glUniformSubroutinesuiv");
}

static void APIENTRY noopUniformui64NV(GLint location, GLuint64 value)
{
   (void) location; (void) value;
   noop_warn("glUniformui64NV");
}

static void APIENTRY noopUniformui64vNV(GLint location, GLsizei count, const GLuint64 *value)
{
   (void) location; (void) count; (void) value;
   noop_warn("glUniformui64vNV");
}

static void APIENTRY noopUnlockArraysEXT(void)
{
   noop_warn("glUnlockArraysEXT");
}

static GLboolean APIENTRY noopUnmapBuffer(GLenum target)
{
   (void) target;
   noop_warn("glUnmapBuffer");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopUnmapBufferARB(GLenum target)
{
   (void) target;
   noop_warn("glUnmapBufferARB");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopUnmapBufferOES(GLenum target)
{
   (void) target;
   noop_warn("glUnmapBufferOES");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopUnmapNamedBuffer(GLuint buffer)
{
   (void) buffer;
   noop_warn("glUnmapNamedBuffer");
   return (GLboolean) 0;
}

static GLboolean APIENTRY noopUnmapNamedBufferEXT(GLuint buffer)
{
   (void) buffer;
   noop_warn("glUnmapNamedBufferEXT");
   return (GLboolean) 0;
}

static void APIENTRY noopUnmapObjectBufferATI(GLuint buffer)
{
   (void) buffer;
   noop_warn("glUnmapObjectBufferATI");
}

static void APIENTRY noopUnmapTexture2DINTEL(GLuint texture, GLint level)
{
   (void) texture; (void) level;
   noop_warn("glUnmapTexture2DINTEL");
}

static void APIENTRY noopUpdateObjectBufferATI(GLuint buffer, GLuint offset, GLsizei size, const void *pointer, GLenum preserve)
{
   (void) buffer; (void) offset; (void) size; (void) pointer; (void) preserve;
   noop_warn("glUpdateObjectBufferATI");
}

static void APIENTRY noopUploadGpuMaskNVX(GLbitfield mask)
{
   (void) mask;
   noop_warn("glUploadGpuMaskNVX");
}

static void APIENTRY noopUseProgram(GLuint program)
{
   (void) program;
   noop_warn("glUseProgram");
}

static void APIENTRY noopUseProgramObjectARB(GLhandleARB programObj)
{
   (void) programObj;
   noop_warn("glUseProgramObjectARB");
}

static void APIENTRY noopUseProgramStages(GLuint pipeline, GLbitfield stages, GLuint program)
{
   (void) pipeline; (void) stages; (void) program;
   noop_warn("glUseProgramStages");
}

static void APIENTRY noopUseProgramStagesEXT(GLuint pipeline, GLbitfield stages, GLuint program)
{
   (void) pipeline; (void) stages; (void) program;
   noop_warn("glUseProgramStagesEXT");
}

static void APIENTRY noopUseShaderProgramEXT(GLenum type, GLuint program)
{
   (void) type; (void) program;
   noop_warn("glUseShaderProgramEXT");
}

static void APIENTRY noopVDPAUFiniNV(void)
{
   noop_warn("glVDPAUFiniNV");
}

static void APIENTRY noopVDPAUGetSurfaceivNV(GLvdpauSurfaceNV surface, GLenum pname, GLsizei count, GLsizei *length, GLint *values)
{
   (void) surface; (void) pname; (void) count; (void) length; (void) values;
   noop_warn("glVDPAUGetSurfaceivNV");
}

static void APIENTRY noopVDPAUInitNV(const void *vdpDevice, const void *getProcAddress)
{
   (void) vdpDevice; (void) getProcAddress;
   noop_warn("glVDPAUInitNV");
}

static GLboolean APIENTRY noopVDPAUIsSurfaceNV(GLvdpauSurfaceNV surface)
{
   (void) surface;
   noop_warn("glVDPAUIsSurfaceNV");
   return (GLboolean) 0;
}

static void APIENTRY noopVDPAUMapSurfacesNV(GLsizei numSurfaces, const GLvdpauSurfaceNV *surfaces)
{
   (void) numSurfaces; (void) surfaces;
   noop_warn("glVDPAUMapSurfacesNV");
}

static GLvdpauSurfaceNV APIENTRY noopVDPAURegisterOutputSurfaceNV(const void *vdpSurface, GLenum target, GLsizei numTextureNames, const GLuint *textureNames)
{
   (void) vdpSurface; (void) target; (void) numTextureNames; (void) textureNames;
   noop_warn("glVDPAURegisterOutputSurfaceNV");
   return (GLvdpauSurfaceNV) 0;
}

static GLvdpauSurfaceNV APIENTRY noopVDPAURegisterVideoSurfaceNV(const void *vdpSurface, GLenum target, GLsizei numTextureNames, const GLuint *textureNames)
{
   (void) vdpSurface; (void) target; (void) numTextureNames; (void) textureNames;
   noop_warn("glVDPAURegisterVideoSurfaceNV");
   return (GLvdpauSurfaceNV) 0;
}

static GLvdpauSurfaceNV APIENTRY noopVDPAURegisterVideoSurfaceWithPictureStructureNV(const void *vdpSurface, GLenum target, GLsizei numTextureNames, const GLuint *textureNames, GLboolean isFrameStructure)
{
   (void) vdpSurface; (void) target; (void) numTextureNames; (void) textureNames; (void) isFrameStructure;
   noop_warn("glVDPAURegisterVideoSurfaceWithPictureStructureNV");
   return (GLvdpauSurfaceNV) 0;
}

static void APIENTRY noopVDPAUSurfaceAccessNV(GLvdpauSurfaceNV surface, GLenum access)
{
   (void) surface; (void) access;
   noop_warn("glVDPAUSurfaceAccessNV");
}

static void APIENTRY noopVDPAUUnmapSurfacesNV(GLsizei numSurface, const GLvdpauSurfaceNV *surfaces)
{
   (void) numSurface; (void) surfaces;
   noop_warn("glVDPAUUnmapSurfacesNV");
}

static void APIENTRY noopVDPAUUnregisterSurfaceNV(GLvdpauSurfaceNV surface)
{
   (void) surface;
   noop_warn("glVDPAUUnregisterSurfaceNV");
}

static GLboolean APIENTRY noopValidBackBufferHintAutodesk(GLint x, GLint y, GLsizei width, GLsizei height)
{
   (void) x; (void) y; (void) width; (void) height;
   noop_warn("glValidBackBufferHintAutodesk");
   return (GLboolean) 0;
}

static void APIENTRY noopValidateProgram(GLuint program)
{
   (void) program;
   noop_warn("glValidateProgram");
}

static void APIENTRY noopValidateProgramARB(GLhandleARB programObj)
{
   (void) programObj;
   noop_warn("glValidateProgramARB");
}

static void APIENTRY noopValidateProgramPipeline(GLuint pipeline)
{
   (void) pipeline;
   noop_warn("glValidateProgramPipeline");
}

static void APIENTRY noopValidateProgramPipelineEXT(GLuint pipeline)
{
   (void) pipeline;
   noop_warn("glValidateProgramPipelineEXT");
}

static void APIENTRY noopVariantArrayObjectATI(GLuint id, GLenum type, GLsizei stride, GLuint buffer, GLuint offset)
{
   (void) id; (void) type; (void) stride; (void) buffer; (void) offset;
   noop_warn("glVariantArrayObjectATI");
}

static void APIENTRY noopVariantPointerEXT(GLuint id, GLenum type, GLuint stride, const void *addr)
{
   (void) id; (void) type; (void) stride; (void) addr;
   noop_warn("glVariantPointerEXT");
}

static void APIENTRY noopVariantbvEXT(GLuint id, const GLbyte *addr)
{
   (void) id; (void) addr;
   noop_warn("glVariantbvEXT");
}

static void APIENTRY noopVariantdvEXT(GLuint id, const GLdouble *addr)
{
   (void) id; (void) addr;
   noop_warn("glVariantdvEXT");
}

static void APIENTRY noopVariantfvEXT(GLuint id, const GLfloat *addr)
{
   (void) id; (void) addr;
   noop_warn("glVariantfvEXT");
}

static void APIENTRY noopVariantivEXT(GLuint id, const GLint *addr)
{
   (void) id; (void) addr;
   noop_warn("glVariantivEXT");
}

static void APIENTRY noopVariantsvEXT(GLuint id, const GLshort *addr)
{
   (void) id; (void) addr;
   noop_warn("glVariantsvEXT");
}

static void APIENTRY noopVariantubvEXT(GLuint id, const GLubyte *addr)
{
   (void) id; (void) addr;
   noop_warn("glVariantubvEXT");
}

static void APIENTRY noopVariantuivEXT(GLuint id, const GLuint *addr)
{
   (void) id; (void) addr;
   noop_warn("glVariantuivEXT");
}

static void APIENTRY noopVariantusvEXT(GLuint id, const GLushort *addr)
{
   (void) id; (void) addr;
   noop_warn("glVariantusvEXT");
}

static void APIENTRY noopVertex2bOES(GLbyte x, GLbyte y)
{
   (void) x; (void) y;
   noop_warn("glVertex2bOES");
}

static void APIENTRY noopVertex2bvOES(const GLbyte *coords)
{
   (void) coords;
   noop_warn("glVertex2bvOES");
}

static void APIENTRY noopVertex2d(GLdouble x, GLdouble y)
{
   (void) x; (void) y;
   noop_warn("glVertex2d");
}

static void APIENTRY noopVertex2dv(const GLdouble *v)
{
   (void) v;
   noop_warn("glVertex2dv");
}

static void APIENTRY noopVertex2f(GLfloat x, GLfloat y)
{
   (void) x; (void) y;
   noop_warn("glVertex2f");
}

static void APIENTRY noopVertex2fv(const GLfloat *v)
{
   (void) v;
   noop_warn("glVertex2fv");
}

static void APIENTRY noopVertex2hNV(GLhalf x, GLhalf y)
{
   (void) x; (void) y;
   noop_warn("glVertex2hNV");
}

static void APIENTRY noopVertex2hvNV(const GLhalf *v)
{
   (void) v;
   noop_warn("glVertex2hvNV");
}

static void APIENTRY noopVertex2i(GLint x, GLint y)
{
   (void) x; (void) y;
   noop_warn("glVertex2i");
}

static void APIENTRY noopVertex2iv(const GLint *v)
{
   (void) v;
   noop_warn("glVertex2iv");
}

static void APIENTRY noopVertex2s(GLshort x, GLshort y)
{
   (void) x; (void) y;
   noop_warn("glVertex2s");
}

static void APIENTRY noopVertex2sv(const GLshort *v)
{
   (void) v;
   noop_warn("glVertex2sv");
}

static void APIENTRY noopVertex2xOES(GLfixed x)
{
   (void) x;
   noop_warn("glVertex2xOES");
}

static void APIENTRY noopVertex2xvOES(const GLfixed *coords)
{
   (void) coords;
   noop_warn("glVertex2xvOES");
}

static void APIENTRY noopVertex3bOES(GLbyte x, GLbyte y, GLbyte z)
{
   (void) x; (void) y; (void) z;
   noop_warn("glVertex3bOES");
}

static void APIENTRY noopVertex3bvOES(const GLbyte *coords)
{
   (void) coords;
   noop_warn("glVertex3bvOES");
}

static void APIENTRY noopVertex3d(GLdouble x, GLdouble y, GLdouble z)
{
   (void) x; (void) y; (void) z;
   noop_warn("glVertex3d");
}

static void APIENTRY noopVertex3dv(const GLdouble *v)
{
   (void) v;
   noop_warn("glVertex3dv");
}

static void APIENTRY noopVertex3f(GLfloat x, GLfloat y, GLfloat z)
{
   (void) x; (void) y; (void) z;
   noop_warn("glVertex3f");
}

static void APIENTRY noopVertex3fv(const GLfloat *v)
{
   (void) v;
   noop_warn("glVertex3fv");
}

static void APIENTRY noopVertex3hNV(GLhalf x, GLhalf y, GLhalf z)
{
   (void) x; (void) y; (void) z;
   noop_warn("glVertex3hNV");
}

static void APIENTRY noopVertex3hvNV(const GLhalf *v)
{
   (void) v;
   noop_warn("glVertex3hvNV");
}

static void APIENTRY noopVertex3i(GLint x, GLint y, GLint z)
{
   (void) x; (void) y; (void) z;
   noop_warn("glVertex3i");
}

static void APIENTRY noopVertex3iv(const GLint *v)
{
   (void) v;
   noop_warn("glVertex3iv");
}

static void APIENTRY noopVertex3s(GLshort x, GLshort y, GLshort z)
{
   (void) x; (void) y; (void) z;
   noop_warn("glVertex3s");
}

static void APIENTRY noopVertex3sv(const GLshort *v)
{
   (void) v;
   noop_warn("glVertex3sv");
}

static void APIENTRY noopVertex3xOES(GLfixed x, GLfixed y)
{
   (void) x; (void) y;
   noop_warn("glVertex3xOES");
}

static void APIENTRY noopVertex3xvOES(const GLfixed *coords)
{
   (void) coords;
   noop_warn("glVertex3xvOES");
}

static void APIENTRY noopVertex4bOES(GLbyte x, GLbyte y, GLbyte z, GLbyte w)
{
   (void) x; (void) y; (void) z; (void) w;
   noop_warn("glVertex4bOES");
}

static void APIENTRY noopVertex4bvOES(const GLbyte *coords)
{
   (void) coords;
   noop_warn("glVertex4bvOES");
}

static void APIENTRY noopVertex4d(GLdouble x, GLdouble y, GLdouble z, GLdouble w)
{
   (void) x; (void) y; (void) z; (void) w;
   noop_warn("glVertex4d");
}

static void APIENTRY noopVertex4dv(const GLdouble *v)
{
   (void) v;
   noop_warn("glVertex4dv");
}

static void APIENTRY noopVertex4f(GLfloat x, GLfloat y, GLfloat z, GLfloat w)
{
   (void) x; (void) y; (void) z; (void) w;
   noop_warn("glVertex4f");
}

static void APIENTRY noopVertex4fv(const GLfloat *v)
{
   (void) v;
   noop_warn("glVertex4fv");
}

static void APIENTRY noopVertex4hNV(GLhalf x, GLhalf y, GLhalf z, GLhalf w)
{
   (void) x; (void) y; (void) z; (void) w;
   noop_warn("glVertex4hNV");
}

static void APIENTRY noopVertex4hvNV(const GLhalf *v)
{
   (void) v;
   noop_warn("glVertex4hvNV");
}

static void APIENTRY noopVertex4i(GLint x, GLint y, GLint z, GLint w)
{
   (void) x; (void) y; (void) z; (void) w;
   noop_warn("glVertex4i");
}

static void APIENTRY noopVertex4iv(const GLint *v)
{
   (void) v;
   noop_warn("glVertex4iv");
}

static void APIENTRY noopVertex4s(GLshort x, GLshort y, GLshort z, GLshort w)
{
   (void) x; (void) y; (void) z; (void) w;
   noop_warn("glVertex4s");
}

static void APIENTRY noopVertex4sv(const GLshort *v)
{
   (void) v;
   noop_warn("glVertex4sv");
}

static void APIENTRY noopVertex4xOES(GLfixed x, GLfixed y, GLfixed z)
{
   (void) x; (void) y; (void) z;
   noop_warn("glVertex4xOES");
}

static void APIENTRY noopVertex4xvOES(const GLfixed *coords)
{
   (void) coords;
   noop_warn("glVertex4xvOES");
}

static void APIENTRY noopVertexArrayAttribBinding(GLuint vaobj, GLuint attribindex, GLuint bindingindex)
{
   (void) vaobj; (void) attribindex; (void) bindingindex;
   noop_warn("glVertexArrayAttribBinding");
}

static void APIENTRY noopVertexArrayAttribFormat(GLuint vaobj, GLuint attribindex, GLint size, GLenum type, GLboolean normalized, GLuint relativeoffset)
{
   (void) vaobj; (void) attribindex; (void) size; (void) type; (void) normalized; (void) relativeoffset;
   noop_warn("glVertexArrayAttribFormat");
}

static void APIENTRY noopVertexArrayAttribIFormat(GLuint vaobj, GLuint attribindex, GLint size, GLenum type, GLuint relativeoffset)
{
   (void) vaobj; (void) attribindex; (void) size; (void) type; (void) relativeoffset;
   noop_warn("glVertexArrayAttribIFormat");
}

static void APIENTRY noopVertexArrayAttribLFormat(GLuint vaobj, GLuint attribindex, GLint size, GLenum type, GLuint relativeoffset)
{
   (void) vaobj; (void) attribindex; (void) size; (void) type; (void) relativeoffset;
   noop_warn("glVertexArrayAttribLFormat");
}

static void APIENTRY noopVertexArrayBindVertexBufferEXT(GLuint vaobj, GLuint bindingindex, GLuint buffer, GLintptr offset, GLsizei stride)
{
   (void) vaobj; (void) bindingindex; (void) buffer; (void) offset; (void) stride;
   noop_warn("glVertexArrayBindVertexBufferEXT");
}

static void APIENTRY noopVertexArrayBindingDivisor(GLuint vaobj, GLuint bindingindex, GLuint divisor)
{
   (void) vaobj; (void) bindingindex; (void) divisor;
   noop_warn("glVertexArrayBindingDivisor");
}

static void APIENTRY noopVertexArrayColorOffsetEXT(GLuint vaobj, GLuint buffer, GLint size, GLenum type, GLsizei stride, GLintptr offset)
{
   (void) vaobj; (void) buffer; (void) size; (void) type; (void) stride; (void) offset;
   noop_warn("glVertexArrayColorOffsetEXT");
}

static void APIENTRY noopVertexArrayEdgeFlagOffsetEXT(GLuint vaobj, GLuint buffer, GLsizei stride, GLintptr offset)
{
   (void) vaobj; (void) buffer; (void) stride; (void) offset;
   noop_warn("glVertexArrayEdgeFlagOffsetEXT");
}

static void APIENTRY noopVertexArrayElementBuffer(GLuint vaobj, GLuint buffer)
{
   (void) vaobj; (void) buffer;
   noop_warn("glVertexArrayElementBuffer");
}

static void APIENTRY noopVertexArrayFogCoordOffsetEXT(GLuint vaobj, GLuint buffer, GLenum type, GLsizei stride, GLintptr offset)
{
   (void) vaobj; (void) buffer; (void) type; (void) stride; (void) offset;
   noop_warn("glVertexArrayFogCoordOffsetEXT");
}

static void APIENTRY noopVertexArrayIndexOffsetEXT(GLuint vaobj, GLuint buffer, GLenum type, GLsizei stride, GLintptr offset)
{
   (void) vaobj; (void) buffer; (void) type; (void) stride; (void) offset;
   noop_warn("glVertexArrayIndexOffsetEXT");
}

static void APIENTRY noopVertexArrayMultiTexCoordOffsetEXT(GLuint vaobj, GLuint buffer, GLenum texunit, GLint size, GLenum type, GLsizei stride, GLintptr offset)
{
   (void) vaobj; (void) buffer; (void) texunit; (void) size; (void) type; (void) stride; (void) offset;
   noop_warn("glVertexArrayMultiTexCoordOffsetEXT");
}

static void APIENTRY noopVertexArrayNormalOffsetEXT(GLuint vaobj, GLuint buffer, GLenum type, GLsizei stride, GLintptr offset)
{
   (void) vaobj; (void) buffer; (void) type; (void) stride; (void) offset;
   noop_warn("glVertexArrayNormalOffsetEXT");
}

static void APIENTRY noopVertexArrayParameteriAPPLE(GLenum pname, GLint param)
{
   (void) pname; (void) param;
   noop_warn("glVertexArrayParameteriAPPLE");
}

static void APIENTRY noopVertexArrayRangeAPPLE(GLsizei length, void *pointer)
{
   (void) length; (void) pointer;
   noop_warn("glVertexArrayRangeAPPLE");
}

static void APIENTRY noopVertexArrayRangeNV(GLsizei length, const void *pointer)
{
   (void) length; (void) pointer;
   noop_warn("glVertexArrayRangeNV");
}

static void APIENTRY noopVertexArraySecondaryColorOffsetEXT(GLuint vaobj, GLuint buffer, GLint size, GLenum type, GLsizei stride, GLintptr offset)
{
   (void) vaobj; (void) buffer; (void) size; (void) type; (void) stride; (void) offset;
   noop_warn("glVertexArraySecondaryColorOffsetEXT");
}

static void APIENTRY noopVertexArrayTexCoordOffsetEXT(GLuint vaobj, GLuint buffer, GLint size, GLenum type, GLsizei stride, GLintptr offset)
{
   (void) vaobj; (void) buffer; (void) size; (void) type; (void) stride; (void) offset;
   noop_warn("glVertexArrayTexCoordOffsetEXT");
}

static void APIENTRY noopVertexArrayVertexAttribBindingEXT(GLuint vaobj, GLuint attribindex, GLuint bindingindex)
{
   (void) vaobj; (void) attribindex; (void) bindingindex;
   noop_warn("glVertexArrayVertexAttribBindingEXT");
}

static void APIENTRY noopVertexArrayVertexAttribDivisorEXT(GLuint vaobj, GLuint index, GLuint divisor)
{
   (void) vaobj; (void) index; (void) divisor;
   noop_warn("glVertexArrayVertexAttribDivisorEXT");
}

static void APIENTRY noopVertexArrayVertexAttribFormatEXT(GLuint vaobj, GLuint attribindex, GLint size, GLenum type, GLboolean normalized, GLuint relativeoffset)
{
   (void) vaobj; (void) attribindex; (void) size; (void) type; (void) normalized; (void) relativeoffset;
   noop_warn("glVertexArrayVertexAttribFormatEXT");
}

static void APIENTRY noopVertexArrayVertexAttribIFormatEXT(GLuint vaobj, GLuint attribindex, GLint size, GLenum type, GLuint relativeoffset)
{
   (void) vaobj; (void) attribindex; (void) size; (void) type; (void) relativeoffset;
   noop_warn("glVertexArrayVertexAttribIFormatEXT");
}

static void APIENTRY noopVertexArrayVertexAttribIOffsetEXT(GLuint vaobj, GLuint buffer, GLuint index, GLint size, GLenum type, GLsizei stride, GLintptr offset)
{
   (void) vaobj; (void) buffer; (void) index; (void) size; (void) type; (void) stride; (void) offset;
   noop_warn("glVertexArrayVertexAttribIOffsetEXT");
}

static void APIENTRY noopVertexArrayVertexAttribLFormatEXT(GLuint vaobj, GLuint attribindex, GLint size, GLenum type, GLuint relativeoffset)
{
   (void) vaobj; (void) attribindex; (void) size; (void) type; (void) relativeoffset;
   noop_warn("glVertexArrayVertexAttribLFormatEXT");
}

static void APIENTRY noopVertexArrayVertexAttribLOffsetEXT(GLuint vaobj, GLuint buffer, GLuint index, GLint size, GLenum type, GLsizei stride, GLintptr offset)
{
   (void) vaobj; (void) buffer; (void) index; (void) size; (void) type; (void) stride; (void) offset;
   noop_warn("glVertexArrayVertexAttribLOffsetEXT");
}

static void APIENTRY noopVertexArrayVertexAttribOffsetEXT(GLuint vaobj, GLuint buffer, GLuint index, GLint size, GLenum type, GLboolean normalized, GLsizei stride, GLintptr offset)
{
   (void) vaobj; (void) buffer; (void) index; (void) size; (void) type; (void) normalized; (void) stride; (void) offset;
   noop_warn("glVertexArrayVertexAttribOffsetEXT");
}

static void APIENTRY noopVertexArrayVertexBindingDivisorEXT(GLuint vaobj, GLuint bindingindex, GLuint divisor)
{
   (void) vaobj; (void) bindingindex; (void) divisor;
   noop_warn("glVertexArrayVertexBindingDivisorEXT");
}

static void APIENTRY noopVertexArrayVertexBuffer(GLuint vaobj, GLuint bindingindex, GLuint buffer, GLintptr offset, GLsizei stride)
{
   (void) vaobj; (void) bindingindex; (void) buffer; (void) offset; (void) stride;
   noop_warn("glVertexArrayVertexBuffer");
}

static void APIENTRY noopVertexArrayVertexBuffers(GLuint vaobj, GLuint first, GLsizei count, const GLuint *buffers, const GLintptr *offsets, const GLsizei *strides)
{
   (void) vaobj; (void) first; (void) count; (void) buffers; (void) offsets; (void) strides;
   noop_warn("glVertexArrayVertexBuffers");
}

static void APIENTRY noopVertexArrayVertexOffsetEXT(GLuint vaobj, GLuint buffer, GLint size, GLenum type, GLsizei stride, GLintptr offset)
{
   (void) vaobj; (void) buffer; (void) size; (void) type; (void) stride; (void) offset;
   noop_warn("glVertexArrayVertexOffsetEXT");
}

static void APIENTRY noopVertexAttrib1d(GLuint index, GLdouble x)
{
   (void) index; (void) x;
   noop_warn("glVertexAttrib1d");
}

static void APIENTRY noopVertexAttrib1dARB(GLuint index, GLdouble x)
{
   (void) index; (void) x;
   noop_warn("glVertexAttrib1dARB");
}

static void APIENTRY noopVertexAttrib1dNV(GLuint index, GLdouble x)
{
   (void) index; (void) x;
   noop_warn("glVertexAttrib1dNV");
}

static void APIENTRY noopVertexAttrib1dv(GLuint index, const GLdouble *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib1dv");
}

static void APIENTRY noopVertexAttrib1dvARB(GLuint index, const GLdouble *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib1dvARB");
}

static void APIENTRY noopVertexAttrib1dvNV(GLuint index, const GLdouble *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib1dvNV");
}

static void APIENTRY noopVertexAttrib1f(GLuint index, GLfloat x)
{
   (void) index; (void) x;
   noop_warn("glVertexAttrib1f");
}

static void APIENTRY noopVertexAttrib1fARB(GLuint index, GLfloat x)
{
   (void) index; (void) x;
   noop_warn("glVertexAttrib1fARB");
}

static void APIENTRY noopVertexAttrib1fNV(GLuint index, GLfloat x)
{
   (void) index; (void) x;
   noop_warn("glVertexAttrib1fNV");
}

static void APIENTRY noopVertexAttrib1fv(GLuint index, const GLfloat *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib1fv");
}

static void APIENTRY noopVertexAttrib1fvARB(GLuint index, const GLfloat *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib1fvARB");
}

static void APIENTRY noopVertexAttrib1fvNV(GLuint index, const GLfloat *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib1fvNV");
}

static void APIENTRY noopVertexAttrib1hNV(GLuint index, GLhalf x)
{
   (void) index; (void) x;
   noop_warn("glVertexAttrib1hNV");
}

static void APIENTRY noopVertexAttrib1hvNV(GLuint index, const GLhalf *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib1hvNV");
}

static void APIENTRY noopVertexAttrib1s(GLuint index, GLshort x)
{
   (void) index; (void) x;
   noop_warn("glVertexAttrib1s");
}

static void APIENTRY noopVertexAttrib1sARB(GLuint index, GLshort x)
{
   (void) index; (void) x;
   noop_warn("glVertexAttrib1sARB");
}

static void APIENTRY noopVertexAttrib1sNV(GLuint index, GLshort x)
{
   (void) index; (void) x;
   noop_warn("glVertexAttrib1sNV");
}

static void APIENTRY noopVertexAttrib1sv(GLuint index, const GLshort *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib1sv");
}

static void APIENTRY noopVertexAttrib1svARB(GLuint index, const GLshort *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib1svARB");
}

static void APIENTRY noopVertexAttrib1svNV(GLuint index, const GLshort *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib1svNV");
}

static void APIENTRY noopVertexAttrib2d(GLuint index, GLdouble x, GLdouble y)
{
   (void) index; (void) x; (void) y;
   noop_warn("glVertexAttrib2d");
}

static void APIENTRY noopVertexAttrib2dARB(GLuint index, GLdouble x, GLdouble y)
{
   (void) index; (void) x; (void) y;
   noop_warn("glVertexAttrib2dARB");
}

static void APIENTRY noopVertexAttrib2dNV(GLuint index, GLdouble x, GLdouble y)
{
   (void) index; (void) x; (void) y;
   noop_warn("glVertexAttrib2dNV");
}

static void APIENTRY noopVertexAttrib2dv(GLuint index, const GLdouble *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib2dv");
}

static void APIENTRY noopVertexAttrib2dvARB(GLuint index, const GLdouble *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib2dvARB");
}

static void APIENTRY noopVertexAttrib2dvNV(GLuint index, const GLdouble *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib2dvNV");
}

static void APIENTRY noopVertexAttrib2f(GLuint index, GLfloat x, GLfloat y)
{
   (void) index; (void) x; (void) y;
   noop_warn("glVertexAttrib2f");
}

static void APIENTRY noopVertexAttrib2fARB(GLuint index, GLfloat x, GLfloat y)
{
   (void) index; (void) x; (void) y;
   noop_warn("glVertexAttrib2fARB");
}

static void APIENTRY noopVertexAttrib2fNV(GLuint index, GLfloat x, GLfloat y)
{
   (void) index; (void) x; (void) y;
   noop_warn("glVertexAttrib2fNV");
}

static void APIENTRY noopVertexAttrib2fv(GLuint index, const GLfloat *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib2fv");
}

static void APIENTRY noopVertexAttrib2fvARB(GLuint index, const GLfloat *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib2fvARB");
}

static void APIENTRY noopVertexAttrib2fvNV(GLuint index, const GLfloat *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib2fvNV");
}

static void APIENTRY noopVertexAttrib2hNV(GLuint index, GLhalf x, GLhalf y)
{
   (void) index; (void) x; (void) y;
   noop_warn("glVertexAttrib2hNV");
}

static void APIENTRY noopVertexAttrib2hvNV(GLuint index, const GLhalf *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib2hvNV");
}

static void APIENTRY noopVertexAttrib2s(GLuint index, GLshort x, GLshort y)
{
   (void) index; (void) x; (void) y;
   noop_warn("glVertexAttrib2s");
}

static void APIENTRY noopVertexAttrib2sARB(GLuint index, GLshort x, GLshort y)
{
   (void) index; (void) x; (void) y;
   noop_warn("glVertexAttrib2sARB");
}

static void APIENTRY noopVertexAttrib2sNV(GLuint index, GLshort x, GLshort y)
{
   (void) index; (void) x; (void) y;
   noop_warn("glVertexAttrib2sNV");
}

static void APIENTRY noopVertexAttrib2sv(GLuint index, const GLshort *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib2sv");
}

static void APIENTRY noopVertexAttrib2svARB(GLuint index, const GLshort *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib2svARB");
}

static void APIENTRY noopVertexAttrib2svNV(GLuint index, const GLshort *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib2svNV");
}

static void APIENTRY noopVertexAttrib3d(GLuint index, GLdouble x, GLdouble y, GLdouble z)
{
   (void) index; (void) x; (void) y; (void) z;
   noop_warn("glVertexAttrib3d");
}

static void APIENTRY noopVertexAttrib3dARB(GLuint index, GLdouble x, GLdouble y, GLdouble z)
{
   (void) index; (void) x; (void) y; (void) z;
   noop_warn("glVertexAttrib3dARB");
}

static void APIENTRY noopVertexAttrib3dNV(GLuint index, GLdouble x, GLdouble y, GLdouble z)
{
   (void) index; (void) x; (void) y; (void) z;
   noop_warn("glVertexAttrib3dNV");
}

static void APIENTRY noopVertexAttrib3dv(GLuint index, const GLdouble *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib3dv");
}

static void APIENTRY noopVertexAttrib3dvARB(GLuint index, const GLdouble *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib3dvARB");
}

static void APIENTRY noopVertexAttrib3dvNV(GLuint index, const GLdouble *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib3dvNV");
}

static void APIENTRY noopVertexAttrib3f(GLuint index, GLfloat x, GLfloat y, GLfloat z)
{
   (void) index; (void) x; (void) y; (void) z;
   noop_warn("glVertexAttrib3f");
}

static void APIENTRY noopVertexAttrib3fARB(GLuint index, GLfloat x, GLfloat y, GLfloat z)
{
   (void) index; (void) x; (void) y; (void) z;
   noop_warn("glVertexAttrib3fARB");
}

static void APIENTRY noopVertexAttrib3fNV(GLuint index, GLfloat x, GLfloat y, GLfloat z)
{
   (void) index; (void) x; (void) y; (void) z;
   noop_warn("glVertexAttrib3fNV");
}

static void APIENTRY noopVertexAttrib3fv(GLuint index, const GLfloat *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib3fv");
}

static void APIENTRY noopVertexAttrib3fvARB(GLuint index, const GLfloat *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib3fvARB");
}

static void APIENTRY noopVertexAttrib3fvNV(GLuint index, const GLfloat *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib3fvNV");
}

static void APIENTRY noopVertexAttrib3hNV(GLuint index, GLhalf x, GLhalf y, GLhalf z)
{
   (void) index; (void) x; (void) y; (void) z;
   noop_warn("glVertexAttrib3hNV");
}

static void APIENTRY noopVertexAttrib3hvNV(GLuint index, const GLhalf *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib3hvNV");
}

static void APIENTRY noopVertexAttrib3s(GLuint index, GLshort x, GLshort y, GLshort z)
{
   (void) index; (void) x; (void) y; (void) z;
   noop_warn("glVertexAttrib3s");
}

static void APIENTRY noopVertexAttrib3sARB(GLuint index, GLshort x, GLshort y, GLshort z)
{
   (void) index; (void) x; (void) y; (void) z;
   noop_warn("glVertexAttrib3sARB");
}

static void APIENTRY noopVertexAttrib3sNV(GLuint index, GLshort x, GLshort y, GLshort z)
{
   (void) index; (void) x; (void) y; (void) z;
   noop_warn("glVertexAttrib3sNV");
}

static void APIENTRY noopVertexAttrib3sv(GLuint index, const GLshort *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib3sv");
}

static void APIENTRY noopVertexAttrib3svARB(GLuint index, const GLshort *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib3svARB");
}

static void APIENTRY noopVertexAttrib3svNV(GLuint index, const GLshort *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib3svNV");
}

static void APIENTRY noopVertexAttrib4Nbv(GLuint index, const GLbyte *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib4Nbv");
}

static void APIENTRY noopVertexAttrib4NbvARB(GLuint index, const GLbyte *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib4NbvARB");
}

static void APIENTRY noopVertexAttrib4Niv(GLuint index, const GLint *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib4Niv");
}

static void APIENTRY noopVertexAttrib4NivARB(GLuint index, const GLint *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib4NivARB");
}

static void APIENTRY noopVertexAttrib4Nsv(GLuint index, const GLshort *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib4Nsv");
}

static void APIENTRY noopVertexAttrib4NsvARB(GLuint index, const GLshort *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib4NsvARB");
}

static void APIENTRY noopVertexAttrib4Nub(GLuint index, GLubyte x, GLubyte y, GLubyte z, GLubyte w)
{
   (void) index; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glVertexAttrib4Nub");
}

static void APIENTRY noopVertexAttrib4NubARB(GLuint index, GLubyte x, GLubyte y, GLubyte z, GLubyte w)
{
   (void) index; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glVertexAttrib4NubARB");
}

static void APIENTRY noopVertexAttrib4Nubv(GLuint index, const GLubyte *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib4Nubv");
}

static void APIENTRY noopVertexAttrib4NubvARB(GLuint index, const GLubyte *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib4NubvARB");
}

static void APIENTRY noopVertexAttrib4Nuiv(GLuint index, const GLuint *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib4Nuiv");
}

static void APIENTRY noopVertexAttrib4NuivARB(GLuint index, const GLuint *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib4NuivARB");
}

static void APIENTRY noopVertexAttrib4Nusv(GLuint index, const GLushort *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib4Nusv");
}

static void APIENTRY noopVertexAttrib4NusvARB(GLuint index, const GLushort *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib4NusvARB");
}

static void APIENTRY noopVertexAttrib4bv(GLuint index, const GLbyte *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib4bv");
}

static void APIENTRY noopVertexAttrib4bvARB(GLuint index, const GLbyte *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib4bvARB");
}

static void APIENTRY noopVertexAttrib4d(GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w)
{
   (void) index; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glVertexAttrib4d");
}

static void APIENTRY noopVertexAttrib4dARB(GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w)
{
   (void) index; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glVertexAttrib4dARB");
}

static void APIENTRY noopVertexAttrib4dNV(GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w)
{
   (void) index; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glVertexAttrib4dNV");
}

static void APIENTRY noopVertexAttrib4dv(GLuint index, const GLdouble *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib4dv");
}

static void APIENTRY noopVertexAttrib4dvARB(GLuint index, const GLdouble *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib4dvARB");
}

static void APIENTRY noopVertexAttrib4dvNV(GLuint index, const GLdouble *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib4dvNV");
}

static void APIENTRY noopVertexAttrib4f(GLuint index, GLfloat x, GLfloat y, GLfloat z, GLfloat w)
{
   (void) index; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glVertexAttrib4f");
}

static void APIENTRY noopVertexAttrib4fARB(GLuint index, GLfloat x, GLfloat y, GLfloat z, GLfloat w)
{
   (void) index; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glVertexAttrib4fARB");
}

static void APIENTRY noopVertexAttrib4fNV(GLuint index, GLfloat x, GLfloat y, GLfloat z, GLfloat w)
{
   (void) index; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glVertexAttrib4fNV");
}

static void APIENTRY noopVertexAttrib4fv(GLuint index, const GLfloat *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib4fv");
}

static void APIENTRY noopVertexAttrib4fvARB(GLuint index, const GLfloat *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib4fvARB");
}

static void APIENTRY noopVertexAttrib4fvNV(GLuint index, const GLfloat *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib4fvNV");
}

static void APIENTRY noopVertexAttrib4hNV(GLuint index, GLhalf x, GLhalf y, GLhalf z, GLhalf w)
{
   (void) index; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glVertexAttrib4hNV");
}

static void APIENTRY noopVertexAttrib4hvNV(GLuint index, const GLhalf *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib4hvNV");
}

static void APIENTRY noopVertexAttrib4iv(GLuint index, const GLint *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib4iv");
}

static void APIENTRY noopVertexAttrib4ivARB(GLuint index, const GLint *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib4ivARB");
}

static void APIENTRY noopVertexAttrib4s(GLuint index, GLshort x, GLshort y, GLshort z, GLshort w)
{
   (void) index; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glVertexAttrib4s");
}

static void APIENTRY noopVertexAttrib4sARB(GLuint index, GLshort x, GLshort y, GLshort z, GLshort w)
{
   (void) index; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glVertexAttrib4sARB");
}

static void APIENTRY noopVertexAttrib4sNV(GLuint index, GLshort x, GLshort y, GLshort z, GLshort w)
{
   (void) index; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glVertexAttrib4sNV");
}

static void APIENTRY noopVertexAttrib4sv(GLuint index, const GLshort *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib4sv");
}

static void APIENTRY noopVertexAttrib4svARB(GLuint index, const GLshort *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib4svARB");
}

static void APIENTRY noopVertexAttrib4svNV(GLuint index, const GLshort *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib4svNV");
}

static void APIENTRY noopVertexAttrib4ubNV(GLuint index, GLubyte x, GLubyte y, GLubyte z, GLubyte w)
{
   (void) index; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glVertexAttrib4ubNV");
}

static void APIENTRY noopVertexAttrib4ubv(GLuint index, const GLubyte *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib4ubv");
}

static void APIENTRY noopVertexAttrib4ubvARB(GLuint index, const GLubyte *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib4ubvARB");
}

static void APIENTRY noopVertexAttrib4ubvNV(GLuint index, const GLubyte *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib4ubvNV");
}

static void APIENTRY noopVertexAttrib4uiv(GLuint index, const GLuint *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib4uiv");
}

static void APIENTRY noopVertexAttrib4uivARB(GLuint index, const GLuint *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib4uivARB");
}

static void APIENTRY noopVertexAttrib4usv(GLuint index, const GLushort *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib4usv");
}

static void APIENTRY noopVertexAttrib4usvARB(GLuint index, const GLushort *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttrib4usvARB");
}

static void APIENTRY noopVertexAttribArrayObjectATI(GLuint index, GLint size, GLenum type, GLboolean normalized, GLsizei stride, GLuint buffer, GLuint offset)
{
   (void) index; (void) size; (void) type; (void) normalized; (void) stride; (void) buffer; (void) offset;
   noop_warn("glVertexAttribArrayObjectATI");
}

static void APIENTRY noopVertexAttribBinding(GLuint attribindex, GLuint bindingindex)
{
   (void) attribindex; (void) bindingindex;
   noop_warn("glVertexAttribBinding");
}

static void APIENTRY noopVertexAttribDivisor(GLuint index, GLuint divisor)
{
   (void) index; (void) divisor;
   noop_warn("glVertexAttribDivisor");
}

static void APIENTRY noopVertexAttribDivisorANGLE(GLuint index, GLuint divisor)
{
   (void) index; (void) divisor;
   noop_warn("glVertexAttribDivisorANGLE");
}

static void APIENTRY noopVertexAttribDivisorARB(GLuint index, GLuint divisor)
{
   (void) index; (void) divisor;
   noop_warn("glVertexAttribDivisorARB");
}

static void APIENTRY noopVertexAttribDivisorEXT(GLuint index, GLuint divisor)
{
   (void) index; (void) divisor;
   noop_warn("glVertexAttribDivisorEXT");
}

static void APIENTRY noopVertexAttribDivisorNV(GLuint index, GLuint divisor)
{
   (void) index; (void) divisor;
   noop_warn("glVertexAttribDivisorNV");
}

static void APIENTRY noopVertexAttribFormat(GLuint attribindex, GLint size, GLenum type, GLboolean normalized, GLuint relativeoffset)
{
   (void) attribindex; (void) size; (void) type; (void) normalized; (void) relativeoffset;
   noop_warn("glVertexAttribFormat");
}

static void APIENTRY noopVertexAttribFormatNV(GLuint index, GLint size, GLenum type, GLboolean normalized, GLsizei stride)
{
   (void) index; (void) size; (void) type; (void) normalized; (void) stride;
   noop_warn("glVertexAttribFormatNV");
}

static void APIENTRY noopVertexAttribI1i(GLuint index, GLint x)
{
   (void) index; (void) x;
   noop_warn("glVertexAttribI1i");
}

static void APIENTRY noopVertexAttribI1iEXT(GLuint index, GLint x)
{
   (void) index; (void) x;
   noop_warn("glVertexAttribI1iEXT");
}

static void APIENTRY noopVertexAttribI1iv(GLuint index, const GLint *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttribI1iv");
}

static void APIENTRY noopVertexAttribI1ivEXT(GLuint index, const GLint *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttribI1ivEXT");
}

static void APIENTRY noopVertexAttribI1ui(GLuint index, GLuint x)
{
   (void) index; (void) x;
   noop_warn("glVertexAttribI1ui");
}

static void APIENTRY noopVertexAttribI1uiEXT(GLuint index, GLuint x)
{
   (void) index; (void) x;
   noop_warn("glVertexAttribI1uiEXT");
}

static void APIENTRY noopVertexAttribI1uiv(GLuint index, const GLuint *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttribI1uiv");
}

static void APIENTRY noopVertexAttribI1uivEXT(GLuint index, const GLuint *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttribI1uivEXT");
}

static void APIENTRY noopVertexAttribI2i(GLuint index, GLint x, GLint y)
{
   (void) index; (void) x; (void) y;
   noop_warn("glVertexAttribI2i");
}

static void APIENTRY noopVertexAttribI2iEXT(GLuint index, GLint x, GLint y)
{
   (void) index; (void) x; (void) y;
   noop_warn("glVertexAttribI2iEXT");
}

static void APIENTRY noopVertexAttribI2iv(GLuint index, const GLint *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttribI2iv");
}

static void APIENTRY noopVertexAttribI2ivEXT(GLuint index, const GLint *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttribI2ivEXT");
}

static void APIENTRY noopVertexAttribI2ui(GLuint index, GLuint x, GLuint y)
{
   (void) index; (void) x; (void) y;
   noop_warn("glVertexAttribI2ui");
}

static void APIENTRY noopVertexAttribI2uiEXT(GLuint index, GLuint x, GLuint y)
{
   (void) index; (void) x; (void) y;
   noop_warn("glVertexAttribI2uiEXT");
}

static void APIENTRY noopVertexAttribI2uiv(GLuint index, const GLuint *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttribI2uiv");
}

static void APIENTRY noopVertexAttribI2uivEXT(GLuint index, const GLuint *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttribI2uivEXT");
}

static void APIENTRY noopVertexAttribI3i(GLuint index, GLint x, GLint y, GLint z)
{
   (void) index; (void) x; (void) y; (void) z;
   noop_warn("glVertexAttribI3i");
}

static void APIENTRY noopVertexAttribI3iEXT(GLuint index, GLint x, GLint y, GLint z)
{
   (void) index; (void) x; (void) y; (void) z;
   noop_warn("glVertexAttribI3iEXT");
}

static void APIENTRY noopVertexAttribI3iv(GLuint index, const GLint *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttribI3iv");
}

static void APIENTRY noopVertexAttribI3ivEXT(GLuint index, const GLint *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttribI3ivEXT");
}

static void APIENTRY noopVertexAttribI3ui(GLuint index, GLuint x, GLuint y, GLuint z)
{
   (void) index; (void) x; (void) y; (void) z;
   noop_warn("glVertexAttribI3ui");
}

static void APIENTRY noopVertexAttribI3uiEXT(GLuint index, GLuint x, GLuint y, GLuint z)
{
   (void) index; (void) x; (void) y; (void) z;
   noop_warn("glVertexAttribI3uiEXT");
}

static void APIENTRY noopVertexAttribI3uiv(GLuint index, const GLuint *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttribI3uiv");
}

static void APIENTRY noopVertexAttribI3uivEXT(GLuint index, const GLuint *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttribI3uivEXT");
}

static void APIENTRY noopVertexAttribI4bv(GLuint index, const GLbyte *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttribI4bv");
}

static void APIENTRY noopVertexAttribI4bvEXT(GLuint index, const GLbyte *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttribI4bvEXT");
}

static void APIENTRY noopVertexAttribI4i(GLuint index, GLint x, GLint y, GLint z, GLint w)
{
   (void) index; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glVertexAttribI4i");
}

static void APIENTRY noopVertexAttribI4iEXT(GLuint index, GLint x, GLint y, GLint z, GLint w)
{
   (void) index; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glVertexAttribI4iEXT");
}

static void APIENTRY noopVertexAttribI4iv(GLuint index, const GLint *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttribI4iv");
}

static void APIENTRY noopVertexAttribI4ivEXT(GLuint index, const GLint *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttribI4ivEXT");
}

static void APIENTRY noopVertexAttribI4sv(GLuint index, const GLshort *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttribI4sv");
}

static void APIENTRY noopVertexAttribI4svEXT(GLuint index, const GLshort *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttribI4svEXT");
}

static void APIENTRY noopVertexAttribI4ubv(GLuint index, const GLubyte *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttribI4ubv");
}

static void APIENTRY noopVertexAttribI4ubvEXT(GLuint index, const GLubyte *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttribI4ubvEXT");
}

static void APIENTRY noopVertexAttribI4ui(GLuint index, GLuint x, GLuint y, GLuint z, GLuint w)
{
   (void) index; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glVertexAttribI4ui");
}

static void APIENTRY noopVertexAttribI4uiEXT(GLuint index, GLuint x, GLuint y, GLuint z, GLuint w)
{
   (void) index; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glVertexAttribI4uiEXT");
}

static void APIENTRY noopVertexAttribI4uiv(GLuint index, const GLuint *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttribI4uiv");
}

static void APIENTRY noopVertexAttribI4uivEXT(GLuint index, const GLuint *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttribI4uivEXT");
}

static void APIENTRY noopVertexAttribI4usv(GLuint index, const GLushort *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttribI4usv");
}

static void APIENTRY noopVertexAttribI4usvEXT(GLuint index, const GLushort *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttribI4usvEXT");
}

static void APIENTRY noopVertexAttribIFormat(GLuint attribindex, GLint size, GLenum type, GLuint relativeoffset)
{
   (void) attribindex; (void) size; (void) type; (void) relativeoffset;
   noop_warn("glVertexAttribIFormat");
}

static void APIENTRY noopVertexAttribIFormatNV(GLuint index, GLint size, GLenum type, GLsizei stride)
{
   (void) index; (void) size; (void) type; (void) stride;
   noop_warn("glVertexAttribIFormatNV");
}

static void APIENTRY noopVertexAttribIPointer(GLuint index, GLint size, GLenum type, GLsizei stride, const void *pointer)
{
   (void) index; (void) size; (void) type; (void) stride; (void) pointer;
   noop_warn("glVertexAttribIPointer");
}

static void APIENTRY noopVertexAttribIPointerEXT(GLuint index, GLint size, GLenum type, GLsizei stride, const void *pointer)
{
   (void) index; (void) size; (void) type; (void) stride; (void) pointer;
   noop_warn("glVertexAttribIPointerEXT");
}

static void APIENTRY noopVertexAttribL1d(GLuint index, GLdouble x)
{
   (void) index; (void) x;
   noop_warn("glVertexAttribL1d");
}

static void APIENTRY noopVertexAttribL1dEXT(GLuint index, GLdouble x)
{
   (void) index; (void) x;
   noop_warn("glVertexAttribL1dEXT");
}

static void APIENTRY noopVertexAttribL1dv(GLuint index, const GLdouble *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttribL1dv");
}

static void APIENTRY noopVertexAttribL1dvEXT(GLuint index, const GLdouble *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttribL1dvEXT");
}

static void APIENTRY noopVertexAttribL1i64NV(GLuint index, GLint64 x)
{
   (void) index; (void) x;
   noop_warn("glVertexAttribL1i64NV");
}

static void APIENTRY noopVertexAttribL1i64vNV(GLuint index, const GLint64 *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttribL1i64vNV");
}

static void APIENTRY noopVertexAttribL1ui64ARB(GLuint index, GLuint64 x)
{
   (void) index; (void) x;
   noop_warn("glVertexAttribL1ui64ARB");
}

static void APIENTRY noopVertexAttribL1ui64NV(GLuint index, GLuint64 x)
{
   (void) index; (void) x;
   noop_warn("glVertexAttribL1ui64NV");
}

static void APIENTRY noopVertexAttribL1ui64vARB(GLuint index, const GLuint64 *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttribL1ui64vARB");
}

static void APIENTRY noopVertexAttribL1ui64vNV(GLuint index, const GLuint64 *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttribL1ui64vNV");
}

static void APIENTRY noopVertexAttribL2d(GLuint index, GLdouble x, GLdouble y)
{
   (void) index; (void) x; (void) y;
   noop_warn("glVertexAttribL2d");
}

static void APIENTRY noopVertexAttribL2dEXT(GLuint index, GLdouble x, GLdouble y)
{
   (void) index; (void) x; (void) y;
   noop_warn("glVertexAttribL2dEXT");
}

static void APIENTRY noopVertexAttribL2dv(GLuint index, const GLdouble *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttribL2dv");
}

static void APIENTRY noopVertexAttribL2dvEXT(GLuint index, const GLdouble *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttribL2dvEXT");
}

static void APIENTRY noopVertexAttribL2i64NV(GLuint index, GLint64 x, GLint64 y)
{
   (void) index; (void) x; (void) y;
   noop_warn("glVertexAttribL2i64NV");
}

static void APIENTRY noopVertexAttribL2i64vNV(GLuint index, const GLint64 *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttribL2i64vNV");
}

static void APIENTRY noopVertexAttribL2ui64NV(GLuint index, GLuint64 x, GLuint64 y)
{
   (void) index; (void) x; (void) y;
   noop_warn("glVertexAttribL2ui64NV");
}

static void APIENTRY noopVertexAttribL2ui64vNV(GLuint index, const GLuint64 *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttribL2ui64vNV");
}

static void APIENTRY noopVertexAttribL3d(GLuint index, GLdouble x, GLdouble y, GLdouble z)
{
   (void) index; (void) x; (void) y; (void) z;
   noop_warn("glVertexAttribL3d");
}

static void APIENTRY noopVertexAttribL3dEXT(GLuint index, GLdouble x, GLdouble y, GLdouble z)
{
   (void) index; (void) x; (void) y; (void) z;
   noop_warn("glVertexAttribL3dEXT");
}

static void APIENTRY noopVertexAttribL3dv(GLuint index, const GLdouble *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttribL3dv");
}

static void APIENTRY noopVertexAttribL3dvEXT(GLuint index, const GLdouble *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttribL3dvEXT");
}

static void APIENTRY noopVertexAttribL3i64NV(GLuint index, GLint64 x, GLint64 y, GLint64 z)
{
   (void) index; (void) x; (void) y; (void) z;
   noop_warn("glVertexAttribL3i64NV");
}

static void APIENTRY noopVertexAttribL3i64vNV(GLuint index, const GLint64 *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttribL3i64vNV");
}

static void APIENTRY noopVertexAttribL3ui64NV(GLuint index, GLuint64 x, GLuint64 y, GLuint64 z)
{
   (void) index; (void) x; (void) y; (void) z;
   noop_warn("glVertexAttribL3ui64NV");
}

static void APIENTRY noopVertexAttribL3ui64vNV(GLuint index, const GLuint64 *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttribL3ui64vNV");
}

static void APIENTRY noopVertexAttribL4d(GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w)
{
   (void) index; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glVertexAttribL4d");
}

static void APIENTRY noopVertexAttribL4dEXT(GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w)
{
   (void) index; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glVertexAttribL4dEXT");
}

static void APIENTRY noopVertexAttribL4dv(GLuint index, const GLdouble *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttribL4dv");
}

static void APIENTRY noopVertexAttribL4dvEXT(GLuint index, const GLdouble *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttribL4dvEXT");
}

static void APIENTRY noopVertexAttribL4i64NV(GLuint index, GLint64 x, GLint64 y, GLint64 z, GLint64 w)
{
   (void) index; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glVertexAttribL4i64NV");
}

static void APIENTRY noopVertexAttribL4i64vNV(GLuint index, const GLint64 *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttribL4i64vNV");
}

static void APIENTRY noopVertexAttribL4ui64NV(GLuint index, GLuint64 x, GLuint64 y, GLuint64 z, GLuint64 w)
{
   (void) index; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glVertexAttribL4ui64NV");
}

static void APIENTRY noopVertexAttribL4ui64vNV(GLuint index, const GLuint64 *v)
{
   (void) index; (void) v;
   noop_warn("glVertexAttribL4ui64vNV");
}

static void APIENTRY noopVertexAttribLFormat(GLuint attribindex, GLint size, GLenum type, GLuint relativeoffset)
{
   (void) attribindex; (void) size; (void) type; (void) relativeoffset;
   noop_warn("glVertexAttribLFormat");
}

static void APIENTRY noopVertexAttribLFormatNV(GLuint index, GLint size, GLenum type, GLsizei stride)
{
   (void) index; (void) size; (void) type; (void) stride;
   noop_warn("glVertexAttribLFormatNV");
}

static void APIENTRY noopVertexAttribLPointer(GLuint index, GLint size, GLenum type, GLsizei stride, const void *pointer)
{
   (void) index; (void) size; (void) type; (void) stride; (void) pointer;
   noop_warn("glVertexAttribLPointer");
}

static void APIENTRY noopVertexAttribLPointerEXT(GLuint index, GLint size, GLenum type, GLsizei stride, const void *pointer)
{
   (void) index; (void) size; (void) type; (void) stride; (void) pointer;
   noop_warn("glVertexAttribLPointerEXT");
}

static void APIENTRY noopVertexAttribP1ui(GLuint index, GLenum type, GLboolean normalized, GLuint value)
{
   (void) index; (void) type; (void) normalized; (void) value;
   noop_warn("glVertexAttribP1ui");
}

static void APIENTRY noopVertexAttribP1uiv(GLuint index, GLenum type, GLboolean normalized, const GLuint *value)
{
   (void) index; (void) type; (void) normalized; (void) value;
   noop_warn("glVertexAttribP1uiv");
}

static void APIENTRY noopVertexAttribP2ui(GLuint index, GLenum type, GLboolean normalized, GLuint value)
{
   (void) index; (void) type; (void) normalized; (void) value;
   noop_warn("glVertexAttribP2ui");
}

static void APIENTRY noopVertexAttribP2uiv(GLuint index, GLenum type, GLboolean normalized, const GLuint *value)
{
   (void) index; (void) type; (void) normalized; (void) value;
   noop_warn("glVertexAttribP2uiv");
}

static void APIENTRY noopVertexAttribP3ui(GLuint index, GLenum type, GLboolean normalized, GLuint value)
{
   (void) index; (void) type; (void) normalized; (void) value;
   noop_warn("glVertexAttribP3ui");
}

static void APIENTRY noopVertexAttribP3uiv(GLuint index, GLenum type, GLboolean normalized, const GLuint *value)
{
   (void) index; (void) type; (void) normalized; (void) value;
   noop_warn("glVertexAttribP3uiv");
}

static void APIENTRY noopVertexAttribP4ui(GLuint index, GLenum type, GLboolean normalized, GLuint value)
{
   (void) index; (void) type; (void) normalized; (void) value;
   noop_warn("glVertexAttribP4ui");
}

static void APIENTRY noopVertexAttribP4uiv(GLuint index, GLenum type, GLboolean normalized, const GLuint *value)
{
   (void) index; (void) type; (void) normalized; (void) value;
   noop_warn("glVertexAttribP4uiv");
}

static void APIENTRY noopVertexAttribParameteriAMD(GLuint index, GLenum pname, GLint param)
{
   (void) index; (void) pname; (void) param;
   noop_warn("glVertexAttribParameteriAMD");
}

static void APIENTRY noopVertexAttribPointer(GLuint index, GLint size, GLenum type, GLboolean normalized, GLsizei stride, const void *pointer)
{
   (void) index; (void) size; (void) type; (void) normalized; (void) stride; (void) pointer;
   noop_warn("glVertexAttribPointer");
}

static void APIENTRY noopVertexAttribPointerARB(GLuint index, GLint size, GLenum type, GLboolean normalized, GLsizei stride, const void *pointer)
{
   (void) index; (void) size; (void) type; (void) normalized; (void) stride; (void) pointer;
   noop_warn("glVertexAttribPointerARB");
}

static void APIENTRY noopVertexAttribPointerNV(GLuint index, GLint fsize, GLenum type, GLsizei stride, const void *pointer)
{
   (void) index; (void) fsize; (void) type; (void) stride; (void) pointer;
   noop_warn("glVertexAttribPointerNV");
}

static void APIENTRY noopVertexAttribs1dvNV(GLuint index, GLsizei count, const GLdouble *v)
{
   (void) index; (void) count; (void) v;
   noop_warn("glVertexAttribs1dvNV");
}

static void APIENTRY noopVertexAttribs1fvNV(GLuint index, GLsizei count, const GLfloat *v)
{
   (void) index; (void) count; (void) v;
   noop_warn("glVertexAttribs1fvNV");
}

static void APIENTRY noopVertexAttribs1hvNV(GLuint index, GLsizei n, const GLhalf *v)
{
   (void) index; (void) n; (void) v;
   noop_warn("glVertexAttribs1hvNV");
}

static void APIENTRY noopVertexAttribs1svNV(GLuint index, GLsizei count, const GLshort *v)
{
   (void) index; (void) count; (void) v;
   noop_warn("glVertexAttribs1svNV");
}

static void APIENTRY noopVertexAttribs2dvNV(GLuint index, GLsizei count, const GLdouble *v)
{
   (void) index; (void) count; (void) v;
   noop_warn("glVertexAttribs2dvNV");
}

static void APIENTRY noopVertexAttribs2fvNV(GLuint index, GLsizei count, const GLfloat *v)
{
   (void) index; (void) count; (void) v;
   noop_warn("glVertexAttribs2fvNV");
}

static void APIENTRY noopVertexAttribs2hvNV(GLuint index, GLsizei n, const GLhalf *v)
{
   (void) index; (void) n; (void) v;
   noop_warn("glVertexAttribs2hvNV");
}

static void APIENTRY noopVertexAttribs2svNV(GLuint index, GLsizei count, const GLshort *v)
{
   (void) index; (void) count; (void) v;
   noop_warn("glVertexAttribs2svNV");
}

static void APIENTRY noopVertexAttribs3dvNV(GLuint index, GLsizei count, const GLdouble *v)
{
   (void) index; (void) count; (void) v;
   noop_warn("glVertexAttribs3dvNV");
}

static void APIENTRY noopVertexAttribs3fvNV(GLuint index, GLsizei count, const GLfloat *v)
{
   (void) index; (void) count; (void) v;
   noop_warn("glVertexAttribs3fvNV");
}

static void APIENTRY noopVertexAttribs3hvNV(GLuint index, GLsizei n, const GLhalf *v)
{
   (void) index; (void) n; (void) v;
   noop_warn("glVertexAttribs3hvNV");
}

static void APIENTRY noopVertexAttribs3svNV(GLuint index, GLsizei count, const GLshort *v)
{
   (void) index; (void) count; (void) v;
   noop_warn("glVertexAttribs3svNV");
}

static void APIENTRY noopVertexAttribs4dvNV(GLuint index, GLsizei count, const GLdouble *v)
{
   (void) index; (void) count; (void) v;
   noop_warn("glVertexAttribs4dvNV");
}

static void APIENTRY noopVertexAttribs4fvNV(GLuint index, GLsizei count, const GLfloat *v)
{
   (void) index; (void) count; (void) v;
   noop_warn("glVertexAttribs4fvNV");
}

static void APIENTRY noopVertexAttribs4hvNV(GLuint index, GLsizei n, const GLhalf *v)
{
   (void) index; (void) n; (void) v;
   noop_warn("glVertexAttribs4hvNV");
}

static void APIENTRY noopVertexAttribs4svNV(GLuint index, GLsizei count, const GLshort *v)
{
   (void) index; (void) count; (void) v;
   noop_warn("glVertexAttribs4svNV");
}

static void APIENTRY noopVertexAttribs4ubvNV(GLuint index, GLsizei count, const GLubyte *v)
{
   (void) index; (void) count; (void) v;
   noop_warn("glVertexAttribs4ubvNV");
}

static void APIENTRY noopVertexBindingDivisor(GLuint bindingindex, GLuint divisor)
{
   (void) bindingindex; (void) divisor;
   noop_warn("glVertexBindingDivisor");
}

static void APIENTRY noopVertexBlendARB(GLint count)
{
   (void) count;
   noop_warn("glVertexBlendARB");
}

static void APIENTRY noopVertexBlendEnvfATI(GLenum pname, GLfloat param)
{
   (void) pname; (void) param;
   noop_warn("glVertexBlendEnvfATI");
}

static void APIENTRY noopVertexBlendEnviATI(GLenum pname, GLint param)
{
   (void) pname; (void) param;
   noop_warn("glVertexBlendEnviATI");
}

static void APIENTRY noopVertexFormatNV(GLint size, GLenum type, GLsizei stride)
{
   (void) size; (void) type; (void) stride;
   noop_warn("glVertexFormatNV");
}

static void APIENTRY noopVertexP2ui(GLenum type, GLuint value)
{
   (void) type; (void) value;
   noop_warn("glVertexP2ui");
}

static void APIENTRY noopVertexP2uiv(GLenum type, const GLuint *value)
{
   (void) type; (void) value;
   noop_warn("glVertexP2uiv");
}

static void APIENTRY noopVertexP3ui(GLenum type, GLuint value)
{
   (void) type; (void) value;
   noop_warn("glVertexP3ui");
}

static void APIENTRY noopVertexP3uiv(GLenum type, const GLuint *value)
{
   (void) type; (void) value;
   noop_warn("glVertexP3uiv");
}

static void APIENTRY noopVertexP4ui(GLenum type, GLuint value)
{
   (void) type; (void) value;
   noop_warn("glVertexP4ui");
}

static void APIENTRY noopVertexP4uiv(GLenum type, const GLuint *value)
{
   (void) type; (void) value;
   noop_warn("glVertexP4uiv");
}

static void APIENTRY noopVertexPointer(GLint size, GLenum type, GLsizei stride, const void *pointer)
{
   (void) size; (void) type; (void) stride; (void) pointer;
   noop_warn("glVertexPointer");
}

static void APIENTRY noopVertexPointerEXT(GLint size, GLenum type, GLsizei stride, GLsizei count, const void *pointer)
{
   (void) size; (void) type; (void) stride; (void) count; (void) pointer;
   noop_warn("glVertexPointerEXT");
}

static void APIENTRY noopVertexPointerListIBM(GLint size, GLenum type, GLint stride, const void **pointer, GLint ptrstride)
{
   (void) size; (void) type; (void) stride; (void) pointer; (void) ptrstride;
   noop_warn("glVertexPointerListIBM");
}

static void APIENTRY noopVertexPointervINTEL(GLint size, GLenum type, const void **pointer)
{
   (void) size; (void) type; (void) pointer;
   noop_warn("glVertexPointervINTEL");
}

static void APIENTRY noopVertexStream1dATI(GLenum stream, GLdouble x)
{
   (void) stream; (void) x;
   noop_warn("glVertexStream1dATI");
}

static void APIENTRY noopVertexStream1dvATI(GLenum stream, const GLdouble *coords)
{
   (void) stream; (void) coords;
   noop_warn("glVertexStream1dvATI");
}

static void APIENTRY noopVertexStream1fATI(GLenum stream, GLfloat x)
{
   (void) stream; (void) x;
   noop_warn("glVertexStream1fATI");
}

static void APIENTRY noopVertexStream1fvATI(GLenum stream, const GLfloat *coords)
{
   (void) stream; (void) coords;
   noop_warn("glVertexStream1fvATI");
}

static void APIENTRY noopVertexStream1iATI(GLenum stream, GLint x)
{
   (void) stream; (void) x;
   noop_warn("glVertexStream1iATI");
}

static void APIENTRY noopVertexStream1ivATI(GLenum stream, const GLint *coords)
{
   (void) stream; (void) coords;
   noop_warn("glVertexStream1ivATI");
}

static void APIENTRY noopVertexStream1sATI(GLenum stream, GLshort x)
{
   (void) stream; (void) x;
   noop_warn("glVertexStream1sATI");
}

static void APIENTRY noopVertexStream1svATI(GLenum stream, const GLshort *coords)
{
   (void) stream; (void) coords;
   noop_warn("glVertexStream1svATI");
}

static void APIENTRY noopVertexStream2dATI(GLenum stream, GLdouble x, GLdouble y)
{
   (void) stream; (void) x; (void) y;
   noop_warn("glVertexStream2dATI");
}

static void APIENTRY noopVertexStream2dvATI(GLenum stream, const GLdouble *coords)
{
   (void) stream; (void) coords;
   noop_warn("glVertexStream2dvATI");
}

static void APIENTRY noopVertexStream2fATI(GLenum stream, GLfloat x, GLfloat y)
{
   (void) stream; (void) x; (void) y;
   noop_warn("glVertexStream2fATI");
}

static void APIENTRY noopVertexStream2fvATI(GLenum stream, const GLfloat *coords)
{
   (void) stream; (void) coords;
   noop_warn("glVertexStream2fvATI");
}

static void APIENTRY noopVertexStream2iATI(GLenum stream, GLint x, GLint y)
{
   (void) stream; (void) x; (void) y;
   noop_warn("glVertexStream2iATI");
}

static void APIENTRY noopVertexStream2ivATI(GLenum stream, const GLint *coords)
{
   (void) stream; (void) coords;
   noop_warn("glVertexStream2ivATI");
}

static void APIENTRY noopVertexStream2sATI(GLenum stream, GLshort x, GLshort y)
{
   (void) stream; (void) x; (void) y;
   noop_warn("glVertexStream2sATI");
}

static void APIENTRY noopVertexStream2svATI(GLenum stream, const GLshort *coords)
{
   (void) stream; (void) coords;
   noop_warn("glVertexStream2svATI");
}

static void APIENTRY noopVertexStream3dATI(GLenum stream, GLdouble x, GLdouble y, GLdouble z)
{
   (void) stream; (void) x; (void) y; (void) z;
   noop_warn("glVertexStream3dATI");
}

static void APIENTRY noopVertexStream3dvATI(GLenum stream, const GLdouble *coords)
{
   (void) stream; (void) coords;
   noop_warn("glVertexStream3dvATI");
}

static void APIENTRY noopVertexStream3fATI(GLenum stream, GLfloat x, GLfloat y, GLfloat z)
{
   (void) stream; (void) x; (void) y; (void) z;
   noop_warn("glVertexStream3fATI");
}

static void APIENTRY noopVertexStream3fvATI(GLenum stream, const GLfloat *coords)
{
   (void) stream; (void) coords;
   noop_warn("glVertexStream3fvATI");
}

static void APIENTRY noopVertexStream3iATI(GLenum stream, GLint x, GLint y, GLint z)
{
   (void) stream; (void) x; (void) y; (void) z;
   noop_warn("glVertexStream3iATI");
}

static void APIENTRY noopVertexStream3ivATI(GLenum stream, const GLint *coords)
{
   (void) stream; (void) coords;
   noop_warn("glVertexStream3ivATI");
}

static void APIENTRY noopVertexStream3sATI(GLenum stream, GLshort x, GLshort y, GLshort z)
{
   (void) stream; (void) x; (void) y; (void) z;
   noop_warn("glVertexStream3sATI");
}

static void APIENTRY noopVertexStream3svATI(GLenum stream, const GLshort *coords)
{
   (void) stream; (void) coords;
   noop_warn("glVertexStream3svATI");
}

static void APIENTRY noopVertexStream4dATI(GLenum stream, GLdouble x, GLdouble y, GLdouble z, GLdouble w)
{
   (void) stream; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glVertexStream4dATI");
}

static void APIENTRY noopVertexStream4dvATI(GLenum stream, const GLdouble *coords)
{
   (void) stream; (void) coords;
   noop_warn("glVertexStream4dvATI");
}

static void APIENTRY noopVertexStream4fATI(GLenum stream, GLfloat x, GLfloat y, GLfloat z, GLfloat w)
{
   (void) stream; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glVertexStream4fATI");
}

static void APIENTRY noopVertexStream4fvATI(GLenum stream, const GLfloat *coords)
{
   (void) stream; (void) coords;
   noop_warn("glVertexStream4fvATI");
}

static void APIENTRY noopVertexStream4iATI(GLenum stream, GLint x, GLint y, GLint z, GLint w)
{
   (void) stream; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glVertexStream4iATI");
}

static void APIENTRY noopVertexStream4ivATI(GLenum stream, const GLint *coords)
{
   (void) stream; (void) coords;
   noop_warn("glVertexStream4ivATI");
}

static void APIENTRY noopVertexStream4sATI(GLenum stream, GLshort x, GLshort y, GLshort z, GLshort w)
{
   (void) stream; (void) x; (void) y; (void) z; (void) w;
   noop_warn("glVertexStream4sATI");
}

static void APIENTRY noopVertexStream4svATI(GLenum stream, const GLshort *coords)
{
   (void) stream; (void) coords;
   noop_warn("glVertexStream4svATI");
}

static void APIENTRY noopVertexWeightPointerEXT(GLint size, GLenum type, GLsizei stride, const void *pointer)
{
   (void) size; (void) type; (void) stride; (void) pointer;
   noop_warn("glVertexWeightPointerEXT");
}

static void APIENTRY noopVertexWeightfEXT(GLfloat weight)
{
   (void) weight;
   noop_warn("glVertexWeightfEXT");
}

static void APIENTRY noopVertexWeightfvEXT(const GLfloat *weight)
{
   (void) weight;
   noop_warn("glVertexWeightfvEXT");
}

static void APIENTRY noopVertexWeighthNV(GLhalf weight)
{
   (void) weight;
   noop_warn("glVertexWeighthNV");
}

static void APIENTRY noopVertexWeighthvNV(const GLhalf *weight)
{
   (void) weight;
   noop_warn("glVertexWeighthvNV");
}

static GLenum APIENTRY noopVideoCaptureNV(GLuint video_capture_slot, GLuint *sequence_num, GLuint64 *capture_time)
{
   (void) video_capture_slot; (void) sequence_num; (void) capture_time;
   noop_warn("glVideoCaptureNV");
   return (GLenum) 0;
}

static void APIENTRY noopVideoCaptureStreamParameterdvNV(GLuint video_capture_slot, GLuint stream, GLenum pname, const GLdouble *params)
{
   (void) video_capture_slot; (void) stream; (void) pname; (void) params;
   noop_warn("glVideoCaptureStreamParameterdvNV");
}

static void APIENTRY noopVideoCaptureStreamParameterfvNV(GLuint video_capture_slot, GLuint stream, GLenum pname, const GLfloat *params)
{
   (void) video_capture_slot; (void) stream; (void) pname; (void) params;
   noop_warn("glVideoCaptureStreamParameterfvNV");
}

static void APIENTRY noopVideoCaptureStreamParameterivNV(GLuint video_capture_slot, GLuint stream, GLenum pname, const GLint *params)
{
   (void) video_capture_slot; (void) stream; (void) pname; (void) params;
   noop_warn("glVideoCaptureStreamParameterivNV");
}

static void APIENTRY noopViewport(GLint x, GLint y, GLsizei width, GLsizei height)
{
   (void) x; (void) y; (void) width; (void) height;
   noop_warn("glViewport");
}

static void APIENTRY noopViewportArrayv(GLuint first, GLsizei count, const GLfloat *v)
{
   (void) first; (void) count; (void) v;
   noop_warn("glViewportArrayv");
}

static void APIENTRY noopViewportArrayvNV(GLuint first, GLsizei count, const GLfloat *v)
{
   (void) first; (void) count; (void) v;
   noop_warn("glViewportArrayvNV");
}

static void APIENTRY noopViewportArrayvOES(GLuint first, GLsizei count, const GLfloat *v)
{
   (void) first; (void) count; (void) v;
   noop_warn("glViewportArrayvOES");
}

static void APIENTRY noopViewportIndexedf(GLuint index, GLfloat x, GLfloat y, GLfloat w, GLfloat h)
{
   (void) index; (void) x; (void) y; (void) w; (void) h;
   noop_warn("glViewportIndexedf");
}

static void APIENTRY noopViewportIndexedfNV(GLuint index, GLfloat x, GLfloat y, GLfloat w, GLfloat h)
{
   (void) index; (void) x; (void) y; (void) w; (void) h;
   noop_warn("glViewportIndexedfNV");
}

static void APIENTRY noopViewportIndexedfOES(GLuint index, GLfloat x, GLfloat y, GLfloat w, GLfloat h)
{
   (void) index; (void) x; (void) y; (void) w; (void) h;
   noop_warn("glViewportIndexedfOES");
}

static void APIENTRY noopViewportIndexedfv(GLuint index, const GLfloat *v)
{
   (void) index; (void) v;
   noop_warn("glViewportIndexedfv");
}

static void APIENTRY noopViewportIndexedfvNV(GLuint index, const GLfloat *v)
{
   (void) index; (void) v;
   noop_warn("glViewportIndexedfvNV");
}

static void APIENTRY noopViewportIndexedfvOES(GLuint index, const GLfloat *v)
{
   (void) index; (void) v;
   noop_warn("glViewportIndexedfvOES");
}

static void APIENTRY noopViewportPositionWScaleNV(GLuint index, GLfloat xcoeff, GLfloat ycoeff)
{
   (void) index; (void) xcoeff; (void) ycoeff;
   noop_warn("glViewportPositionWScaleNV");
}

static void APIENTRY noopViewportSwizzleNV(GLuint index, GLenum swizzlex, GLenum swizzley, GLenum swizzlez, GLenum swizzlew)
{
   (void) index; (void) swizzlex; (void) swizzley; (void) swizzlez; (void) swizzlew;
   noop_warn("glViewportSwizzleNV");
}

static void APIENTRY noopWaitSemaphoreEXT(GLuint semaphore, GLuint numBufferBarriers, const GLuint *buffers, GLuint numTextureBarriers, const GLuint *textures, const GLenum *srcLayouts)
{
   (void) semaphore; (void) numBufferBarriers; (void) buffers; (void) numTextureBarriers; (void) textures; (void) srcLayouts;
   noop_warn("glWaitSemaphoreEXT");
}

static void APIENTRY noopWaitSemaphoreui64NVX(GLuint waitGpu, GLsizei fenceObjectCount, const GLuint *semaphoreArray, const GLuint64 *fenceValueArray)
{
   (void) waitGpu; (void) fenceObjectCount; (void) semaphoreArray; (void) fenceValueArray;
   noop_warn("glWaitSemaphoreui64NVX");
}

static void APIENTRY noopWaitSync(GLsync sync, GLbitfield flags, GLuint64 timeout)
{
   (void) sync; (void) flags; (void) timeout;
   noop_warn("glWaitSync");
}

static void APIENTRY noopWaitSyncAPPLE(GLsync sync, GLbitfield flags, GLuint64 timeout)
{
   (void) sync; (void) flags; (void) timeout;
   noop_warn("glWaitSyncAPPLE");
}

static void APIENTRY noopWaitSyncValueuiNVX(GLsync sync, GLbitfield flags, GLuint64 timeout, GLuint value, GLboolean GEQ)
{
   (void) sync; (void) flags; (void) timeout; (void) value; (void) GEQ;
   noop_warn("glWaitSyncValueuiNVX");
}

static void APIENTRY noopWaitVkSemaphoreNV(GLuint64 vkSemaphore)
{
   (void) vkSemaphore;
   noop_warn("glWaitVkSemaphoreNV");
}

static void APIENTRY noopWeightPathsNV(GLuint resultPath, GLsizei numPaths, const GLuint *paths, const GLfloat *weights)
{
   (void) resultPath; (void) numPaths; (void) paths; (void) weights;
   noop_warn("glWeightPathsNV");
}

static void APIENTRY noopWeightPointerARB(GLint size, GLenum type, GLsizei stride, const void *pointer)
{
   (void) size; (void) type; (void) stride; (void) pointer;
   noop_warn("glWeightPointerARB");
}

static void APIENTRY noopWeightPointerOES(GLint size, GLenum type, GLsizei stride, const void *pointer)
{
   (void) size; (void) type; (void) stride; (void) pointer;
   noop_warn("glWeightPointerOES");
}

static void APIENTRY noopWeightbvARB(GLint size, const GLbyte *weights)
{
   (void) size; (void) weights;
   noop_warn("glWeightbvARB");
}

static void APIENTRY noopWeightdvARB(GLint size, const GLdouble *weights)
{
   (void) size; (void) weights;
   noop_warn("glWeightdvARB");
}

static void APIENTRY noopWeightfvARB(GLint size, const GLfloat *weights)
{
   (void) size; (void) weights;
   noop_warn("glWeightfvARB");
}

static void APIENTRY noopWeightivARB(GLint size, const GLint *weights)
{
   (void) size; (void) weights;
   noop_warn("glWeightivARB");
}

static void APIENTRY noopWeightsvARB(GLint size, const GLshort *weights)
{
   (void) size; (void) weights;
   noop_warn("glWeightsvARB");
}

static void APIENTRY noopWeightubvARB(GLint size, const GLubyte *weights)
{
   (void) size; (void) weights;
   noop_warn("glWeightubvARB");
}

static void APIENTRY noopWeightuivARB(GLint size, const GLuint *weights)
{
   (void) size; (void) weights;
   noop_warn("glWeightuivARB");
}

static void APIENTRY noopWeightusvARB(GLint size, const GLushort *weights)
{
   (void) size; (void) weights;
   noop_warn("glWeightusvARB");
}

static void APIENTRY noopWindowBackBufferHintAutodesk(void)
{
   noop_warn("glWindowBackBufferHintAutodesk");
}

static void APIENTRY noopWindowPos2d(GLdouble x, GLdouble y)
{
   (void) x; (void) y;
   noop_warn("glWindowPos2d");
}

static void APIENTRY noopWindowPos2dARB(GLdouble x, GLdouble y)
{
   (void) x; (void) y;
   noop_warn("glWindowPos2dARB");
}

static void APIENTRY noopWindowPos2dMESA(GLdouble x, GLdouble y)
{
   (void) x; (void) y;
   noop_warn("glWindowPos2dMESA");
}

static void APIENTRY noopWindowPos2dv(const GLdouble *v)
{
   (void) v;
   noop_warn("glWindowPos2dv");
}

static void APIENTRY noopWindowPos2dvARB(const GLdouble *v)
{
   (void) v;
   noop_warn("glWindowPos2dvARB");
}

static void APIENTRY noopWindowPos2dvMESA(const GLdouble *v)
{
   (void) v;
   noop_warn("glWindowPos2dvMESA");
}

static void APIENTRY noopWindowPos2f(GLfloat x, GLfloat y)
{
   (void) x; (void) y;
   noop_warn("glWindowPos2f");
}

static void APIENTRY noopWindowPos2fARB(GLfloat x, GLfloat y)
{
   (void) x; (void) y;
   noop_warn("glWindowPos2fARB");
}

static void APIENTRY noopWindowPos2fMESA(GLfloat x, GLfloat y)
{
   (void) x; (void) y;
   noop_warn("glWindowPos2fMESA");
}

static void APIENTRY noopWindowPos2fv(const GLfloat *v)
{
   (void) v;
   noop_warn("glWindowPos2fv");
}

static void APIENTRY noopWindowPos2fvARB(const GLfloat *v)
{
   (void) v;
   noop_warn("glWindowPos2fvARB");
}

static void APIENTRY noopWindowPos2fvMESA(const GLfloat *v)
{
   (void) v;
   noop_warn("glWindowPos2fvMESA");
}

static void APIENTRY noopWindowPos2i(GLint x, GLint y)
{
   (void) x; (void) y;
   noop_warn("glWindowPos2i");
}

static void APIENTRY noopWindowPos2iARB(GLint x, GLint y)
{
   (void) x; (void) y;
   noop_warn("glWindowPos2iARB");
}

static void APIENTRY noopWindowPos2iMESA(GLint x, GLint y)
{
   (void) x; (void) y;
   noop_warn("glWindowPos2iMESA");
}

static void APIENTRY noopWindowPos2iv(const GLint *v)
{
   (void) v;
   noop_warn("glWindowPos2iv");
}

static void APIENTRY noopWindowPos2ivARB(const GLint *v)
{
   (void) v;
   noop_warn("glWindowPos2ivARB");
}

static void APIENTRY noopWindowPos2ivMESA(const GLint *v)
{
   (void) v;
   noop_warn("glWindowPos2ivMESA");
}

static void APIENTRY noopWindowPos2s(GLshort x, GLshort y)
{
   (void) x; (void) y;
   noop_warn("glWindowPos2s");
}

static void APIENTRY noopWindowPos2sARB(GLshort x, GLshort y)
{
   (void) x; (void) y;
   noop_warn("glWindowPos2sARB");
}

static void APIENTRY noopWindowPos2sMESA(GLshort x, GLshort y)
{
   (void) x; (void) y;
   noop_warn("glWindowPos2sMESA");
}

static void APIENTRY noopWindowPos2sv(const GLshort *v)
{
   (void) v;
   noop_warn("glWindowPos2sv");
}

static void APIENTRY noopWindowPos2svARB(const GLshort *v)
{
   (void) v;
   noop_warn("glWindowPos2svARB");
}

static void APIENTRY noopWindowPos2svMESA(const GLshort *v)
{
   (void) v;
   noop_warn("glWindowPos2svMESA");
}

static void APIENTRY noopWindowPos3d(GLdouble x, GLdouble y, GLdouble z)
{
   (void) x; (void) y; (void) z;
   noop_warn("glWindowPos3d");
}

static void APIENTRY noopWindowPos3dARB(GLdouble x, GLdouble y, GLdouble z)
{
   (void) x; (void) y; (void) z;
   noop_warn("glWindowPos3dARB");
}

static void APIENTRY noopWindowPos3dMESA(GLdouble x, GLdouble y, GLdouble z)
{
   (void) x; (void) y; (void) z;
   noop_warn("glWindowPos3dMESA");
}

static void APIENTRY noopWindowPos3dv(const GLdouble *v)
{
   (void) v;
   noop_warn("glWindowPos3dv");
}

static void APIENTRY noopWindowPos3dvARB(const GLdouble *v)
{
   (void) v;
   noop_warn("glWindowPos3dvARB");
}

static void APIENTRY noopWindowPos3dvMESA(const GLdouble *v)
{
   (void) v;
   noop_warn("glWindowPos3dvMESA");
}

static void APIENTRY noopWindowPos3f(GLfloat x, GLfloat y, GLfloat z)
{
   (void) x; (void) y; (void) z;
   noop_warn("glWindowPos3f");
}

static void APIENTRY noopWindowPos3fARB(GLfloat x, GLfloat y, GLfloat z)
{
   (void) x; (void) y; (void) z;
   noop_warn("glWindowPos3fARB");
}

static void APIENTRY noopWindowPos3fMESA(GLfloat x, GLfloat y, GLfloat z)
{
   (void) x; (void) y; (void) z;
   noop_warn("glWindowPos3fMESA");
}

static void APIENTRY noopWindowPos3fv(const GLfloat *v)
{
   (void) v;
   noop_warn("glWindowPos3fv");
}

static void APIENTRY noopWindowPos3fvARB(const GLfloat *v)
{
   (void) v;
   noop_warn("glWindowPos3fvARB");
}

static void APIENTRY noopWindowPos3fvMESA(const GLfloat *v)
{
   (void) v;
   noop_warn("glWindowPos3fvMESA");
}

static void APIENTRY noopWindowPos3i(GLint x, GLint y, GLint z)
{
   (void) x; (void) y; (void) z;
   noop_warn("glWindowPos3i");
}

static void APIENTRY noopWindowPos3iARB(GLint x, GLint y, GLint z)
{
   (void) x; (void) y; (void) z;
   noop_warn("glWindowPos3iARB");
}

static void APIENTRY noopWindowPos3iMESA(GLint x, GLint y, GLint z)
{
   (void) x; (void) y; (void) z;
   noop_warn("glWindowPos3iMESA");
}

static void APIENTRY noopWindowPos3iv(const GLint *v)
{
   (void) v;
   noop_warn("glWindowPos3iv");
}

static void APIENTRY noopWindowPos3ivARB(const GLint *v)
{
   (void) v;
   noop_warn("glWindowPos3ivARB");
}

static void APIENTRY noopWindowPos3ivMESA(const GLint *v)
{
   (void) v;
   noop_warn("glWindowPos3ivMESA");
}

static void APIENTRY noopWindowPos3s(GLshort x, GLshort y, GLshort z)
{
   (void) x; (void) y; (void) z;
   noop_warn("glWindowPos3s");
}

static void APIENTRY noopWindowPos3sARB(GLshort x, GLshort y, GLshort z)
{
   (void) x; (void) y; (void) z;
   noop_warn("glWindowPos3sARB");
}

static void APIENTRY noopWindowPos3sMESA(GLshort x, GLshort y, GLshort z)
{
   (void) x; (void) y; (void) z;
   noop_warn("glWindowPos3sMESA");
}

static void APIENTRY noopWindowPos3sv(const GLshort *v)
{
   (void) v;
   noop_warn("glWindowPos3sv");
}

static void APIENTRY noopWindowPos3svARB(const GLshort *v)
{
   (void) v;
   noop_warn("glWindowPos3svARB");
}

static void APIENTRY noopWindowPos3svMESA(const GLshort *v)
{
   (void) v;
   noop_warn("glWindowPos3svMESA");
}

static void APIENTRY noopWindowPos4dMESA(GLdouble x, GLdouble y, GLdouble z, GLdouble w)
{
   (void) x; (void) y; (void) z; (void) w;
   noop_warn("glWindowPos4dMESA");
}

static void APIENTRY noopWindowPos4dvMESA(const GLdouble *v)
{
   (void) v;
   noop_warn("glWindowPos4dvMESA");
}

static void APIENTRY noopWindowPos4fMESA(GLfloat x, GLfloat y, GLfloat z, GLfloat w)
{
   (void) x; (void) y; (void) z; (void) w;
   noop_warn("glWindowPos4fMESA");
}

static void APIENTRY noopWindowPos4fvMESA(const GLfloat *v)
{
   (void) v;
   noop_warn("glWindowPos4fvMESA");
}

static void APIENTRY noopWindowPos4iMESA(GLint x, GLint y, GLint z, GLint w)
{
   (void) x; (void) y; (void) z; (void) w;
   noop_warn("glWindowPos4iMESA");
}

static void APIENTRY noopWindowPos4ivMESA(const GLint *v)
{
   (void) v;
   noop_warn("glWindowPos4ivMESA");
}

static void APIENTRY noopWindowPos4sMESA(GLshort x, GLshort y, GLshort z, GLshort w)
{
   (void) x; (void) y; (void) z; (void) w;
   noop_warn("glWindowPos4sMESA");
}

static void APIENTRY noopWindowPos4svMESA(const GLshort *v)
{
   (void) v;
   noop_warn("glWindowPos4svMESA");
}

static void APIENTRY noopWindowRectanglesEXT(GLenum mode, GLsizei count, const GLint *box)
{
   (void) mode; (void) count; (void) box;
   noop_warn("glWindowRectanglesEXT");
}

static void APIENTRY noopWriteMaskEXT(GLuint res, GLuint in, GLenum outX, GLenum outY, GLenum outZ, GLenum outW)
{
   (void) res; (void) in; (void) outX; (void) outY; (void) outZ; (void) outW;
   noop_warn("glWriteMaskEXT");
}

const mapi_func table_noop_array[] = {
   (mapi_func) noopAccum,
   (mapi_func) noopAccumxOES,
   (mapi_func) noopAcquireKeyedMutexWin32EXT,
   (mapi_func) noopActiveProgramEXT,
   (mapi_func) noopActiveShaderProgram,
   (mapi_func) noopActiveShaderProgramEXT,
   (mapi_func) noopActiveStencilFaceEXT,
   (mapi_func) noopActiveTexture,
   (mapi_func) noopActiveTextureARB,
   (mapi_func) noopActiveVaryingNV,
   (mapi_func) noopAlphaFragmentOp1ATI,
   (mapi_func) noopAlphaFragmentOp2ATI,
   (mapi_func) noopAlphaFragmentOp3ATI,
   (mapi_func) noopAlphaFunc,
   (mapi_func) noopAlphaFuncQCOM,
   (mapi_func) noopAlphaFuncx,
   (mapi_func) noopAlphaFuncxOES,
   (mapi_func) noopAlphaToCoverageDitherControlNV,
   (mapi_func) noopApplyFramebufferAttachmentCMAAINTEL,
   (mapi_func) noopApplyTextureEXT,
   (mapi_func) noopAreProgramsResidentNV,
   (mapi_func) noopAreTexturesResident,
   (mapi_func) noopAreTexturesResidentEXT,
   (mapi_func) noopArrayElement,
   (mapi_func) noopArrayElementEXT,
   (mapi_func) noopArrayObjectATI,
   (mapi_func) noopAsyncCopyBufferSubDataNVX,
   (mapi_func) noopAsyncCopyImageSubDataNVX,
   (mapi_func) noopAsyncMarkerSGIX,
   (mapi_func) noopAttachObjectARB,
   (mapi_func) noopAttachShader,
   (mapi_func) noopBegin,
   (mapi_func) noopBeginConditionalRender,
   (mapi_func) noopBeginConditionalRenderNV,
   (mapi_func) noopBeginConditionalRenderNVX,
   (mapi_func) noopBeginFragmentShaderATI,
   (mapi_func) noopBeginOcclusionQueryNV,
   (mapi_func) noopBeginPerfMonitorAMD,
   (mapi_func) noopBeginPerfQueryINTEL,
   (mapi_func) noopBeginQuery,
   (mapi_func) noopBeginQueryARB,
   (mapi_func) noopBeginQueryEXT,
   (mapi_func) noopBeginQueryIndexed,
   (mapi_func) noopBeginTransformFeedback,
   (mapi_func) noopBeginTransformFeedbackEXT,
   (mapi_func) noopBeginTransformFeedbackNV,
   (mapi_func) noopBeginVertexShaderEXT,
   (mapi_func) noopBeginVideoCaptureNV,
   (mapi_func) noopBindANCCaptureStreamBufferNVX,
   (mapi_func) noopBindAttribLocation,
   (mapi_func) noopBindAttribLocationARB,
   (mapi_func) noopBindBuffer,
   (mapi_func) noopBindBufferARB,
   (mapi_func) noopBindBufferBase,
   (mapi_func) noopBindBufferBaseEXT,
   (mapi_func) noopBindBufferBaseNV,
   (mapi_func) noopBindBufferOffsetEXT,
   (mapi_func) noopBindBufferOffsetNV,
   (mapi_func) noopBindBufferRange,
   (mapi_func) noopBindBufferRangeEXT,
   (mapi_func) noopBindBufferRangeNV,
   (mapi_func) noopBindBuffersBase,
   (mapi_func) noopBindBuffersRange,
   (mapi_func) noopBindFragDataLocation,
   (mapi_func) noopBindFragDataLocationEXT,
   (mapi_func) noopBindFragDataLocationIndexed,
   (mapi_func) noopBindFragDataLocationIndexedEXT,
   (mapi_func) noopBindFragmentShaderATI,
   (mapi_func) noopBindFramebuffer,
   (mapi_func) noopBindFramebufferEXT,
   (mapi_func) noopBindFramebufferOES,
   (mapi_func) noopBindImageTexture,
   (mapi_func) noopBindImageTextureEXT,
   (mapi_func) noopBindImageTextures,
   (mapi_func) noopBindLightParameterEXT,
   (mapi_func) noopBindMaterialParameterEXT,
   (mapi_func) noopBindMultiTextureEXT,
   (mapi_func) noopBindParameterEXT,
   (mapi_func) noopBindProgramARB,
   (mapi_func) noopBindProgramNV,
   (mapi_func) noopBindProgramPipeline,
   (mapi_func) noopBindProgramPipelineEXT,
   (mapi_func) noopBindRenderbuffer,
   (mapi_func) noopBindRenderbufferEXT,
   (mapi_func) noopBindRenderbufferOES,
   (mapi_func) noopBindSampler,
   (mapi_func) noopBindSamplers,
   (mapi_func) noopBindShadingRateImageNV,
   (mapi_func) noopBindTexGenParameterEXT,
   (mapi_func) noopBindTexture,
   (mapi_func) noopBindTextureEXT,
   (mapi_func) noopBindTextureUnit,
   (mapi_func) noopBindTextureUnitParameterEXT,
   (mapi_func) noopBindTextures,
   (mapi_func) noopBindTransformFeedback,
   (mapi_func) noopBindTransformFeedbackEXT,
   (mapi_func) noopBindTransformFeedbackNV,
   (mapi_func) noopBindVertexArray,
   (mapi_func) noopBindVertexArrayAPPLE,
   (mapi_func) noopBindVertexArrayOES,
   (mapi_func) noopBindVertexBuffer,
   (mapi_func) noopBindVertexBuffers,
   (mapi_func) noopBindVertexShaderEXT,
   (mapi_func) noopBindVideoCaptureStreamBufferNV,
   (mapi_func) noopBindVideoCaptureStreamTextureNV,
   (mapi_func) noopBinormal3bEXT,
   (mapi_func) noopBinormal3bvEXT,
   (mapi_func) noopBinormal3dEXT,
   (mapi_func) noopBinormal3dvEXT,
   (mapi_func) noopBinormal3fEXT,
   (mapi_func) noopBinormal3fvEXT,
   (mapi_func) noopBinormal3iEXT,
   (mapi_func) noopBinormal3ivEXT,
   (mapi_func) noopBinormal3sEXT,
   (mapi_func) noopBinormal3svEXT,
   (mapi_func) noopBinormalPointerEXT,
   (mapi_func) noopBitmap,
   (mapi_func) noopBitmapxOES,
   (mapi_func) noopBlendBarrier,
   (mapi_func) noopBlendBarrierKHR,
   (mapi_func) noopBlendBarrierNV,
   (mapi_func) noopBlendColor,
   (mapi_func) noopBlendColorEXT,
   (mapi_func) noopBlendColorxOES,
   (mapi_func) noopBlendEquation,
   (mapi_func) noopBlendEquationEXT,
   (mapi_func) noopBlendEquationIndexedAMD,
   (mapi_func) noopBlendEquationOES,
   (mapi_func) noopBlendEquationSeparate,
   (mapi_func) noopBlendEquationSeparateEXT,
   (mapi_func) noopBlendEquationSeparateIndexedAMD,
   (mapi_func) noopBlendEquationSeparateOES,
   (mapi_func) noopBlendEquationSeparatei,
   (mapi_func) noopBlendEquationSeparateiARB,
   (mapi_func) noopBlendEquationSeparateiEXT,
   (mapi_func) noopBlendEquationSeparateiOES,
   (mapi_func) noopBlendEquationi,
   (mapi_func) noopBlendEquationiARB,
   (mapi_func) noopBlendEquationiEXT,
   (mapi_func) noopBlendEquationiOES,
   (mapi_func) noopBlendFunc,
   (mapi_func) noopBlendFuncIndexedAMD,
   (mapi_func) noopBlendFuncSeparate,
   (mapi_func) noopBlendFuncSeparateEXT,
   (mapi_func) noopBlendFuncSeparateINGR,
   (mapi_func) noopBlendFuncSeparateIndexedAMD,
   (mapi_func) noopBlendFuncSeparateOES,
   (mapi_func) noopBlendFuncSeparatei,
   (mapi_func) noopBlendFuncSeparateiARB,
   (mapi_func) noopBlendFuncSeparateiEXT,
   (mapi_func) noopBlendFuncSeparateiOES,
   (mapi_func) noopBlendFunci,
   (mapi_func) noopBlendFunciARB,
   (mapi_func) noopBlendFunciEXT,
   (mapi_func) noopBlendFunciOES,
   (mapi_func) noopBlendParameteriNV,
   (mapi_func) noopBlitFramebuffer,
   (mapi_func) noopBlitFramebufferANGLE,
   (mapi_func) noopBlitFramebufferEXT,
   (mapi_func) noopBlitFramebufferNV,
   (mapi_func) noopBlitNamedFramebuffer,
   (mapi_func) noopBufferAddressRangeNV,
   (mapi_func) noopBufferAttachMemoryNV,
   (mapi_func) noopBufferData,
   (mapi_func) noopBufferDataARB,
   (mapi_func) noopBufferDataSysmem,
   (mapi_func) noopBufferPageCommitmentARB,
   (mapi_func) noopBufferParameteriAPPLE,
   (mapi_func) noopBufferStorage,
   (mapi_func) noopBufferStorageEXT,
   (mapi_func) noopBufferStorageExternalEXT,
   (mapi_func) noopBufferStorageMemEXT,
   (mapi_func) noopBufferSubData,
   (mapi_func) noopBufferSubDataARB,
   (mapi_func) noopCallCommandListNV,
   (mapi_func) noopCallList,
   (mapi_func) noopCallLists,
   (mapi_func) noopCheckFramebufferStatus,
   (mapi_func) noopCheckFramebufferStatusEXT,
   (mapi_func) noopCheckFramebufferStatusOES,
   (mapi_func) noopCheckNamedFramebufferStatus,
   (mapi_func) noopCheckNamedFramebufferStatusEXT,
   (mapi_func) noopClampColor,
   (mapi_func) noopClampColorARB,
   (mapi_func) noopClear,
   (mapi_func) noopClearAccum,
   (mapi_func) noopClearAccumxOES,
   (mapi_func) noopClearBufferData,
   (mapi_func) noopClearBufferSubData,
   (mapi_func) noopClearBufferfi,
   (mapi_func) noopClearBufferfv,
   (mapi_func) noopClearBufferiv,
   (mapi_func) noopClearBufferuiv,
   (mapi_func) noopClearColor,
   (mapi_func) noopClearColorIiEXT,
   (mapi_func) noopClearColorIuiEXT,
   (mapi_func) noopClearColorx,
   (mapi_func) noopClearColorxOES,
   (mapi_func) noopClearDepth,
   (mapi_func) noopClearDepthdNV,
   (mapi_func) noopClearDepthf,
   (mapi_func) noopClearDepthfOES,
   (mapi_func) noopClearDepthx,
   (mapi_func) noopClearDepthxOES,
   (mapi_func) noopClearIndex,
   (mapi_func) noopClearNamedBufferData,
   (mapi_func) noopClearNamedBufferDataEXT,
   (mapi_func) noopClearNamedBufferSubData,
   (mapi_func) noopClearNamedBufferSubDataEXT,
   (mapi_func) noopClearNamedFramebufferfi,
   (mapi_func) noopClearNamedFramebufferfv,
   (mapi_func) noopClearNamedFramebufferiv,
   (mapi_func) noopClearNamedFramebufferuiv,
   (mapi_func) noopClearPixelLocalStorageuiEXT,
   (mapi_func) noopClearStencil,
   (mapi_func) noopClearTexImage,
   (mapi_func) noopClearTexImageEXT,
   (mapi_func) noopClearTexSubImage,
   (mapi_func) noopClearTexSubImageEXT,
   (mapi_func) noopClientActiveTexture,
   (mapi_func) noopClientActiveTextureARB,
   (mapi_func) noopClientActiveVertexStreamATI,
   (mapi_func) noopClientAttribDefaultEXT,
   (mapi_func) noopClientWaitSemaphoreui64NVX,
   (mapi_func) noopClientWaitSync,
   (mapi_func) noopClientWaitSyncAPPLE,
   (mapi_func) noopClientWaitSyncValueuiNVX,
   (mapi_func) noopClipControl,
   (mapi_func) noopClipControlEXT,
   (mapi_func) noopClipPlane,
   (mapi_func) noopClipPlanef,
   (mapi_func) noopClipPlanefIMG,
   (mapi_func) noopClipPlanefOES,
   (mapi_func) noopClipPlanex,
   (mapi_func) noopClipPlanexIMG,
   (mapi_func) noopClipPlanexOES,
   (mapi_func) noopColor3b,
   (mapi_func) noopColor3bv,
   (mapi_func) noopColor3d,
   (mapi_func) noopColor3dv,
   (mapi_func) noopColor3f,
   (mapi_func) noopColor3fVertex3fSUN,
   (mapi_func) noopColor3fVertex3fvSUN,
   (mapi_func) noopColor3fv,
   (mapi_func) noopColor3hNV,
   (mapi_func) noopColor3hvNV,
   (mapi_func) noopColor3i,
   (mapi_func) noopColor3iv,
   (mapi_func) noopColor3s,
   (mapi_func) noopColor3sv,
   (mapi_func) noopColor3ub,
   (mapi_func) noopColor3ubv,
   (mapi_func) noopColor3ui,
   (mapi_func) noopColor3uiv,
   (mapi_func) noopColor3us,
   (mapi_func) noopColor3usv,
   (mapi_func) noopColor3x,
   (mapi_func) noopColor3xOES,
   (mapi_func) noopColor3xvOES,
   (mapi_func) noopColor4b,
   (mapi_func) noopColor4bv,
   (mapi_func) noopColor4d,
   (mapi_func) noopColor4dv,
   (mapi_func) noopColor4f,
   (mapi_func) noopColor4fNormal3fVertex3fSUN,
   (mapi_func) noopColor4fNormal3fVertex3fvSUN,
   (mapi_func) noopColor4fv,
   (mapi_func) noopColor4hNV,
   (mapi_func) noopColor4hvNV,
   (mapi_func) noopColor4i,
   (mapi_func) noopColor4iv,
   (mapi_func) noopColor4s,
   (mapi_func) noopColor4sv,
   (mapi_func) noopColor4ub,
   (mapi_func) noopColor4ubVertex2fSUN,
   (mapi_func) noopColor4ubVertex2fvSUN,
   (mapi_func) noopColor4ubVertex3fSUN,
   (mapi_func) noopColor4ubVertex3fvSUN,
   (mapi_func) noopColor4ubv,
   (mapi_func) noopColor4ui,
   (mapi_func) noopColor4uiv,
   (mapi_func) noopColor4us,
   (mapi_func) noopColor4usv,
   (mapi_func) noopColor4x,
   (mapi_func) noopColor4xOES,
   (mapi_func) noopColor4xvOES,
   (mapi_func) noopColorFormatNV,
   (mapi_func) noopColorFragmentOp1ATI,
   (mapi_func) noopColorFragmentOp2ATI,
   (mapi_func) noopColorFragmentOp3ATI,
   (mapi_func) noopColorMask,
   (mapi_func) noopColorMaskIndexedEXT,
   (mapi_func) noopColorMaski,
   (mapi_func) noopColorMaskiEXT,
   (mapi_func) noopColorMaskiOES,
   (mapi_func) noopColorMaterial,
   (mapi_func) noopColorP3ui,
   (mapi_func) noopColorP3uiv,
   (mapi_func) noopColorP4ui,
   (mapi_func) noopColorP4uiv,
   (mapi_func) noopColorPointer,
   (mapi_func) noopColorPointerEXT,
   (mapi_func) noopColorPointerListIBM,
   (mapi_func) noopColorPointervINTEL,
   (mapi_func) noopColorSubTable,
   (mapi_func) noopColorSubTableEXT,
   (mapi_func) noopColorTable,
   (mapi_func) noopColorTableEXT,
   (mapi_func) noopColorTableParameterfv,
   (mapi_func) noopColorTableParameterfvSGI,
   (mapi_func) noopColorTableParameteriv,
   (mapi_func) noopColorTableParameterivSGI,
   (mapi_func) noopColorTableSGI,
   (mapi_func) noopCombinerInputNV,
   (mapi_func) noopCombinerOutputNV,
   (mapi_func) noopCombinerParameterfNV,
   (mapi_func) noopCombinerParameterfvNV,
   (mapi_func) noopCombinerParameteriNV,
   (mapi_func) noopCombinerParameterivNV,
   (mapi_func) noopCombinerStageParameterfvNV,
   (mapi_func) noopCommandListSegmentsNV,
   (mapi_func) noopCompileCommandListNV,
   (mapi_func) noopCompileShader,
   (mapi_func) noopCompileShaderARB,
   (mapi_func) noopCompileShaderIncludeARB,
   (mapi_func) noopCompressedMultiTexImage1DEXT,
   (mapi_func) noopCompressedMultiTexImage2DEXT,
   (mapi_func) noopCompressedMultiTexImage3DEXT,
   (mapi_func) noopCompressedMultiTexSubImage1DEXT,
   (mapi_func) noopCompressedMultiTexSubImage2DEXT,
   (mapi_func) noopCompressedMultiTexSubImage3DEXT,
   (mapi_func) noopCompressedTexImage1D,
   (mapi_func) noopCompressedTexImage1DARB,
   (mapi_func) noopCompressedTexImage2D,
   (mapi_func) noopCompressedTexImage2DARB,
   (mapi_func) noopCompressedTexImage3D,
   (mapi_func) noopCompressedTexImage3DARB,
   (mapi_func) noopCompressedTexImage3DNV,
   (mapi_func) noopCompressedTexImage3DOES,
   (mapi_func) noopCompressedTexSubImage1D,
   (mapi_func) noopCompressedTexSubImage1DARB,
   (mapi_func) noopCompressedTexSubImage2D,
   (mapi_func) noopCompressedTexSubImage2DARB,
   (mapi_func) noopCompressedTexSubImage3D,
   (mapi_func) noopCompressedTexSubImage3DARB,
   (mapi_func) noopCompressedTexSubImage3DNV,
   (mapi_func) noopCompressedTexSubImage3DOES,
   (mapi_func) noopCompressedTextureImage1DEXT,
   (mapi_func) noopCompressedTextureImage2DEXT,
   (mapi_func) noopCompressedTextureImage3DEXT,
   (mapi_func) noopCompressedTextureSubImage1D,
   (mapi_func) noopCompressedTextureSubImage1DEXT,
   (mapi_func) noopCompressedTextureSubImage2D,
   (mapi_func) noopCompressedTextureSubImage2DEXT,
   (mapi_func) noopCompressedTextureSubImage3D,
   (mapi_func) noopCompressedTextureSubImage3DEXT,
   (mapi_func) noopConservativeRasterParameterfNV,
   (mapi_func) noopConservativeRasterParameteriNV,
   (mapi_func) noopConvolutionFilter1D,
   (mapi_func) noopConvolutionFilter1DEXT,
   (mapi_func) noopConvolutionFilter2D,
   (mapi_func) noopConvolutionFilter2DEXT,
   (mapi_func) noopConvolutionParameterf,
   (mapi_func) noopConvolutionParameterfEXT,
   (mapi_func) noopConvolutionParameterfv,
   (mapi_func) noopConvolutionParameterfvEXT,
   (mapi_func) noopConvolutionParameteri,
   (mapi_func) noopConvolutionParameteriEXT,
   (mapi_func) noopConvolutionParameteriv,
   (mapi_func) noopConvolutionParameterivEXT,
   (mapi_func) noopConvolutionParameterxOES,
   (mapi_func) noopConvolutionParameterxvOES,
   (mapi_func) noopCopyBufferSubData,
   (mapi_func) noopCopyBufferSubDataNV,
   (mapi_func) noopCopyColorSubTable,
   (mapi_func) noopCopyColorSubTableEXT,
   (mapi_func) noopCopyColorTable,
   (mapi_func) noopCopyColorTableSGI,
   (mapi_func) noopCopyConvolutionFilter1D,
   (mapi_func) noopCopyConvolutionFilter1DEXT,
   (mapi_func) noopCopyConvolutionFilter2D,
   (mapi_func) noopCopyConvolutionFilter2DEXT,
   (mapi_func) noopCopyImageSubData,
   (mapi_func) noopCopyImageSubDataEXT,
   (mapi_func) noopCopyImageSubDataNV,
   (mapi_func) noopCopyImageSubDataOES,
   (mapi_func) noopCopyMultiTexImage1DEXT,
   (mapi_func) noopCopyMultiTexImage2DEXT,
   (mapi_func) noopCopyMultiTexSubImage1DEXT,
   (mapi_func) noopCopyMultiTexSubImage2DEXT,
   (mapi_func) noopCopyMultiTexSubImage3DEXT,
   (mapi_func) noopCopyNamedBufferSubData,
   (mapi_func) noopCopyPathNV,
   (mapi_func) noopCopyPixels,
   (mapi_func) noopCopyTexImage1D,
   (mapi_func) noopCopyTexImage1DEXT,
   (mapi_func) noopCopyTexImage2D,
   (mapi_func) noopCopyTexImage2DEXT,
   (mapi_func) noopCopyTexSubImage1D,
   (mapi_func) noopCopyTexSubImage1DEXT,
   (mapi_func) noopCopyTexSubImage2D,
   (mapi_func) noopCopyTexSubImage2DEXT,
   (mapi_func) noopCopyTexSubImage3D,
   (mapi_func) noopCopyTexSubImage3DEXT,
   (mapi_func) noopCopyTexSubImage3DNV,
   (mapi_func) noopCopyTexSubImage3DOES,
   (mapi_func) noopCopyTextureImage1DEXT,
   (mapi_func) noopCopyTextureImage2DEXT,
   (mapi_func) noopCopyTextureLevelsAPPLE,
   (mapi_func) noopCopyTextureSubImage1D,
   (mapi_func) noopCopyTextureSubImage1DEXT,
   (mapi_func) noopCopyTextureSubImage2D,
   (mapi_func) noopCopyTextureSubImage2DEXT,
   (mapi_func) noopCopyTextureSubImage3D,
   (mapi_func) noopCopyTextureSubImage3DEXT,
   (mapi_func) noopCoverFillPathInstancedNV,
   (mapi_func) noopCoverFillPathNV,
   (mapi_func) noopCoverStrokePathInstancedNV,
   (mapi_func) noopCoverStrokePathNV,
   (mapi_func) noopCoverageMaskNV,
   (mapi_func) noopCoverageModulationNV,
   (mapi_func) noopCoverageModulationTableNV,
   (mapi_func) noopCoverageOperationNV,
   (mapi_func) noopCreateBuffers,
   (mapi_func) noopCreateCommandListsNV,
   (mapi_func) noopCreateFramebuffers,
   (mapi_func) noopCreateMemoryObjectsEXT,
   (mapi_func) noopCreatePerfQueryINTEL,
   (mapi_func) noopCreateProgram,
   (mapi_func) noopCreateProgramObjectARB,
   (mapi_func) noopCreateProgramPipelines,
   (mapi_func) noopCreateProgressFenceNVX,
   (mapi_func) noopCreateQueries,
   (mapi_func) noopCreateRenderbuffers,
   (mapi_func) noopCreateSamplers,
   (mapi_func) noopCreateShader,
   (mapi_func) noopCreateShaderObjectARB,
   (mapi_func) noopCreateShaderProgramEXT,
   (mapi_func) noopCreateShaderProgramv,
   (mapi_func) noopCreateShaderProgramvEXT,
   (mapi_func) noopCreateStatesNV,
   (mapi_func) noopCreateSyncFromCLeventARB,
   (mapi_func) noopCreateTextures,
   (mapi_func) noopCreateTransformFeedbacks,
   (mapi_func) noopCreateVertexArrays,
   (mapi_func) noopCullFace,
   (mapi_func) noopCullParameterdvEXT,
   (mapi_func) noopCullParameterfvEXT,
   (mapi_func) noopCurrentPaletteMatrixARB,
   (mapi_func) noopCurrentPaletteMatrixOES,
   (mapi_func) noopDebugMessageCallback,
   (mapi_func) noopDebugMessageCallbackAMD,
   (mapi_func) noopDebugMessageCallbackARB,
   (mapi_func) noopDebugMessageCallbackKHR,
   (mapi_func) noopDebugMessageCallbackOES,
   (mapi_func) noopDebugMessageControl,
   (mapi_func) noopDebugMessageControlARB,
   (mapi_func) noopDebugMessageControlKHR,
   (mapi_func) noopDebugMessageControlOES,
   (mapi_func) noopDebugMessageEnableAMD,
   (mapi_func) noopDebugMessageInsert,
   (mapi_func) noopDebugMessageInsertAMD,
   (mapi_func) noopDebugMessageInsertARB,
   (mapi_func) noopDebugMessageInsertKHR,
   (mapi_func) noopDebugMessageInsertOES,
   (mapi_func) noopDeformSGIX,
   (mapi_func) noopDeformationMap3dSGIX,
   (mapi_func) noopDeformationMap3fSGIX,
   (mapi_func) noopDeleteAsyncMarkersSGIX,
   (mapi_func) noopDeleteBuffers,
   (mapi_func) noopDeleteBuffersARB,
   (mapi_func) noopDeleteCommandListsNV,
   (mapi_func) noopDeleteFencesAPPLE,
   (mapi_func) noopDeleteFencesNV,
   (mapi_func) noopDeleteFragmentShaderATI,
   (mapi_func) noopDeleteFramebuffers,
   (mapi_func) noopDeleteFramebuffersEXT,
   (mapi_func) noopDeleteFramebuffersOES,
   (mapi_func) noopDeleteLists,
   (mapi_func) noopDeleteMemoryObjectsEXT,
   (mapi_func) noopDeleteNamedStringARB,
   (mapi_func) noopDeleteNamesAMD,
   (mapi_func) noopDeleteObjectARB,
   (mapi_func) noopDeleteOcclusionQueriesNV,
   (mapi_func) noopDeletePathsNV,
   (mapi_func) noopDeletePerfMonitorsAMD,
   (mapi_func) noopDeletePerfQueryINTEL,
   (mapi_func) noopDeleteProgram,
   (mapi_func) noopDeleteProgramPipelines,
   (mapi_func) noopDeleteProgramPipelinesEXT,
   (mapi_func) noopDeleteProgramsARB,
   (mapi_func) noopDeleteProgramsNV,
   (mapi_func) noopDeleteQueries,
   (mapi_func) noopDeleteQueriesARB,
   (mapi_func) noopDeleteQueriesEXT,
   (mapi_func) noopDeleteQueryResourceTagNV,
   (mapi_func) noopDeleteRenderbuffers,
   (mapi_func) noopDeleteRenderbuffersEXT,
   (mapi_func) noopDeleteRenderbuffersOES,
   (mapi_func) noopDeleteSamplers,
   (mapi_func) noopDeleteSemaphoresEXT,
   (mapi_func) noopDeleteShader,
   (mapi_func) noopDeleteStatesNV,
   (mapi_func) noopDeleteSync,
   (mapi_func) noopDeleteSyncAPPLE,
   (mapi_func) noopDeleteTextures,
   (mapi_func) noopDeleteTexturesEXT,
   (mapi_func) noopDeleteTransformFeedbacks,
   (mapi_func) noopDeleteTransformFeedbacksEXT,
   (mapi_func) noopDeleteTransformFeedbacksNV,
   (mapi_func) noopDeleteVertexArrays,
   (mapi_func) noopDeleteVertexArraysAPPLE,
   (mapi_func) noopDeleteVertexArraysOES,
   (mapi_func) noopDeleteVertexShaderEXT,
   (mapi_func) noopDepthBoundsEXT,
   (mapi_func) noopDepthBoundsdNV,
   (mapi_func) noopDepthFunc,
   (mapi_func) noopDepthMask,
   (mapi_func) noopDepthRange,
   (mapi_func) noopDepthRangeArraydvNV,
   (mapi_func) noopDepthRangeArrayfvNV,
   (mapi_func) noopDepthRangeArrayfvOES,
   (mapi_func) noopDepthRangeArrayv,
   (mapi_func) noopDepthRangeIndexed,
   (mapi_func) noopDepthRangeIndexeddNV,
   (mapi_func) noopDepthRangeIndexedfNV,
   (mapi_func) noopDepthRangeIndexedfOES,
   (mapi_func) noopDepthRangedNV,
   (mapi_func) noopDepthRangef,
   (mapi_func) noopDepthRangefOES,
   (mapi_func) noopDepthRangex,
   (mapi_func) noopDepthRangexOES,
   (mapi_func) noopDetachObjectARB,
   (mapi_func) noopDetachShader,
   (mapi_func) noopDetailTexFuncSGIS,
   (mapi_func) noopDevtoolsCorrelationIdNVX,
   (mapi_func) noopDevtoolsInvokeStreamedCallbackNVX,
   (mapi_func) noopDisable,
   (mapi_func) noopDisableClientState,
   (mapi_func) noopDisableClientStateIndexedEXT,
   (mapi_func) noopDisableClientStateiEXT,
   (mapi_func) noopDisableDriverControlQCOM,
   (mapi_func) noopDisableIndexedEXT,
   (mapi_func) noopDisableVariantClientStateEXT,
   (mapi_func) noopDisableVertexArrayAttrib,
   (mapi_func) noopDisableVertexArrayAttribEXT,
   (mapi_func) noopDisableVertexArrayEXT,
   (mapi_func) noopDisableVertexAttribAPPLE,
   (mapi_func) noopDisableVertexAttribArray,
   (mapi_func) noopDisableVertexAttribArrayARB,
   (mapi_func) noopDisablei,
   (mapi_func) noopDisableiEXT,
   (mapi_func) noopDisableiNV,
   (mapi_func) noopDisableiOES,
   (mapi_func) noopDiscardFramebufferEXT,
   (mapi_func) noopDispatchCompute,
   (mapi_func) noopDispatchComputeGroupSizeARB,
   (mapi_func) noopDispatchComputeIndirect,
   (mapi_func) noopDrawArrays,
   (mapi_func) noopDrawArraysEXT,
   (mapi_func) noopDrawArraysIndirect,
   (mapi_func) noopDrawArraysInstanced,
   (mapi_func) noopDrawArraysInstancedANGLE,
   (mapi_func) noopDrawArraysInstancedARB,
   (mapi_func) noopDrawArraysInstancedBaseInstance,
   (mapi_func) noopDrawArraysInstancedBaseInstanceEXT,
   (mapi_func) noopDrawArraysInstancedEXT,
   (mapi_func) noopDrawArraysInstancedNV,
   (mapi_func) noopDrawBuffer,
   (mapi_func) noopDrawBuffers,
   (mapi_func) noopDrawBuffersARB,
   (mapi_func) noopDrawBuffersATI,
   (mapi_func) noopDrawBuffersEXT,
   (mapi_func) noopDrawBuffersIndexedEXT,
   (mapi_func) noopDrawBuffersNV,
   (mapi_func) noopDrawCommandsAddressNV,
   (mapi_func) noopDrawCommandsNV,
   (mapi_func) noopDrawCommandsStatesAddressNV,
   (mapi_func) noopDrawCommandsStatesNV,
   (mapi_func) noopDrawElementArrayAPPLE,
   (mapi_func) noopDrawElementArrayATI,
   (mapi_func) noopDrawElements,
   (mapi_func) noopDrawElementsBaseVertex,
   (mapi_func) noopDrawElementsBaseVertexEXT,
   (mapi_func) noopDrawElementsBaseVertexOES,
   (mapi_func) noopDrawElementsIndirect,
   (mapi_func) noopDrawElementsInstanced,
   (mapi_func) noopDrawElementsInstancedANGLE,
   (mapi_func) noopDrawElementsInstancedARB,
   (mapi_func) noopDrawElementsInstancedBaseInstance,
   (mapi_func) noopDrawElementsInstancedBaseInstanceEXT,
   (mapi_func) noopDrawElementsInstancedBaseVertex,
   (mapi_func) noopDrawElementsInstancedBaseVertexBaseInstance,
   (mapi_func) noopDrawElementsInstancedBaseVertexBaseInstanceEXT,
   (mapi_func) noopDrawElementsInstancedBaseVertexEXT,
   (mapi_func) noopDrawElementsInstancedBaseVertexOES,
   (mapi_func) noopDrawElementsInstancedEXT,
   (mapi_func) noopDrawElementsInstancedNV,
   (mapi_func) noopDrawMeshArraysSUN,
   (mapi_func) noopDrawMeshNV,
   (mapi_func) noopDrawMeshTasksIndirectNV,
   (mapi_func) noopDrawMeshTasksNV,
   (mapi_func) noopDrawPixels,
   (mapi_func) noopDrawRangeElementArrayAPPLE,
   (mapi_func) noopDrawRangeElementArrayATI,
   (mapi_func) noopDrawRangeElements,
   (mapi_func) noopDrawRangeElementsBaseVertex,
   (mapi_func) noopDrawRangeElementsBaseVertexEXT,
   (mapi_func) noopDrawRangeElementsBaseVertexOES,
   (mapi_func) noopDrawRangeElementsEXT,
   (mapi_func) noopDrawTexfOES,
   (mapi_func) noopDrawTexfvOES,
   (mapi_func) noopDrawTexiOES,
   (mapi_func) noopDrawTexivOES,
   (mapi_func) noopDrawTexsOES,
   (mapi_func) noopDrawTexsvOES,
   (mapi_func) noopDrawTextureNV,
   (mapi_func) noopDrawTexxOES,
   (mapi_func) noopDrawTexxvOES,
   (mapi_func) noopDrawTransformFeedback,
   (mapi_func) noopDrawTransformFeedbackEXT,
   (mapi_func) noopDrawTransformFeedbackInstanced,
   (mapi_func) noopDrawTransformFeedbackInstancedEXT,
   (mapi_func) noopDrawTransformFeedbackNV,
   (mapi_func) noopDrawTransformFeedbackStream,
   (mapi_func) noopDrawTransformFeedbackStreamInstanced,
   (mapi_func) noopDrawVkImageNV,
   (mapi_func) noopEGLImageTargetRenderbufferStorageOES,
   (mapi_func) noopEGLImageTargetTexStorageEXT,
   (mapi_func) noopEGLImageTargetTexture2DOES,
   (mapi_func) noopEGLImageTargetTextureStorageEXT,
   (mapi_func) noopEdgeFlag,
   (mapi_func) noopEdgeFlagFormatNV,
   (mapi_func) noopEdgeFlagPointer,
   (mapi_func) noopEdgeFlagPointerEXT,
   (mapi_func) noopEdgeFlagPointerListIBM,
   (mapi_func) noopEdgeFlagv,
   (mapi_func) noopElementPointerAPPLE,
   (mapi_func) noopElementPointerATI,
   (mapi_func) noopEnable,
   (mapi_func) noopEnableClientState,
   (mapi_func) noopEnableClientStateIndexedEXT,
   (mapi_func) noopEnableClientStateiEXT,
   (mapi_func) noopEnableDriverControlQCOM,
   (mapi_func) noopEnableIndexedEXT,
   (mapi_func) noopEnableVariantClientStateEXT,
   (mapi_func) noopEnableVertexArrayAttrib,
   (mapi_func) noopEnableVertexArrayAttribEXT,
   (mapi_func) noopEnableVertexArrayEXT,
   (mapi_func) noopEnableVertexAttribAPPLE,
   (mapi_func) noopEnableVertexAttribArray,
   (mapi_func) noopEnableVertexAttribArrayARB,
   (mapi_func) noopEnablei,
   (mapi_func) noopEnableiEXT,
   (mapi_func) noopEnableiNV,
   (mapi_func) noopEnableiOES,
   (mapi_func) noopEnd,
   (mapi_func) noopEndConditionalRender,
   (mapi_func) noopEndConditionalRenderNV,
   (mapi_func) noopEndConditionalRenderNVX,
   (mapi_func) noopEndFragmentShaderATI,
   (mapi_func) noopEndList,
   (mapi_func) noopEndOcclusionQueryNV,
   (mapi_func) noopEndPerfMonitorAMD,
   (mapi_func) noopEndPerfQueryINTEL,
   (mapi_func) noopEndQuery,
   (mapi_func) noopEndQueryARB,
   (mapi_func) noopEndQueryEXT,
   (mapi_func) noopEndQueryIndexed,
   (mapi_func) noopEndTilingQCOM,
   (mapi_func) noopEndTransformFeedback,
   (mapi_func) noopEndTransformFeedbackEXT,
   (mapi_func) noopEndTransformFeedbackNV,
   (mapi_func) noopEndVertexShaderEXT,
   (mapi_func) noopEndVideoCaptureNV,
   (mapi_func) noopEvalCoord1d,
   (mapi_func) noopEvalCoord1dv,
   (mapi_func) noopEvalCoord1f,
   (mapi_func) noopEvalCoord1fv,
   (mapi_func) noopEvalCoord1xOES,
   (mapi_func) noopEvalCoord1xvOES,
   (mapi_func) noopEvalCoord2d,
   (mapi_func) noopEvalCoord2dv,
   (mapi_func) noopEvalCoord2f,
   (mapi_func) noopEvalCoord2fv,
   (mapi_func) noopEvalCoord2xOES,
   (mapi_func) noopEvalCoord2xvOES,
   (mapi_func) noopEvalMapsNV,
   (mapi_func) noopEvalMesh1,
   (mapi_func) noopEvalMesh2,
   (mapi_func) noopEvalPoint1,
   (mapi_func) noopEvalPoint2,
   (mapi_func) noopEvaluateDepthValuesARB,
   (mapi_func) noopExecuteProgramNV,
   (mapi_func) noopExtGetBufferPointervQCOM,
   (mapi_func) noopExtGetBuffersQCOM,
   (mapi_func) noopExtGetFramebuffersQCOM,
   (mapi_func) noopExtGetProgramBinarySourceQCOM,
   (mapi_func) noopExtGetProgramsQCOM,
   (mapi_func) noopExtGetRenderbuffersQCOM,
   (mapi_func) noopExtGetShadersQCOM,
   (mapi_func) noopExtGetTexLevelParameterivQCOM,
   (mapi_func) noopExtGetTexSubImageQCOM,
   (mapi_func) noopExtGetTexturesQCOM,
   (mapi_func) noopExtIsProgramBinaryQCOM,
   (mapi_func) noopExtTexObjectStateOverrideiQCOM,
   (mapi_func) noopExtractComponentEXT,
   (mapi_func) noopFeedbackBuffer,
   (mapi_func) noopFeedbackBufferxOES,
   (mapi_func) noopFenceSync,
   (mapi_func) noopFenceSyncAPPLE,
   (mapi_func) noopFenceValueuiNVX,
   (mapi_func) noopFinalCombinerInputNV,
   (mapi_func) noopFinish,
   (mapi_func) noopFinishAsyncSGIX,
   (mapi_func) noopFinishFenceAPPLE,
   (mapi_func) noopFinishFenceNV,
   (mapi_func) noopFinishObjectAPPLE,
   (mapi_func) noopFinishTextureSUNX,
   (mapi_func) noopFlush,
   (mapi_func) noopFlushMappedBufferRange,
   (mapi_func) noopFlushMappedBufferRangeAPPLE,
   (mapi_func) noopFlushMappedBufferRangeEXT,
   (mapi_func) noopFlushMappedNamedBufferRange,
   (mapi_func) noopFlushMappedNamedBufferRangeEXT,
   (mapi_func) noopFlushPixelDataRangeNV,
   (mapi_func) noopFlushRasterSGIX,
   (mapi_func) noopFlushStaticDataIBM,
   (mapi_func) noopFlushVertexArrayRangeAPPLE,
   (mapi_func) noopFlushVertexArrayRangeNV,
   (mapi_func) noopFogCoordFormatNV,
   (mapi_func) noopFogCoordPointer,
   (mapi_func) noopFogCoordPointerEXT,
   (mapi_func) noopFogCoordPointerListIBM,
   (mapi_func) noopFogCoordd,
   (mapi_func) noopFogCoorddEXT,
   (mapi_func) noopFogCoorddv,
   (mapi_func) noopFogCoorddvEXT,
   (mapi_func) noopFogCoordf,
   (mapi_func) noopFogCoordfEXT,
   (mapi_func) noopFogCoordfv,
   (mapi_func) noopFogCoordfvEXT,
   (mapi_func) noopFogCoordhNV,
   (mapi_func) noopFogCoordhvNV,
   (mapi_func) noopFogFuncSGIS,
   (mapi_func) noopFogf,
   (mapi_func) noopFogfv,
   (mapi_func) noopFogi,
   (mapi_func) noopFogiv,
   (mapi_func) noopFogx,
   (mapi_func) noopFogxOES,
   (mapi_func) noopFogxv,
   (mapi_func) noopFogxvOES,
   (mapi_func) noopFragmentColorMaterialSGIX,
   (mapi_func) noopFragmentCoverageColorNV,
   (mapi_func) noopFragmentLightModelfSGIX,
   (mapi_func) noopFragmentLightModelfvSGIX,
   (mapi_func) noopFragmentLightModeliSGIX,
   (mapi_func) noopFragmentLightModelivSGIX,
   (mapi_func) noopFragmentLightfSGIX,
   (mapi_func) noopFragmentLightfvSGIX,
   (mapi_func) noopFragmentLightiSGIX,
   (mapi_func) noopFragmentLightivSGIX,
   (mapi_func) noopFragmentMaterialfSGIX,
   (mapi_func) noopFragmentMaterialfvSGIX,
   (mapi_func) noopFragmentMaterialiSGIX,
   (mapi_func) noopFragmentMaterialivSGIX,
   (mapi_func) noopFrameTerminatorGREMEDY,
   (mapi_func) noopFrameZoomSGIX,
   (mapi_func) noopFramebufferDrawBufferEXT,
   (mapi_func) noopFramebufferDrawBuffersEXT,
   (mapi_func) noopFramebufferFetchBarrierEXT,
   (mapi_func) noopFramebufferFetchBarrierQCOM,
   (mapi_func) noopFramebufferFoveationConfigQCOM,
   (mapi_func) noopFramebufferFoveationParametersQCOM,
   (mapi_func) noopFramebufferParameteri,
   (mapi_func) noopFramebufferParameteriMESA,
   (mapi_func) noopFramebufferPixelLocalStorageSizeEXT,
   (mapi_func) noopFramebufferReadBufferEXT,
   (mapi_func) noopFramebufferRenderbuffer,
   (mapi_func) noopFramebufferRenderbufferEXT,
   (mapi_func) noopFramebufferRenderbufferOES,
   (mapi_func) noopFramebufferSampleLocationsfvARB,
   (mapi_func) noopFramebufferSampleLocationsfvNV,
   (mapi_func) noopFramebufferSamplePositionsfvAMD,
   (mapi_func) noopFramebufferTexture,
   (mapi_func) noopFramebufferTexture1D,
   (mapi_func) noopFramebufferTexture1DEXT,
   (mapi_func) noopFramebufferTexture2D,
   (mapi_func) noopFramebufferTexture2DDownsampleIMG,
   (mapi_func) noopFramebufferTexture2DEXT,
   (mapi_func) noopFramebufferTexture2DMultisampleEXT,
   (mapi_func) noopFramebufferTexture2DMultisampleIMG,
   (mapi_func) noopFramebufferTexture2DOES,
   (mapi_func) noopFramebufferTexture3D,
   (mapi_func) noopFramebufferTexture3DEXT,
   (mapi_func) noopFramebufferTexture3DOES,
   (mapi_func) noopFramebufferTextureARB,
   (mapi_func) noopFramebufferTextureEXT,
   (mapi_func) noopFramebufferTextureFaceARB,
   (mapi_func) noopFramebufferTextureFaceEXT,
   (mapi_func) noopFramebufferTextureLayer,
   (mapi_func) noopFramebufferTextureLayerARB,
   (mapi_func) noopFramebufferTextureLayerDownsampleIMG,
   (mapi_func) noopFramebufferTextureLayerEXT,
   (mapi_func) noopFramebufferTextureLayerNV,
   (mapi_func) noopFramebufferTextureMultisampleMultiviewOVR,
   (mapi_func) noopFramebufferTextureMultiviewOVR,
   (mapi_func) noopFramebufferTextureOES,
   (mapi_func) noopFreeObjectBufferATI,
   (mapi_func) noopFrontFace,
   (mapi_func) noopFrustum,
   (mapi_func) noopFrustumf,
   (mapi_func) noopFrustumfOES,
   (mapi_func) noopFrustumx,
   (mapi_func) noopFrustumxOES,
   (mapi_func) noopGenAsyncMarkersSGIX,
   (mapi_func) noopGenBuffers,
   (mapi_func) noopGenBuffersARB,
   (mapi_func) noopGenFencesAPPLE,
   (mapi_func) noopGenFencesNV,
   (mapi_func) noopGenFragmentShadersATI,
   (mapi_func) noopGenFramebuffers,
   (mapi_func) noopGenFramebuffersEXT,
   (mapi_func) noopGenFramebuffersOES,
   (mapi_func) noopGenLists,
   (mapi_func) noopGenNamesAMD,
   (mapi_func) noopGenOcclusionQueriesNV,
   (mapi_func) noopGenPathsNV,
   (mapi_func) noopGenPerfMonitorsAMD,
   (mapi_func) noopGenProgramPipelines,
   (mapi_func) noopGenProgramPipelinesEXT,
   (mapi_func) noopGenProgramsARB,
   (mapi_func) noopGenProgramsNV,
   (mapi_func) noopGenQueries,
   (mapi_func) noopGenQueriesARB,
   (mapi_func) noopGenQueriesEXT,
   (mapi_func) noopGenQueryResourceTagNV,
   (mapi_func) noopGenRenderbuffers,
   (mapi_func) noopGenRenderbuffersEXT,
   (mapi_func) noopGenRenderbuffersOES,
   (mapi_func) noopGenSamplers,
   (mapi_func) noopGenSemaphoresEXT,
   (mapi_func) noopGenSymbolsEXT,
   (mapi_func) noopGenTextures,
   (mapi_func) noopGenTexturesEXT,
   (mapi_func) noopGenTransformFeedbacks,
   (mapi_func) noopGenTransformFeedbacksEXT,
   (mapi_func) noopGenTransformFeedbacksNV,
   (mapi_func) noopGenVertexArrays,
   (mapi_func) noopGenVertexArraysAPPLE,
   (mapi_func) noopGenVertexArraysOES,
   (mapi_func) noopGenVertexShadersEXT,
   (mapi_func) noopGenerateMipmap,
   (mapi_func) noopGenerateMipmapEXT,
   (mapi_func) noopGenerateMipmapOES,
   (mapi_func) noopGenerateMultiTexMipmapEXT,
   (mapi_func) noopGenerateTextureMipmap,
   (mapi_func) noopGenerateTextureMipmapEXT,
   (mapi_func) noopGetActiveAtomicCounterBufferiv,
   (mapi_func) noopGetActiveAttrib,
   (mapi_func) noopGetActiveAttribARB,
   (mapi_func) noopGetActiveSubroutineName,
   (mapi_func) noopGetActiveSubroutineUniformName,
   (mapi_func) noopGetActiveSubroutineUniformiv,
   (mapi_func) noopGetActiveUniform,
   (mapi_func) noopGetActiveUniformARB,
   (mapi_func) noopGetActiveUniformBlockName,
   (mapi_func) noopGetActiveUniformBlockiv,
   (mapi_func) noopGetActiveUniformName,
   (mapi_func) noopGetActiveUniformsiv,
   (mapi_func) noopGetActiveVaryingNV,
   (mapi_func) noopGetArrayObjectfvATI,
   (mapi_func) noopGetArrayObjectivATI,
   (mapi_func) noopGetAttachedObjectsARB,
   (mapi_func) noopGetAttachedShaders,
   (mapi_func) noopGetAttribLocation,
   (mapi_func) noopGetAttribLocationARB,
   (mapi_func) noopGetBooleanIndexedvEXT,
   (mapi_func) noopGetBooleani_v,
   (mapi_func) noopGetBooleanv,
   (mapi_func) noopGetBufferParameteri64v,
   (mapi_func) noopGetBufferParameteriv,
   (mapi_func) noopGetBufferParameterivARB,
   (mapi_func) noopGetBufferParameterui64vNV,
   (mapi_func) noopGetBufferPointerv,
   (mapi_func) noopGetBufferPointervARB,
   (mapi_func) noopGetBufferPointervOES,
   (mapi_func) noopGetBufferSubData,
   (mapi_func) noopGetBufferSubDataARB,
   (mapi_func) noopGetClipPlane,
   (mapi_func) noopGetClipPlanef,
   (mapi_func) noopGetClipPlanefOES,
   (mapi_func) noopGetClipPlanex,
   (mapi_func) noopGetClipPlanexOES,
   (mapi_func) noopGetColorTable,
   (mapi_func) noopGetColorTableEXT,
   (mapi_func) noopGetColorTableParameterfv,
   (mapi_func) noopGetColorTableParameterfvEXT,
   (mapi_func) noopGetColorTableParameterfvSGI,
   (mapi_func) noopGetColorTableParameteriv,
   (mapi_func) noopGetColorTableParameterivEXT,
   (mapi_func) noopGetColorTableParameterivSGI,
   (mapi_func) noopGetColorTableSGI,
   (mapi_func) noopGetCombinerInputParameterfvNV,
   (mapi_func) noopGetCombinerInputParameterivNV,
   (mapi_func) noopGetCombinerOutputParameterfvNV,
   (mapi_func) noopGetCombinerOutputParameterivNV,
   (mapi_func) noopGetCombinerStageParameterfvNV,
   (mapi_func) noopGetCommandHeaderNV,
   (mapi_func) noopGetCompressedMultiTexImageEXT,
   (mapi_func) noopGetCompressedTexImage,
   (mapi_func) noopGetCompressedTexImageARB,
   (mapi_func) noopGetCompressedTexImageNV,
   (mapi_func) noopGetCompressedTextureImage,
   (mapi_func) noopGetCompressedTextureImageEXT,
   (mapi_func) noopGetCompressedTextureSubImage,
   (mapi_func) noopGetConvolutionFilter,
   (mapi_func) noopGetConvolutionFilterEXT,
   (mapi_func) noopGetConvolutionParameterfv,
   (mapi_func) noopGetConvolutionParameterfvEXT,
   (mapi_func) noopGetConvolutionParameteriv,
   (mapi_func) noopGetConvolutionParameterivEXT,
   (mapi_func) noopGetConvolutionParameterxvOES,
   (mapi_func) noopGetCoverageModulationTableNV,
   (mapi_func) noopGetDebugMessageLog,
   (mapi_func) noopGetDebugMessageLogAMD,
   (mapi_func) noopGetDebugMessageLogARB,
   (mapi_func) noopGetDebugMessageLogKHR,
   (mapi_func) noopGetDebugMessageLogOES,
   (mapi_func) noopGetDetailTexFuncSGIS,
   (mapi_func) noopGetDoubleIndexedvEXT,
   (mapi_func) noopGetDoublei_v,
   (mapi_func) noopGetDoublei_vEXT,
   (mapi_func) noopGetDoublev,
   (mapi_func) noopGetDriverControlStringQCOM,
   (mapi_func) noopGetDriverControlsQCOM,
   (mapi_func) noopGetError,
   (mapi_func) noopGetFenceivNV,
   (mapi_func) noopGetFinalCombinerInputParameterfvNV,
   (mapi_func) noopGetFinalCombinerInputParameterivNV,
   (mapi_func) noopGetFirstPerfQueryIdINTEL,
   (mapi_func) noopGetFixedv,
   (mapi_func) noopGetFixedvOES,
   (mapi_func) noopGetFloatIndexedvEXT,
   (mapi_func) noopGetFloati_v,
   (mapi_func) noopGetFloati_vEXT,
   (mapi_func) noopGetFloati_vNV,
   (mapi_func) noopGetFloati_vOES,
   (mapi_func) noopGetFloatv,
   (mapi_func) noopGetFogFuncSGIS,
   (mapi_func) noopGetFragDataIndex,
   (mapi_func) noopGetFragDataIndexEXT,
   (mapi_func) noopGetFragDataLocation,
   (mapi_func) noopGetFragDataLocationEXT,
   (mapi_func) noopGetFragmentLightfvSGIX,
   (mapi_func) noopGetFragmentLightivSGIX,
   (mapi_func) noopGetFragmentMaterialfvSGIX,
   (mapi_func) noopGetFragmentMaterialivSGIX,
   (mapi_func) noopGetFramebufferAttachmentParameteriv,
   (mapi_func) noopGetFramebufferAttachmentParameterivEXT,
   (mapi_func) noopGetFramebufferAttachmentParameterivOES,
   (mapi_func) noopGetFramebufferParameterfvAMD,
   (mapi_func) noopGetFramebufferParameteriv,
   (mapi_func) noopGetFramebufferParameterivEXT,
   (mapi_func) noopGetFramebufferParameterivMESA,
   (mapi_func) noopGetFramebufferPixelLocalStorageSizeEXT,
   (mapi_func) noopGetGraphicsResetStatus,
   (mapi_func) noopGetGraphicsResetStatusARB,
   (mapi_func) noopGetGraphicsResetStatusEXT,
   (mapi_func) noopGetGraphicsResetStatusKHR,
   (mapi_func) noopGetHandleARB,
   (mapi_func) noopGetHistogram,
   (mapi_func) noopGetHistogramEXT,
   (mapi_func) noopGetHistogramParameterfv,
   (mapi_func) noopGetHistogramParameterfvEXT,
   (mapi_func) noopGetHistogramParameteriv,
   (mapi_func) noopGetHistogramParameterivEXT,
   (mapi_func) noopGetHistogramParameterxvOES,
   (mapi_func) noopGetImageHandleARB,
   (mapi_func) noopGetImageHandleNV,
   (mapi_func) noopGetImageTransformParameterfvHP,
   (mapi_func) noopGetImageTransformParameterivHP,
   (mapi_func) noopGetInfoLogARB,
   (mapi_func) noopGetInstrumentsSGIX,
   (mapi_func) noopGetInteger64i_v,
   (mapi_func) noopGetInteger64v,
   (mapi_func) noopGetInteger64vAPPLE,
   (mapi_func) noopGetIntegerIndexedvEXT,
   (mapi_func) noopGetIntegeri_v,
   (mapi_func) noopGetIntegeri_vEXT,
   (mapi_func) noopGetIntegerui64i_vNV,
   (mapi_func) noopGetIntegerui64vNV,
   (mapi_func) noopGetIntegerv,
   (mapi_func) noopGetInternalformatSampleivNV,
   (mapi_func) noopGetInternalformati64v,
   (mapi_func) noopGetInternalformativ,
   (mapi_func) noopGetInvariantBooleanvEXT,
   (mapi_func) noopGetInvariantFloatvEXT,
   (mapi_func) noopGetInvariantIntegervEXT,
   (mapi_func) noopGetLightfv,
   (mapi_func) noopGetLightiv,
   (mapi_func) noopGetLightxOES,
   (mapi_func) noopGetLightxv,
   (mapi_func) noopGetLightxvOES,
   (mapi_func) noopGetListParameterfvSGIX,
   (mapi_func) noopGetListParameterivSGIX,
   (mapi_func) noopGetLocalConstantBooleanvEXT,
   (mapi_func) noopGetLocalConstantFloatvEXT,
   (mapi_func) noopGetLocalConstantIntegervEXT,
   (mapi_func) noopGetMapAttribParameterfvNV,
   (mapi_func) noopGetMapAttribParameterivNV,
   (mapi_func) noopGetMapControlPointsNV,
   (mapi_func) noopGetMapParameterfvNV,
   (mapi_func) noopGetMapParameterivNV,
   (mapi_func) noopGetMapdv,
   (mapi_func) noopGetMapfv,
   (mapi_func) noopGetMapiv,
   (mapi_func) noopGetMapxvOES,
   (mapi_func) noopGetMaterialfv,
   (mapi_func) noopGetMaterialiv,
   (mapi_func) noopGetMaterialxOES,
   (mapi_func) noopGetMaterialxv,
   (mapi_func) noopGetMaterialxvOES,
   (mapi_func) noopGetMemoryObjectDetachedResourcesuivNV,
   (mapi_func) noopGetMemoryObjectParameterivEXT,
   (mapi_func) noopGetMinmax,
   (mapi_func) noopGetMinmaxEXT,
   (mapi_func) noopGetMinmaxParameterfv,
   (mapi_func) noopGetMinmaxParameterfvEXT,
   (mapi_func) noopGetMinmaxParameteriv,
   (mapi_func) noopGetMinmaxParameterivEXT,
   (mapi_func) noopGetMultiTexEnvfvEXT,
   (mapi_func) noopGetMultiTexEnvivEXT,
   (mapi_func) noopGetMultiTexGendvEXT,
   (mapi_func) noopGetMultiTexGenfvEXT,
   (mapi_func) noopGetMultiTexGenivEXT,
   (mapi_func) noopGetMultiTexImageEXT,
   (mapi_func) noopGetMultiTexLevelParameterfvEXT,
   (mapi_func) noopGetMultiTexLevelParameterivEXT,
   (mapi_func) noopGetMultiTexParameterIivEXT,
   (mapi_func) noopGetMultiTexParameterIuivEXT,
   (mapi_func) noopGetMultiTexParameterfvEXT,
   (mapi_func) noopGetMultiTexParameterivEXT,
   (mapi_func) noopGetMultisamplefv,
   (mapi_func) noopGetMultisamplefvNV,
   (mapi_func) noopGetNamedBufferParameteri64v,
   (mapi_func) noopGetNamedBufferParameteri64vEXT,
   (mapi_func) noopGetNamedBufferParameteriv,
   (mapi_func) noopGetNamedBufferParameterivEXT,
   (mapi_func) noopGetNamedBufferParameterui64vNV,
   (mapi_func) noopGetNamedBufferPointerv,
   (mapi_func) noopGetNamedBufferPointervEXT,
   (mapi_func) noopGetNamedBufferSubData,
   (mapi_func) noopGetNamedBufferSubDataEXT,
   (mapi_func) noopGetNamedFramebufferAttachmentParameteriv,
   (mapi_func) noopGetNamedFramebufferAttachmentParameterivEXT,
   (mapi_func) noopGetNamedFramebufferParameterfvAMD,
   (mapi_func) noopGetNamedFramebufferParameteriv,
   (mapi_func) noopGetNamedFramebufferParameterivEXT,
   (mapi_func) noopGetNamedProgramLocalParameterIivEXT,
   (mapi_func) noopGetNamedProgramLocalParameterIuivEXT,
   (mapi_func) noopGetNamedProgramLocalParameterdvEXT,
   (mapi_func) noopGetNamedProgramLocalParameterfvEXT,
   (mapi_func) noopGetNamedProgramStringEXT,
   (mapi_func) noopGetNamedProgramivEXT,
   (mapi_func) noopGetNamedRenderbufferParameteriv,
   (mapi_func) noopGetNamedRenderbufferParameterivEXT,
   (mapi_func) noopGetNamedStringARB,
   (mapi_func) noopGetNamedStringivARB,
   (mapi_func) noopGetNextPerfQueryIdINTEL,
   (mapi_func) noopGetObjectBufferfvATI,
   (mapi_func) noopGetObjectBufferivATI,
   (mapi_func) noopGetObjectLabel,
   (mapi_func) noopGetObjectLabelEXT,
   (mapi_func) noopGetObjectLabelKHR,
   (mapi_func) noopGetObjectLabelOES,
   (mapi_func) noopGetObjectParameterfvARB,
   (mapi_func) noopGetObjectParameterivAPPLE,
   (mapi_func) noopGetObjectParameterivARB,
   (mapi_func) noopGetObjectPtrLabel,
   (mapi_func) noopGetObjectPtrLabelKHR,
   (mapi_func) noopGetObjectPtrLabelOES,
   (mapi_func) noopGetOcclusionQueryivNV,
   (mapi_func) noopGetOcclusionQueryuivNV,
   (mapi_func) noopGetPathColorGenfvNV,
   (mapi_func) noopGetPathColorGenivNV,
   (mapi_func) noopGetPathCommandsNV,
   (mapi_func) noopGetPathCoordsNV,
   (mapi_func) noopGetPathDashArrayNV,
   (mapi_func) noopGetPathLengthNV,
   (mapi_func) noopGetPathMetricRangeNV,
   (mapi_func) noopGetPathMetricsNV,
   (mapi_func) noopGetPathParameterfvNV,
   (mapi_func) noopGetPathParameterivNV,
   (mapi_func) noopGetPathSpacingNV,
   (mapi_func) noopGetPathTexGenfvNV,
   (mapi_func) noopGetPathTexGenivNV,
   (mapi_func) noopGetPerfCounterInfoINTEL,
   (mapi_func) noopGetPerfMonitorCounterDataAMD,
   (mapi_func) noopGetPerfMonitorCounterInfoAMD,
   (mapi_func) noopGetPerfMonitorCounterStringAMD,
   (mapi_func) noopGetPerfMonitorCountersAMD,
   (mapi_func) noopGetPerfMonitorGroupStringAMD,
   (mapi_func) noopGetPerfMonitorGroupsAMD,
   (mapi_func) noopGetPerfQueryDataINTEL,
   (mapi_func) noopGetPerfQueryIdByNameINTEL,
   (mapi_func) noopGetPerfQueryInfoINTEL,
   (mapi_func) noopGetPixelMapfv,
   (mapi_func) noopGetPixelMapuiv,
   (mapi_func) noopGetPixelMapusv,
   (mapi_func) noopGetPixelMapxv,
   (mapi_func) noopGetPixelTexGenParameterfvSGIS,
   (mapi_func) noopGetPixelTexGenParameterivSGIS,
   (mapi_func) noopGetPixelTransformParameterfvEXT,
   (mapi_func) noopGetPixelTransformParameterivEXT,
   (mapi_func) noopGetPointerIndexedvEXT,
   (mapi_func) noopGetPointeri_vEXT,
   (mapi_func) noopGetPointerv,
   (mapi_func) noopGetPointervEXT,
   (mapi_func) noopGetPointervKHR,
   (mapi_func) noopGetPointervOES,
   (mapi_func) noopGetPolygonStipple,
   (mapi_func) noopGetProgramBinary,
   (mapi_func) noopGetProgramBinaryOES,
   (mapi_func) noopGetProgramEnvParameterIivNV,
   (mapi_func) noopGetProgramEnvParameterIuivNV,
   (mapi_func) noopGetProgramEnvParameterdvARB,
   (mapi_func) noopGetProgramEnvParameterfvARB,
   (mapi_func) noopGetProgramInfoLog,
   (mapi_func) noopGetProgramInterfaceiv,
   (mapi_func) noopGetProgramLocalParameterIivNV,
   (mapi_func) noopGetProgramLocalParameterIuivNV,
   (mapi_func) noopGetProgramLocalParameterdvARB,
   (mapi_func) noopGetProgramLocalParameterfvARB,
   (mapi_func) noopGetProgramNamedParameterdvNV,
   (mapi_func) noopGetProgramNamedParameterfvNV,
   (mapi_func) noopGetProgramParameterdvNV,
   (mapi_func) noopGetProgramParameterfvNV,
   (mapi_func) noopGetProgramPipelineInfoLog,
   (mapi_func) noopGetProgramPipelineInfoLogEXT,
   (mapi_func) noopGetProgramPipelineiv,
   (mapi_func) noopGetProgramPipelineivEXT,
   (mapi_func) noopGetProgramResourceIndex,
   (mapi_func) noopGetProgramResourceLocation,
   (mapi_func) noopGetProgramResourceLocationIndex,
   (mapi_func) noopGetProgramResourceLocationIndexEXT,
   (mapi_func) noopGetProgramResourceName,
   (mapi_func) noopGetProgramResourcefvNV,
   (mapi_func) noopGetProgramResourceiv,
   (mapi_func) noopGetProgramStageiv,
   (mapi_func) noopGetProgramStringARB,
   (mapi_func) noopGetProgramStringNV,
   (mapi_func) noopGetProgramSubroutineParameteruivNV,
   (mapi_func) noopGetProgramiv,
   (mapi_func) noopGetProgramivARB,
   (mapi_func) noopGetProgramivNV,
   (mapi_func) noopGetQueryBufferObjecti64v,
   (mapi_func) noopGetQueryBufferObjectiv,
   (mapi_func) noopGetQueryBufferObjectui64v,
   (mapi_func) noopGetQueryBufferObjectuiv,
   (mapi_func) noopGetQueryIndexediv,
   (mapi_func) noopGetQueryObjecti64v,
   (mapi_func) noopGetQueryObjecti64vEXT,
   (mapi_func) noopGetQueryObjectiv,
   (mapi_func) noopGetQueryObjectivARB,
   (mapi_func) noopGetQueryObjectivEXT,
   (mapi_func) noopGetQueryObjectui64v,
   (mapi_func) noopGetQueryObjectui64vEXT,
   (mapi_func) noopGetQueryObjectui64vNV,
   (mapi_func) noopGetQueryObjectuiv,
   (mapi_func) noopGetQueryObjectuivARB,
   (mapi_func) noopGetQueryObjectuivEXT,
   (mapi_func) noopGetQueryiv,
   (mapi_func) noopGetQueryivARB,
   (mapi_func) noopGetQueryivEXT,
   (mapi_func) noopGetRenderbufferParameteriv,
   (mapi_func) noopGetRenderbufferParameterivEXT,
   (mapi_func) noopGetRenderbufferParameterivOES,
   (mapi_func) noopGetSamplerParameterIiv,
   (mapi_func) noopGetSamplerParameterIivEXT,
   (mapi_func) noopGetSamplerParameterIivOES,
   (mapi_func) noopGetSamplerParameterIuiv,
   (mapi_func) noopGetSamplerParameterIuivEXT,
   (mapi_func) noopGetSamplerParameterIuivOES,
   (mapi_func) noopGetSamplerParameterfv,
   (mapi_func) noopGetSamplerParameteriv,
   (mapi_func) noopGetSemaphoreParameterui64vEXT,
   (mapi_func) noopGetSeparableFilter,
   (mapi_func) noopGetSeparableFilterEXT,
   (mapi_func) noopGetShaderInfoLog,
   (mapi_func) noopGetShaderPrecisionFormat,
   (mapi_func) noopGetShaderSource,
   (mapi_func) noopGetShaderSourceARB,
   (mapi_func) noopGetShaderiv,
   (mapi_func) noopGetShadingRateImagePaletteNV,
   (mapi_func) noopGetShadingRateSampleLocationivNV,
   (mapi_func) noopGetSharpenTexFuncSGIS,
   (mapi_func) noopGetStageIndexNV,
   (mapi_func) noopGetString,
   (mapi_func) noopGetStringi,
   (mapi_func) noopGetSubroutineIndex,
   (mapi_func) noopGetSubroutineUniformLocation,
   (mapi_func) noopGetSynciv,
   (mapi_func) noopGetSyncivAPPLE,
   (mapi_func) noopGetSyncv64NVX,
   (mapi_func) noopGetTexBumpParameterfvATI,
   (mapi_func) noopGetTexBumpParameterivATI,
   (mapi_func) noopGetTexEnvfv,
   (mapi_func) noopGetTexEnviv,
   (mapi_func) noopGetTexEnvxv,
   (mapi_func) noopGetTexEnvxvOES,
   (mapi_func) noopGetTexFilterFuncSGIS,
   (mapi_func) noopGetTexGendv,
   (mapi_func) noopGetTexGenfv,
   (mapi_func) noopGetTexGenfvOES,
   (mapi_func) noopGetTexGeniv,
   (mapi_func) noopGetTexGenivOES,
   (mapi_func) noopGetTexGenxvOES,
   (mapi_func) noopGetTexImage,
   (mapi_func) noopGetTexImageNV,
   (mapi_func) noopGetTexLevelParameterfv,
   (mapi_func) noopGetTexLevelParameterfvNV,
   (mapi_func) noopGetTexLevelParameteriv,
   (mapi_func) noopGetTexLevelParameterivNV,
   (mapi_func) noopGetTexLevelParameterxvOES,
   (mapi_func) noopGetTexParameterIiv,
   (mapi_func) noopGetTexParameterIivEXT,
   (mapi_func) noopGetTexParameterIivOES,
   (mapi_func) noopGetTexParameterIuiv,
   (mapi_func) noopGetTexParameterIuivEXT,
   (mapi_func) noopGetTexParameterIuivOES,
   (mapi_func) noopGetTexParameterPointervAPPLE,
   (mapi_func) noopGetTexParameterfv,
   (mapi_func) noopGetTexParameteriv,
   (mapi_func) noopGetTexParameterxv,
   (mapi_func) noopGetTexParameterxvOES,
   (mapi_func) noopGetTextureHandleARB,
   (mapi_func) noopGetTextureHandleIMG,
   (mapi_func) noopGetTextureHandleNV,
   (mapi_func) noopGetTextureImage,
   (mapi_func) noopGetTextureImageEXT,
   (mapi_func) noopGetTextureLevelParameterfv,
   (mapi_func) noopGetTextureLevelParameterfvEXT,
   (mapi_func) noopGetTextureLevelParameteriv,
   (mapi_func) noopGetTextureLevelParameterivEXT,
   (mapi_func) noopGetTextureParameterIiv,
   (mapi_func) noopGetTextureParameterIivEXT,
   (mapi_func) noopGetTextureParameterIuiv,
   (mapi_func) noopGetTextureParameterIuivEXT,
   (mapi_func) noopGetTextureParameterfv,
   (mapi_func) noopGetTextureParameterfvEXT,
   (mapi_func) noopGetTextureParameteriv,
   (mapi_func) noopGetTextureParameterivEXT,
   (mapi_func) noopGetTextureSamplerHandleARB,
   (mapi_func) noopGetTextureSamplerHandleIMG,
   (mapi_func) noopGetTextureSamplerHandleNV,
   (mapi_func) noopGetTextureSubImage,
   (mapi_func) noopGetTrackMatrixivNV,
   (mapi_func) noopGetTransformFeedbackVarying,
   (mapi_func) noopGetTransformFeedbackVaryingEXT,
   (mapi_func) noopGetTransformFeedbackVaryingNV,
   (mapi_func) noopGetTransformFeedbacki64_v,
   (mapi_func) noopGetTransformFeedbacki_v,
   (mapi_func) noopGetTransformFeedbackiv,
   (mapi_func) noopGetTranslatedShaderSourceANGLE,
   (mapi_func) noopGetUniformBlockIndex,
   (mapi_func) noopGetUniformBufferSizeEXT,
   (mapi_func) noopGetUniformIndices,
   (mapi_func) noopGetUniformLocation,
   (mapi_func) noopGetUniformLocationARB,
   (mapi_func) noopGetUniformOffsetEXT,
   (mapi_func) noopGetUniformSubroutineuiv,
   (mapi_func) noopGetUniformdv,
   (mapi_func) noopGetUniformfv,
   (mapi_func) noopGetUniformfvARB,
   (mapi_func) noopGetUniformi64vARB,
   (mapi_func) noopGetUniformi64vNV,
   (mapi_func) noopGetUniformiv,
   (mapi_func) noopGetUniformivARB,
   (mapi_func) noopGetUniformui64vARB,
   (mapi_func) noopGetUniformui64vNV,
   (mapi_func) noopGetUniformuiv,
   (mapi_func) noopGetUniformuivEXT,
   (mapi_func) noopGetUnsignedBytei_vEXT,
   (mapi_func) noopGetUnsignedBytevEXT,
   (mapi_func) noopGetVariantArrayObjectfvATI,
   (mapi_func) noopGetVariantArrayObjectivATI,
   (mapi_func) noopGetVariantBooleanvEXT,
   (mapi_func) noopGetVariantFloatvEXT,
   (mapi_func) noopGetVariantIntegervEXT,
   (mapi_func) noopGetVariantPointervEXT,
   (mapi_func) noopGetVaryingLocationNV,
   (mapi_func) noopGetVertexArrayIndexed64iv,
   (mapi_func) noopGetVertexArrayIndexediv,
   (mapi_func) noopGetVertexArrayIntegeri_vEXT,
   (mapi_func) noopGetVertexArrayIntegervEXT,
   (mapi_func) noopGetVertexArrayPointeri_vEXT,
   (mapi_func) noopGetVertexArrayPointervEXT,
   (mapi_func) noopGetVertexArrayiv,
   (mapi_func) noopGetVertexAttribArrayObjectfvATI,
   (mapi_func) noopGetVertexAttribArrayObjectivATI,
   (mapi_func) noopGetVertexAttribIiv,
   (mapi_func) noopGetVertexAttribIivEXT,
   (mapi_func) noopGetVertexAttribIuiv,
   (mapi_func) noopGetVertexAttribIuivEXT,
   (mapi_func) noopGetVertexAttribLdv,
   (mapi_func) noopGetVertexAttribLdvEXT,
   (mapi_func) noopGetVertexAttribLi64vNV,
   (mapi_func) noopGetVertexAttribLui64vARB,
   (mapi_func) noopGetVertexAttribLui64vNV,
   (mapi_func) noopGetVertexAttribPointerv,
   (mapi_func) noopGetVertexAttribPointervARB,
   (mapi_func) noopGetVertexAttribPointervNV,
   (mapi_func) noopGetVertexAttribdv,
   (mapi_func) noopGetVertexAttribdvARB,
   (mapi_func) noopGetVertexAttribdvNV,
   (mapi_func) noopGetVertexAttribfv,
   (mapi_func) noopGetVertexAttribfvARB,
   (mapi_func) noopGetVertexAttribfvNV,
   (mapi_func) noopGetVertexAttribiv,
   (mapi_func) noopGetVertexAttribivARB,
   (mapi_func) noopGetVertexAttribivNV,
   (mapi_func) noopGetVideoCaptureANCStreamivNVX,
   (mapi_func) noopGetVideoCaptureStreamdvNV,
   (mapi_func) noopGetVideoCaptureStreamfvNV,
   (mapi_func) noopGetVideoCaptureStreamivNV,
   (mapi_func) noopGetVideoCaptureivNV,
   (mapi_func) noopGetVideoi64vNV,
   (mapi_func) noopGetVideoivNV,
   (mapi_func) noopGetVideoui64vNV,
   (mapi_func) noopGetVideouivNV,
   (mapi_func) noopGetVkProcAddrNV,
   (mapi_func) noopGetnColorTable,
   (mapi_func) noopGetnColorTableARB,
   (mapi_func) noopGetnCompressedTexImage,
   (mapi_func) noopGetnCompressedTexImageARB,
   (mapi_func) noopGetnConvolutionFilter,
   (mapi_func) noopGetnConvolutionFilterARB,
   (mapi_func) noopGetnHistogram,
   (mapi_func) noopGetnHistogramARB,
   (mapi_func) noopGetnMapdv,
   (mapi_func) noopGetnMapdvARB,
   (mapi_func) noopGetnMapfv,
   (mapi_func) noopGetnMapfvARB,
   (mapi_func) noopGetnMapiv,
   (mapi_func) noopGetnMapivARB,
   (mapi_func) noopGetnMinmax,
   (mapi_func) noopGetnMinmaxARB,
   (mapi_func) noopGetnPixelMapfv,
   (mapi_func) noopGetnPixelMapfvARB,
   (mapi_func) noopGetnPixelMapuiv,
   (mapi_func) noopGetnPixelMapuivARB,
   (mapi_func) noopGetnPixelMapusv,
   (mapi_func) noopGetnPixelMapusvARB,
   (mapi_func) noopGetnPolygonStipple,
   (mapi_func) noopGetnPolygonStippleARB,
   (mapi_func) noopGetnSeparableFilter,
   (mapi_func) noopGetnSeparableFilterARB,
   (mapi_func) noopGetnTexImage,
   (mapi_func) noopGetnTexImageARB,
   (mapi_func) noopGetnUniformdv,
   (mapi_func) noopGetnUniformdvARB,
   (mapi_func) noopGetnUniformfv,
   (mapi_func) noopGetnUniformfvARB,
   (mapi_func) noopGetnUniformfvEXT,
   (mapi_func) noopGetnUniformfvKHR,
   (mapi_func) noopGetnUniformi64vARB,
   (mapi_func) noopGetnUniformiv,
   (mapi_func) noopGetnUniformivARB,
   (mapi_func) noopGetnUniformivEXT,
   (mapi_func) noopGetnUniformivKHR,
   (mapi_func) noopGetnUniformui64vARB,
   (mapi_func) noopGetnUniformuiv,
   (mapi_func) noopGetnUniformuivARB,
   (mapi_func) noopGetnUniformuivKHR,
   (mapi_func) noopGlobalAlphaFactorbSUN,
   (mapi_func) noopGlobalAlphaFactordSUN,
   (mapi_func) noopGlobalAlphaFactorfSUN,
   (mapi_func) noopGlobalAlphaFactoriSUN,
   (mapi_func) noopGlobalAlphaFactorsSUN,
   (mapi_func) noopGlobalAlphaFactorubSUN,
   (mapi_func) noopGlobalAlphaFactoruiSUN,
   (mapi_func) noopGlobalAlphaFactorusSUN,
   (mapi_func) noopGpuSyncAcquireNVX,
   (mapi_func) noopGpuSyncCreateNVX,
   (mapi_func) noopGpuSyncDestroyNVX,
   (mapi_func) noopGpuSyncReleaseNVX,
   (mapi_func) noopHint,
   (mapi_func) noopHintPGI,
   (mapi_func) noopHistogram,
   (mapi_func) noopHistogramEXT,
   (mapi_func) noopIglooInterfaceSGIX,
   (mapi_func) noopImageTransformParameterfHP,
   (mapi_func) noopImageTransformParameterfvHP,
   (mapi_func) noopImageTransformParameteriHP,
   (mapi_func) noopImageTransformParameterivHP,
   (mapi_func) noopImportMemoryFdEXT,
   (mapi_func) noopImportMemoryWin32HandleEXT,
   (mapi_func) noopImportMemoryWin32NameEXT,
   (mapi_func) noopImportSemaphoreFdEXT,
   (mapi_func) noopImportSemaphoreWin32HandleEXT,
   (mapi_func) noopImportSemaphoreWin32NameEXT,
   (mapi_func) noopImportSyncEXT,
   (mapi_func) noopIndexFormatNV,
   (mapi_func) noopIndexFuncEXT,
   (mapi_func) noopIndexMask,
   (mapi_func) noopIndexMaterialEXT,
   (mapi_func) noopIndexPointer,
   (mapi_func) noopIndexPointerEXT,
   (mapi_func) noopIndexPointerListIBM,
   (mapi_func) noopIndexd,
   (mapi_func) noopIndexdv,
   (mapi_func) noopIndexf,
   (mapi_func) noopIndexfv,
   (mapi_func) noopIndexi,
   (mapi_func) noopIndexiv,
   (mapi_func) noopIndexs,
   (mapi_func) noopIndexsv,
   (mapi_func) noopIndexub,
   (mapi_func) noopIndexubv,
   (mapi_func) noopIndexxOES,
   (mapi_func) noopIndexxvOES,
   (mapi_func) noopInitNames,
   (mapi_func) noopInsertComponentEXT,
   (mapi_func) noopInsertEventMarkerEXT,
   (mapi_func) noopInstrumentsBufferSGIX,
   (mapi_func) noopInterleavedArrays,
   (mapi_func) noopInterpolatePathsNV,
   (mapi_func) noopInvalidateBufferData,
   (mapi_func) noopInvalidateBufferSubData,
   (mapi_func) noopInvalidateFramebuffer,
   (mapi_func) noopInvalidateNamedFramebufferData,
   (mapi_func) noopInvalidateNamedFramebufferSubData,
   (mapi_func) noopInvalidateSubFramebuffer,
   (mapi_func) noopInvalidateTexImage,
   (mapi_func) noopInvalidateTexSubImage,
   (mapi_func) noopIsAsyncMarkerSGIX,
   (mapi_func) noopIsBuffer,
   (mapi_func) noopIsBufferARB,
   (mapi_func) noopIsBufferResidentNV,
   (mapi_func) noopIsCommandListNV,
   (mapi_func) noopIsEnabled,
   (mapi_func) noopIsEnabledIndexedEXT,
   (mapi_func) noopIsEnabledi,
   (mapi_func) noopIsEnablediEXT,
   (mapi_func) noopIsEnablediNV,
   (mapi_func) noopIsEnablediOES,
   (mapi_func) noopIsFenceAPPLE,
   (mapi_func) noopIsFenceNV,
   (mapi_func) noopIsFramebuffer,
   (mapi_func) noopIsFramebufferEXT,
   (mapi_func) noopIsFramebufferOES,
   (mapi_func) noopIsImageHandleResidentARB,
   (mapi_func) noopIsImageHandleResidentNV,
   (mapi_func) noopIsList,
   (mapi_func) noopIsMemoryObjectEXT,
   (mapi_func) noopIsNameAMD,
   (mapi_func) noopIsNamedBufferResidentNV,
   (mapi_func) noopIsNamedStringARB,
   (mapi_func) noopIsObjectBufferATI,
   (mapi_func) noopIsOcclusionQueryNV,
   (mapi_func) noopIsPathNV,
   (mapi_func) noopIsPointInFillPathNV,
   (mapi_func) noopIsPointInStrokePathNV,
   (mapi_func) noopIsProgram,
   (mapi_func) noopIsProgramARB,
   (mapi_func) noopIsProgramNV,
   (mapi_func) noopIsProgramPipeline,
   (mapi_func) noopIsProgramPipelineEXT,
   (mapi_func) noopIsQuery,
   (mapi_func) noopIsQueryARB,
   (mapi_func) noopIsQueryEXT,
   (mapi_func) noopIsRenderbuffer,
   (mapi_func) noopIsRenderbufferEXT,
   (mapi_func) noopIsRenderbufferOES,
   (mapi_func) noopIsSampler,
   (mapi_func) noopIsSemaphoreEXT,
   (mapi_func) noopIsShader,
   (mapi_func) noopIsStateNV,
   (mapi_func) noopIsSync,
   (mapi_func) noopIsSyncAPPLE,
   (mapi_func) noopIsTexture,
   (mapi_func) noopIsTextureEXT,
   (mapi_func) noopIsTextureHandleResidentARB,
   (mapi_func) noopIsTextureHandleResidentNV,
   (mapi_func) noopIsTransformFeedback,
   (mapi_func) noopIsTransformFeedbackEXT,
   (mapi_func) noopIsTransformFeedbackNV,
   (mapi_func) noopIsVariantEnabledEXT,
   (mapi_func) noopIsVertexArray,
   (mapi_func) noopIsVertexArrayAPPLE,
   (mapi_func) noopIsVertexArrayOES,
   (mapi_func) noopIsVertexAttribEnabledAPPLE,
   (mapi_func) noopLGPUCopyImageSubDataNVX,
   (mapi_func) noopLGPUInterlockNVX,
   (mapi_func) noopLGPUNamedBufferSubDataNVX,
   (mapi_func) noopLabelObjectEXT,
   (mapi_func) noopLightEnviSGIX,
   (mapi_func) noopLightModelf,
   (mapi_func) noopLightModelfv,
   (mapi_func) noopLightModeli,
   (mapi_func) noopLightModeliv,
   (mapi_func) noopLightModelx,
   (mapi_func) noopLightModelxOES,
   (mapi_func) noopLightModelxv,
   (mapi_func) noopLightModelxvOES,
   (mapi_func) noopLightf,
   (mapi_func) noopLightfv,
   (mapi_func) noopLighti,
   (mapi_func) noopLightiv,
   (mapi_func) noopLightx,
   (mapi_func) noopLightxOES,
   (mapi_func) noopLightxv,
   (mapi_func) noopLightxvOES,
   (mapi_func) noopLineStipple,
   (mapi_func) noopLineWidth,
   (mapi_func) noopLineWidthx,
   (mapi_func) noopLineWidthxOES,
   (mapi_func) noopLinkProgram,
   (mapi_func) noopLinkProgramARB,
   (mapi_func) noopListBase,
   (mapi_func) noopListDrawCommandsStatesClientNV,
   (mapi_func) noopListParameterfSGIX,
   (mapi_func) noopListParameterfvSGIX,
   (mapi_func) noopListParameteriSGIX,
   (mapi_func) noopListParameterivSGIX,
   (mapi_func) noopLoadIdentity,
   (mapi_func) noopLoadIdentityDeformationMapSGIX,
   (mapi_func) noopLoadMatrixd,
   (mapi_func) noopLoadMatrixf,
   (mapi_func) noopLoadMatrixx,
   (mapi_func) noopLoadMatrixxOES,
   (mapi_func) noopLoadName,
   (mapi_func) noopLoadPaletteFromModelViewMatrixOES,
   (mapi_func) noopLoadProgramNV,
   (mapi_func) noopLoadTransformEXT,
   (mapi_func) noopLoadTransposeMatrixd,
   (mapi_func) noopLoadTransposeMatrixdARB,
   (mapi_func) noopLoadTransposeMatrixf,
   (mapi_func) noopLoadTransposeMatrixfARB,
   (mapi_func) noopLoadTransposeMatrixxOES,
   (mapi_func) noopLockArraysEXT,
   (mapi_func) noopLogicOp,
   (mapi_func) noopMakeBufferNonResidentNV,
   (mapi_func) noopMakeBufferResidentNV,
   (mapi_func) noopMakeImageHandleNonResidentARB,
   (mapi_func) noopMakeImageHandleNonResidentNV,
   (mapi_func) noopMakeImageHandleResidentARB,
   (mapi_func) noopMakeImageHandleResidentNV,
   (mapi_func) noopMakeNamedBufferNonResidentNV,
   (mapi_func) noopMakeNamedBufferResidentNV,
   (mapi_func) noopMakeTextureHandleNonResidentARB,
   (mapi_func) noopMakeTextureHandleNonResidentNV,
   (mapi_func) noopMakeTextureHandleResidentARB,
   (mapi_func) noopMakeTextureHandleResidentNV,
   (mapi_func) noopMap1d,
   (mapi_func) noopMap1f,
   (mapi_func) noopMap1xOES,
   (mapi_func) noopMap2d,
   (mapi_func) noopMap2f,
   (mapi_func) noopMap2xOES,
   (mapi_func) noopMapBuffer,
   (mapi_func) noopMapBufferARB,
   (mapi_func) noopMapBufferOES,
   (mapi_func) noopMapBufferRange,
   (mapi_func) noopMapBufferRangeEXT,
   (mapi_func) noopMapControlPointsNV,
   (mapi_func) noopMapGrid1d,
   (mapi_func) noopMapGrid1f,
   (mapi_func) noopMapGrid1xOES,
   (mapi_func) noopMapGrid2d,
   (mapi_func) noopMapGrid2f,
   (mapi_func) noopMapGrid2xOES,
   (mapi_func) noopMapNamedBuffer,
   (mapi_func) noopMapNamedBufferEXT,
   (mapi_func) noopMapNamedBufferRange,
   (mapi_func) noopMapNamedBufferRangeEXT,
   (mapi_func) noopMapObjectBufferATI,
   (mapi_func) noopMapParameterfvNV,
   (mapi_func) noopMapParameterivNV,
   (mapi_func) noopMapTexture2DINTEL,
   (mapi_func) noopMapVertexAttrib1dAPPLE,
   (mapi_func) noopMapVertexAttrib1fAPPLE,
   (mapi_func) noopMapVertexAttrib2dAPPLE,
   (mapi_func) noopMapVertexAttrib2fAPPLE,
   (mapi_func) noopMaterialf,
   (mapi_func) noopMaterialfv,
   (mapi_func) noopMateriali,
   (mapi_func) noopMaterialiv,
   (mapi_func) noopMaterialx,
   (mapi_func) noopMaterialxOES,
   (mapi_func) noopMaterialxv,
   (mapi_func) noopMaterialxvOES,
   (mapi_func) noopMatrixFrustumEXT,
   (mapi_func) noopMatrixIndexPointerARB,
   (mapi_func) noopMatrixIndexPointerOES,
   (mapi_func) noopMatrixIndexubvARB,
   (mapi_func) noopMatrixIndexuivARB,
   (mapi_func) noopMatrixIndexusvARB,
   (mapi_func) noopMatrixLoad3x2fNV,
   (mapi_func) noopMatrixLoad3x3fNV,
   (mapi_func) noopMatrixLoadIdentityEXT,
   (mapi_func) noopMatrixLoadTranspose3x3fNV,
   (mapi_func) noopMatrixLoadTransposedEXT,
   (mapi_func) noopMatrixLoadTransposefEXT,
   (mapi_func) noopMatrixLoaddEXT,
   (mapi_func) noopMatrixLoadfEXT,
   (mapi_func) noopMatrixMode,
   (mapi_func) noopMatrixMult3x2fNV,
   (mapi_func) noopMatrixMult3x3fNV,
   (mapi_func) noopMatrixMultTranspose3x3fNV,
   (mapi_func) noopMatrixMultTransposedEXT,
   (mapi_func) noopMatrixMultTransposefEXT,
   (mapi_func) noopMatrixMultdEXT,
   (mapi_func) noopMatrixMultfEXT,
   (mapi_func) noopMatrixOrthoEXT,
   (mapi_func) noopMatrixPopEXT,
   (mapi_func) noopMatrixPushEXT,
   (mapi_func) noopMatrixRotatedEXT,
   (mapi_func) noopMatrixRotatefEXT,
   (mapi_func) noopMatrixScaledEXT,
   (mapi_func) noopMatrixScalefEXT,
   (mapi_func) noopMatrixTranslatedEXT,
   (mapi_func) noopMatrixTranslatefEXT,
   (mapi_func) noopMaxShaderCompilerThreadsARB,
   (mapi_func) noopMaxShaderCompilerThreadsKHR,
   (mapi_func) noopMemoryBarrier,
   (mapi_func) noopMemoryBarrierByRegion,
   (mapi_func) noopMemoryBarrierEXT,
   (mapi_func) noopMemoryObjectParameterivEXT,
   (mapi_func) noopMinSampleShading,
   (mapi_func) noopMinSampleShadingARB,
   (mapi_func) noopMinSampleShadingOES,
   (mapi_func) noopMinmax,
   (mapi_func) noopMinmaxEXT,
   (mapi_func) noopMultMatrixd,
   (mapi_func) noopMultMatrixf,
   (mapi_func) noopMultMatrixx,
   (mapi_func) noopMultMatrixxOES,
   (mapi_func) noopMultTransformEXT,
   (mapi_func) noopMultTransposeMatrixd,
   (mapi_func) noopMultTransposeMatrixdARB,
   (mapi_func) noopMultTransposeMatrixf,
   (mapi_func) noopMultTransposeMatrixfARB,
   (mapi_func) noopMultTransposeMatrixxOES,
   (mapi_func) noopMultiDrawArrays,
   (mapi_func) noopMultiDrawArraysEXT,
   (mapi_func) noopMultiDrawArraysIndirect,
   (mapi_func) noopMultiDrawArraysIndirectAMD,
   (mapi_func) noopMultiDrawArraysIndirectBindlessCountNV,
   (mapi_func) noopMultiDrawArraysIndirectBindlessNV,
   (mapi_func) noopMultiDrawArraysIndirectCount,
   (mapi_func) noopMultiDrawArraysIndirectCountARB,
   (mapi_func) noopMultiDrawArraysIndirectEXT,
   (mapi_func) noopMultiDrawElementArrayAPPLE,
   (mapi_func) noopMultiDrawElements,
   (mapi_func) noopMultiDrawElementsBaseVertex,
   (mapi_func) noopMultiDrawElementsBaseVertexEXT,
   (mapi_func) noopMultiDrawElementsEXT,
   (mapi_func) noopMultiDrawElementsIndirect,
   (mapi_func) noopMultiDrawElementsIndirectAMD,
   (mapi_func) noopMultiDrawElementsIndirectBindlessCountNV,
   (mapi_func) noopMultiDrawElementsIndirectBindlessNV,
   (mapi_func) noopMultiDrawElementsIndirectCount,
   (mapi_func) noopMultiDrawElementsIndirectCountARB,
   (mapi_func) noopMultiDrawElementsIndirectEXT,
   (mapi_func) noopMultiDrawMeshTasksIndirectCountNV,
   (mapi_func) noopMultiDrawMeshTasksIndirectNV,
   (mapi_func) noopMultiDrawRangeElementArrayAPPLE,
   (mapi_func) noopMultiModeDrawArraysIBM,
   (mapi_func) noopMultiModeDrawElementsIBM,
   (mapi_func) noopMultiTexBufferEXT,
   (mapi_func) noopMultiTexCoord1bOES,
   (mapi_func) noopMultiTexCoord1bvOES,
   (mapi_func) noopMultiTexCoord1d,
   (mapi_func) noopMultiTexCoord1dARB,
   (mapi_func) noopMultiTexCoord1dv,
   (mapi_func) noopMultiTexCoord1dvARB,
   (mapi_func) noopMultiTexCoord1f,
   (mapi_func) noopMultiTexCoord1fARB,
   (mapi_func) noopMultiTexCoord1fv,
   (mapi_func) noopMultiTexCoord1fvARB,
   (mapi_func) noopMultiTexCoord1hNV,
   (mapi_func) noopMultiTexCoord1hvNV,
   (mapi_func) noopMultiTexCoord1i,
   (mapi_func) noopMultiTexCoord1iARB,
   (mapi_func) noopMultiTexCoord1iv,
   (mapi_func) noopMultiTexCoord1ivARB,
   (mapi_func) noopMultiTexCoord1s,
   (mapi_func) noopMultiTexCoord1sARB,
   (mapi_func) noopMultiTexCoord1sv,
   (mapi_func) noopMultiTexCoord1svARB,
   (mapi_func) noopMultiTexCoord1x,
   (mapi_func) noopMultiTexCoord1xOES,
   (mapi_func) noopMultiTexCoord1xv,
   (mapi_func) noopMultiTexCoord1xvOES,
   (mapi_func) noopMultiTexCoord2bOES,
   (mapi_func) noopMultiTexCoord2bvOES,
   (mapi_func) noopMultiTexCoord2d,
   (mapi_func) noopMultiTexCoord2dARB,
   (mapi_func) noopMultiTexCoord2dv,
   (mapi_func) noopMultiTexCoord2dvARB,
   (mapi_func) noopMultiTexCoord2f,
   (mapi_func) noopMultiTexCoord2fARB,
   (mapi_func) noopMultiTexCoord2fv,
   (mapi_func) noopMultiTexCoord2fvARB,
   (mapi_func) noopMultiTexCoord2hNV,
   (mapi_func) noopMultiTexCoord2hvNV,
   (mapi_func) noopMultiTexCoord2i,
   (mapi_func) noopMultiTexCoord2iARB,
   (mapi_func) noopMultiTexCoord2iv,
   (mapi_func) noopMultiTexCoord2ivARB,
   (mapi_func) noopMultiTexCoord2s,
   (mapi_func) noopMultiTexCoord2sARB,
   (mapi_func) noopMultiTexCoord2sv,
   (mapi_func) noopMultiTexCoord2svARB,
   (mapi_func) noopMultiTexCoord2x,
   (mapi_func) noopMultiTexCoord2xOES,
   (mapi_func) noopMultiTexCoord2xv,
   (mapi_func) noopMultiTexCoord2xvOES,
   (mapi_func) noopMultiTexCoord3bOES,
   (mapi_func) noopMultiTexCoord3bvOES,
   (mapi_func) noopMultiTexCoord3d,
   (mapi_func) noopMultiTexCoord3dARB,
   (mapi_func) noopMultiTexCoord3dv,
   (mapi_func) noopMultiTexCoord3dvARB,
   (mapi_func) noopMultiTexCoord3f,
   (mapi_func) noopMultiTexCoord3fARB,
   (mapi_func) noopMultiTexCoord3fv,
   (mapi_func) noopMultiTexCoord3fvARB,
   (mapi_func) noopMultiTexCoord3hNV,
   (mapi_func) noopMultiTexCoord3hvNV,
   (mapi_func) noopMultiTexCoord3i,
   (mapi_func) noopMultiTexCoord3iARB,
   (mapi_func) noopMultiTexCoord3iv,
   (mapi_func) noopMultiTexCoord3ivARB,
   (mapi_func) noopMultiTexCoord3s,
   (mapi_func) noopMultiTexCoord3sARB,
   (mapi_func) noopMultiTexCoord3sv,
   (mapi_func) noopMultiTexCoord3svARB,
   (mapi_func) noopMultiTexCoord3x,
   (mapi_func) noopMultiTexCoord3xOES,
   (mapi_func) noopMultiTexCoord3xv,
   (mapi_func) noopMultiTexCoord3xvOES,
   (mapi_func) noopMultiTexCoord4bOES,
   (mapi_func) noopMultiTexCoord4bvOES,
   (mapi_func) noopMultiTexCoord4d,
   (mapi_func) noopMultiTexCoord4dARB,
   (mapi_func) noopMultiTexCoord4dv,
   (mapi_func) noopMultiTexCoord4dvARB,
   (mapi_func) noopMultiTexCoord4f,
   (mapi_func) noopMultiTexCoord4fARB,
   (mapi_func) noopMultiTexCoord4fv,
   (mapi_func) noopMultiTexCoord4fvARB,
   (mapi_func) noopMultiTexCoord4hNV,
   (mapi_func) noopMultiTexCoord4hvNV,
   (mapi_func) noopMultiTexCoord4i,
   (mapi_func) noopMultiTexCoord4iARB,
   (mapi_func) noopMultiTexCoord4iv,
   (mapi_func) noopMultiTexCoord4ivARB,
   (mapi_func) noopMultiTexCoord4s,
   (mapi_func) noopMultiTexCoord4sARB,
   (mapi_func) noopMultiTexCoord4sv,
   (mapi_func) noopMultiTexCoord4svARB,
   (mapi_func) noopMultiTexCoord4x,
   (mapi_func) noopMultiTexCoord4xOES,
   (mapi_func) noopMultiTexCoord4xv,
   (mapi_func) noopMultiTexCoord4xvOES,
   (mapi_func) noopMultiTexCoordP1ui,
   (mapi_func) noopMultiTexCoordP1uiv,
   (mapi_func) noopMultiTexCoordP2ui,
   (mapi_func) noopMultiTexCoordP2uiv,
   (mapi_func) noopMultiTexCoordP3ui,
   (mapi_func) noopMultiTexCoordP3uiv,
   (mapi_func) noopMultiTexCoordP4ui,
   (mapi_func) noopMultiTexCoordP4uiv,
   (mapi_func) noopMultiTexCoordPointerEXT,
   (mapi_func) noopMultiTexEnvfEXT,
   (mapi_func) noopMultiTexEnvfvEXT,
   (mapi_func) noopMultiTexEnviEXT,
   (mapi_func) noopMultiTexEnvivEXT,
   (mapi_func) noopMultiTexGendEXT,
   (mapi_func) noopMultiTexGendvEXT,
   (mapi_func) noopMultiTexGenfEXT,
   (mapi_func) noopMultiTexGenfvEXT,
   (mapi_func) noopMultiTexGeniEXT,
   (mapi_func) noopMultiTexGenivEXT,
   (mapi_func) noopMultiTexImage1DEXT,
   (mapi_func) noopMultiTexImage2DEXT,
   (mapi_func) noopMultiTexImage3DEXT,
   (mapi_func) noopMultiTexParameterIivEXT,
   (mapi_func) noopMultiTexParameterIuivEXT,
   (mapi_func) noopMultiTexParameterfEXT,
   (mapi_func) noopMultiTexParameterfvEXT,
   (mapi_func) noopMultiTexParameteriEXT,
   (mapi_func) noopMultiTexParameterivEXT,
   (mapi_func) noopMultiTexRenderbufferEXT,
   (mapi_func) noopMultiTexSubImage1DEXT,
   (mapi_func) noopMultiTexSubImage2DEXT,
   (mapi_func) noopMultiTexSubImage3DEXT,
   (mapi_func) noopMulticastBarrierNV,
   (mapi_func) noopMulticastBlitFramebufferNV,
   (mapi_func) noopMulticastBufferSubDataNV,
   (mapi_func) noopMulticastCopyBufferSubDataNV,
   (mapi_func) noopMulticastCopyImageSubDataNV,
   (mapi_func) noopMulticastFramebufferSampleLocationsfvNV,
   (mapi_func) noopMulticastGetQueryObjecti64vNV,
   (mapi_func) noopMulticastGetQueryObjectivNV,
   (mapi_func) noopMulticastGetQueryObjectui64vNV,
   (mapi_func) noopMulticastGetQueryObjectuivNV,
   (mapi_func) noopMulticastScissorArrayvNVX,
   (mapi_func) noopMulticastViewportArrayvNVX,
   (mapi_func) noopMulticastViewportPositionWScaleNVX,
   (mapi_func) noopMulticastWaitSyncNV,
   (mapi_func) noopNVENCInterOpFunctionNVX,
   (mapi_func) noopNamedBufferAttachMemoryNV,
   (mapi_func) noopNamedBufferData,
   (mapi_func) noopNamedBufferDataEXT,
   (mapi_func) noopNamedBufferPageCommitmentARB,
   (mapi_func) noopNamedBufferPageCommitmentEXT,
   (mapi_func) noopNamedBufferStorage,
   (mapi_func) noopNamedBufferStorageEXT,
   (mapi_func) noopNamedBufferStorageExternalEXT,
   (mapi_func) noopNamedBufferStorageMemEXT,
   (mapi_func) noopNamedBufferSubData,
   (mapi_func) noopNamedBufferSubDataEXT,
   (mapi_func) noopNamedCopyBufferSubDataEXT,
   (mapi_func) noopNamedFramebufferDrawBuffer,
   (mapi_func) noopNamedFramebufferDrawBuffers,
   (mapi_func) noopNamedFramebufferParameteri,
   (mapi_func) noopNamedFramebufferParameteriEXT,
   (mapi_func) noopNamedFramebufferReadBuffer,
   (mapi_func) noopNamedFramebufferRenderbuffer,
   (mapi_func) noopNamedFramebufferRenderbufferEXT,
   (mapi_func) noopNamedFramebufferSampleLocationsfvARB,
   (mapi_func) noopNamedFramebufferSampleLocationsfvNV,
   (mapi_func) noopNamedFramebufferSamplePositionsfvAMD,
   (mapi_func) noopNamedFramebufferTexture,
   (mapi_func) noopNamedFramebufferTexture1DEXT,
   (mapi_func) noopNamedFramebufferTexture2DEXT,
   (mapi_func) noopNamedFramebufferTexture3DEXT,
   (mapi_func) noopNamedFramebufferTextureEXT,
   (mapi_func) noopNamedFramebufferTextureFaceEXT,
   (mapi_func) noopNamedFramebufferTextureLayer,
   (mapi_func) noopNamedFramebufferTextureLayerEXT,
   (mapi_func) noopNamedProgramLocalParameter4dEXT,
   (mapi_func) noopNamedProgramLocalParameter4dvEXT,
   (mapi_func) noopNamedProgramLocalParameter4fEXT,
   (mapi_func) noopNamedProgramLocalParameter4fvEXT,
   (mapi_func) noopNamedProgramLocalParameterI4iEXT,
   (mapi_func) noopNamedProgramLocalParameterI4ivEXT,
   (mapi_func) noopNamedProgramLocalParameterI4uiEXT,
   (mapi_func) noopNamedProgramLocalParameterI4uivEXT,
   (mapi_func) noopNamedProgramLocalParameters4fvEXT,
   (mapi_func) noopNamedProgramLocalParametersI4ivEXT,
   (mapi_func) noopNamedProgramLocalParametersI4uivEXT,
   (mapi_func) noopNamedProgramStringEXT,
   (mapi_func) noopNamedRenderbufferStorage,
   (mapi_func) noopNamedRenderbufferStorageEXT,
   (mapi_func) noopNamedRenderbufferStorageMultisample,
   (mapi_func) noopNamedRenderbufferStorageMultisampleAdvancedAMD,
   (mapi_func) noopNamedRenderbufferStorageMultisampleCoverageEXT,
   (mapi_func) noopNamedRenderbufferStorageMultisampleEXT,
   (mapi_func) noopNamedStringARB,
   (mapi_func) noopNewList,
   (mapi_func) noopNewObjectBufferATI,
   (mapi_func) noopNormal3b,
   (mapi_func) noopNormal3bv,
   (mapi_func) noopNormal3d,
   (mapi_func) noopNormal3dv,
   (mapi_func) noopNormal3f,
   (mapi_func) noopNormal3fVertex3fSUN,
   (mapi_func) noopNormal3fVertex3fvSUN,
   (mapi_func) noopNormal3fv,
   (mapi_func) noopNormal3hNV,
   (mapi_func) noopNormal3hvNV,
   (mapi_func) noopNormal3i,
   (mapi_func) noopNormal3iv,
   (mapi_func) noopNormal3s,
   (mapi_func) noopNormal3sv,
   (mapi_func) noopNormal3x,
   (mapi_func) noopNormal3xOES,
   (mapi_func) noopNormal3xvOES,
   (mapi_func) noopNormalFormatNV,
   (mapi_func) noopNormalP3ui,
   (mapi_func) noopNormalP3uiv,
   (mapi_func) noopNormalPointer,
   (mapi_func) noopNormalPointerEXT,
   (mapi_func) noopNormalPointerListIBM,
   (mapi_func) noopNormalPointervINTEL,
   (mapi_func) noopNormalStream3bATI,
   (mapi_func) noopNormalStream3bvATI,
   (mapi_func) noopNormalStream3dATI,
   (mapi_func) noopNormalStream3dvATI,
   (mapi_func) noopNormalStream3fATI,
   (mapi_func) noopNormalStream3fvATI,
   (mapi_func) noopNormalStream3iATI,
   (mapi_func) noopNormalStream3ivATI,
   (mapi_func) noopNormalStream3sATI,
   (mapi_func) noopNormalStream3svATI,
   (mapi_func) noopObjectLabel,
   (mapi_func) noopObjectLabelKHR,
   (mapi_func) noopObjectLabelOES,
   (mapi_func) noopObjectPtrLabel,
   (mapi_func) noopObjectPtrLabelKHR,
   (mapi_func) noopObjectPtrLabelOES,
   (mapi_func) noopObjectPurgeableAPPLE,
   (mapi_func) noopObjectUnpurgeableAPPLE,
   (mapi_func) noopOrtho,
   (mapi_func) noopOrthof,
   (mapi_func) noopOrthofOES,
   (mapi_func) noopOrthox,
   (mapi_func) noopOrthoxOES,
   (mapi_func) noopPNTrianglesfATI,
   (mapi_func) noopPNTrianglesiATI,
   (mapi_func) noopPassTexCoordATI,
   (mapi_func) noopPassThrough,
   (mapi_func) noopPassThroughxOES,
   (mapi_func) noopPatchParameterfv,
   (mapi_func) noopPatchParameterfvEXT,
   (mapi_func) noopPatchParameterfvNV,
   (mapi_func) noopPatchParameteri,
   (mapi_func) noopPatchParameteriEXT,
   (mapi_func) noopPatchParameteriNV,
   (mapi_func) noopPatchParameteriOES,
   (mapi_func) noopPathColorGenNV,
   (mapi_func) noopPathCommandsNV,
   (mapi_func) noopPathCoordsNV,
   (mapi_func) noopPathCoverDepthFuncNV,
   (mapi_func) noopPathDashArrayNV,
   (mapi_func) noopPathFogGenNV,
   (mapi_func) noopPathGlyphIndexArrayNV,
   (mapi_func) noopPathGlyphIndexRangeNV,
   (mapi_func) noopPathGlyphRangeNV,
   (mapi_func) noopPathGlyphsNV,
   (mapi_func) noopPathMemoryGlyphIndexArrayNV,
   (mapi_func) noopPathParameterfNV,
   (mapi_func) noopPathParameterfvNV,
   (mapi_func) noopPathParameteriNV,
   (mapi_func) noopPathParameterivNV,
   (mapi_func) noopPathStencilDepthOffsetNV,
   (mapi_func) noopPathStencilFuncNV,
   (mapi_func) noopPathStringNV,
   (mapi_func) noopPathSubCommandsNV,
   (mapi_func) noopPathSubCoordsNV,
   (mapi_func) noopPathTexGenNV,
   (mapi_func) noopPauseTransformFeedback,
   (mapi_func) noopPauseTransformFeedbackEXT,
   (mapi_func) noopPauseTransformFeedbackNV,
   (mapi_func) noopPixelDataRangeNV,
   (mapi_func) noopPixelMapfv,
   (mapi_func) noopPixelMapuiv,
   (mapi_func) noopPixelMapusv,
   (mapi_func) noopPixelMapx,
   (mapi_func) noopPixelStoref,
   (mapi_func) noopPixelStorei,
   (mapi_func) noopPixelStorex,
   (mapi_func) noopPixelTexGenParameterfSGIS,
   (mapi_func) noopPixelTexGenParameterfvSGIS,
   (mapi_func) noopPixelTexGenParameteriSGIS,
   (mapi_func) noopPixelTexGenParameterivSGIS,
   (mapi_func) noopPixelTexGenSGIX,
   (mapi_func) noopPixelTransferf,
   (mapi_func) noopPixelTransferi,
   (mapi_func) noopPixelTransferxOES,
   (mapi_func) noopPixelTransformParameterfEXT,
   (mapi_func) noopPixelTransformParameterfvEXT,
   (mapi_func) noopPixelTransformParameteriEXT,
   (mapi_func) noopPixelTransformParameterivEXT,
   (mapi_func) noopPixelZoom,
   (mapi_func) noopPixelZoomxOES,
   (mapi_func) noopPointAlongPathNV,
   (mapi_func) noopPointParameterf,
   (mapi_func) noopPointParameterfARB,
   (mapi_func) noopPointParameterfEXT,
   (mapi_func) noopPointParameterfSGIS,
   (mapi_func) noopPointParameterfv,
   (mapi_func) noopPointParameterfvARB,
   (mapi_func) noopPointParameterfvEXT,
   (mapi_func) noopPointParameterfvSGIS,
   (mapi_func) noopPointParameteri,
   (mapi_func) noopPointParameteriNV,
   (mapi_func) noopPointParameteriv,
   (mapi_func) noopPointParameterivNV,
   (mapi_func) noopPointParameterx,
   (mapi_func) noopPointParameterxOES,
   (mapi_func) noopPointParameterxv,
   (mapi_func) noopPointParameterxvOES,
   (mapi_func) noopPointSize,
   (mapi_func) noopPointSizePointerOES,
   (mapi_func) noopPointSizex,
   (mapi_func) noopPointSizexOES,
   (mapi_func) noopPollAsyncSGIX,
   (mapi_func) noopPollInstrumentsSGIX,
   (mapi_func) noopPolygonMode,
   (mapi_func) noopPolygonModeNV,
   (mapi_func) noopPolygonOffset,
   (mapi_func) noopPolygonOffsetClamp,
   (mapi_func) noopPolygonOffsetClampEXT,
   (mapi_func) noopPolygonOffsetEXT,
   (mapi_func) noopPolygonOffsetx,
   (mapi_func) noopPolygonOffsetxOES,
   (mapi_func) noopPolygonStipple,
   (mapi_func) noopPopAttrib,
   (mapi_func) noopPopClientAttrib,
   (mapi_func) noopPopDebugGroup,
   (mapi_func) noopPopDebugGroupKHR,
   (mapi_func) noopPopDebugGroupOES,
   (mapi_func) noopPopGroupMarkerEXT,
   (mapi_func) noopPopMatrix,
   (mapi_func) noopPopName,
   (mapi_func) noopPresentFrameDualFillNV,
   (mapi_func) noopPresentFrameKeyedNV,
   (mapi_func) noopPrimitiveBoundingBox,
   (mapi_func) noopPrimitiveBoundingBoxARB,
   (mapi_func) noopPrimitiveBoundingBoxEXT,
   (mapi_func) noopPrimitiveBoundingBoxOES,
   (mapi_func) noopPrimitiveRestart,
   (mapi_func) noopPrimitiveRestartIndex,
   (mapi_func) noopPrimitiveRestartIndexNV,
   (mapi_func) noopPrimitiveRestartNV,
   (mapi_func) noopPrioritizeTextures,
   (mapi_func) noopPrioritizeTexturesEXT,
   (mapi_func) noopPrioritizeTexturesxOES,
   (mapi_func) noopProgramBinary,
   (mapi_func) noopProgramBinaryOES,
   (mapi_func) noopProgramBufferParametersIivNV,
   (mapi_func) noopProgramBufferParametersIuivNV,
   (mapi_func) noopProgramBufferParametersfvNV,
   (mapi_func) noopProgramEnvParameter4dARB,
   (mapi_func) noopProgramEnvParameter4dvARB,
   (mapi_func) noopProgramEnvParameter4fARB,
   (mapi_func) noopProgramEnvParameter4fvARB,
   (mapi_func) noopProgramEnvParameterI4iNV,
   (mapi_func) noopProgramEnvParameterI4ivNV,
   (mapi_func) noopProgramEnvParameterI4uiNV,
   (mapi_func) noopProgramEnvParameterI4uivNV,
   (mapi_func) noopProgramEnvParameters4fvEXT,
   (mapi_func) noopProgramEnvParametersI4ivNV,
   (mapi_func) noopProgramEnvParametersI4uivNV,
   (mapi_func) noopProgramLocalParameter4dARB,
   (mapi_func) noopProgramLocalParameter4dvARB,
   (mapi_func) noopProgramLocalParameter4fARB,
   (mapi_func) noopProgramLocalParameter4fvARB,
   (mapi_func) noopProgramLocalParameterI4iNV,
   (mapi_func) noopProgramLocalParameterI4ivNV,
   (mapi_func) noopProgramLocalParameterI4uiNV,
   (mapi_func) noopProgramLocalParameterI4uivNV,
   (mapi_func) noopProgramLocalParameters4fvEXT,
   (mapi_func) noopProgramLocalParametersI4ivNV,
   (mapi_func) noopProgramLocalParametersI4uivNV,
   (mapi_func) noopProgramNamedParameter4dNV,
   (mapi_func) noopProgramNamedParameter4dvNV,
   (mapi_func) noopProgramNamedParameter4fNV,
   (mapi_func) noopProgramNamedParameter4fvNV,
   (mapi_func) noopProgramParameter4dNV,
   (mapi_func) noopProgramParameter4dvNV,
   (mapi_func) noopProgramParameter4fNV,
   (mapi_func) noopProgramParameter4fvNV,
   (mapi_func) noopProgramParameteri,
   (mapi_func) noopProgramParameteriARB,
   (mapi_func) noopProgramParameteriEXT,
   (mapi_func) noopProgramParameters4dvNV,
   (mapi_func) noopProgramParameters4fvNV,
   (mapi_func) noopProgramPathFragmentInputGenNV,
   (mapi_func) noopProgramStringARB,
   (mapi_func) noopProgramSubroutineParametersuivNV,
   (mapi_func) noopProgramUniform1d,
   (mapi_func) noopProgramUniform1dEXT,
   (mapi_func) noopProgramUniform1dv,
   (mapi_func) noopProgramUniform1dvEXT,
   (mapi_func) noopProgramUniform1f,
   (mapi_func) noopProgramUniform1fEXT,
   (mapi_func) noopProgramUniform1fv,
   (mapi_func) noopProgramUniform1fvEXT,
   (mapi_func) noopProgramUniform1i,
   (mapi_func) noopProgramUniform1i64ARB,
   (mapi_func) noopProgramUniform1i64NV,
   (mapi_func) noopProgramUniform1i64vARB,
   (mapi_func) noopProgramUniform1i64vNV,
   (mapi_func) noopProgramUniform1iEXT,
   (mapi_func) noopProgramUniform1iv,
   (mapi_func) noopProgramUniform1ivEXT,
   (mapi_func) noopProgramUniform1ui,
   (mapi_func) noopProgramUniform1ui64ARB,
   (mapi_func) noopProgramUniform1ui64NV,
   (mapi_func) noopProgramUniform1ui64vARB,
   (mapi_func) noopProgramUniform1ui64vNV,
   (mapi_func) noopProgramUniform1uiEXT,
   (mapi_func) noopProgramUniform1uiv,
   (mapi_func) noopProgramUniform1uivEXT,
   (mapi_func) noopProgramUniform2d,
   (mapi_func) noopProgramUniform2dEXT,
   (mapi_func) noopProgramUniform2dv,
   (mapi_func) noopProgramUniform2dvEXT,
   (mapi_func) noopProgramUniform2f,
   (mapi_func) noopProgramUniform2fEXT,
   (mapi_func) noopProgramUniform2fv,
   (mapi_func) noopProgramUniform2fvEXT,
   (mapi_func) noopProgramUniform2i,
   (mapi_func) noopProgramUniform2i64ARB,
   (mapi_func) noopProgramUniform2i64NV,
   (mapi_func) noopProgramUniform2i64vARB,
   (mapi_func) noopProgramUniform2i64vNV,
   (mapi_func) noopProgramUniform2iEXT,
   (mapi_func) noopProgramUniform2iv,
   (mapi_func) noopProgramUniform2ivEXT,
   (mapi_func) noopProgramUniform2ui,
   (mapi_func) noopProgramUniform2ui64ARB,
   (mapi_func) noopProgramUniform2ui64NV,
   (mapi_func) noopProgramUniform2ui64vARB,
   (mapi_func) noopProgramUniform2ui64vNV,
   (mapi_func) noopProgramUniform2uiEXT,
   (mapi_func) noopProgramUniform2uiv,
   (mapi_func) noopProgramUniform2uivEXT,
   (mapi_func) noopProgramUniform3d,
   (mapi_func) noopProgramUniform3dEXT,
   (mapi_func) noopProgramUniform3dv,
   (mapi_func) noopProgramUniform3dvEXT,
   (mapi_func) noopProgramUniform3f,
   (mapi_func) noopProgramUniform3fEXT,
   (mapi_func) noopProgramUniform3fv,
   (mapi_func) noopProgramUniform3fvEXT,
   (mapi_func) noopProgramUniform3i,
   (mapi_func) noopProgramUniform3i64ARB,
   (mapi_func) noopProgramUniform3i64NV,
   (mapi_func) noopProgramUniform3i64vARB,
   (mapi_func) noopProgramUniform3i64vNV,
   (mapi_func) noopProgramUniform3iEXT,
   (mapi_func) noopProgramUniform3iv,
   (mapi_func) noopProgramUniform3ivEXT,
   (mapi_func) noopProgramUniform3ui,
   (mapi_func) noopProgramUniform3ui64ARB,
   (mapi_func) noopProgramUniform3ui64NV,
   (mapi_func) noopProgramUniform3ui64vARB,
   (mapi_func) noopProgramUniform3ui64vNV,
   (mapi_func) noopProgramUniform3uiEXT,
   (mapi_func) noopProgramUniform3uiv,
   (mapi_func) noopProgramUniform3uivEXT,
   (mapi_func) noopProgramUniform4d,
   (mapi_func) noopProgramUniform4dEXT,
   (mapi_func) noopProgramUniform4dv,
   (mapi_func) noopProgramUniform4dvEXT,
   (mapi_func) noopProgramUniform4f,
   (mapi_func) noopProgramUniform4fEXT,
   (mapi_func) noopProgramUniform4fv,
   (mapi_func) noopProgramUniform4fvEXT,
   (mapi_func) noopProgramUniform4i,
   (mapi_func) noopProgramUniform4i64ARB,
   (mapi_func) noopProgramUniform4i64NV,
   (mapi_func) noopProgramUniform4i64vARB,
   (mapi_func) noopProgramUniform4i64vNV,
   (mapi_func) noopProgramUniform4iEXT,
   (mapi_func) noopProgramUniform4iv,
   (mapi_func) noopProgramUniform4ivEXT,
   (mapi_func) noopProgramUniform4ui,
   (mapi_func) noopProgramUniform4ui64ARB,
   (mapi_func) noopProgramUniform4ui64NV,
   (mapi_func) noopProgramUniform4ui64vARB,
   (mapi_func) noopProgramUniform4ui64vNV,
   (mapi_func) noopProgramUniform4uiEXT,
   (mapi_func) noopProgramUniform4uiv,
   (mapi_func) noopProgramUniform4uivEXT,
   (mapi_func) noopProgramUniformHandleui64ARB,
   (mapi_func) noopProgramUniformHandleui64IMG,
   (mapi_func) noopProgramUniformHandleui64NV,
   (mapi_func) noopProgramUniformHandleui64vARB,
   (mapi_func) noopProgramUniformHandleui64vIMG,
   (mapi_func) noopProgramUniformHandleui64vNV,
   (mapi_func) noopProgramUniformMatrix2dv,
   (mapi_func) noopProgramUniformMatrix2dvEXT,
   (mapi_func) noopProgramUniformMatrix2fv,
   (mapi_func) noopProgramUniformMatrix2fvEXT,
   (mapi_func) noopProgramUniformMatrix2x3dv,
   (mapi_func) noopProgramUniformMatrix2x3dvEXT,
   (mapi_func) noopProgramUniformMatrix2x3fv,
   (mapi_func) noopProgramUniformMatrix2x3fvEXT,
   (mapi_func) noopProgramUniformMatrix2x4dv,
   (mapi_func) noopProgramUniformMatrix2x4dvEXT,
   (mapi_func) noopProgramUniformMatrix2x4fv,
   (mapi_func) noopProgramUniformMatrix2x4fvEXT,
   (mapi_func) noopProgramUniformMatrix3dv,
   (mapi_func) noopProgramUniformMatrix3dvEXT,
   (mapi_func) noopProgramUniformMatrix3fv,
   (mapi_func) noopProgramUniformMatrix3fvEXT,
   (mapi_func) noopProgramUniformMatrix3x2dv,
   (mapi_func) noopProgramUniformMatrix3x2dvEXT,
   (mapi_func) noopProgramUniformMatrix3x2fv,
   (mapi_func) noopProgramUniformMatrix3x2fvEXT,
   (mapi_func) noopProgramUniformMatrix3x4dv,
   (mapi_func) noopProgramUniformMatrix3x4dvEXT,
   (mapi_func) noopProgramUniformMatrix3x4fv,
   (mapi_func) noopProgramUniformMatrix3x4fvEXT,
   (mapi_func) noopProgramUniformMatrix4dv,
   (mapi_func) noopProgramUniformMatrix4dvEXT,
   (mapi_func) noopProgramUniformMatrix4fv,
   (mapi_func) noopProgramUniformMatrix4fvEXT,
   (mapi_func) noopProgramUniformMatrix4x2dv,
   (mapi_func) noopProgramUniformMatrix4x2dvEXT,
   (mapi_func) noopProgramUniformMatrix4x2fv,
   (mapi_func) noopProgramUniformMatrix4x2fvEXT,
   (mapi_func) noopProgramUniformMatrix4x3dv,
   (mapi_func) noopProgramUniformMatrix4x3dvEXT,
   (mapi_func) noopProgramUniformMatrix4x3fv,
   (mapi_func) noopProgramUniformMatrix4x3fvEXT,
   (mapi_func) noopProgramUniformui64NV,
   (mapi_func) noopProgramUniformui64vNV,
   (mapi_func) noopProgramVertexLimitNV,
   (mapi_func) noopProvokingVertex,
   (mapi_func) noopProvokingVertexEXT,
   (mapi_func) noopPushAttrib,
   (mapi_func) noopPushClientAttrib,
   (mapi_func) noopPushClientAttribDefaultEXT,
   (mapi_func) noopPushDebugGroup,
   (mapi_func) noopPushDebugGroupKHR,
   (mapi_func) noopPushDebugGroupOES,
   (mapi_func) noopPushGroupMarkerEXT,
   (mapi_func) noopPushMatrix,
   (mapi_func) noopPushName,
   (mapi_func) noopQueryCounter,
   (mapi_func) noopQueryCounterEXT,
   (mapi_func) noopQueryCounterNV,
   (mapi_func) noopQueryMatrixxOES,
   (mapi_func) noopQueryObjectParameteruiAMD,
   (mapi_func) noopQueryResourceNV,
   (mapi_func) noopQueryResourceTagNV,
   (mapi_func) noopRasterPos2d,
   (mapi_func) noopRasterPos2dv,
   (mapi_func) noopRasterPos2f,
   (mapi_func) noopRasterPos2fv,
   (mapi_func) noopRasterPos2i,
   (mapi_func) noopRasterPos2iv,
   (mapi_func) noopRasterPos2s,
   (mapi_func) noopRasterPos2sv,
   (mapi_func) noopRasterPos2xOES,
   (mapi_func) noopRasterPos2xvOES,
   (mapi_func) noopRasterPos3d,
   (mapi_func) noopRasterPos3dv,
   (mapi_func) noopRasterPos3f,
   (mapi_func) noopRasterPos3fv,
   (mapi_func) noopRasterPos3i,
   (mapi_func) noopRasterPos3iv,
   (mapi_func) noopRasterPos3s,
   (mapi_func) noopRasterPos3sv,
   (mapi_func) noopRasterPos3xOES,
   (mapi_func) noopRasterPos3xvOES,
   (mapi_func) noopRasterPos4d,
   (mapi_func) noopRasterPos4dv,
   (mapi_func) noopRasterPos4f,
   (mapi_func) noopRasterPos4fv,
   (mapi_func) noopRasterPos4i,
   (mapi_func) noopRasterPos4iv,
   (mapi_func) noopRasterPos4s,
   (mapi_func) noopRasterPos4sv,
   (mapi_func) noopRasterPos4xOES,
   (mapi_func) noopRasterPos4xvOES,
   (mapi_func) noopRasterSamplesEXT,
   (mapi_func) noopReadBuffer,
   (mapi_func) noopReadBufferIndexedEXT,
   (mapi_func) noopReadBufferNV,
   (mapi_func) noopReadInstrumentsSGIX,
   (mapi_func) noopReadPixels,
   (mapi_func) noopReadnPixels,
   (mapi_func) noopReadnPixelsARB,
   (mapi_func) noopReadnPixelsEXT,
   (mapi_func) noopReadnPixelsKHR,
   (mapi_func) noopRectd,
   (mapi_func) noopRectdv,
   (mapi_func) noopRectf,
   (mapi_func) noopRectfv,
   (mapi_func) noopRecti,
   (mapi_func) noopRectiv,
   (mapi_func) noopRects,
   (mapi_func) noopRectsv,
   (mapi_func) noopRectxOES,
   (mapi_func) noopRectxvOES,
   (mapi_func) noopReferencePlaneSGIX,
   (mapi_func) noopReleaseKeyedMutexWin32EXT,
   (mapi_func) noopReleaseShaderCompiler,
   (mapi_func) noopRenderGpuMaskNV,
   (mapi_func) noopRenderMode,
   (mapi_func) noopRenderbufferStorage,
   (mapi_func) noopRenderbufferStorageEXT,
   (mapi_func) noopRenderbufferStorageMultisample,
   (mapi_func) noopRenderbufferStorageMultisampleANGLE,
   (mapi_func) noopRenderbufferStorageMultisampleAPPLE,
   (mapi_func) noopRenderbufferStorageMultisampleAdvancedAMD,
   (mapi_func) noopRenderbufferStorageMultisampleCoverageNV,
   (mapi_func) noopRenderbufferStorageMultisampleEXT,
   (mapi_func) noopRenderbufferStorageMultisampleIMG,
   (mapi_func) noopRenderbufferStorageMultisampleNV,
   (mapi_func) noopRenderbufferStorageOES,
   (mapi_func) noopReplacementCodePointerSUN,
   (mapi_func) noopReplacementCodeubSUN,
   (mapi_func) noopReplacementCodeubvSUN,
   (mapi_func) noopReplacementCodeuiColor3fVertex3fSUN,
   (mapi_func) noopReplacementCodeuiColor3fVertex3fvSUN,
   (mapi_func) noopReplacementCodeuiColor4fNormal3fVertex3fSUN,
   (mapi_func) noopReplacementCodeuiColor4fNormal3fVertex3fvSUN,
   (mapi_func) noopReplacementCodeuiColor4ubVertex3fSUN,
   (mapi_func) noopReplacementCodeuiColor4ubVertex3fvSUN,
   (mapi_func) noopReplacementCodeuiNormal3fVertex3fSUN,
   (mapi_func) noopReplacementCodeuiNormal3fVertex3fvSUN,
   (mapi_func) noopReplacementCodeuiSUN,
   (mapi_func) noopReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fSUN,
   (mapi_func) noopReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fvSUN,
   (mapi_func) noopReplacementCodeuiTexCoord2fNormal3fVertex3fSUN,
   (mapi_func) noopReplacementCodeuiTexCoord2fNormal3fVertex3fvSUN,
   (mapi_func) noopReplacementCodeuiTexCoord2fVertex3fSUN,
   (mapi_func) noopReplacementCodeuiTexCoord2fVertex3fvSUN,
   (mapi_func) noopReplacementCodeuiVertex3fSUN,
   (mapi_func) noopReplacementCodeuiVertex3fvSUN,
   (mapi_func) noopReplacementCodeuivSUN,
   (mapi_func) noopReplacementCodeusSUN,
   (mapi_func) noopReplacementCodeusvSUN,
   (mapi_func) noopRequestResidentProgramsNV,
   (mapi_func) noopResetHistogram,
   (mapi_func) noopResetHistogramEXT,
   (mapi_func) noopResetMemoryObjectParameterNV,
   (mapi_func) noopResetMinmax,
   (mapi_func) noopResetMinmaxEXT,
   (mapi_func) noopResizeBuffersMESA,
   (mapi_func) noopResolveDepthValuesNV,
   (mapi_func) noopResolveMultisampleFramebufferAPPLE,
   (mapi_func) noopResumeTransformFeedback,
   (mapi_func) noopResumeTransformFeedbackEXT,
   (mapi_func) noopResumeTransformFeedbackNV,
   (mapi_func) noopRotated,
   (mapi_func) noopRotatef,
   (mapi_func) noopRotatex,
   (mapi_func) noopRotatexOES,
   (mapi_func) noopSampleCoverage,
   (mapi_func) noopSampleCoverageARB,
   (mapi_func) noopSampleCoveragex,
   (mapi_func) noopSampleCoveragexOES,
   (mapi_func) noopSampleMapATI,
   (mapi_func) noopSampleMaskEXT,
   (mapi_func) noopSampleMaskIndexedNV,
   (mapi_func) noopSampleMaskSGIS,
   (mapi_func) noopSampleMaski,
   (mapi_func) noopSamplePatternEXT,
   (mapi_func) noopSamplePatternSGIS,
   (mapi_func) noopSamplerParameterIiv,
   (mapi_func) noopSamplerParameterIivEXT,
   (mapi_func) noopSamplerParameterIivOES,
   (mapi_func) noopSamplerParameterIuiv,
   (mapi_func) noopSamplerParameterIuivEXT,
   (mapi_func) noopSamplerParameterIuivOES,
   (mapi_func) noopSamplerParameterf,
   (mapi_func) noopSamplerParameterfv,
   (mapi_func) noopSamplerParameteri,
   (mapi_func) noopSamplerParameteriv,
   (mapi_func) noopScaled,
   (mapi_func) noopScalef,
   (mapi_func) noopScalex,
   (mapi_func) noopScalexOES,
   (mapi_func) noopScissor,
   (mapi_func) noopScissorArrayv,
   (mapi_func) noopScissorArrayvNV,
   (mapi_func) noopScissorArrayvOES,
   (mapi_func) noopScissorExclusiveArrayvNV,
   (mapi_func) noopScissorExclusiveNV,
   (mapi_func) noopScissorIndexed,
   (mapi_func) noopScissorIndexedNV,
   (mapi_func) noopScissorIndexedOES,
   (mapi_func) noopScissorIndexedv,
   (mapi_func) noopScissorIndexedvNV,
   (mapi_func) noopScissorIndexedvOES,
   (mapi_func) noopSecondaryColor3b,
   (mapi_func) noopSecondaryColor3bEXT,
   (mapi_func) noopSecondaryColor3bv,
   (mapi_func) noopSecondaryColor3bvEXT,
   (mapi_func) noopSecondaryColor3d,
   (mapi_func) noopSecondaryColor3dEXT,
   (mapi_func) noopSecondaryColor3dv,
   (mapi_func) noopSecondaryColor3dvEXT,
   (mapi_func) noopSecondaryColor3f,
   (mapi_func) noopSecondaryColor3fEXT,
   (mapi_func) noopSecondaryColor3fv,
   (mapi_func) noopSecondaryColor3fvEXT,
   (mapi_func) noopSecondaryColor3hNV,
   (mapi_func) noopSecondaryColor3hvNV,
   (mapi_func) noopSecondaryColor3i,
   (mapi_func) noopSecondaryColor3iEXT,
   (mapi_func) noopSecondaryColor3iv,
   (mapi_func) noopSecondaryColor3ivEXT,
   (mapi_func) noopSecondaryColor3s,
   (mapi_func) noopSecondaryColor3sEXT,
   (mapi_func) noopSecondaryColor3sv,
   (mapi_func) noopSecondaryColor3svEXT,
   (mapi_func) noopSecondaryColor3ub,
   (mapi_func) noopSecondaryColor3ubEXT,
   (mapi_func) noopSecondaryColor3ubv,
   (mapi_func) noopSecondaryColor3ubvEXT,
   (mapi_func) noopSecondaryColor3ui,
   (mapi_func) noopSecondaryColor3uiEXT,
   (mapi_func) noopSecondaryColor3uiv,
   (mapi_func) noopSecondaryColor3uivEXT,
   (mapi_func) noopSecondaryColor3us,
   (mapi_func) noopSecondaryColor3usEXT,
   (mapi_func) noopSecondaryColor3usv,
   (mapi_func) noopSecondaryColor3usvEXT,
   (mapi_func) noopSecondaryColorFormatNV,
   (mapi_func) noopSecondaryColorP3ui,
   (mapi_func) noopSecondaryColorP3uiv,
   (mapi_func) noopSecondaryColorPointer,
   (mapi_func) noopSecondaryColorPointerEXT,
   (mapi_func) noopSecondaryColorPointerListIBM,
   (mapi_func) noopSelectBuffer,
   (mapi_func) noopSelectPerfMonitorCountersAMD,
   (mapi_func) noopSemaphoreParameterui64vEXT,
   (mapi_func) noopSeparableFilter2D,
   (mapi_func) noopSeparableFilter2DEXT,
   (mapi_func) noopSetFenceAPPLE,
   (mapi_func) noopSetFenceNV,
   (mapi_func) noopSetFragmentShaderConstantATI,
   (mapi_func) noopSetInvariantEXT,
   (mapi_func) noopSetLocalConstantEXT,
   (mapi_func) noopSetMultisamplefvAMD,
   (mapi_func) noopShadeModel,
   (mapi_func) noopShaderBinary,
   (mapi_func) noopShaderOp1EXT,
   (mapi_func) noopShaderOp2EXT,
   (mapi_func) noopShaderOp3EXT,
   (mapi_func) noopShaderSource,
   (mapi_func) noopShaderSourceARB,
   (mapi_func) noopShaderStorageBlockBinding,
   (mapi_func) noopShadingRateImageBarrierNV,
   (mapi_func) noopShadingRateImagePaletteNV,
   (mapi_func) noopShadingRateSampleOrderCustomNV,
   (mapi_func) noopShadingRateSampleOrderNV,
   (mapi_func) noopSharpenTexFuncSGIS,
   (mapi_func) noopSignalSemaphoreEXT,
   (mapi_func) noopSignalSemaphoreui64NVX,
   (mapi_func) noopSignalVkFenceNV,
   (mapi_func) noopSignalVkSemaphoreNV,
   (mapi_func) noopSpecializeShader,
   (mapi_func) noopSpecializeShaderARB,
   (mapi_func) noopSpriteParameterfSGIX,
   (mapi_func) noopSpriteParameterfvSGIX,
   (mapi_func) noopSpriteParameteriSGIX,
   (mapi_func) noopSpriteParameterivSGIX,
   (mapi_func) noopStartInstrumentsSGIX,
   (mapi_func) noopStartTilingQCOM,
   (mapi_func) noopStateCaptureNV,
   (mapi_func) noopStencilClearTagEXT,
   (mapi_func) noopStencilFillPathInstancedNV,
   (mapi_func) noopStencilFillPathNV,
   (mapi_func) noopStencilFunc,
   (mapi_func) noopStencilFuncSeparate,
   (mapi_func) noopStencilFuncSeparateATI,
   (mapi_func) noopStencilMask,
   (mapi_func) noopStencilMaskSeparate,
   (mapi_func) noopStencilOp,
   (mapi_func) noopStencilOpSeparate,
   (mapi_func) noopStencilOpSeparateATI,
   (mapi_func) noopStencilOpValueAMD,
   (mapi_func) noopStencilStrokePathInstancedNV,
   (mapi_func) noopStencilStrokePathNV,
   (mapi_func) noopStencilThenCoverFillPathInstancedNV,
   (mapi_func) noopStencilThenCoverFillPathNV,
   (mapi_func) noopStencilThenCoverStrokePathInstancedNV,
   (mapi_func) noopStencilThenCoverStrokePathNV,
   (mapi_func) noopStopInstrumentsSGIX,
   (mapi_func) noopStringMarkerGREMEDY,
   (mapi_func) noopSubpixelPrecisionBiasNV,
   (mapi_func) noopSwizzleEXT,
   (mapi_func) noopSyncTextureINTEL,
   (mapi_func) noopTagSampleBufferSGIX,
   (mapi_func) noopTangent3bEXT,
   (mapi_func) noopTangent3bvEXT,
   (mapi_func) noopTangent3dEXT,
   (mapi_func) noopTangent3dvEXT,
   (mapi_func) noopTangent3fEXT,
   (mapi_func) noopTangent3fvEXT,
   (mapi_func) noopTangent3iEXT,
   (mapi_func) noopTangent3ivEXT,
   (mapi_func) noopTangent3sEXT,
   (mapi_func) noopTangent3svEXT,
   (mapi_func) noopTangentPointerEXT,
   (mapi_func) noopTbufferMask3DFX,
   (mapi_func) noopTessellationFactorAMD,
   (mapi_func) noopTessellationModeAMD,
   (mapi_func) noopTestFenceAPPLE,
   (mapi_func) noopTestFenceNV,
   (mapi_func) noopTestObjectAPPLE,
   (mapi_func) noopTexAttachMemoryNV,
   (mapi_func) noopTexBuffer,
   (mapi_func) noopTexBufferARB,
   (mapi_func) noopTexBufferEXT,
   (mapi_func) noopTexBufferOES,
   (mapi_func) noopTexBufferRange,
   (mapi_func) noopTexBufferRangeEXT,
   (mapi_func) noopTexBufferRangeOES,
   (mapi_func) noopTexBumpParameterfvATI,
   (mapi_func) noopTexBumpParameterivATI,
   (mapi_func) noopTexCoord1bOES,
   (mapi_func) noopTexCoord1bvOES,
   (mapi_func) noopTexCoord1d,
   (mapi_func) noopTexCoord1dv,
   (mapi_func) noopTexCoord1f,
   (mapi_func) noopTexCoord1fv,
   (mapi_func) noopTexCoord1hNV,
   (mapi_func) noopTexCoord1hvNV,
   (mapi_func) noopTexCoord1i,
   (mapi_func) noopTexCoord1iv,
   (mapi_func) noopTexCoord1s,
   (mapi_func) noopTexCoord1sv,
   (mapi_func) noopTexCoord1xOES,
   (mapi_func) noopTexCoord1xvOES,
   (mapi_func) noopTexCoord2bOES,
   (mapi_func) noopTexCoord2bvOES,
   (mapi_func) noopTexCoord2d,
   (mapi_func) noopTexCoord2dv,
   (mapi_func) noopTexCoord2f,
   (mapi_func) noopTexCoord2fColor3fVertex3fSUN,
   (mapi_func) noopTexCoord2fColor3fVertex3fvSUN,
   (mapi_func) noopTexCoord2fColor4fNormal3fVertex3fSUN,
   (mapi_func) noopTexCoord2fColor4fNormal3fVertex3fvSUN,
   (mapi_func) noopTexCoord2fColor4ubVertex3fSUN,
   (mapi_func) noopTexCoord2fColor4ubVertex3fvSUN,
   (mapi_func) noopTexCoord2fNormal3fVertex3fSUN,
   (mapi_func) noopTexCoord2fNormal3fVertex3fvSUN,
   (mapi_func) noopTexCoord2fVertex3fSUN,
   (mapi_func) noopTexCoord2fVertex3fvSUN,
   (mapi_func) noopTexCoord2fv,
   (mapi_func) noopTexCoord2hNV,
   (mapi_func) noopTexCoord2hvNV,
   (mapi_func) noopTexCoord2i,
   (mapi_func) noopTexCoord2iv,
   (mapi_func) noopTexCoord2s,
   (mapi_func) noopTexCoord2sv,
   (mapi_func) noopTexCoord2xOES,
   (mapi_func) noopTexCoord2xvOES,
   (mapi_func) noopTexCoord3bOES,
   (mapi_func) noopTexCoord3bvOES,
   (mapi_func) noopTexCoord3d,
   (mapi_func) noopTexCoord3dv,
   (mapi_func) noopTexCoord3f,
   (mapi_func) noopTexCoord3fv,
   (mapi_func) noopTexCoord3hNV,
   (mapi_func) noopTexCoord3hvNV,
   (mapi_func) noopTexCoord3i,
   (mapi_func) noopTexCoord3iv,
   (mapi_func) noopTexCoord3s,
   (mapi_func) noopTexCoord3sv,
   (mapi_func) noopTexCoord3xOES,
   (mapi_func) noopTexCoord3xvOES,
   (mapi_func) noopTexCoord4bOES,
   (mapi_func) noopTexCoord4bvOES,
   (mapi_func) noopTexCoord4d,
   (mapi_func) noopTexCoord4dv,
   (mapi_func) noopTexCoord4f,
   (mapi_func) noopTexCoord4fColor4fNormal3fVertex4fSUN,
   (mapi_func) noopTexCoord4fColor4fNormal3fVertex4fvSUN,
   (mapi_func) noopTexCoord4fVertex4fSUN,
   (mapi_func) noopTexCoord4fVertex4fvSUN,
   (mapi_func) noopTexCoord4fv,
   (mapi_func) noopTexCoord4hNV,
   (mapi_func) noopTexCoord4hvNV,
   (mapi_func) noopTexCoord4i,
   (mapi_func) noopTexCoord4iv,
   (mapi_func) noopTexCoord4s,
   (mapi_func) noopTexCoord4sv,
   (mapi_func) noopTexCoord4xOES,
   (mapi_func) noopTexCoord4xvOES,
   (mapi_func) noopTexCoordFormatNV,
   (mapi_func) noopTexCoordP1ui,
   (mapi_func) noopTexCoordP1uiv,
   (mapi_func) noopTexCoordP2ui,
   (mapi_func) noopTexCoordP2uiv,
   (mapi_func) noopTexCoordP3ui,
   (mapi_func) noopTexCoordP3uiv,
   (mapi_func) noopTexCoordP4ui,
   (mapi_func) noopTexCoordP4uiv,
   (mapi_func) noopTexCoordPointer,
   (mapi_func) noopTexCoordPointerEXT,
   (mapi_func) noopTexCoordPointerListIBM,
   (mapi_func) noopTexCoordPointervINTEL,
   (mapi_func) noopTexEnvf,
   (mapi_func) noopTexEnvfv,
   (mapi_func) noopTexEnvi,
   (mapi_func) noopTexEnviv,
   (mapi_func) noopTexEnvx,
   (mapi_func) noopTexEnvxOES,
   (mapi_func) noopTexEnvxv,
   (mapi_func) noopTexEnvxvOES,
   (mapi_func) noopTexFilterFuncSGIS,
   (mapi_func) noopTexGend,
   (mapi_func) noopTexGendv,
   (mapi_func) noopTexGenf,
   (mapi_func) noopTexGenfOES,
   (mapi_func) noopTexGenfv,
   (mapi_func) noopTexGenfvOES,
   (mapi_func) noopTexGeni,
   (mapi_func) noopTexGeniOES,
   (mapi_func) noopTexGeniv,
   (mapi_func) noopTexGenivOES,
   (mapi_func) noopTexGenxOES,
   (mapi_func) noopTexGenxvOES,
   (mapi_func) noopTexImage1D,
   (mapi_func) noopTexImage2D,
   (mapi_func) noopTexImage2DMultisample,
   (mapi_func) noopTexImage2DMultisampleCoverageNV,
   (mapi_func) noopTexImage3D,
   (mapi_func) noopTexImage3DEXT,
   (mapi_func) noopTexImage3DMultisample,
   (mapi_func) noopTexImage3DMultisampleCoverageNV,
   (mapi_func) noopTexImage3DNV,
   (mapi_func) noopTexImage3DOES,
   (mapi_func) noopTexImage4DSGIS,
   (mapi_func) noopTexPageCommitmentARB,
   (mapi_func) noopTexPageCommitmentEXT,
   (mapi_func) noopTexParameterIiv,
   (mapi_func) noopTexParameterIivEXT,
   (mapi_func) noopTexParameterIivOES,
   (mapi_func) noopTexParameterIuiv,
   (mapi_func) noopTexParameterIuivEXT,
   (mapi_func) noopTexParameterIuivOES,
   (mapi_func) noopTexParameterf,
   (mapi_func) noopTexParameterfv,
   (mapi_func) noopTexParameteri,
   (mapi_func) noopTexParameteriv,
   (mapi_func) noopTexParameterx,
   (mapi_func) noopTexParameterxOES,
   (mapi_func) noopTexParameterxv,
   (mapi_func) noopTexParameterxvOES,
   (mapi_func) noopTexRenderbufferNV,
   (mapi_func) noopTexStorage1D,
   (mapi_func) noopTexStorage1DEXT,
   (mapi_func) noopTexStorage2D,
   (mapi_func) noopTexStorage2DEXT,
   (mapi_func) noopTexStorage2DMultisample,
   (mapi_func) noopTexStorage3D,
   (mapi_func) noopTexStorage3DEXT,
   (mapi_func) noopTexStorage3DMultisample,
   (mapi_func) noopTexStorage3DMultisampleOES,
   (mapi_func) noopTexStorageMem1DEXT,
   (mapi_func) noopTexStorageMem2DEXT,
   (mapi_func) noopTexStorageMem2DMultisampleEXT,
   (mapi_func) noopTexStorageMem3DEXT,
   (mapi_func) noopTexStorageMem3DMultisampleEXT,
   (mapi_func) noopTexStorageSparseAMD,
   (mapi_func) noopTexSubImage1D,
   (mapi_func) noopTexSubImage1DEXT,
   (mapi_func) noopTexSubImage2D,
   (mapi_func) noopTexSubImage2DEXT,
   (mapi_func) noopTexSubImage3D,
   (mapi_func) noopTexSubImage3DEXT,
   (mapi_func) noopTexSubImage3DNV,
   (mapi_func) noopTexSubImage3DOES,
   (mapi_func) noopTexSubImage4DSGIS,
   (mapi_func) noopTextureAttachMemoryNV,
   (mapi_func) noopTextureBarrier,
   (mapi_func) noopTextureBarrierNV,
   (mapi_func) noopTextureBuffer,
   (mapi_func) noopTextureBufferEXT,
   (mapi_func) noopTextureBufferRange,
   (mapi_func) noopTextureBufferRangeEXT,
   (mapi_func) noopTextureColorMaskSGIS,
   (mapi_func) noopTextureFoveationParametersQCOM,
   (mapi_func) noopTextureImage1DEXT,
   (mapi_func) noopTextureImage2DEXT,
   (mapi_func) noopTextureImage2DMultisampleCoverageNV,
   (mapi_func) noopTextureImage2DMultisampleNV,
   (mapi_func) noopTextureImage3DEXT,
   (mapi_func) noopTextureImage3DMultisampleCoverageNV,
   (mapi_func) noopTextureImage3DMultisampleNV,
   (mapi_func) noopTextureLightEXT,
   (mapi_func) noopTextureMaterialEXT,
   (mapi_func) noopTextureNormalEXT,
   (mapi_func) noopTexturePageCommitmentEXT,
   (mapi_func) noopTextureParameterIiv,
   (mapi_func) noopTextureParameterIivEXT,
   (mapi_func) noopTextureParameterIuiv,
   (mapi_func) noopTextureParameterIuivEXT,
   (mapi_func) noopTextureParameterf,
   (mapi_func) noopTextureParameterfEXT,
   (mapi_func) noopTextureParameterfv,
   (mapi_func) noopTextureParameterfvEXT,
   (mapi_func) noopTextureParameteri,
   (mapi_func) noopTextureParameteriEXT,
   (mapi_func) noopTextureParameteriv,
   (mapi_func) noopTextureParameterivEXT,
   (mapi_func) noopTextureRangeAPPLE,
   (mapi_func) noopTextureRenderbufferEXT,
   (mapi_func) noopTextureStorage1D,
   (mapi_func) noopTextureStorage1DEXT,
   (mapi_func) noopTextureStorage2D,
   (mapi_func) noopTextureStorage2DEXT,
   (mapi_func) noopTextureStorage2DMultisample,
   (mapi_func) noopTextureStorage2DMultisampleEXT,
   (mapi_func) noopTextureStorage3D,
   (mapi_func) noopTextureStorage3DEXT,
   (mapi_func) noopTextureStorage3DMultisample,
   (mapi_func) noopTextureStorage3DMultisampleEXT,
   (mapi_func) noopTextureStorageMem1DEXT,
   (mapi_func) noopTextureStorageMem2DEXT,
   (mapi_func) noopTextureStorageMem2DMultisampleEXT,
   (mapi_func) noopTextureStorageMem3DEXT,
   (mapi_func) noopTextureStorageMem3DMultisampleEXT,
   (mapi_func) noopTextureStorageSparseAMD,
   (mapi_func) noopTextureSubImage1D,
   (mapi_func) noopTextureSubImage1DEXT,
   (mapi_func) noopTextureSubImage2D,
   (mapi_func) noopTextureSubImage2DEXT,
   (mapi_func) noopTextureSubImage3D,
   (mapi_func) noopTextureSubImage3DEXT,
   (mapi_func) noopTextureView,
   (mapi_func) noopTextureViewEXT,
   (mapi_func) noopTextureViewOES,
   (mapi_func) noopTrackMatrixNV,
   (mapi_func) noopTransformFeedbackAttribsNV,
   (mapi_func) noopTransformFeedbackBufferBase,
   (mapi_func) noopTransformFeedbackBufferRange,
   (mapi_func) noopTransformFeedbackStreamAttribsNV,
   (mapi_func) noopTransformFeedbackVaryings,
   (mapi_func) noopTransformFeedbackVaryingsEXT,
   (mapi_func) noopTransformFeedbackVaryingsNV,
   (mapi_func) noopTransformPathNV,
   (mapi_func) noopTranslated,
   (mapi_func) noopTranslatef,
   (mapi_func) noopTranslatex,
   (mapi_func) noopTranslatexOES,
   (mapi_func) noopUniform1d,
   (mapi_func) noopUniform1dv,
   (mapi_func) noopUniform1f,
   (mapi_func) noopUniform1fARB,
   (mapi_func) noopUniform1fv,
   (mapi_func) noopUniform1fvARB,
   (mapi_func) noopUniform1i,
   (mapi_func) noopUniform1i64ARB,
   (mapi_func) noopUniform1i64NV,
   (mapi_func) noopUniform1i64vARB,
   (mapi_func) noopUniform1i64vNV,
   (mapi_func) noopUniform1iARB,
   (mapi_func) noopUniform1iv,
   (mapi_func) noopUniform1ivARB,
   (mapi_func) noopUniform1ui,
   (mapi_func) noopUniform1ui64ARB,
   (mapi_func) noopUniform1ui64NV,
   (mapi_func) noopUniform1ui64vARB,
   (mapi_func) noopUniform1ui64vNV,
   (mapi_func) noopUniform1uiEXT,
   (mapi_func) noopUniform1uiv,
   (mapi_func) noopUniform1uivEXT,
   (mapi_func) noopUniform2d,
   (mapi_func) noopUniform2dv,
   (mapi_func) noopUniform2f,
   (mapi_func) noopUniform2fARB,
   (mapi_func) noopUniform2fv,
   (mapi_func) noopUniform2fvARB,
   (mapi_func) noopUniform2i,
   (mapi_func) noopUniform2i64ARB,
   (mapi_func) noopUniform2i64NV,
   (mapi_func) noopUniform2i64vARB,
   (mapi_func) noopUniform2i64vNV,
   (mapi_func) noopUniform2iARB,
   (mapi_func) noopUniform2iv,
   (mapi_func) noopUniform2ivARB,
   (mapi_func) noopUniform2ui,
   (mapi_func) noopUniform2ui64ARB,
   (mapi_func) noopUniform2ui64NV,
   (mapi_func) noopUniform2ui64vARB,
   (mapi_func) noopUniform2ui64vNV,
   (mapi_func) noopUniform2uiEXT,
   (mapi_func) noopUniform2uiv,
   (mapi_func) noopUniform2uivEXT,
   (mapi_func) noopUniform3d,
   (mapi_func) noopUniform3dv,
   (mapi_func) noopUniform3f,
   (mapi_func) noopUniform3fARB,
   (mapi_func) noopUniform3fv,
   (mapi_func) noopUniform3fvARB,
   (mapi_func) noopUniform3i,
   (mapi_func) noopUniform3i64ARB,
   (mapi_func) noopUniform3i64NV,
   (mapi_func) noopUniform3i64vARB,
   (mapi_func) noopUniform3i64vNV,
   (mapi_func) noopUniform3iARB,
   (mapi_func) noopUniform3iv,
   (mapi_func) noopUniform3ivARB,
   (mapi_func) noopUniform3ui,
   (mapi_func) noopUniform3ui64ARB,
   (mapi_func) noopUniform3ui64NV,
   (mapi_func) noopUniform3ui64vARB,
   (mapi_func) noopUniform3ui64vNV,
   (mapi_func) noopUniform3uiEXT,
   (mapi_func) noopUniform3uiv,
   (mapi_func) noopUniform3uivEXT,
   (mapi_func) noopUniform4d,
   (mapi_func) noopUniform4dv,
   (mapi_func) noopUniform4f,
   (mapi_func) noopUniform4fARB,
   (mapi_func) noopUniform4fv,
   (mapi_func) noopUniform4fvARB,
   (mapi_func) noopUniform4i,
   (mapi_func) noopUniform4i64ARB,
   (mapi_func) noopUniform4i64NV,
   (mapi_func) noopUniform4i64vARB,
   (mapi_func) noopUniform4i64vNV,
   (mapi_func) noopUniform4iARB,
   (mapi_func) noopUniform4iv,
   (mapi_func) noopUniform4ivARB,
   (mapi_func) noopUniform4ui,
   (mapi_func) noopUniform4ui64ARB,
   (mapi_func) noopUniform4ui64NV,
   (mapi_func) noopUniform4ui64vARB,
   (mapi_func) noopUniform4ui64vNV,
   (mapi_func) noopUniform4uiEXT,
   (mapi_func) noopUniform4uiv,
   (mapi_func) noopUniform4uivEXT,
   (mapi_func) noopUniformBlockBinding,
   (mapi_func) noopUniformBufferEXT,
   (mapi_func) noopUniformHandleui64ARB,
   (mapi_func) noopUniformHandleui64IMG,
   (mapi_func) noopUniformHandleui64NV,
   (mapi_func) noopUniformHandleui64vARB,
   (mapi_func) noopUniformHandleui64vIMG,
   (mapi_func) noopUniformHandleui64vNV,
   (mapi_func) noopUniformMatrix2dv,
   (mapi_func) noopUniformMatrix2fv,
   (mapi_func) noopUniformMatrix2fvARB,
   (mapi_func) noopUniformMatrix2x3dv,
   (mapi_func) noopUniformMatrix2x3fv,
   (mapi_func) noopUniformMatrix2x3fvNV,
   (mapi_func) noopUniformMatrix2x4dv,
   (mapi_func) noopUniformMatrix2x4fv,
   (mapi_func) noopUniformMatrix2x4fvNV,
   (mapi_func) noopUniformMatrix3dv,
   (mapi_func) noopUniformMatrix3fv,
   (mapi_func) noopUniformMatrix3fvARB,
   (mapi_func) noopUniformMatrix3x2dv,
   (mapi_func) noopUniformMatrix3x2fv,
   (mapi_func) noopUniformMatrix3x2fvNV,
   (mapi_func) noopUniformMatrix3x4dv,
   (mapi_func) noopUniformMatrix3x4fv,
   (mapi_func) noopUniformMatrix3x4fvNV,
   (mapi_func) noopUniformMatrix4dv,
   (mapi_func) noopUniformMatrix4fv,
   (mapi_func) noopUniformMatrix4fvARB,
   (mapi_func) noopUniformMatrix4x2dv,
   (mapi_func) noopUniformMatrix4x2fv,
   (mapi_func) noopUniformMatrix4x2fvNV,
   (mapi_func) noopUniformMatrix4x3dv,
   (mapi_func) noopUniformMatrix4x3fv,
   (mapi_func) noopUniformMatrix4x3fvNV,
   (mapi_func) noopUniformSubroutinesuiv,
   (mapi_func) noopUniformui64NV,
   (mapi_func) noopUniformui64vNV,
   (mapi_func) noopUnlockArraysEXT,
   (mapi_func) noopUnmapBuffer,
   (mapi_func) noopUnmapBufferARB,
   (mapi_func) noopUnmapBufferOES,
   (mapi_func) noopUnmapNamedBuffer,
   (mapi_func) noopUnmapNamedBufferEXT,
   (mapi_func) noopUnmapObjectBufferATI,
   (mapi_func) noopUnmapTexture2DINTEL,
   (mapi_func) noopUpdateObjectBufferATI,
   (mapi_func) noopUploadGpuMaskNVX,
   (mapi_func) noopUseProgram,
   (mapi_func) noopUseProgramObjectARB,
   (mapi_func) noopUseProgramStages,
   (mapi_func) noopUseProgramStagesEXT,
   (mapi_func) noopUseShaderProgramEXT,
   (mapi_func) noopVDPAUFiniNV,
   (mapi_func) noopVDPAUGetSurfaceivNV,
   (mapi_func) noopVDPAUInitNV,
   (mapi_func) noopVDPAUIsSurfaceNV,
   (mapi_func) noopVDPAUMapSurfacesNV,
   (mapi_func) noopVDPAURegisterOutputSurfaceNV,
   (mapi_func) noopVDPAURegisterVideoSurfaceNV,
   (mapi_func) noopVDPAURegisterVideoSurfaceWithPictureStructureNV,
   (mapi_func) noopVDPAUSurfaceAccessNV,
   (mapi_func) noopVDPAUUnmapSurfacesNV,
   (mapi_func) noopVDPAUUnregisterSurfaceNV,
   (mapi_func) noopValidBackBufferHintAutodesk,
   (mapi_func) noopValidateProgram,
   (mapi_func) noopValidateProgramARB,
   (mapi_func) noopValidateProgramPipeline,
   (mapi_func) noopValidateProgramPipelineEXT,
   (mapi_func) noopVariantArrayObjectATI,
   (mapi_func) noopVariantPointerEXT,
   (mapi_func) noopVariantbvEXT,
   (mapi_func) noopVariantdvEXT,
   (mapi_func) noopVariantfvEXT,
   (mapi_func) noopVariantivEXT,
   (mapi_func) noopVariantsvEXT,
   (mapi_func) noopVariantubvEXT,
   (mapi_func) noopVariantuivEXT,
   (mapi_func) noopVariantusvEXT,
   (mapi_func) noopVertex2bOES,
   (mapi_func) noopVertex2bvOES,
   (mapi_func) noopVertex2d,
   (mapi_func) noopVertex2dv,
   (mapi_func) noopVertex2f,
   (mapi_func) noopVertex2fv,
   (mapi_func) noopVertex2hNV,
   (mapi_func) noopVertex2hvNV,
   (mapi_func) noopVertex2i,
   (mapi_func) noopVertex2iv,
   (mapi_func) noopVertex2s,
   (mapi_func) noopVertex2sv,
   (mapi_func) noopVertex2xOES,
   (mapi_func) noopVertex2xvOES,
   (mapi_func) noopVertex3bOES,
   (mapi_func) noopVertex3bvOES,
   (mapi_func) noopVertex3d,
   (mapi_func) noopVertex3dv,
   (mapi_func) noopVertex3f,
   (mapi_func) noopVertex3fv,
   (mapi_func) noopVertex3hNV,
   (mapi_func) noopVertex3hvNV,
   (mapi_func) noopVertex3i,
   (mapi_func) noopVertex3iv,
   (mapi_func) noopVertex3s,
   (mapi_func) noopVertex3sv,
   (mapi_func) noopVertex3xOES,
   (mapi_func) noopVertex3xvOES,
   (mapi_func) noopVertex4bOES,
   (mapi_func) noopVertex4bvOES,
   (mapi_func) noopVertex4d,
   (mapi_func) noopVertex4dv,
   (mapi_func) noopVertex4f,
   (mapi_func) noopVertex4fv,
   (mapi_func) noopVertex4hNV,
   (mapi_func) noopVertex4hvNV,
   (mapi_func) noopVertex4i,
   (mapi_func) noopVertex4iv,
   (mapi_func) noopVertex4s,
   (mapi_func) noopVertex4sv,
   (mapi_func) noopVertex4xOES,
   (mapi_func) noopVertex4xvOES,
   (mapi_func) noopVertexArrayAttribBinding,
   (mapi_func) noopVertexArrayAttribFormat,
   (mapi_func) noopVertexArrayAttribIFormat,
   (mapi_func) noopVertexArrayAttribLFormat,
   (mapi_func) noopVertexArrayBindVertexBufferEXT,
   (mapi_func) noopVertexArrayBindingDivisor,
   (mapi_func) noopVertexArrayColorOffsetEXT,
   (mapi_func) noopVertexArrayEdgeFlagOffsetEXT,
   (mapi_func) noopVertexArrayElementBuffer,
   (mapi_func) noopVertexArrayFogCoordOffsetEXT,
   (mapi_func) noopVertexArrayIndexOffsetEXT,
   (mapi_func) noopVertexArrayMultiTexCoordOffsetEXT,
   (mapi_func) noopVertexArrayNormalOffsetEXT,
   (mapi_func) noopVertexArrayParameteriAPPLE,
   (mapi_func) noopVertexArrayRangeAPPLE,
   (mapi_func) noopVertexArrayRangeNV,
   (mapi_func) noopVertexArraySecondaryColorOffsetEXT,
   (mapi_func) noopVertexArrayTexCoordOffsetEXT,
   (mapi_func) noopVertexArrayVertexAttribBindingEXT,
   (mapi_func) noopVertexArrayVertexAttribDivisorEXT,
   (mapi_func) noopVertexArrayVertexAttribFormatEXT,
   (mapi_func) noopVertexArrayVertexAttribIFormatEXT,
   (mapi_func) noopVertexArrayVertexAttribIOffsetEXT,
   (mapi_func) noopVertexArrayVertexAttribLFormatEXT,
   (mapi_func) noopVertexArrayVertexAttribLOffsetEXT,
   (mapi_func) noopVertexArrayVertexAttribOffsetEXT,
   (mapi_func) noopVertexArrayVertexBindingDivisorEXT,
   (mapi_func) noopVertexArrayVertexBuffer,
   (mapi_func) noopVertexArrayVertexBuffers,
   (mapi_func) noopVertexArrayVertexOffsetEXT,
   (mapi_func) noopVertexAttrib1d,
   (mapi_func) noopVertexAttrib1dARB,
   (mapi_func) noopVertexAttrib1dNV,
   (mapi_func) noopVertexAttrib1dv,
   (mapi_func) noopVertexAttrib1dvARB,
   (mapi_func) noopVertexAttrib1dvNV,
   (mapi_func) noopVertexAttrib1f,
   (mapi_func) noopVertexAttrib1fARB,
   (mapi_func) noopVertexAttrib1fNV,
   (mapi_func) noopVertexAttrib1fv,
   (mapi_func) noopVertexAttrib1fvARB,
   (mapi_func) noopVertexAttrib1fvNV,
   (mapi_func) noopVertexAttrib1hNV,
   (mapi_func) noopVertexAttrib1hvNV,
   (mapi_func) noopVertexAttrib1s,
   (mapi_func) noopVertexAttrib1sARB,
   (mapi_func) noopVertexAttrib1sNV,
   (mapi_func) noopVertexAttrib1sv,
   (mapi_func) noopVertexAttrib1svARB,
   (mapi_func) noopVertexAttrib1svNV,
   (mapi_func) noopVertexAttrib2d,
   (mapi_func) noopVertexAttrib2dARB,
   (mapi_func) noopVertexAttrib2dNV,
   (mapi_func) noopVertexAttrib2dv,
   (mapi_func) noopVertexAttrib2dvARB,
   (mapi_func) noopVertexAttrib2dvNV,
   (mapi_func) noopVertexAttrib2f,
   (mapi_func) noopVertexAttrib2fARB,
   (mapi_func) noopVertexAttrib2fNV,
   (mapi_func) noopVertexAttrib2fv,
   (mapi_func) noopVertexAttrib2fvARB,
   (mapi_func) noopVertexAttrib2fvNV,
   (mapi_func) noopVertexAttrib2hNV,
   (mapi_func) noopVertexAttrib2hvNV,
   (mapi_func) noopVertexAttrib2s,
   (mapi_func) noopVertexAttrib2sARB,
   (mapi_func) noopVertexAttrib2sNV,
   (mapi_func) noopVertexAttrib2sv,
   (mapi_func) noopVertexAttrib2svARB,
   (mapi_func) noopVertexAttrib2svNV,
   (mapi_func) noopVertexAttrib3d,
   (mapi_func) noopVertexAttrib3dARB,
   (mapi_func) noopVertexAttrib3dNV,
   (mapi_func) noopVertexAttrib3dv,
   (mapi_func) noopVertexAttrib3dvARB,
   (mapi_func) noopVertexAttrib3dvNV,
   (mapi_func) noopVertexAttrib3f,
   (mapi_func) noopVertexAttrib3fARB,
   (mapi_func) noopVertexAttrib3fNV,
   (mapi_func) noopVertexAttrib3fv,
   (mapi_func) noopVertexAttrib3fvARB,
   (mapi_func) noopVertexAttrib3fvNV,
   (mapi_func) noopVertexAttrib3hNV,
   (mapi_func) noopVertexAttrib3hvNV,
   (mapi_func) noopVertexAttrib3s,
   (mapi_func) noopVertexAttrib3sARB,
   (mapi_func) noopVertexAttrib3sNV,
   (mapi_func) noopVertexAttrib3sv,
   (mapi_func) noopVertexAttrib3svARB,
   (mapi_func) noopVertexAttrib3svNV,
   (mapi_func) noopVertexAttrib4Nbv,
   (mapi_func) noopVertexAttrib4NbvARB,
   (mapi_func) noopVertexAttrib4Niv,
   (mapi_func) noopVertexAttrib4NivARB,
   (mapi_func) noopVertexAttrib4Nsv,
   (mapi_func) noopVertexAttrib4NsvARB,
   (mapi_func) noopVertexAttrib4Nub,
   (mapi_func) noopVertexAttrib4NubARB,
   (mapi_func) noopVertexAttrib4Nubv,
   (mapi_func) noopVertexAttrib4NubvARB,
   (mapi_func) noopVertexAttrib4Nuiv,
   (mapi_func) noopVertexAttrib4NuivARB,
   (mapi_func) noopVertexAttrib4Nusv,
   (mapi_func) noopVertexAttrib4NusvARB,
   (mapi_func) noopVertexAttrib4bv,
   (mapi_func) noopVertexAttrib4bvARB,
   (mapi_func) noopVertexAttrib4d,
   (mapi_func) noopVertexAttrib4dARB,
   (mapi_func) noopVertexAttrib4dNV,
   (mapi_func) noopVertexAttrib4dv,
   (mapi_func) noopVertexAttrib4dvARB,
   (mapi_func) noopVertexAttrib4dvNV,
   (mapi_func) noopVertexAttrib4f,
   (mapi_func) noopVertexAttrib4fARB,
   (mapi_func) noopVertexAttrib4fNV,
   (mapi_func) noopVertexAttrib4fv,
   (mapi_func) noopVertexAttrib4fvARB,
   (mapi_func) noopVertexAttrib4fvNV,
   (mapi_func) noopVertexAttrib4hNV,
   (mapi_func) noopVertexAttrib4hvNV,
   (mapi_func) noopVertexAttrib4iv,
   (mapi_func) noopVertexAttrib4ivARB,
   (mapi_func) noopVertexAttrib4s,
   (mapi_func) noopVertexAttrib4sARB,
   (mapi_func) noopVertexAttrib4sNV,
   (mapi_func) noopVertexAttrib4sv,
   (mapi_func) noopVertexAttrib4svARB,
   (mapi_func) noopVertexAttrib4svNV,
   (mapi_func) noopVertexAttrib4ubNV,
   (mapi_func) noopVertexAttrib4ubv,
   (mapi_func) noopVertexAttrib4ubvARB,
   (mapi_func) noopVertexAttrib4ubvNV,
   (mapi_func) noopVertexAttrib4uiv,
   (mapi_func) noopVertexAttrib4uivARB,
   (mapi_func) noopVertexAttrib4usv,
   (mapi_func) noopVertexAttrib4usvARB,
   (mapi_func) noopVertexAttribArrayObjectATI,
   (mapi_func) noopVertexAttribBinding,
   (mapi_func) noopVertexAttribDivisor,
   (mapi_func) noopVertexAttribDivisorANGLE,
   (mapi_func) noopVertexAttribDivisorARB,
   (mapi_func) noopVertexAttribDivisorEXT,
   (mapi_func) noopVertexAttribDivisorNV,
   (mapi_func) noopVertexAttribFormat,
   (mapi_func) noopVertexAttribFormatNV,
   (mapi_func) noopVertexAttribI1i,
   (mapi_func) noopVertexAttribI1iEXT,
   (mapi_func) noopVertexAttribI1iv,
   (mapi_func) noopVertexAttribI1ivEXT,
   (mapi_func) noopVertexAttribI1ui,
   (mapi_func) noopVertexAttribI1uiEXT,
   (mapi_func) noopVertexAttribI1uiv,
   (mapi_func) noopVertexAttribI1uivEXT,
   (mapi_func) noopVertexAttribI2i,
   (mapi_func) noopVertexAttribI2iEXT,
   (mapi_func) noopVertexAttribI2iv,
   (mapi_func) noopVertexAttribI2ivEXT,
   (mapi_func) noopVertexAttribI2ui,
   (mapi_func) noopVertexAttribI2uiEXT,
   (mapi_func) noopVertexAttribI2uiv,
   (mapi_func) noopVertexAttribI2uivEXT,
   (mapi_func) noopVertexAttribI3i,
   (mapi_func) noopVertexAttribI3iEXT,
   (mapi_func) noopVertexAttribI3iv,
   (mapi_func) noopVertexAttribI3ivEXT,
   (mapi_func) noopVertexAttribI3ui,
   (mapi_func) noopVertexAttribI3uiEXT,
   (mapi_func) noopVertexAttribI3uiv,
   (mapi_func) noopVertexAttribI3uivEXT,
   (mapi_func) noopVertexAttribI4bv,
   (mapi_func) noopVertexAttribI4bvEXT,
   (mapi_func) noopVertexAttribI4i,
   (mapi_func) noopVertexAttribI4iEXT,
   (mapi_func) noopVertexAttribI4iv,
   (mapi_func) noopVertexAttribI4ivEXT,
   (mapi_func) noopVertexAttribI4sv,
   (mapi_func) noopVertexAttribI4svEXT,
   (mapi_func) noopVertexAttribI4ubv,
   (mapi_func) noopVertexAttribI4ubvEXT,
   (mapi_func) noopVertexAttribI4ui,
   (mapi_func) noopVertexAttribI4uiEXT,
   (mapi_func) noopVertexAttribI4uiv,
   (mapi_func) noopVertexAttribI4uivEXT,
   (mapi_func) noopVertexAttribI4usv,
   (mapi_func) noopVertexAttribI4usvEXT,
   (mapi_func) noopVertexAttribIFormat,
   (mapi_func) noopVertexAttribIFormatNV,
   (mapi_func) noopVertexAttribIPointer,
   (mapi_func) noopVertexAttribIPointerEXT,
   (mapi_func) noopVertexAttribL1d,
   (mapi_func) noopVertexAttribL1dEXT,
   (mapi_func) noopVertexAttribL1dv,
   (mapi_func) noopVertexAttribL1dvEXT,
   (mapi_func) noopVertexAttribL1i64NV,
   (mapi_func) noopVertexAttribL1i64vNV,
   (mapi_func) noopVertexAttribL1ui64ARB,
   (mapi_func) noopVertexAttribL1ui64NV,
   (mapi_func) noopVertexAttribL1ui64vARB,
   (mapi_func) noopVertexAttribL1ui64vNV,
   (mapi_func) noopVertexAttribL2d,
   (mapi_func) noopVertexAttribL2dEXT,
   (mapi_func) noopVertexAttribL2dv,
   (mapi_func) noopVertexAttribL2dvEXT,
   (mapi_func) noopVertexAttribL2i64NV,
   (mapi_func) noopVertexAttribL2i64vNV,
   (mapi_func) noopVertexAttribL2ui64NV,
   (mapi_func) noopVertexAttribL2ui64vNV,
   (mapi_func) noopVertexAttribL3d,
   (mapi_func) noopVertexAttribL3dEXT,
   (mapi_func) noopVertexAttribL3dv,
   (mapi_func) noopVertexAttribL3dvEXT,
   (mapi_func) noopVertexAttribL3i64NV,
   (mapi_func) noopVertexAttribL3i64vNV,
   (mapi_func) noopVertexAttribL3ui64NV,
   (mapi_func) noopVertexAttribL3ui64vNV,
   (mapi_func) noopVertexAttribL4d,
   (mapi_func) noopVertexAttribL4dEXT,
   (mapi_func) noopVertexAttribL4dv,
   (mapi_func) noopVertexAttribL4dvEXT,
   (mapi_func) noopVertexAttribL4i64NV,
   (mapi_func) noopVertexAttribL4i64vNV,
   (mapi_func) noopVertexAttribL4ui64NV,
   (mapi_func) noopVertexAttribL4ui64vNV,
   (mapi_func) noopVertexAttribLFormat,
   (mapi_func) noopVertexAttribLFormatNV,
   (mapi_func) noopVertexAttribLPointer,
   (mapi_func) noopVertexAttribLPointerEXT,
   (mapi_func) noopVertexAttribP1ui,
   (mapi_func) noopVertexAttribP1uiv,
   (mapi_func) noopVertexAttribP2ui,
   (mapi_func) noopVertexAttribP2uiv,
   (mapi_func) noopVertexAttribP3ui,
   (mapi_func) noopVertexAttribP3uiv,
   (mapi_func) noopVertexAttribP4ui,
   (mapi_func) noopVertexAttribP4uiv,
   (mapi_func) noopVertexAttribParameteriAMD,
   (mapi_func) noopVertexAttribPointer,
   (mapi_func) noopVertexAttribPointerARB,
   (mapi_func) noopVertexAttribPointerNV,
   (mapi_func) noopVertexAttribs1dvNV,
   (mapi_func) noopVertexAttribs1fvNV,
   (mapi_func) noopVertexAttribs1hvNV,
   (mapi_func) noopVertexAttribs1svNV,
   (mapi_func) noopVertexAttribs2dvNV,
   (mapi_func) noopVertexAttribs2fvNV,
   (mapi_func) noopVertexAttribs2hvNV,
   (mapi_func) noopVertexAttribs2svNV,
   (mapi_func) noopVertexAttribs3dvNV,
   (mapi_func) noopVertexAttribs3fvNV,
   (mapi_func) noopVertexAttribs3hvNV,
   (mapi_func) noopVertexAttribs3svNV,
   (mapi_func) noopVertexAttribs4dvNV,
   (mapi_func) noopVertexAttribs4fvNV,
   (mapi_func) noopVertexAttribs4hvNV,
   (mapi_func) noopVertexAttribs4svNV,
   (mapi_func) noopVertexAttribs4ubvNV,
   (mapi_func) noopVertexBindingDivisor,
   (mapi_func) noopVertexBlendARB,
   (mapi_func) noopVertexBlendEnvfATI,
   (mapi_func) noopVertexBlendEnviATI,
   (mapi_func) noopVertexFormatNV,
   (mapi_func) noopVertexP2ui,
   (mapi_func) noopVertexP2uiv,
   (mapi_func) noopVertexP3ui,
   (mapi_func) noopVertexP3uiv,
   (mapi_func) noopVertexP4ui,
   (mapi_func) noopVertexP4uiv,
   (mapi_func) noopVertexPointer,
   (mapi_func) noopVertexPointerEXT,
   (mapi_func) noopVertexPointerListIBM,
   (mapi_func) noopVertexPointervINTEL,
   (mapi_func) noopVertexStream1dATI,
   (mapi_func) noopVertexStream1dvATI,
   (mapi_func) noopVertexStream1fATI,
   (mapi_func) noopVertexStream1fvATI,
   (mapi_func) noopVertexStream1iATI,
   (mapi_func) noopVertexStream1ivATI,
   (mapi_func) noopVertexStream1sATI,
   (mapi_func) noopVertexStream1svATI,
   (mapi_func) noopVertexStream2dATI,
   (mapi_func) noopVertexStream2dvATI,
   (mapi_func) noopVertexStream2fATI,
   (mapi_func) noopVertexStream2fvATI,
   (mapi_func) noopVertexStream2iATI,
   (mapi_func) noopVertexStream2ivATI,
   (mapi_func) noopVertexStream2sATI,
   (mapi_func) noopVertexStream2svATI,
   (mapi_func) noopVertexStream3dATI,
   (mapi_func) noopVertexStream3dvATI,
   (mapi_func) noopVertexStream3fATI,
   (mapi_func) noopVertexStream3fvATI,
   (mapi_func) noopVertexStream3iATI,
   (mapi_func) noopVertexStream3ivATI,
   (mapi_func) noopVertexStream3sATI,
   (mapi_func) noopVertexStream3svATI,
   (mapi_func) noopVertexStream4dATI,
   (mapi_func) noopVertexStream4dvATI,
   (mapi_func) noopVertexStream4fATI,
   (mapi_func) noopVertexStream4fvATI,
   (mapi_func) noopVertexStream4iATI,
   (mapi_func) noopVertexStream4ivATI,
   (mapi_func) noopVertexStream4sATI,
   (mapi_func) noopVertexStream4svATI,
   (mapi_func) noopVertexWeightPointerEXT,
   (mapi_func) noopVertexWeightfEXT,
   (mapi_func) noopVertexWeightfvEXT,
   (mapi_func) noopVertexWeighthNV,
   (mapi_func) noopVertexWeighthvNV,
   (mapi_func) noopVideoCaptureNV,
   (mapi_func) noopVideoCaptureStreamParameterdvNV,
   (mapi_func) noopVideoCaptureStreamParameterfvNV,
   (mapi_func) noopVideoCaptureStreamParameterivNV,
   (mapi_func) noopViewport,
   (mapi_func) noopViewportArrayv,
   (mapi_func) noopViewportArrayvNV,
   (mapi_func) noopViewportArrayvOES,
   (mapi_func) noopViewportIndexedf,
   (mapi_func) noopViewportIndexedfNV,
   (mapi_func) noopViewportIndexedfOES,
   (mapi_func) noopViewportIndexedfv,
   (mapi_func) noopViewportIndexedfvNV,
   (mapi_func) noopViewportIndexedfvOES,
   (mapi_func) noopViewportPositionWScaleNV,
   (mapi_func) noopViewportSwizzleNV,
   (mapi_func) noopWaitSemaphoreEXT,
   (mapi_func) noopWaitSemaphoreui64NVX,
   (mapi_func) noopWaitSync,
   (mapi_func) noopWaitSyncAPPLE,
   (mapi_func) noopWaitSyncValueuiNVX,
   (mapi_func) noopWaitVkSemaphoreNV,
   (mapi_func) noopWeightPathsNV,
   (mapi_func) noopWeightPointerARB,
   (mapi_func) noopWeightPointerOES,
   (mapi_func) noopWeightbvARB,
   (mapi_func) noopWeightdvARB,
   (mapi_func) noopWeightfvARB,
   (mapi_func) noopWeightivARB,
   (mapi_func) noopWeightsvARB,
   (mapi_func) noopWeightubvARB,
   (mapi_func) noopWeightuivARB,
   (mapi_func) noopWeightusvARB,
   (mapi_func) noopWindowBackBufferHintAutodesk,
   (mapi_func) noopWindowPos2d,
   (mapi_func) noopWindowPos2dARB,
   (mapi_func) noopWindowPos2dMESA,
   (mapi_func) noopWindowPos2dv,
   (mapi_func) noopWindowPos2dvARB,
   (mapi_func) noopWindowPos2dvMESA,
   (mapi_func) noopWindowPos2f,
   (mapi_func) noopWindowPos2fARB,
   (mapi_func) noopWindowPos2fMESA,
   (mapi_func) noopWindowPos2fv,
   (mapi_func) noopWindowPos2fvARB,
   (mapi_func) noopWindowPos2fvMESA,
   (mapi_func) noopWindowPos2i,
   (mapi_func) noopWindowPos2iARB,
   (mapi_func) noopWindowPos2iMESA,
   (mapi_func) noopWindowPos2iv,
   (mapi_func) noopWindowPos2ivARB,
   (mapi_func) noopWindowPos2ivMESA,
   (mapi_func) noopWindowPos2s,
   (mapi_func) noopWindowPos2sARB,
   (mapi_func) noopWindowPos2sMESA,
   (mapi_func) noopWindowPos2sv,
   (mapi_func) noopWindowPos2svARB,
   (mapi_func) noopWindowPos2svMESA,
   (mapi_func) noopWindowPos3d,
   (mapi_func) noopWindowPos3dARB,
   (mapi_func) noopWindowPos3dMESA,
   (mapi_func) noopWindowPos3dv,
   (mapi_func) noopWindowPos3dvARB,
   (mapi_func) noopWindowPos3dvMESA,
   (mapi_func) noopWindowPos3f,
   (mapi_func) noopWindowPos3fARB,
   (mapi_func) noopWindowPos3fMESA,
   (mapi_func) noopWindowPos3fv,
   (mapi_func) noopWindowPos3fvARB,
   (mapi_func) noopWindowPos3fvMESA,
   (mapi_func) noopWindowPos3i,
   (mapi_func) noopWindowPos3iARB,
   (mapi_func) noopWindowPos3iMESA,
   (mapi_func) noopWindowPos3iv,
   (mapi_func) noopWindowPos3ivARB,
   (mapi_func) noopWindowPos3ivMESA,
   (mapi_func) noopWindowPos3s,
   (mapi_func) noopWindowPos3sARB,
   (mapi_func) noopWindowPos3sMESA,
   (mapi_func) noopWindowPos3sv,
   (mapi_func) noopWindowPos3svARB,
   (mapi_func) noopWindowPos3svMESA,
   (mapi_func) noopWindowPos4dMESA,
   (mapi_func) noopWindowPos4dvMESA,
   (mapi_func) noopWindowPos4fMESA,
   (mapi_func) noopWindowPos4fvMESA,
   (mapi_func) noopWindowPos4iMESA,
   (mapi_func) noopWindowPos4ivMESA,
   (mapi_func) noopWindowPos4sMESA,
   (mapi_func) noopWindowPos4svMESA,
   (mapi_func) noopWindowRectanglesEXT,
   (mapi_func) noopWriteMaskEXT,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic
};

#else /* DEBUG */

const mapi_func table_noop_array[] = {
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic,
   (mapi_func) noop_generic
};

#endif /* DEBUG */
#undef MAPI_TMP_NOOP_ARRAY
#endif /* MAPI_TMP_NOOP_ARRAY */

#ifdef MAPI_TMP_PUBLIC_STUBS
static const struct mapi_stub public_stubs[] = {
   { "glAccum", 0 },
   { "glAccumxOES", 1 },
   { "glAcquireKeyedMutexWin32EXT", 2 },
   { "glActiveProgramEXT", 3 },
   { "glActiveShaderProgram", 4 },
   { "glActiveShaderProgramEXT", 5 },
   { "glActiveStencilFaceEXT", 6 },
   { "glActiveTexture", 7 },
   { "glActiveTextureARB", 8 },
   { "glActiveVaryingNV", 9 },
   { "glAlphaFragmentOp1ATI", 10 },
   { "glAlphaFragmentOp2ATI", 11 },
   { "glAlphaFragmentOp3ATI", 12 },
   { "glAlphaFunc", 13 },
   { "glAlphaFuncQCOM", 14 },
   { "glAlphaFuncx", 15 },
   { "glAlphaFuncxOES", 16 },
   { "glAlphaToCoverageDitherControlNV", 17 },
   { "glApplyFramebufferAttachmentCMAAINTEL", 18 },
   { "glApplyTextureEXT", 19 },
   { "glAreProgramsResidentNV", 20 },
   { "glAreTexturesResident", 21 },
   { "glAreTexturesResidentEXT", 22 },
   { "glArrayElement", 23 },
   { "glArrayElementEXT", 24 },
   { "glArrayObjectATI", 25 },
   { "glAsyncCopyBufferSubDataNVX", 26 },
   { "glAsyncCopyImageSubDataNVX", 27 },
   { "glAsyncMarkerSGIX", 28 },
   { "glAttachObjectARB", 29 },
   { "glAttachShader", 30 },
   { "glBegin", 31 },
   { "glBeginConditionalRender", 32 },
   { "glBeginConditionalRenderNV", 33 },
   { "glBeginConditionalRenderNVX", 34 },
   { "glBeginFragmentShaderATI", 35 },
   { "glBeginOcclusionQueryNV", 36 },
   { "glBeginPerfMonitorAMD", 37 },
   { "glBeginPerfQueryINTEL", 38 },
   { "glBeginQuery", 39 },
   { "glBeginQueryARB", 40 },
   { "glBeginQueryEXT", 41 },
   { "glBeginQueryIndexed", 42 },
   { "glBeginTransformFeedback", 43 },
   { "glBeginTransformFeedbackEXT", 44 },
   { "glBeginTransformFeedbackNV", 45 },
   { "glBeginVertexShaderEXT", 46 },
   { "glBeginVideoCaptureNV", 47 },
   { "glBindANCCaptureStreamBufferNVX", 48 },
   { "glBindAttribLocation", 49 },
   { "glBindAttribLocationARB", 50 },
   { "glBindBuffer", 51 },
   { "glBindBufferARB", 52 },
   { "glBindBufferBase", 53 },
   { "glBindBufferBaseEXT", 54 },
   { "glBindBufferBaseNV", 55 },
   { "glBindBufferOffsetEXT", 56 },
   { "glBindBufferOffsetNV", 57 },
   { "glBindBufferRange", 58 },
   { "glBindBufferRangeEXT", 59 },
   { "glBindBufferRangeNV", 60 },
   { "glBindBuffersBase", 61 },
   { "glBindBuffersRange", 62 },
   { "glBindFragDataLocation", 63 },
   { "glBindFragDataLocationEXT", 64 },
   { "glBindFragDataLocationIndexed", 65 },
   { "glBindFragDataLocationIndexedEXT", 66 },
   { "glBindFragmentShaderATI", 67 },
   { "glBindFramebuffer", 68 },
   { "glBindFramebufferEXT", 69 },
   { "glBindFramebufferOES", 70 },
   { "glBindImageTexture", 71 },
   { "glBindImageTextureEXT", 72 },
   { "glBindImageTextures", 73 },
   { "glBindLightParameterEXT", 74 },
   { "glBindMaterialParameterEXT", 75 },
   { "glBindMultiTextureEXT", 76 },
   { "glBindParameterEXT", 77 },
   { "glBindProgramARB", 78 },
   { "glBindProgramNV", 79 },
   { "glBindProgramPipeline", 80 },
   { "glBindProgramPipelineEXT", 81 },
   { "glBindRenderbuffer", 82 },
   { "glBindRenderbufferEXT", 83 },
   { "glBindRenderbufferOES", 84 },
   { "glBindSampler", 85 },
   { "glBindSamplers", 86 },
   { "glBindShadingRateImageNV", 87 },
   { "glBindTexGenParameterEXT", 88 },
   { "glBindTexture", 89 },
   { "glBindTextureEXT", 90 },
   { "glBindTextureUnit", 91 },
   { "glBindTextureUnitParameterEXT", 92 },
   { "glBindTextures", 93 },
   { "glBindTransformFeedback", 94 },
   { "glBindTransformFeedbackEXT", 95 },
   { "glBindTransformFeedbackNV", 96 },
   { "glBindVertexArray", 97 },
   { "glBindVertexArrayAPPLE", 98 },
   { "glBindVertexArrayOES", 99 },
   { "glBindVertexBuffer", 100 },
   { "glBindVertexBuffers", 101 },
   { "glBindVertexShaderEXT", 102 },
   { "glBindVideoCaptureStreamBufferNV", 103 },
   { "glBindVideoCaptureStreamTextureNV", 104 },
   { "glBinormal3bEXT", 105 },
   { "glBinormal3bvEXT", 106 },
   { "glBinormal3dEXT", 107 },
   { "glBinormal3dvEXT", 108 },
   { "glBinormal3fEXT", 109 },
   { "glBinormal3fvEXT", 110 },
   { "glBinormal3iEXT", 111 },
   { "glBinormal3ivEXT", 112 },
   { "glBinormal3sEXT", 113 },
   { "glBinormal3svEXT", 114 },
   { "glBinormalPointerEXT", 115 },
   { "glBitmap", 116 },
   { "glBitmapxOES", 117 },
   { "glBlendBarrier", 118 },
   { "glBlendBarrierKHR", 119 },
   { "glBlendBarrierNV", 120 },
   { "glBlendColor", 121 },
   { "glBlendColorEXT", 122 },
   { "glBlendColorxOES", 123 },
   { "glBlendEquation", 124 },
   { "glBlendEquationEXT", 125 },
   { "glBlendEquationIndexedAMD", 126 },
   { "glBlendEquationOES", 127 },
   { "glBlendEquationSeparate", 128 },
   { "glBlendEquationSeparateEXT", 129 },
   { "glBlendEquationSeparateIndexedAMD", 130 },
   { "glBlendEquationSeparateOES", 131 },
   { "glBlendEquationSeparatei", 132 },
   { "glBlendEquationSeparateiARB", 133 },
   { "glBlendEquationSeparateiEXT", 134 },
   { "glBlendEquationSeparateiOES", 135 },
   { "glBlendEquationi", 136 },
   { "glBlendEquationiARB", 137 },
   { "glBlendEquationiEXT", 138 },
   { "glBlendEquationiOES", 139 },
   { "glBlendFunc", 140 },
   { "glBlendFuncIndexedAMD", 141 },
   { "glBlendFuncSeparate", 142 },
   { "glBlendFuncSeparateEXT", 143 },
   { "glBlendFuncSeparateINGR", 144 },
   { "glBlendFuncSeparateIndexedAMD", 145 },
   { "glBlendFuncSeparateOES", 146 },
   { "glBlendFuncSeparatei", 147 },
   { "glBlendFuncSeparateiARB", 148 },
   { "glBlendFuncSeparateiEXT", 149 },
   { "glBlendFuncSeparateiOES", 150 },
   { "glBlendFunci", 151 },
   { "glBlendFunciARB", 152 },
   { "glBlendFunciEXT", 153 },
   { "glBlendFunciOES", 154 },
   { "glBlendParameteriNV", 155 },
   { "glBlitFramebuffer", 156 },
   { "glBlitFramebufferANGLE", 157 },
   { "glBlitFramebufferEXT", 158 },
   { "glBlitFramebufferNV", 159 },
   { "glBlitNamedFramebuffer", 160 },
   { "glBufferAddressRangeNV", 161 },
   { "glBufferAttachMemoryNV", 162 },
   { "glBufferData", 163 },
   { "glBufferDataARB", 164 },
   { "glBufferDataSysmem", 165 },
   { "glBufferPageCommitmentARB", 166 },
   { "glBufferParameteriAPPLE", 168 },
   { "glBufferStorage", 169 },
   { "glBufferStorageEXT", 170 },
   { "glBufferStorageExternalEXT", 171 },
   { "glBufferStorageMemEXT", 172 },
   { "glBufferSubData", 173 },
   { "glBufferSubDataARB", 174 },
   { "glCallCommandListNV", 175 },
   { "glCallList", 176 },
   { "glCallLists", 177 },
   { "glCheckFramebufferStatus", 178 },
   { "glCheckFramebufferStatusEXT", 179 },
   { "glCheckFramebufferStatusOES", 180 },
   { "glCheckNamedFramebufferStatus", 181 },
   { "glCheckNamedFramebufferStatusEXT", 182 },
   { "glClampColor", 183 },
   { "glClampColorARB", 184 },
   { "glClear", 185 },
   { "glClearAccum", 186 },
   { "glClearAccumxOES", 187 },
   { "glClearBufferData", 188 },
   { "glClearBufferSubData", 189 },
   { "glClearBufferfi", 190 },
   { "glClearBufferfv", 191 },
   { "glClearBufferiv", 192 },
   { "glClearBufferuiv", 193 },
   { "glClearColor", 194 },
   { "glClearColorIiEXT", 195 },
   { "glClearColorIuiEXT", 196 },
   { "glClearColorx", 197 },
   { "glClearColorxOES", 198 },
   { "glClearDepth", 199 },
   { "glClearDepthdNV", 200 },
   { "glClearDepthf", 201 },
   { "glClearDepthfOES", 202 },
   { "glClearDepthx", 203 },
   { "glClearDepthxOES", 204 },
   { "glClearIndex", 205 },
   { "glClearNamedBufferData", 206 },
   { "glClearNamedBufferDataEXT", 207 },
   { "glClearNamedBufferSubData", 208 },
   { "glClearNamedBufferSubDataEXT", 209 },
   { "glClearNamedFramebufferfi", 210 },
   { "glClearNamedFramebufferfv", 211 },
   { "glClearNamedFramebufferiv", 212 },
   { "glClearNamedFramebufferuiv", 213 },
   { "glClearPixelLocalStorageuiEXT", 214 },
   { "glClearStencil", 215 },
   { "glClearTexImage", 216 },
   { "glClearTexImageEXT", 217 },
   { "glClearTexSubImage", 218 },
   { "glClearTexSubImageEXT", 219 },
   { "glClientActiveTexture", 220 },
   { "glClientActiveTextureARB", 221 },
   { "glClientActiveVertexStreamATI", 222 },
   { "glClientAttribDefaultEXT", 223 },
   { "glClientWaitSemaphoreui64NVX", 224 },
   { "glClientWaitSync", 225 },
   { "glClientWaitSyncAPPLE", 226 },
   { "glClientWaitSyncValueuiNVX", 227 },
   { "glClipControl", 228 },
   { "glClipControlEXT", 229 },
   { "glClipPlane", 230 },
   { "glClipPlanef", 231 },
   { "glClipPlanefIMG", 232 },
   { "glClipPlanefOES", 233 },
   { "glClipPlanex", 234 },
   { "glClipPlanexIMG", 235 },
   { "glClipPlanexOES", 236 },
   { "glColor3b", 237 },
   { "glColor3bv", 238 },
   { "glColor3d", 239 },
   { "glColor3dv", 240 },
   { "glColor3f", 241 },
   { "glColor3fVertex3fSUN", 242 },
   { "glColor3fVertex3fvSUN", 243 },
   { "glColor3fv", 244 },
   { "glColor3hNV", 245 },
   { "glColor3hvNV", 246 },
   { "glColor3i", 247 },
   { "glColor3iv", 248 },
   { "glColor3s", 249 },
   { "glColor3sv", 250 },
   { "glColor3ub", 251 },
   { "glColor3ubv", 252 },
   { "glColor3ui", 253 },
   { "glColor3uiv", 254 },
   { "glColor3us", 255 },
   { "glColor3usv", 256 },
   { "glColor3x", 257 },
   { "glColor3xOES", 258 },
   { "glColor3xvOES", 259 },
   { "glColor4b", 260 },
   { "glColor4bv", 261 },
   { "glColor4d", 262 },
   { "glColor4dv", 263 },
   { "glColor4f", 264 },
   { "glColor4fNormal3fVertex3fSUN", 265 },
   { "glColor4fNormal3fVertex3fvSUN", 266 },
   { "glColor4fv", 267 },
   { "glColor4hNV", 268 },
   { "glColor4hvNV", 269 },
   { "glColor4i", 270 },
   { "glColor4iv", 271 },
   { "glColor4s", 272 },
   { "glColor4sv", 273 },
   { "glColor4ub", 274 },
   { "glColor4ubVertex2fSUN", 275 },
   { "glColor4ubVertex2fvSUN", 276 },
   { "glColor4ubVertex3fSUN", 277 },
   { "glColor4ubVertex3fvSUN", 278 },
   { "glColor4ubv", 279 },
   { "glColor4ui", 280 },
   { "glColor4uiv", 281 },
   { "glColor4us", 282 },
   { "glColor4usv", 283 },
   { "glColor4x", 284 },
   { "glColor4xOES", 285 },
   { "glColor4xvOES", 286 },
   { "glColorFormatNV", 287 },
   { "glColorFragmentOp1ATI", 288 },
   { "glColorFragmentOp2ATI", 289 },
   { "glColorFragmentOp3ATI", 290 },
   { "glColorMask", 291 },
   { "glColorMaskIndexedEXT", 292 },
   { "glColorMaski", 293 },
   { "glColorMaskiEXT", 294 },
   { "glColorMaskiOES", 295 },
   { "glColorMaterial", 296 },
   { "glColorP3ui", 297 },
   { "glColorP3uiv", 298 },
   { "glColorP4ui", 299 },
   { "glColorP4uiv", 300 },
   { "glColorPointer", 301 },
   { "glColorPointerEXT", 302 },
   { "glColorPointerListIBM", 303 },
   { "glColorPointervINTEL", 304 },
   { "glColorSubTable", 305 },
   { "glColorSubTableEXT", 306 },
   { "glColorTable", 307 },
   { "glColorTableEXT", 308 },
   { "glColorTableParameterfv", 309 },
   { "glColorTableParameterfvSGI", 310 },
   { "glColorTableParameteriv", 311 },
   { "glColorTableParameterivSGI", 312 },
   { "glColorTableSGI", 313 },
   { "glCombinerInputNV", 314 },
   { "glCombinerOutputNV", 315 },
   { "glCombinerParameterfNV", 316 },
   { "glCombinerParameterfvNV", 317 },
   { "glCombinerParameteriNV", 318 },
   { "glCombinerParameterivNV", 319 },
   { "glCombinerStageParameterfvNV", 320 },
   { "glCommandListSegmentsNV", 321 },
   { "glCompileCommandListNV", 322 },
   { "glCompileShader", 323 },
   { "glCompileShaderARB", 324 },
   { "glCompileShaderIncludeARB", 325 },
   { "glCompressedMultiTexImage1DEXT", 326 },
   { "glCompressedMultiTexImage2DEXT", 327 },
   { "glCompressedMultiTexImage3DEXT", 328 },
   { "glCompressedMultiTexSubImage1DEXT", 329 },
   { "glCompressedMultiTexSubImage2DEXT", 330 },
   { "glCompressedMultiTexSubImage3DEXT", 331 },
   { "glCompressedTexImage1D", 332 },
   { "glCompressedTexImage1DARB", 333 },
   { "glCompressedTexImage2D", 334 },
   { "glCompressedTexImage2DARB", 335 },
   { "glCompressedTexImage3D", 336 },
   { "glCompressedTexImage3DARB", 337 },
   { "glCompressedTexImage3DNV", 338 },
   { "glCompressedTexImage3DOES", 339 },
   { "glCompressedTexSubImage1D", 340 },
   { "glCompressedTexSubImage1DARB", 341 },
   { "glCompressedTexSubImage2D", 342 },
   { "glCompressedTexSubImage2DARB", 343 },
   { "glCompressedTexSubImage3D", 344 },
   { "glCompressedTexSubImage3DARB", 345 },
   { "glCompressedTexSubImage3DNV", 346 },
   { "glCompressedTexSubImage3DOES", 347 },
   { "glCompressedTextureImage1DEXT", 348 },
   { "glCompressedTextureImage2DEXT", 349 },
   { "glCompressedTextureImage3DEXT", 350 },
   { "glCompressedTextureSubImage1D", 351 },
   { "glCompressedTextureSubImage1DEXT", 352 },
   { "glCompressedTextureSubImage2D", 353 },
   { "glCompressedTextureSubImage2DEXT", 354 },
   { "glCompressedTextureSubImage3D", 355 },
   { "glCompressedTextureSubImage3DEXT", 356 },
   { "glConservativeRasterParameterfNV", 357 },
   { "glConservativeRasterParameteriNV", 358 },
   { "glConvolutionFilter1D", 359 },
   { "glConvolutionFilter1DEXT", 360 },
   { "glConvolutionFilter2D", 361 },
   { "glConvolutionFilter2DEXT", 362 },
   { "glConvolutionParameterf", 363 },
   { "glConvolutionParameterfEXT", 364 },
   { "glConvolutionParameterfv", 365 },
   { "glConvolutionParameterfvEXT", 366 },
   { "glConvolutionParameteri", 367 },
   { "glConvolutionParameteriEXT", 368 },
   { "glConvolutionParameteriv", 369 },
   { "glConvolutionParameterivEXT", 370 },
   { "glConvolutionParameterxOES", 371 },
   { "glConvolutionParameterxvOES", 372 },
   { "glCopyBufferSubData", 373 },
   { "glCopyBufferSubDataNV", 374 },
   { "glCopyColorSubTable", 375 },
   { "glCopyColorSubTableEXT", 376 },
   { "glCopyColorTable", 377 },
   { "glCopyColorTableSGI", 378 },
   { "glCopyConvolutionFilter1D", 379 },
   { "glCopyConvolutionFilter1DEXT", 380 },
   { "glCopyConvolutionFilter2D", 381 },
   { "glCopyConvolutionFilter2DEXT", 382 },
   { "glCopyImageSubData", 383 },
   { "glCopyImageSubDataEXT", 384 },
   { "glCopyImageSubDataNV", 385 },
   { "glCopyImageSubDataOES", 386 },
   { "glCopyMultiTexImage1DEXT", 387 },
   { "glCopyMultiTexImage2DEXT", 388 },
   { "glCopyMultiTexSubImage1DEXT", 389 },
   { "glCopyMultiTexSubImage2DEXT", 390 },
   { "glCopyMultiTexSubImage3DEXT", 391 },
   { "glCopyNamedBufferSubData", 392 },
   { "glCopyPathNV", 393 },
   { "glCopyPixels", 394 },
   { "glCopyTexImage1D", 395 },
   { "glCopyTexImage1DEXT", 396 },
   { "glCopyTexImage2D", 397 },
   { "glCopyTexImage2DEXT", 398 },
   { "glCopyTexSubImage1D", 399 },
   { "glCopyTexSubImage1DEXT", 400 },
   { "glCopyTexSubImage2D", 401 },
   { "glCopyTexSubImage2DEXT", 402 },
   { "glCopyTexSubImage3D", 403 },
   { "glCopyTexSubImage3DEXT", 404 },
   { "glCopyTexSubImage3DNV", 405 },
   { "glCopyTexSubImage3DOES", 406 },
   { "glCopyTextureImage1DEXT", 407 },
   { "glCopyTextureImage2DEXT", 408 },
   { "glCopyTextureLevelsAPPLE", 409 },
   { "glCopyTextureSubImage1D", 410 },
   { "glCopyTextureSubImage1DEXT", 411 },
   { "glCopyTextureSubImage2D", 412 },
   { "glCopyTextureSubImage2DEXT", 413 },
   { "glCopyTextureSubImage3D", 414 },
   { "glCopyTextureSubImage3DEXT", 415 },
   { "glCoverFillPathInstancedNV", 416 },
   { "glCoverFillPathNV", 417 },
   { "glCoverStrokePathInstancedNV", 418 },
   { "glCoverStrokePathNV", 419 },
   { "glCoverageMaskNV", 420 },
   { "glCoverageModulationNV", 421 },
   { "glCoverageModulationTableNV", 422 },
   { "glCoverageOperationNV", 423 },
   { "glCreateBuffers", 424 },
   { "glCreateCommandListsNV", 425 },
   { "glCreateFramebuffers", 426 },
   { "glCreateMemoryObjectsEXT", 427 },
   { "glCreatePerfQueryINTEL", 428 },
   { "glCreateProgram", 429 },
   { "glCreateProgramObjectARB", 430 },
   { "glCreateProgramPipelines", 431 },
   { "glCreateProgressFenceNVX", 432 },
   { "glCreateQueries", 433 },
   { "glCreateRenderbuffers", 434 },
   { "glCreateSamplers", 435 },
   { "glCreateShader", 437 },
   { "glCreateShaderObjectARB", 438 },
   { "glCreateShaderProgramEXT", 439 },
   { "glCreateShaderProgramv", 440 },
   { "glCreateShaderProgramvEXT", 441 },
   { "glCreateStatesNV", 442 },
   { "glCreateSyncFromCLeventARB", 443 },
   { "glCreateTextures", 444 },
   { "glCreateTransformFeedbacks", 445 },
   { "glCreateVertexArrays", 446 },
   { "glCullFace", 447 },
   { "glCullParameterdvEXT", 448 },
   { "glCullParameterfvEXT", 449 },
   { "glCurrentPaletteMatrixARB", 450 },
   { "glCurrentPaletteMatrixOES", 451 },
   { "glDebugMessageCallback", 452 },
   { "glDebugMessageCallbackAMD", 453 },
   { "glDebugMessageCallbackARB", 454 },
   { "glDebugMessageCallbackKHR", 455 },
   { "glDebugMessageCallbackOES", 456 },
   { "glDebugMessageControl", 457 },
   { "glDebugMessageControlARB", 458 },
   { "glDebugMessageControlKHR", 459 },
   { "glDebugMessageControlOES", 460 },
   { "glDebugMessageEnableAMD", 461 },
   { "glDebugMessageInsert", 462 },
   { "glDebugMessageInsertAMD", 463 },
   { "glDebugMessageInsertARB", 464 },
   { "glDebugMessageInsertKHR", 465 },
   { "glDebugMessageInsertOES", 466 },
   { "glDeformSGIX", 467 },
   { "glDeformationMap3dSGIX", 468 },
   { "glDeformationMap3fSGIX", 469 },
   { "glDeleteAsyncMarkersSGIX", 470 },
   { "glDeleteBuffers", 471 },
   { "glDeleteBuffersARB", 472 },
   { "glDeleteCommandListsNV", 473 },
   { "glDeleteFencesAPPLE", 474 },
   { "glDeleteFencesNV", 475 },
   { "glDeleteFragmentShaderATI", 476 },
   { "glDeleteFramebuffers", 477 },
   { "glDeleteFramebuffersEXT", 478 },
   { "glDeleteFramebuffersOES", 479 },
   { "glDeleteLists", 480 },
   { "glDeleteMemoryObjectsEXT", 481 },
   { "glDeleteNamedStringARB", 482 },
   { "glDeleteNamesAMD", 483 },
   { "glDeleteObjectARB", 484 },
   { "glDeleteOcclusionQueriesNV", 485 },
   { "glDeletePathsNV", 486 },
   { "glDeletePerfMonitorsAMD", 487 },
   { "glDeletePerfQueryINTEL", 488 },
   { "glDeleteProgram", 489 },
   { "glDeleteProgramPipelines", 490 },
   { "glDeleteProgramPipelinesEXT", 491 },
   { "glDeleteProgramsARB", 492 },
   { "glDeleteProgramsNV", 493 },
   { "glDeleteQueries", 494 },
   { "glDeleteQueriesARB", 495 },
   { "glDeleteQueriesEXT", 496 },
   { "glDeleteQueryResourceTagNV", 497 },
   { "glDeleteRenderbuffers", 498 },
   { "glDeleteRenderbuffersEXT", 499 },
   { "glDeleteRenderbuffersOES", 500 },
   { "glDeleteSamplers", 501 },
   { "glDeleteSemaphoresEXT", 502 },
   { "glDeleteShader", 503 },
   { "glDeleteStatesNV", 504 },
   { "glDeleteSync", 505 },
   { "glDeleteSyncAPPLE", 506 },
   { "glDeleteTextures", 507 },
   { "glDeleteTexturesEXT", 508 },
   { "glDeleteTransformFeedbacks", 509 },
   { "glDeleteTransformFeedbacksEXT", 510 },
   { "glDeleteTransformFeedbacksNV", 511 },
   { "glDeleteVertexArrays", 512 },
   { "glDeleteVertexArraysAPPLE", 513 },
   { "glDeleteVertexArraysOES", 514 },
   { "glDeleteVertexShaderEXT", 515 },
   { "glDepthBoundsEXT", 516 },
   { "glDepthBoundsdNV", 517 },
   { "glDepthFunc", 518 },
   { "glDepthMask", 519 },
   { "glDepthRange", 520 },
   { "glDepthRangeArraydvNV", 521 },
   { "glDepthRangeArrayfvNV", 522 },
   { "glDepthRangeArrayfvOES", 523 },
   { "glDepthRangeArrayv", 524 },
   { "glDepthRangeIndexed", 525 },
   { "glDepthRangeIndexeddNV", 526 },
   { "glDepthRangeIndexedfNV", 527 },
   { "glDepthRangeIndexedfOES", 528 },
   { "glDepthRangedNV", 529 },
   { "glDepthRangef", 530 },
   { "glDepthRangefOES", 531 },
   { "glDepthRangex", 532 },
   { "glDepthRangexOES", 533 },
   { "glDetachObjectARB", 534 },
   { "glDetachShader", 535 },
   { "glDetailTexFuncSGIS", 536 },
   { "glDevtoolsCorrelationIdNVX", 537 },
   { "glDevtoolsInvokeStreamedCallbackNVX", 538 },
   { "glDisable", 539 },
   { "glDisableClientState", 540 },
   { "glDisableClientStateIndexedEXT", 541 },
   { "glDisableClientStateiEXT", 542 },
   { "glDisableDriverControlQCOM", 543 },
   { "glDisableIndexedEXT", 544 },
   { "glDisableVariantClientStateEXT", 545 },
   { "glDisableVertexArrayAttrib", 546 },
   { "glDisableVertexArrayAttribEXT", 547 },
   { "glDisableVertexArrayEXT", 548 },
   { "glDisableVertexAttribAPPLE", 549 },
   { "glDisableVertexAttribArray", 550 },
   { "glDisableVertexAttribArrayARB", 551 },
   { "glDisablei", 552 },
   { "glDisableiEXT", 553 },
   { "glDisableiNV", 554 },
   { "glDisableiOES", 555 },
   { "glDiscardFramebufferEXT", 556 },
   { "glDispatchCompute", 557 },
   { "glDispatchComputeGroupSizeARB", 558 },
   { "glDispatchComputeIndirect", 559 },
   { "glDrawArrays", 560 },
   { "glDrawArraysEXT", 561 },
   { "glDrawArraysIndirect", 562 },
   { "glDrawArraysInstanced", 563 },
   { "glDrawArraysInstancedANGLE", 564 },
   { "glDrawArraysInstancedARB", 565 },
   { "glDrawArraysInstancedBaseInstance", 566 },
   { "glDrawArraysInstancedBaseInstanceEXT", 567 },
   { "glDrawArraysInstancedEXT", 568 },
   { "glDrawArraysInstancedNV", 569 },
   { "glDrawBuffer", 570 },
   { "glDrawBuffers", 571 },
   { "glDrawBuffersARB", 572 },
   { "glDrawBuffersATI", 573 },
   { "glDrawBuffersEXT", 574 },
   { "glDrawBuffersIndexedEXT", 575 },
   { "glDrawBuffersNV", 576 },
   { "glDrawCommandsAddressNV", 577 },
   { "glDrawCommandsNV", 578 },
   { "glDrawCommandsStatesAddressNV", 579 },
   { "glDrawCommandsStatesNV", 580 },
   { "glDrawElementArrayAPPLE", 581 },
   { "glDrawElementArrayATI", 582 },
   { "glDrawElements", 583 },
   { "glDrawElementsBaseVertex", 584 },
   { "glDrawElementsBaseVertexEXT", 585 },
   { "glDrawElementsBaseVertexOES", 586 },
   { "glDrawElementsIndirect", 587 },
   { "glDrawElementsInstanced", 588 },
   { "glDrawElementsInstancedANGLE", 589 },
   { "glDrawElementsInstancedARB", 590 },
   { "glDrawElementsInstancedBaseInstance", 591 },
   { "glDrawElementsInstancedBaseInstanceEXT", 592 },
   { "glDrawElementsInstancedBaseVertex", 593 },
   { "glDrawElementsInstancedBaseVertexBaseInstance", 594 },
   { "glDrawElementsInstancedBaseVertexBaseInstanceEXT", 595 },
   { "glDrawElementsInstancedBaseVertexEXT", 596 },
   { "glDrawElementsInstancedBaseVertexOES", 597 },
   { "glDrawElementsInstancedEXT", 598 },
   { "glDrawElementsInstancedNV", 599 },
   { "glDrawMeshArraysSUN", 600 },
   { "glDrawMeshNV", 601 },
   { "glDrawMeshTasksIndirectNV", 602 },
   { "glDrawMeshTasksNV", 603 },
   { "glDrawPixels", 604 },
   { "glDrawRangeElementArrayAPPLE", 605 },
   { "glDrawRangeElementArrayATI", 606 },
   { "glDrawRangeElements", 607 },
   { "glDrawRangeElementsBaseVertex", 608 },
   { "glDrawRangeElementsBaseVertexEXT", 609 },
   { "glDrawRangeElementsBaseVertexOES", 610 },
   { "glDrawRangeElementsEXT", 611 },
   { "glDrawTexfOES", 612 },
   { "glDrawTexfvOES", 613 },
   { "glDrawTexiOES", 614 },
   { "glDrawTexivOES", 615 },
   { "glDrawTexsOES", 616 },
   { "glDrawTexsvOES", 617 },
   { "glDrawTextureNV", 618 },
   { "glDrawTexxOES", 619 },
   { "glDrawTexxvOES", 620 },
   { "glDrawTransformFeedback", 621 },
   { "glDrawTransformFeedbackEXT", 622 },
   { "glDrawTransformFeedbackInstanced", 623 },
   { "glDrawTransformFeedbackInstancedEXT", 624 },
   { "glDrawTransformFeedbackNV", 625 },
   { "glDrawTransformFeedbackStream", 626 },
   { "glDrawTransformFeedbackStreamInstanced", 627 },
   { "glDrawVkImageNV", 628 },
   { "glEGLImageTargetRenderbufferStorageOES", 629 },
   { "glEGLImageTargetTexStorageEXT", 630 },
   { "glEGLImageTargetTexture2DOES", 631 },
   { "glEGLImageTargetTextureStorageEXT", 632 },
   { "glEdgeFlag", 633 },
   { "glEdgeFlagFormatNV", 634 },
   { "glEdgeFlagPointer", 635 },
   { "glEdgeFlagPointerEXT", 636 },
   { "glEdgeFlagPointerListIBM", 637 },
   { "glEdgeFlagv", 638 },
   { "glElementPointerAPPLE", 639 },
   { "glElementPointerATI", 640 },
   { "glEnable", 641 },
   { "glEnableClientState", 642 },
   { "glEnableClientStateIndexedEXT", 643 },
   { "glEnableClientStateiEXT", 644 },
   { "glEnableDriverControlQCOM", 645 },
   { "glEnableIndexedEXT", 646 },
   { "glEnableVariantClientStateEXT", 647 },
   { "glEnableVertexArrayAttrib", 648 },
   { "glEnableVertexArrayAttribEXT", 649 },
   { "glEnableVertexArrayEXT", 650 },
   { "glEnableVertexAttribAPPLE", 651 },
   { "glEnableVertexAttribArray", 652 },
   { "glEnableVertexAttribArrayARB", 653 },
   { "glEnablei", 654 },
   { "glEnableiEXT", 655 },
   { "glEnableiNV", 656 },
   { "glEnableiOES", 657 },
   { "glEnd", 658 },
   { "glEndConditionalRender", 659 },
   { "glEndConditionalRenderNV", 660 },
   { "glEndConditionalRenderNVX", 661 },
   { "glEndFragmentShaderATI", 662 },
   { "glEndList", 663 },
   { "glEndOcclusionQueryNV", 664 },
   { "glEndPerfMonitorAMD", 665 },
   { "glEndPerfQueryINTEL", 666 },
   { "glEndQuery", 667 },
   { "glEndQueryARB", 668 },
   { "glEndQueryEXT", 669 },
   { "glEndQueryIndexed", 670 },
   { "glEndTilingQCOM", 671 },
   { "glEndTransformFeedback", 672 },
   { "glEndTransformFeedbackEXT", 673 },
   { "glEndTransformFeedbackNV", 674 },
   { "glEndVertexShaderEXT", 675 },
   { "glEndVideoCaptureNV", 676 },
   { "glEvalCoord1d", 677 },
   { "glEvalCoord1dv", 678 },
   { "glEvalCoord1f", 679 },
   { "glEvalCoord1fv", 680 },
   { "glEvalCoord1xOES", 681 },
   { "glEvalCoord1xvOES", 682 },
   { "glEvalCoord2d", 683 },
   { "glEvalCoord2dv", 684 },
   { "glEvalCoord2f", 685 },
   { "glEvalCoord2fv", 686 },
   { "glEvalCoord2xOES", 687 },
   { "glEvalCoord2xvOES", 688 },
   { "glEvalMapsNV", 689 },
   { "glEvalMesh1", 690 },
   { "glEvalMesh2", 691 },
   { "glEvalPoint1", 692 },
   { "glEvalPoint2", 693 },
   { "glEvaluateDepthValuesARB", 694 },
   { "glExecuteProgramNV", 695 },
   { "glExtGetBufferPointervQCOM", 696 },
   { "glExtGetBuffersQCOM", 697 },
   { "glExtGetFramebuffersQCOM", 698 },
   { "glExtGetProgramBinarySourceQCOM", 699 },
   { "glExtGetProgramsQCOM", 700 },
   { "glExtGetRenderbuffersQCOM", 701 },
   { "glExtGetShadersQCOM", 702 },
   { "glExtGetTexLevelParameterivQCOM", 703 },
   { "glExtGetTexSubImageQCOM", 704 },
   { "glExtGetTexturesQCOM", 705 },
   { "glExtIsProgramBinaryQCOM", 706 },
   { "glExtTexObjectStateOverrideiQCOM", 707 },
   { "glExtractComponentEXT", 708 },
   { "glFeedbackBuffer", 710 },
   { "glFeedbackBufferxOES", 711 },
   { "glFenceSync", 712 },
   { "glFenceSyncAPPLE", 713 },
   { "glFenceValueuiNVX", 714 },
   { "glFinalCombinerInputNV", 715 },
   { "glFinish", 716 },
   { "glFinishAsyncSGIX", 717 },
   { "glFinishFenceAPPLE", 718 },
   { "glFinishFenceNV", 719 },
   { "glFinishObjectAPPLE", 720 },
   { "glFinishTextureSUNX", 721 },
   { "glFlush", 722 },
   { "glFlushMappedBufferRange", 723 },
   { "glFlushMappedBufferRangeAPPLE", 724 },
   { "glFlushMappedBufferRangeEXT", 725 },
   { "glFlushMappedNamedBufferRange", 726 },
   { "glFlushMappedNamedBufferRangeEXT", 727 },
   { "glFlushPixelDataRangeNV", 728 },
   { "glFlushRasterSGIX", 729 },
   { "glFlushStaticDataIBM", 730 },
   { "glFlushVertexArrayRangeAPPLE", 731 },
   { "glFlushVertexArrayRangeNV", 732 },
   { "glFogCoordFormatNV", 733 },
   { "glFogCoordPointer", 734 },
   { "glFogCoordPointerEXT", 735 },
   { "glFogCoordPointerListIBM", 736 },
   { "glFogCoordd", 737 },
   { "glFogCoorddEXT", 738 },
   { "glFogCoorddv", 739 },
   { "glFogCoorddvEXT", 740 },
   { "glFogCoordf", 741 },
   { "glFogCoordfEXT", 742 },
   { "glFogCoordfv", 743 },
   { "glFogCoordfvEXT", 744 },
   { "glFogCoordhNV", 745 },
   { "glFogCoordhvNV", 746 },
   { "glFogFuncSGIS", 747 },
   { "glFogf", 748 },
   { "glFogfv", 749 },
   { "glFogi", 750 },
   { "glFogiv", 751 },
   { "glFogx", 752 },
   { "glFogxOES", 753 },
   { "glFogxv", 754 },
   { "glFogxvOES", 755 },
   { "glFragmentColorMaterialSGIX", 756 },
   { "glFragmentCoverageColorNV", 757 },
   { "glFragmentLightModelfSGIX", 758 },
   { "glFragmentLightModelfvSGIX", 759 },
   { "glFragmentLightModeliSGIX", 760 },
   { "glFragmentLightModelivSGIX", 761 },
   { "glFragmentLightfSGIX", 762 },
   { "glFragmentLightfvSGIX", 763 },
   { "glFragmentLightiSGIX", 764 },
   { "glFragmentLightivSGIX", 765 },
   { "glFragmentMaterialfSGIX", 766 },
   { "glFragmentMaterialfvSGIX", 767 },
   { "glFragmentMaterialiSGIX", 768 },
   { "glFragmentMaterialivSGIX", 769 },
   { "glFrameTerminatorGREMEDY", 770 },
   { "glFrameZoomSGIX", 771 },
   { "glFramebufferDrawBufferEXT", 772 },
   { "glFramebufferDrawBuffersEXT", 773 },
   { "glFramebufferFetchBarrierEXT", 774 },
   { "glFramebufferFetchBarrierQCOM", 775 },
   { "glFramebufferFoveationConfigQCOM", 776 },
   { "glFramebufferFoveationParametersQCOM", 777 },
   { "glFramebufferParameteri", 778 },
   { "glFramebufferParameteriMESA", 779 },
   { "glFramebufferPixelLocalStorageSizeEXT", 780 },
   { "glFramebufferReadBufferEXT", 781 },
   { "glFramebufferRenderbuffer", 782 },
   { "glFramebufferRenderbufferEXT", 783 },
   { "glFramebufferRenderbufferOES", 784 },
   { "glFramebufferSampleLocationsfvARB", 785 },
   { "glFramebufferSampleLocationsfvNV", 786 },
   { "glFramebufferSamplePositionsfvAMD", 787 },
   { "glFramebufferTexture", 789 },
   { "glFramebufferTexture1D", 790 },
   { "glFramebufferTexture1DEXT", 791 },
   { "glFramebufferTexture2D", 792 },
   { "glFramebufferTexture2DDownsampleIMG", 793 },
   { "glFramebufferTexture2DEXT", 794 },
   { "glFramebufferTexture2DMultisampleEXT", 795 },
   { "glFramebufferTexture2DMultisampleIMG", 796 },
   { "glFramebufferTexture2DOES", 797 },
   { "glFramebufferTexture3D", 798 },
   { "glFramebufferTexture3DEXT", 799 },
   { "glFramebufferTexture3DOES", 800 },
   { "glFramebufferTextureARB", 801 },
   { "glFramebufferTextureEXT", 802 },
   { "glFramebufferTextureFaceARB", 803 },
   { "glFramebufferTextureFaceEXT", 804 },
   { "glFramebufferTextureLayer", 805 },
   { "glFramebufferTextureLayerARB", 806 },
   { "glFramebufferTextureLayerDownsampleIMG", 807 },
   { "glFramebufferTextureLayerEXT", 808 },
   { "glFramebufferTextureLayerNV", 809 },
   { "glFramebufferTextureMultisampleMultiviewOVR", 810 },
   { "glFramebufferTextureMultiviewOVR", 811 },
   { "glFramebufferTextureOES", 812 },
   { "glFreeObjectBufferATI", 813 },
   { "glFrontFace", 814 },
   { "glFrustum", 815 },
   { "glFrustumf", 816 },
   { "glFrustumfOES", 817 },
   { "glFrustumx", 818 },
   { "glFrustumxOES", 819 },
   { "glGenAsyncMarkersSGIX", 820 },
   { "glGenBuffers", 821 },
   { "glGenBuffersARB", 822 },
   { "glGenFencesAPPLE", 823 },
   { "glGenFencesNV", 824 },
   { "glGenFragmentShadersATI", 825 },
   { "glGenFramebuffers", 826 },
   { "glGenFramebuffersEXT", 827 },
   { "glGenFramebuffersOES", 828 },
   { "glGenLists", 829 },
   { "glGenNamesAMD", 830 },
   { "glGenOcclusionQueriesNV", 831 },
   { "glGenPathsNV", 832 },
   { "glGenPerfMonitorsAMD", 833 },
   { "glGenProgramPipelines", 834 },
   { "glGenProgramPipelinesEXT", 835 },
   { "glGenProgramsARB", 836 },
   { "glGenProgramsNV", 837 },
   { "glGenQueries", 838 },
   { "glGenQueriesARB", 839 },
   { "glGenQueriesEXT", 840 },
   { "glGenQueryResourceTagNV", 841 },
   { "glGenRenderbuffers", 842 },
   { "glGenRenderbuffersEXT", 843 },
   { "glGenRenderbuffersOES", 844 },
   { "glGenSamplers", 845 },
   { "glGenSemaphoresEXT", 846 },
   { "glGenSymbolsEXT", 847 },
   { "glGenTextures", 848 },
   { "glGenTexturesEXT", 849 },
   { "glGenTransformFeedbacks", 850 },
   { "glGenTransformFeedbacksEXT", 851 },
   { "glGenTransformFeedbacksNV", 852 },
   { "glGenVertexArrays", 853 },
   { "glGenVertexArraysAPPLE", 854 },
   { "glGenVertexArraysOES", 855 },
   { "glGenVertexShadersEXT", 856 },
   { "glGenerateMipmap", 857 },
   { "glGenerateMipmapEXT", 858 },
   { "glGenerateMipmapOES", 859 },
   { "glGenerateMultiTexMipmapEXT", 860 },
   { "glGenerateTextureMipmap", 861 },
   { "glGenerateTextureMipmapEXT", 862 },
   { "glGetActiveAtomicCounterBufferiv", 863 },
   { "glGetActiveAttrib", 864 },
   { "glGetActiveAttribARB", 865 },
   { "glGetActiveSubroutineName", 866 },
   { "glGetActiveSubroutineUniformName", 867 },
   { "glGetActiveSubroutineUniformiv", 868 },
   { "glGetActiveUniform", 869 },
   { "glGetActiveUniformARB", 870 },
   { "glGetActiveUniformBlockName", 871 },
   { "glGetActiveUniformBlockiv", 872 },
   { "glGetActiveUniformName", 873 },
   { "glGetActiveUniformsiv", 874 },
   { "glGetActiveVaryingNV", 875 },
   { "glGetArrayObjectfvATI", 876 },
   { "glGetArrayObjectivATI", 877 },
   { "glGetAttachedObjectsARB", 878 },
   { "glGetAttachedShaders", 879 },
   { "glGetAttribLocation", 880 },
   { "glGetAttribLocationARB", 881 },
   { "glGetBooleanIndexedvEXT", 882 },
   { "glGetBooleani_v", 883 },
   { "glGetBooleanv", 884 },
   { "glGetBufferParameteri64v", 885 },
   { "glGetBufferParameteriv", 886 },
   { "glGetBufferParameterivARB", 887 },
   { "glGetBufferParameterui64vNV", 888 },
   { "glGetBufferPointerv", 889 },
   { "glGetBufferPointervARB", 890 },
   { "glGetBufferPointervOES", 891 },
   { "glGetBufferSubData", 892 },
   { "glGetBufferSubDataARB", 893 },
   { "glGetClipPlane", 894 },
   { "glGetClipPlanef", 895 },
   { "glGetClipPlanefOES", 896 },
   { "glGetClipPlanex", 897 },
   { "glGetClipPlanexOES", 898 },
   { "glGetColorTable", 899 },
   { "glGetColorTableEXT", 900 },
   { "glGetColorTableParameterfv", 901 },
   { "glGetColorTableParameterfvEXT", 902 },
   { "glGetColorTableParameterfvSGI", 903 },
   { "glGetColorTableParameteriv", 904 },
   { "glGetColorTableParameterivEXT", 905 },
   { "glGetColorTableParameterivSGI", 906 },
   { "glGetColorTableSGI", 907 },
   { "glGetCombinerInputParameterfvNV", 908 },
   { "glGetCombinerInputParameterivNV", 909 },
   { "glGetCombinerOutputParameterfvNV", 910 },
   { "glGetCombinerOutputParameterivNV", 911 },
   { "glGetCombinerStageParameterfvNV", 912 },
   { "glGetCommandHeaderNV", 913 },
   { "glGetCompressedMultiTexImageEXT", 914 },
   { "glGetCompressedTexImage", 915 },
   { "glGetCompressedTexImageARB", 916 },
   { "glGetCompressedTexImageNV", 917 },
   { "glGetCompressedTextureImage", 918 },
   { "glGetCompressedTextureImageEXT", 919 },
   { "glGetCompressedTextureSubImage", 920 },
   { "glGetConvolutionFilter", 921 },
   { "glGetConvolutionFilterEXT", 922 },
   { "glGetConvolutionParameterfv", 923 },
   { "glGetConvolutionParameterfvEXT", 924 },
   { "glGetConvolutionParameteriv", 925 },
   { "glGetConvolutionParameterivEXT", 926 },
   { "glGetConvolutionParameterxvOES", 927 },
   { "glGetCoverageModulationTableNV", 928 },
   { "glGetDebugMessageLog", 929 },
   { "glGetDebugMessageLogAMD", 930 },
   { "glGetDebugMessageLogARB", 931 },
   { "glGetDebugMessageLogKHR", 932 },
   { "glGetDebugMessageLogOES", 933 },
   { "glGetDetailTexFuncSGIS", 934 },
   { "glGetDoubleIndexedvEXT", 935 },
   { "glGetDoublei_v", 936 },
   { "glGetDoublei_vEXT", 937 },
   { "glGetDoublev", 938 },
   { "glGetDriverControlStringQCOM", 939 },
   { "glGetDriverControlsQCOM", 940 },
   { "glGetError", 941 },
   { "glGetFenceivNV", 942 },
   { "glGetFinalCombinerInputParameterfvNV", 943 },
   { "glGetFinalCombinerInputParameterivNV", 944 },
   { "glGetFirstPerfQueryIdINTEL", 945 },
   { "glGetFixedv", 946 },
   { "glGetFixedvOES", 947 },
   { "glGetFloatIndexedvEXT", 948 },
   { "glGetFloati_v", 949 },
   { "glGetFloati_vEXT", 950 },
   { "glGetFloati_vNV", 951 },
   { "glGetFloati_vOES", 952 },
   { "glGetFloatv", 953 },
   { "glGetFogFuncSGIS", 954 },
   { "glGetFragDataIndex", 955 },
   { "glGetFragDataIndexEXT", 956 },
   { "glGetFragDataLocation", 957 },
   { "glGetFragDataLocationEXT", 958 },
   { "glGetFragmentLightfvSGIX", 959 },
   { "glGetFragmentLightivSGIX", 960 },
   { "glGetFragmentMaterialfvSGIX", 961 },
   { "glGetFragmentMaterialivSGIX", 962 },
   { "glGetFramebufferAttachmentParameteriv", 964 },
   { "glGetFramebufferAttachmentParameterivEXT", 965 },
   { "glGetFramebufferAttachmentParameterivOES", 966 },
   { "glGetFramebufferParameterfvAMD", 967 },
   { "glGetFramebufferParameteriv", 968 },
   { "glGetFramebufferParameterivEXT", 969 },
   { "glGetFramebufferParameterivMESA", 970 },
   { "glGetFramebufferPixelLocalStorageSizeEXT", 971 },
   { "glGetGraphicsResetStatus", 972 },
   { "glGetGraphicsResetStatusARB", 973 },
   { "glGetGraphicsResetStatusEXT", 974 },
   { "glGetGraphicsResetStatusKHR", 975 },
   { "glGetHandleARB", 976 },
   { "glGetHistogram", 977 },
   { "glGetHistogramEXT", 978 },
   { "glGetHistogramParameterfv", 979 },
   { "glGetHistogramParameterfvEXT", 980 },
   { "glGetHistogramParameteriv", 981 },
   { "glGetHistogramParameterivEXT", 982 },
   { "glGetHistogramParameterxvOES", 983 },
   { "glGetImageHandleARB", 984 },
   { "glGetImageHandleNV", 985 },
   { "glGetImageTransformParameterfvHP", 986 },
   { "glGetImageTransformParameterivHP", 987 },
   { "glGetInfoLogARB", 988 },
   { "glGetInstrumentsSGIX", 989 },
   { "glGetInteger64i_v", 990 },
   { "glGetInteger64v", 991 },
   { "glGetInteger64vAPPLE", 992 },
   { "glGetIntegerIndexedvEXT", 994 },
   { "glGetIntegeri_v", 995 },
   { "glGetIntegeri_vEXT", 996 },
   { "glGetIntegerui64i_vNV", 997 },
   { "glGetIntegerui64vNV", 998 },
   { "glGetIntegerv", 999 },
   { "glGetInternalformatSampleivNV", 1000 },
   { "glGetInternalformati64v", 1001 },
   { "glGetInternalformativ", 1002 },
   { "glGetInvariantBooleanvEXT", 1003 },
   { "glGetInvariantFloatvEXT", 1004 },
   { "glGetInvariantIntegervEXT", 1005 },
   { "glGetLightfv", 1006 },
   { "glGetLightiv", 1007 },
   { "glGetLightxOES", 1008 },
   { "glGetLightxv", 1009 },
   { "glGetLightxvOES", 1010 },
   { "glGetListParameterfvSGIX", 1011 },
   { "glGetListParameterivSGIX", 1012 },
   { "glGetLocalConstantBooleanvEXT", 1013 },
   { "glGetLocalConstantFloatvEXT", 1014 },
   { "glGetLocalConstantIntegervEXT", 1015 },
   { "glGetMapAttribParameterfvNV", 1016 },
   { "glGetMapAttribParameterivNV", 1017 },
   { "glGetMapControlPointsNV", 1018 },
   { "glGetMapParameterfvNV", 1019 },
   { "glGetMapParameterivNV", 1020 },
   { "glGetMapdv", 1021 },
   { "glGetMapfv", 1022 },
   { "glGetMapiv", 1023 },
   { "glGetMapxvOES", 1024 },
   { "glGetMaterialfv", 1025 },
   { "glGetMaterialiv", 1026 },
   { "glGetMaterialxOES", 1027 },
   { "glGetMaterialxv", 1028 },
   { "glGetMaterialxvOES", 1029 },
   { "glGetMemoryObjectDetachedResourcesuivNV", 1030 },
   { "glGetMemoryObjectParameterivEXT", 1031 },
   { "glGetMinmax", 1032 },
   { "glGetMinmaxEXT", 1033 },
   { "glGetMinmaxParameterfv", 1034 },
   { "glGetMinmaxParameterfvEXT", 1035 },
   { "glGetMinmaxParameteriv", 1036 },
   { "glGetMinmaxParameterivEXT", 1037 },
   { "glGetMultiTexEnvfvEXT", 1038 },
   { "glGetMultiTexEnvivEXT", 1039 },
   { "glGetMultiTexGendvEXT", 1040 },
   { "glGetMultiTexGenfvEXT", 1041 },
   { "glGetMultiTexGenivEXT", 1042 },
   { "glGetMultiTexImageEXT", 1043 },
   { "glGetMultiTexLevelParameterfvEXT", 1044 },
   { "glGetMultiTexLevelParameterivEXT", 1045 },
   { "glGetMultiTexParameterIivEXT", 1046 },
   { "glGetMultiTexParameterIuivEXT", 1047 },
   { "glGetMultiTexParameterfvEXT", 1048 },
   { "glGetMultiTexParameterivEXT", 1049 },
   { "glGetMultisamplefv", 1050 },
   { "glGetMultisamplefvNV", 1051 },
   { "glGetNamedBufferParameteri64v", 1052 },
   { "glGetNamedBufferParameteri64vEXT", 1053 },
   { "glGetNamedBufferParameteriv", 1054 },
   { "glGetNamedBufferParameterivEXT", 1055 },
   { "glGetNamedBufferParameterui64vNV", 1056 },
   { "glGetNamedBufferPointerv", 1057 },
   { "glGetNamedBufferPointervEXT", 1058 },
   { "glGetNamedBufferSubData", 1059 },
   { "glGetNamedBufferSubDataEXT", 1060 },
   { "glGetNamedFramebufferAttachmentParameteriv", 1061 },
   { "glGetNamedFramebufferAttachmentParameterivEXT", 1062 },
   { "glGetNamedFramebufferParameterfvAMD", 1063 },
   { "glGetNamedFramebufferParameteriv", 1064 },
   { "glGetNamedFramebufferParameterivEXT", 1065 },
   { "glGetNamedProgramLocalParameterIivEXT", 1066 },
   { "glGetNamedProgramLocalParameterIuivEXT", 1067 },
   { "glGetNamedProgramLocalParameterdvEXT", 1068 },
   { "glGetNamedProgramLocalParameterfvEXT", 1069 },
   { "glGetNamedProgramStringEXT", 1070 },
   { "glGetNamedProgramivEXT", 1071 },
   { "glGetNamedRenderbufferParameteriv", 1072 },
   { "glGetNamedRenderbufferParameterivEXT", 1073 },
   { "glGetNamedStringARB", 1074 },
   { "glGetNamedStringivARB", 1075 },
   { "glGetNextPerfQueryIdINTEL", 1076 },
   { "glGetObjectBufferfvATI", 1077 },
   { "glGetObjectBufferivATI", 1078 },
   { "glGetObjectLabel", 1079 },
   { "glGetObjectLabelEXT", 1080 },
   { "glGetObjectLabelKHR", 1081 },
   { "glGetObjectLabelOES", 1082 },
   { "glGetObjectParameterfvARB", 1083 },
   { "glGetObjectParameterivAPPLE", 1084 },
   { "glGetObjectParameterivARB", 1085 },
   { "glGetObjectPtrLabel", 1086 },
   { "glGetObjectPtrLabelKHR", 1087 },
   { "glGetObjectPtrLabelOES", 1088 },
   { "glGetOcclusionQueryivNV", 1089 },
   { "glGetOcclusionQueryuivNV", 1090 },
   { "glGetPathColorGenfvNV", 1091 },
   { "glGetPathColorGenivNV", 1092 },
   { "glGetPathCommandsNV", 1093 },
   { "glGetPathCoordsNV", 1094 },
   { "glGetPathDashArrayNV", 1095 },
   { "glGetPathLengthNV", 1096 },
   { "glGetPathMetricRangeNV", 1097 },
   { "glGetPathMetricsNV", 1098 },
   { "glGetPathParameterfvNV", 1099 },
   { "glGetPathParameterivNV", 1100 },
   { "glGetPathSpacingNV", 1101 },
   { "glGetPathTexGenfvNV", 1102 },
   { "glGetPathTexGenivNV", 1103 },
   { "glGetPerfCounterInfoINTEL", 1104 },
   { "glGetPerfMonitorCounterDataAMD", 1105 },
   { "glGetPerfMonitorCounterInfoAMD", 1106 },
   { "glGetPerfMonitorCounterStringAMD", 1107 },
   { "glGetPerfMonitorCountersAMD", 1108 },
   { "glGetPerfMonitorGroupStringAMD", 1109 },
   { "glGetPerfMonitorGroupsAMD", 1110 },
   { "glGetPerfQueryDataINTEL", 1111 },
   { "glGetPerfQueryIdByNameINTEL", 1112 },
   { "glGetPerfQueryInfoINTEL", 1113 },
   { "glGetPixelMapfv", 1114 },
   { "glGetPixelMapuiv", 1115 },
   { "glGetPixelMapusv", 1116 },
   { "glGetPixelMapxv", 1117 },
   { "glGetPixelTexGenParameterfvSGIS", 1118 },
   { "glGetPixelTexGenParameterivSGIS", 1119 },
   { "glGetPixelTransformParameterfvEXT", 1120 },
   { "glGetPixelTransformParameterivEXT", 1121 },
   { "glGetPointerIndexedvEXT", 1122 },
   { "glGetPointeri_vEXT", 1123 },
   { "glGetPointerv", 1124 },
   { "glGetPointervEXT", 1125 },
   { "glGetPointervKHR", 1126 },
   { "glGetPointervOES", 1127 },
   { "glGetPolygonStipple", 1128 },
   { "glGetProgramBinary", 1129 },
   { "glGetProgramBinaryOES", 1130 },
   { "glGetProgramEnvParameterIivNV", 1131 },
   { "glGetProgramEnvParameterIuivNV", 1132 },
   { "glGetProgramEnvParameterdvARB", 1133 },
   { "glGetProgramEnvParameterfvARB", 1134 },
   { "glGetProgramInfoLog", 1135 },
   { "glGetProgramInterfaceiv", 1136 },
   { "glGetProgramLocalParameterIivNV", 1137 },
   { "glGetProgramLocalParameterIuivNV", 1138 },
   { "glGetProgramLocalParameterdvARB", 1139 },
   { "glGetProgramLocalParameterfvARB", 1140 },
   { "glGetProgramNamedParameterdvNV", 1141 },
   { "glGetProgramNamedParameterfvNV", 1142 },
   { "glGetProgramParameterdvNV", 1143 },
   { "glGetProgramParameterfvNV", 1144 },
   { "glGetProgramPipelineInfoLog", 1145 },
   { "glGetProgramPipelineInfoLogEXT", 1146 },
   { "glGetProgramPipelineiv", 1147 },
   { "glGetProgramPipelineivEXT", 1148 },
   { "glGetProgramResourceIndex", 1149 },
   { "glGetProgramResourceLocation", 1150 },
   { "glGetProgramResourceLocationIndex", 1151 },
   { "glGetProgramResourceLocationIndexEXT", 1152 },
   { "glGetProgramResourceName", 1153 },
   { "glGetProgramResourcefvNV", 1154 },
   { "glGetProgramResourceiv", 1155 },
   { "glGetProgramStageiv", 1156 },
   { "glGetProgramStringARB", 1157 },
   { "glGetProgramStringNV", 1158 },
   { "glGetProgramSubroutineParameteruivNV", 1159 },
   { "glGetProgramiv", 1160 },
   { "glGetProgramivARB", 1161 },
   { "glGetProgramivNV", 1162 },
   { "glGetQueryBufferObjecti64v", 1163 },
   { "glGetQueryBufferObjectiv", 1164 },
   { "glGetQueryBufferObjectui64v", 1165 },
   { "glGetQueryBufferObjectuiv", 1166 },
   { "glGetQueryIndexediv", 1167 },
   { "glGetQueryObjecti64v", 1168 },
   { "glGetQueryObjecti64vEXT", 1169 },
   { "glGetQueryObjectiv", 1170 },
   { "glGetQueryObjectivARB", 1171 },
   { "glGetQueryObjectivEXT", 1172 },
   { "glGetQueryObjectui64v", 1173 },
   { "glGetQueryObjectui64vEXT", 1174 },
   { "glGetQueryObjectui64vNV", 1175 },
   { "glGetQueryObjectuiv", 1176 },
   { "glGetQueryObjectuivARB", 1177 },
   { "glGetQueryObjectuivEXT", 1178 },
   { "glGetQueryiv", 1179 },
   { "glGetQueryivARB", 1180 },
   { "glGetQueryivEXT", 1181 },
   { "glGetRenderbufferParameteriv", 1182 },
   { "glGetRenderbufferParameterivEXT", 1183 },
   { "glGetRenderbufferParameterivOES", 1184 },
   { "glGetSamplerParameterIiv", 1185 },
   { "glGetSamplerParameterIivEXT", 1186 },
   { "glGetSamplerParameterIivOES", 1187 },
   { "glGetSamplerParameterIuiv", 1188 },
   { "glGetSamplerParameterIuivEXT", 1189 },
   { "glGetSamplerParameterIuivOES", 1190 },
   { "glGetSamplerParameterfv", 1191 },
   { "glGetSamplerParameteriv", 1192 },
   { "glGetSemaphoreParameterui64vEXT", 1194 },
   { "glGetSeparableFilter", 1195 },
   { "glGetSeparableFilterEXT", 1196 },
   { "glGetShaderInfoLog", 1197 },
   { "glGetShaderPrecisionFormat", 1198 },
   { "glGetShaderSource", 1199 },
   { "glGetShaderSourceARB", 1200 },
   { "glGetShaderiv", 1201 },
   { "glGetShadingRateImagePaletteNV", 1202 },
   { "glGetShadingRateSampleLocationivNV", 1203 },
   { "glGetSharpenTexFuncSGIS", 1204 },
   { "glGetStageIndexNV", 1205 },
   { "glGetString", 1206 },
   { "glGetStringi", 1207 },
   { "glGetSubroutineIndex", 1208 },
   { "glGetSubroutineUniformLocation", 1209 },
   { "glGetSynciv", 1210 },
   { "glGetSyncivAPPLE", 1211 },
   { "glGetSyncv64NVX", 1212 },
   { "glGetTexBumpParameterfvATI", 1213 },
   { "glGetTexBumpParameterivATI", 1214 },
   { "glGetTexEnvfv", 1215 },
   { "glGetTexEnviv", 1216 },
   { "glGetTexEnvxv", 1217 },
   { "glGetTexEnvxvOES", 1218 },
   { "glGetTexFilterFuncSGIS", 1219 },
   { "glGetTexGendv", 1220 },
   { "glGetTexGenfv", 1221 },
   { "glGetTexGenfvOES", 1222 },
   { "glGetTexGeniv", 1223 },
   { "glGetTexGenivOES", 1224 },
   { "glGetTexGenxvOES", 1225 },
   { "glGetTexImage", 1226 },
   { "glGetTexImageNV", 1227 },
   { "glGetTexLevelParameterfv", 1228 },
   { "glGetTexLevelParameterfvNV", 1229 },
   { "glGetTexLevelParameteriv", 1230 },
   { "glGetTexLevelParameterivNV", 1231 },
   { "glGetTexLevelParameterxvOES", 1232 },
   { "glGetTexParameterIiv", 1233 },
   { "glGetTexParameterIivEXT", 1234 },
   { "glGetTexParameterIivOES", 1235 },
   { "glGetTexParameterIuiv", 1236 },
   { "glGetTexParameterIuivEXT", 1237 },
   { "glGetTexParameterIuivOES", 1238 },
   { "glGetTexParameterPointervAPPLE", 1239 },
   { "glGetTexParameterfv", 1240 },
   { "glGetTexParameteriv", 1241 },
   { "glGetTexParameterxv", 1242 },
   { "glGetTexParameterxvOES", 1243 },
   { "glGetTextureHandleARB", 1244 },
   { "glGetTextureHandleIMG", 1245 },
   { "glGetTextureHandleNV", 1246 },
   { "glGetTextureImage", 1247 },
   { "glGetTextureImageEXT", 1248 },
   { "glGetTextureLevelParameterfv", 1249 },
   { "glGetTextureLevelParameterfvEXT", 1250 },
   { "glGetTextureLevelParameteriv", 1251 },
   { "glGetTextureLevelParameterivEXT", 1252 },
   { "glGetTextureParameterIiv", 1253 },
   { "glGetTextureParameterIivEXT", 1254 },
   { "glGetTextureParameterIuiv", 1255 },
   { "glGetTextureParameterIuivEXT", 1256 },
   { "glGetTextureParameterfv", 1257 },
   { "glGetTextureParameterfvEXT", 1258 },
   { "glGetTextureParameteriv", 1259 },
   { "glGetTextureParameterivEXT", 1260 },
   { "glGetTextureSamplerHandleARB", 1261 },
   { "glGetTextureSamplerHandleIMG", 1262 },
   { "glGetTextureSamplerHandleNV", 1263 },
   { "glGetTextureSubImage", 1264 },
   { "glGetTrackMatrixivNV", 1265 },
   { "glGetTransformFeedbackVarying", 1266 },
   { "glGetTransformFeedbackVaryingEXT", 1267 },
   { "glGetTransformFeedbackVaryingNV", 1268 },
   { "glGetTransformFeedbacki64_v", 1269 },
   { "glGetTransformFeedbacki_v", 1270 },
   { "glGetTransformFeedbackiv", 1271 },
   { "glGetTranslatedShaderSourceANGLE", 1272 },
   { "glGetUniformBlockIndex", 1273 },
   { "glGetUniformBufferSizeEXT", 1274 },
   { "glGetUniformIndices", 1275 },
   { "glGetUniformLocation", 1276 },
   { "glGetUniformLocationARB", 1277 },
   { "glGetUniformOffsetEXT", 1278 },
   { "glGetUniformSubroutineuiv", 1279 },
   { "glGetUniformdv", 1280 },
   { "glGetUniformfv", 1281 },
   { "glGetUniformfvARB", 1282 },
   { "glGetUniformi64vARB", 1283 },
   { "glGetUniformi64vNV", 1284 },
   { "glGetUniformiv", 1285 },
   { "glGetUniformivARB", 1286 },
   { "glGetUniformui64vARB", 1287 },
   { "glGetUniformui64vNV", 1288 },
   { "glGetUniformuiv", 1289 },
   { "glGetUniformuivEXT", 1290 },
   { "glGetUnsignedBytei_vEXT", 1291 },
   { "glGetUnsignedBytevEXT", 1292 },
   { "glGetVariantArrayObjectfvATI", 1293 },
   { "glGetVariantArrayObjectivATI", 1294 },
   { "glGetVariantBooleanvEXT", 1295 },
   { "glGetVariantFloatvEXT", 1296 },
   { "glGetVariantIntegervEXT", 1297 },
   { "glGetVariantPointervEXT", 1298 },
   { "glGetVaryingLocationNV", 1299 },
   { "glGetVertexArrayIndexed64iv", 1300 },
   { "glGetVertexArrayIndexediv", 1301 },
   { "glGetVertexArrayIntegeri_vEXT", 1302 },
   { "glGetVertexArrayIntegervEXT", 1303 },
   { "glGetVertexArrayPointeri_vEXT", 1304 },
   { "glGetVertexArrayPointervEXT", 1305 },
   { "glGetVertexArrayiv", 1306 },
   { "glGetVertexAttribArrayObjectfvATI", 1307 },
   { "glGetVertexAttribArrayObjectivATI", 1308 },
   { "glGetVertexAttribIiv", 1309 },
   { "glGetVertexAttribIivEXT", 1310 },
   { "glGetVertexAttribIuiv", 1311 },
   { "glGetVertexAttribIuivEXT", 1312 },
   { "glGetVertexAttribLdv", 1313 },
   { "glGetVertexAttribLdvEXT", 1314 },
   { "glGetVertexAttribLi64vNV", 1315 },
   { "glGetVertexAttribLui64vARB", 1316 },
   { "glGetVertexAttribLui64vNV", 1317 },
   { "glGetVertexAttribPointerv", 1318 },
   { "glGetVertexAttribPointervARB", 1319 },
   { "glGetVertexAttribPointervNV", 1320 },
   { "glGetVertexAttribdv", 1321 },
   { "glGetVertexAttribdvARB", 1322 },
   { "glGetVertexAttribdvNV", 1323 },
   { "glGetVertexAttribfv", 1324 },
   { "glGetVertexAttribfvARB", 1325 },
   { "glGetVertexAttribfvNV", 1326 },
   { "glGetVertexAttribiv", 1327 },
   { "glGetVertexAttribivARB", 1328 },
   { "glGetVertexAttribivNV", 1329 },
   { "glGetVideoCaptureANCStreamivNVX", 1330 },
   { "glGetVideoCaptureStreamdvNV", 1331 },
   { "glGetVideoCaptureStreamfvNV", 1332 },
   { "glGetVideoCaptureStreamivNV", 1333 },
   { "glGetVideoCaptureivNV", 1334 },
   { "glGetVideoi64vNV", 1335 },
   { "glGetVideoivNV", 1336 },
   { "glGetVideoui64vNV", 1337 },
   { "glGetVideouivNV", 1338 },
   { "glGetVkProcAddrNV", 1339 },
   { "glGetnColorTable", 1340 },
   { "glGetnColorTableARB", 1341 },
   { "glGetnCompressedTexImage", 1342 },
   { "glGetnCompressedTexImageARB", 1343 },
   { "glGetnConvolutionFilter", 1344 },
   { "glGetnConvolutionFilterARB", 1345 },
   { "glGetnHistogram", 1346 },
   { "glGetnHistogramARB", 1347 },
   { "glGetnMapdv", 1348 },
   { "glGetnMapdvARB", 1349 },
   { "glGetnMapfv", 1350 },
   { "glGetnMapfvARB", 1351 },
   { "glGetnMapiv", 1352 },
   { "glGetnMapivARB", 1353 },
   { "glGetnMinmax", 1354 },
   { "glGetnMinmaxARB", 1355 },
   { "glGetnPixelMapfv", 1356 },
   { "glGetnPixelMapfvARB", 1357 },
   { "glGetnPixelMapuiv", 1358 },
   { "glGetnPixelMapuivARB", 1359 },
   { "glGetnPixelMapusv", 1360 },
   { "glGetnPixelMapusvARB", 1361 },
   { "glGetnPolygonStipple", 1362 },
   { "glGetnPolygonStippleARB", 1363 },
   { "glGetnSeparableFilter", 1364 },
   { "glGetnSeparableFilterARB", 1365 },
   { "glGetnTexImage", 1366 },
   { "glGetnTexImageARB", 1367 },
   { "glGetnUniformdv", 1368 },
   { "glGetnUniformdvARB", 1369 },
   { "glGetnUniformfv", 1370 },
   { "glGetnUniformfvARB", 1371 },
   { "glGetnUniformfvEXT", 1372 },
   { "glGetnUniformfvKHR", 1373 },
   { "glGetnUniformi64vARB", 1374 },
   { "glGetnUniformiv", 1375 },
   { "glGetnUniformivARB", 1376 },
   { "glGetnUniformivEXT", 1377 },
   { "glGetnUniformivKHR", 1378 },
   { "glGetnUniformui64vARB", 1379 },
   { "glGetnUniformuiv", 1380 },
   { "glGetnUniformuivARB", 1381 },
   { "glGetnUniformuivKHR", 1382 },
   { "glGlobalAlphaFactorbSUN", 1383 },
   { "glGlobalAlphaFactordSUN", 1384 },
   { "glGlobalAlphaFactorfSUN", 1385 },
   { "glGlobalAlphaFactoriSUN", 1386 },
   { "glGlobalAlphaFactorsSUN", 1387 },
   { "glGlobalAlphaFactorubSUN", 1388 },
   { "glGlobalAlphaFactoruiSUN", 1389 },
   { "glGlobalAlphaFactorusSUN", 1390 },
   { "glGpuSyncAcquireNVX", 1391 },
   { "glGpuSyncCreateNVX", 1392 },
   { "glGpuSyncDestroyNVX", 1393 },
   { "glGpuSyncReleaseNVX", 1394 },
   { "glHint", 1395 },
   { "glHintPGI", 1396 },
   { "glHistogram", 1397 },
   { "glHistogramEXT", 1398 },
   { "glIglooInterfaceSGIX", 1399 },
   { "glImageTransformParameterfHP", 1400 },
   { "glImageTransformParameterfvHP", 1401 },
   { "glImageTransformParameteriHP", 1402 },
   { "glImageTransformParameterivHP", 1403 },
   { "glImportMemoryFdEXT", 1404 },
   { "glImportMemoryWin32HandleEXT", 1405 },
   { "glImportMemoryWin32NameEXT", 1406 },
   { "glImportSemaphoreFdEXT", 1407 },
   { "glImportSemaphoreWin32HandleEXT", 1408 },
   { "glImportSemaphoreWin32NameEXT", 1409 },
   { "glImportSyncEXT", 1410 },
   { "glIndexFormatNV", 1411 },
   { "glIndexFuncEXT", 1412 },
   { "glIndexMask", 1413 },
   { "glIndexMaterialEXT", 1414 },
   { "glIndexPointer", 1415 },
   { "glIndexPointerEXT", 1416 },
   { "glIndexPointerListIBM", 1417 },
   { "glIndexd", 1418 },
   { "glIndexdv", 1419 },
   { "glIndexf", 1420 },
   { "glIndexfv", 1421 },
   { "glIndexi", 1422 },
   { "glIndexiv", 1423 },
   { "glIndexs", 1424 },
   { "glIndexsv", 1425 },
   { "glIndexub", 1426 },
   { "glIndexubv", 1427 },
   { "glIndexxOES", 1428 },
   { "glIndexxvOES", 1429 },
   { "glInitNames", 1430 },
   { "glInsertComponentEXT", 1431 },
   { "glInsertEventMarkerEXT", 1432 },
   { "glInstrumentsBufferSGIX", 1433 },
   { "glInterleavedArrays", 1434 },
   { "glInterpolatePathsNV", 1435 },
   { "glInvalidateBufferData", 1436 },
   { "glInvalidateBufferSubData", 1437 },
   { "glInvalidateFramebuffer", 1438 },
   { "glInvalidateNamedFramebufferData", 1439 },
   { "glInvalidateNamedFramebufferSubData", 1440 },
   { "glInvalidateSubFramebuffer", 1441 },
   { "glInvalidateTexImage", 1442 },
   { "glInvalidateTexSubImage", 1443 },
   { "glIsAsyncMarkerSGIX", 1444 },
   { "glIsBuffer", 1445 },
   { "glIsBufferARB", 1446 },
   { "glIsBufferResidentNV", 1447 },
   { "glIsCommandListNV", 1448 },
   { "glIsEnabled", 1449 },
   { "glIsEnabledIndexedEXT", 1450 },
   { "glIsEnabledi", 1451 },
   { "glIsEnablediEXT", 1452 },
   { "glIsEnablediNV", 1453 },
   { "glIsEnablediOES", 1454 },
   { "glIsFenceAPPLE", 1455 },
   { "glIsFenceNV", 1456 },
   { "glIsFramebuffer", 1457 },
   { "glIsFramebufferEXT", 1458 },
   { "glIsFramebufferOES", 1459 },
   { "glIsImageHandleResidentARB", 1460 },
   { "glIsImageHandleResidentNV", 1461 },
   { "glIsList", 1462 },
   { "glIsMemoryObjectEXT", 1463 },
   { "glIsNameAMD", 1464 },
   { "glIsNamedBufferResidentNV", 1465 },
   { "glIsNamedStringARB", 1466 },
   { "glIsObjectBufferATI", 1467 },
   { "glIsOcclusionQueryNV", 1468 },
   { "glIsPathNV", 1469 },
   { "glIsPointInFillPathNV", 1470 },
   { "glIsPointInStrokePathNV", 1471 },
   { "glIsProgram", 1472 },
   { "glIsProgramARB", 1473 },
   { "glIsProgramNV", 1474 },
   { "glIsProgramPipeline", 1475 },
   { "glIsProgramPipelineEXT", 1476 },
   { "glIsQuery", 1477 },
   { "glIsQueryARB", 1478 },
   { "glIsQueryEXT", 1479 },
   { "glIsRenderbuffer", 1480 },
   { "glIsRenderbufferEXT", 1481 },
   { "glIsRenderbufferOES", 1482 },
   { "glIsSampler", 1483 },
   { "glIsSemaphoreEXT", 1484 },
   { "glIsShader", 1485 },
   { "glIsStateNV", 1486 },
   { "glIsSync", 1487 },
   { "glIsSyncAPPLE", 1488 },
   { "glIsTexture", 1489 },
   { "glIsTextureEXT", 1490 },
   { "glIsTextureHandleResidentARB", 1491 },
   { "glIsTextureHandleResidentNV", 1492 },
   { "glIsTransformFeedback", 1493 },
   { "glIsTransformFeedbackEXT", 1494 },
   { "glIsTransformFeedbackNV", 1495 },
   { "glIsVariantEnabledEXT", 1496 },
   { "glIsVertexArray", 1497 },
   { "glIsVertexArrayAPPLE", 1498 },
   { "glIsVertexArrayOES", 1499 },
   { "glIsVertexAttribEnabledAPPLE", 1500 },
   { "glLGPUCopyImageSubDataNVX", 1501 },
   { "glLGPUInterlockNVX", 1502 },
   { "glLGPUNamedBufferSubDataNVX", 1503 },
   { "glLabelObjectEXT", 1504 },
   { "glLightEnviSGIX", 1505 },
   { "glLightModelf", 1506 },
   { "glLightModelfv", 1507 },
   { "glLightModeli", 1508 },
   { "glLightModeliv", 1509 },
   { "glLightModelx", 1510 },
   { "glLightModelxOES", 1511 },
   { "glLightModelxv", 1512 },
   { "glLightModelxvOES", 1513 },
   { "glLightf", 1514 },
   { "glLightfv", 1515 },
   { "glLighti", 1516 },
   { "glLightiv", 1517 },
   { "glLightx", 1518 },
   { "glLightxOES", 1519 },
   { "glLightxv", 1520 },
   { "glLightxvOES", 1521 },
   { "glLineStipple", 1522 },
   { "glLineWidth", 1523 },
   { "glLineWidthx", 1524 },
   { "glLineWidthxOES", 1525 },
   { "glLinkProgram", 1526 },
   { "glLinkProgramARB", 1527 },
   { "glListBase", 1528 },
   { "glListDrawCommandsStatesClientNV", 1529 },
   { "glListParameterfSGIX", 1530 },
   { "glListParameterfvSGIX", 1531 },
   { "glListParameteriSGIX", 1532 },
   { "glListParameterivSGIX", 1533 },
   { "glLoadIdentity", 1534 },
   { "glLoadIdentityDeformationMapSGIX", 1535 },
   { "glLoadMatrixd", 1536 },
   { "glLoadMatrixf", 1537 },
   { "glLoadMatrixx", 1538 },
   { "glLoadMatrixxOES", 1539 },
   { "glLoadName", 1540 },
   { "glLoadPaletteFromModelViewMatrixOES", 1541 },
   { "glLoadProgramNV", 1542 },
   { "glLoadTransformEXT", 1543 },
   { "glLoadTransposeMatrixd", 1544 },
   { "glLoadTransposeMatrixdARB", 1545 },
   { "glLoadTransposeMatrixf", 1546 },
   { "glLoadTransposeMatrixfARB", 1547 },
   { "glLoadTransposeMatrixxOES", 1548 },
   { "glLockArraysEXT", 1549 },
   { "glLogicOp", 1550 },
   { "glMakeBufferNonResidentNV", 1551 },
   { "glMakeBufferResidentNV", 1552 },
   { "glMakeImageHandleNonResidentARB", 1553 },
   { "glMakeImageHandleNonResidentNV", 1554 },
   { "glMakeImageHandleResidentARB", 1555 },
   { "glMakeImageHandleResidentNV", 1556 },
   { "glMakeNamedBufferNonResidentNV", 1557 },
   { "glMakeNamedBufferResidentNV", 1558 },
   { "glMakeTextureHandleNonResidentARB", 1559 },
   { "glMakeTextureHandleNonResidentNV", 1560 },
   { "glMakeTextureHandleResidentARB", 1561 },
   { "glMakeTextureHandleResidentNV", 1562 },
   { "glMap1d", 1563 },
   { "glMap1f", 1564 },
   { "glMap1xOES", 1565 },
   { "glMap2d", 1566 },
   { "glMap2f", 1567 },
   { "glMap2xOES", 1568 },
   { "glMapBuffer", 1569 },
   { "glMapBufferARB", 1570 },
   { "glMapBufferOES", 1571 },
   { "glMapBufferRange", 1572 },
   { "glMapBufferRangeEXT", 1573 },
   { "glMapControlPointsNV", 1574 },
   { "glMapGrid1d", 1575 },
   { "glMapGrid1f", 1576 },
   { "glMapGrid1xOES", 1577 },
   { "glMapGrid2d", 1578 },
   { "glMapGrid2f", 1579 },
   { "glMapGrid2xOES", 1580 },
   { "glMapNamedBuffer", 1581 },
   { "glMapNamedBufferEXT", 1582 },
   { "glMapNamedBufferRange", 1583 },
   { "glMapNamedBufferRangeEXT", 1584 },
   { "glMapObjectBufferATI", 1585 },
   { "glMapParameterfvNV", 1586 },
   { "glMapParameterivNV", 1587 },
   { "glMapTexture2DINTEL", 1588 },
   { "glMapVertexAttrib1dAPPLE", 1589 },
   { "glMapVertexAttrib1fAPPLE", 1590 },
   { "glMapVertexAttrib2dAPPLE", 1591 },
   { "glMapVertexAttrib2fAPPLE", 1592 },
   { "glMaterialf", 1593 },
   { "glMaterialfv", 1594 },
   { "glMateriali", 1595 },
   { "glMaterialiv", 1596 },
   { "glMaterialx", 1597 },
   { "glMaterialxOES", 1598 },
   { "glMaterialxv", 1599 },
   { "glMaterialxvOES", 1600 },
   { "glMatrixFrustumEXT", 1601 },
   { "glMatrixIndexPointerARB", 1602 },
   { "glMatrixIndexPointerOES", 1603 },
   { "glMatrixIndexubvARB", 1604 },
   { "glMatrixIndexuivARB", 1605 },
   { "glMatrixIndexusvARB", 1606 },
   { "glMatrixLoad3x2fNV", 1607 },
   { "glMatrixLoad3x3fNV", 1608 },
   { "glMatrixLoadIdentityEXT", 1609 },
   { "glMatrixLoadTranspose3x3fNV", 1610 },
   { "glMatrixLoadTransposedEXT", 1611 },
   { "glMatrixLoadTransposefEXT", 1612 },
   { "glMatrixLoaddEXT", 1613 },
   { "glMatrixLoadfEXT", 1614 },
   { "glMatrixMode", 1615 },
   { "glMatrixMult3x2fNV", 1616 },
   { "glMatrixMult3x3fNV", 1617 },
   { "glMatrixMultTranspose3x3fNV", 1618 },
   { "glMatrixMultTransposedEXT", 1619 },
   { "glMatrixMultTransposefEXT", 1620 },
   { "glMatrixMultdEXT", 1621 },
   { "glMatrixMultfEXT", 1622 },
   { "glMatrixOrthoEXT", 1623 },
   { "glMatrixPopEXT", 1624 },
   { "glMatrixPushEXT", 1625 },
   { "glMatrixRotatedEXT", 1626 },
   { "glMatrixRotatefEXT", 1627 },
   { "glMatrixScaledEXT", 1628 },
   { "glMatrixScalefEXT", 1629 },
   { "glMatrixTranslatedEXT", 1630 },
   { "glMatrixTranslatefEXT", 1631 },
   { "glMaxShaderCompilerThreadsARB", 1632 },
   { "glMaxShaderCompilerThreadsKHR", 1633 },
   { "glMemoryBarrier", 1634 },
   { "glMemoryBarrierByRegion", 1635 },
   { "glMemoryBarrierEXT", 1636 },
   { "glMemoryObjectParameterivEXT", 1637 },
   { "glMinSampleShading", 1638 },
   { "glMinSampleShadingARB", 1639 },
   { "glMinSampleShadingOES", 1640 },
   { "glMinmax", 1641 },
   { "glMinmaxEXT", 1642 },
   { "glMultMatrixd", 1643 },
   { "glMultMatrixf", 1644 },
   { "glMultMatrixx", 1645 },
   { "glMultMatrixxOES", 1646 },
   { "glMultTransformEXT", 1647 },
   { "glMultTransposeMatrixd", 1648 },
   { "glMultTransposeMatrixdARB", 1649 },
   { "glMultTransposeMatrixf", 1650 },
   { "glMultTransposeMatrixfARB", 1651 },
   { "glMultTransposeMatrixxOES", 1652 },
   { "glMultiDrawArrays", 1653 },
   { "glMultiDrawArraysEXT", 1654 },
   { "glMultiDrawArraysIndirect", 1655 },
   { "glMultiDrawArraysIndirectAMD", 1656 },
   { "glMultiDrawArraysIndirectBindlessCountNV", 1657 },
   { "glMultiDrawArraysIndirectBindlessNV", 1658 },
   { "glMultiDrawArraysIndirectCount", 1659 },
   { "glMultiDrawArraysIndirectCountARB", 1660 },
   { "glMultiDrawArraysIndirectEXT", 1661 },
   { "glMultiDrawElementArrayAPPLE", 1662 },
   { "glMultiDrawElements", 1663 },
   { "glMultiDrawElementsBaseVertex", 1664 },
   { "glMultiDrawElementsBaseVertexEXT", 1665 },
   { "glMultiDrawElementsEXT", 1666 },
   { "glMultiDrawElementsIndirect", 1667 },
   { "glMultiDrawElementsIndirectAMD", 1668 },
   { "glMultiDrawElementsIndirectBindlessCountNV", 1669 },
   { "glMultiDrawElementsIndirectBindlessNV", 1670 },
   { "glMultiDrawElementsIndirectCount", 1671 },
   { "glMultiDrawElementsIndirectCountARB", 1672 },
   { "glMultiDrawElementsIndirectEXT", 1673 },
   { "glMultiDrawMeshTasksIndirectCountNV", 1674 },
   { "glMultiDrawMeshTasksIndirectNV", 1675 },
   { "glMultiDrawRangeElementArrayAPPLE", 1676 },
   { "glMultiModeDrawArraysIBM", 1677 },
   { "glMultiModeDrawElementsIBM", 1678 },
   { "glMultiTexBufferEXT", 1679 },
   { "glMultiTexCoord1bOES", 1680 },
   { "glMultiTexCoord1bvOES", 1681 },
   { "glMultiTexCoord1d", 1682 },
   { "glMultiTexCoord1dARB", 1683 },
   { "glMultiTexCoord1dv", 1684 },
   { "glMultiTexCoord1dvARB", 1685 },
   { "glMultiTexCoord1f", 1686 },
   { "glMultiTexCoord1fARB", 1687 },
   { "glMultiTexCoord1fv", 1688 },
   { "glMultiTexCoord1fvARB", 1689 },
   { "glMultiTexCoord1hNV", 1690 },
   { "glMultiTexCoord1hvNV", 1691 },
   { "glMultiTexCoord1i", 1692 },
   { "glMultiTexCoord1iARB", 1693 },
   { "glMultiTexCoord1iv", 1694 },
   { "glMultiTexCoord1ivARB", 1695 },
   { "glMultiTexCoord1s", 1696 },
   { "glMultiTexCoord1sARB", 1697 },
   { "glMultiTexCoord1sv", 1698 },
   { "glMultiTexCoord1svARB", 1699 },
   { "glMultiTexCoord1x", 1700 },
   { "glMultiTexCoord1xOES", 1701 },
   { "glMultiTexCoord1xv", 1702 },
   { "glMultiTexCoord1xvOES", 1703 },
   { "glMultiTexCoord2bOES", 1704 },
   { "glMultiTexCoord2bvOES", 1705 },
   { "glMultiTexCoord2d", 1706 },
   { "glMultiTexCoord2dARB", 1707 },
   { "glMultiTexCoord2dv", 1708 },
   { "glMultiTexCoord2dvARB", 1709 },
   { "glMultiTexCoord2f", 1710 },
   { "glMultiTexCoord2fARB", 1711 },
   { "glMultiTexCoord2fv", 1712 },
   { "glMultiTexCoord2fvARB", 1713 },
   { "glMultiTexCoord2hNV", 1714 },
   { "glMultiTexCoord2hvNV", 1715 },
   { "glMultiTexCoord2i", 1716 },
   { "glMultiTexCoord2iARB", 1717 },
   { "glMultiTexCoord2iv", 1718 },
   { "glMultiTexCoord2ivARB", 1719 },
   { "glMultiTexCoord2s", 1720 },
   { "glMultiTexCoord2sARB", 1721 },
   { "glMultiTexCoord2sv", 1722 },
   { "glMultiTexCoord2svARB", 1723 },
   { "glMultiTexCoord2x", 1724 },
   { "glMultiTexCoord2xOES", 1725 },
   { "glMultiTexCoord2xv", 1726 },
   { "glMultiTexCoord2xvOES", 1727 },
   { "glMultiTexCoord3bOES", 1728 },
   { "glMultiTexCoord3bvOES", 1729 },
   { "glMultiTexCoord3d", 1730 },
   { "glMultiTexCoord3dARB", 1731 },
   { "glMultiTexCoord3dv", 1732 },
   { "glMultiTexCoord3dvARB", 1733 },
   { "glMultiTexCoord3f", 1734 },
   { "glMultiTexCoord3fARB", 1735 },
   { "glMultiTexCoord3fv", 1736 },
   { "glMultiTexCoord3fvARB", 1737 },
   { "glMultiTexCoord3hNV", 1738 },
   { "glMultiTexCoord3hvNV", 1739 },
   { "glMultiTexCoord3i", 1740 },
   { "glMultiTexCoord3iARB", 1741 },
   { "glMultiTexCoord3iv", 1742 },
   { "glMultiTexCoord3ivARB", 1743 },
   { "glMultiTexCoord3s", 1744 },
   { "glMultiTexCoord3sARB", 1745 },
   { "glMultiTexCoord3sv", 1746 },
   { "glMultiTexCoord3svARB", 1747 },
   { "glMultiTexCoord3x", 1748 },
   { "glMultiTexCoord3xOES", 1749 },
   { "glMultiTexCoord3xv", 1750 },
   { "glMultiTexCoord3xvOES", 1751 },
   { "glMultiTexCoord4bOES", 1752 },
   { "glMultiTexCoord4bvOES", 1753 },
   { "glMultiTexCoord4d", 1754 },
   { "glMultiTexCoord4dARB", 1755 },
   { "glMultiTexCoord4dv", 1756 },
   { "glMultiTexCoord4dvARB", 1757 },
   { "glMultiTexCoord4f", 1758 },
   { "glMultiTexCoord4fARB", 1759 },
   { "glMultiTexCoord4fv", 1760 },
   { "glMultiTexCoord4fvARB", 1761 },
   { "glMultiTexCoord4hNV", 1762 },
   { "glMultiTexCoord4hvNV", 1763 },
   { "glMultiTexCoord4i", 1764 },
   { "glMultiTexCoord4iARB", 1765 },
   { "glMultiTexCoord4iv", 1766 },
   { "glMultiTexCoord4ivARB", 1767 },
   { "glMultiTexCoord4s", 1768 },
   { "glMultiTexCoord4sARB", 1769 },
   { "glMultiTexCoord4sv", 1770 },
   { "glMultiTexCoord4svARB", 1771 },
   { "glMultiTexCoord4x", 1772 },
   { "glMultiTexCoord4xOES", 1773 },
   { "glMultiTexCoord4xv", 1774 },
   { "glMultiTexCoord4xvOES", 1775 },
   { "glMultiTexCoordP1ui", 1776 },
   { "glMultiTexCoordP1uiv", 1777 },
   { "glMultiTexCoordP2ui", 1778 },
   { "glMultiTexCoordP2uiv", 1779 },
   { "glMultiTexCoordP3ui", 1780 },
   { "glMultiTexCoordP3uiv", 1781 },
   { "glMultiTexCoordP4ui", 1782 },
   { "glMultiTexCoordP4uiv", 1783 },
   { "glMultiTexCoordPointerEXT", 1784 },
   { "glMultiTexEnvfEXT", 1785 },
   { "glMultiTexEnvfvEXT", 1786 },
   { "glMultiTexEnviEXT", 1787 },
   { "glMultiTexEnvivEXT", 1788 },
   { "glMultiTexGendEXT", 1789 },
   { "glMultiTexGendvEXT", 1790 },
   { "glMultiTexGenfEXT", 1791 },
   { "glMultiTexGenfvEXT", 1792 },
   { "glMultiTexGeniEXT", 1793 },
   { "glMultiTexGenivEXT", 1794 },
   { "glMultiTexImage1DEXT", 1795 },
   { "glMultiTexImage2DEXT", 1796 },
   { "glMultiTexImage3DEXT", 1797 },
   { "glMultiTexParameterIivEXT", 1798 },
   { "glMultiTexParameterIuivEXT", 1799 },
   { "glMultiTexParameterfEXT", 1800 },
   { "glMultiTexParameterfvEXT", 1801 },
   { "glMultiTexParameteriEXT", 1802 },
   { "glMultiTexParameterivEXT", 1803 },
   { "glMultiTexRenderbufferEXT", 1804 },
   { "glMultiTexSubImage1DEXT", 1805 },
   { "glMultiTexSubImage2DEXT", 1806 },
   { "glMultiTexSubImage3DEXT", 1807 },
   { "glMulticastBarrierNV", 1808 },
   { "glMulticastBlitFramebufferNV", 1809 },
   { "glMulticastBufferSubDataNV", 1810 },
   { "glMulticastCopyBufferSubDataNV", 1811 },
   { "glMulticastCopyImageSubDataNV", 1812 },
   { "glMulticastFramebufferSampleLocationsfvNV", 1813 },
   { "glMulticastGetQueryObjecti64vNV", 1814 },
   { "glMulticastGetQueryObjectivNV", 1815 },
   { "glMulticastGetQueryObjectui64vNV", 1816 },
   { "glMulticastGetQueryObjectuivNV", 1817 },
   { "glMulticastScissorArrayvNVX", 1818 },
   { "glMulticastViewportArrayvNVX", 1819 },
   { "glMulticastViewportPositionWScaleNVX", 1820 },
   { "glMulticastWaitSyncNV", 1821 },
   { "glNVENCInterOpFunctionNVX", 1822 },
   { "glNamedBufferAttachMemoryNV", 1823 },
   { "glNamedBufferData", 1824 },
   { "glNamedBufferDataEXT", 1825 },
   { "glNamedBufferPageCommitmentARB", 1826 },
   { "glNamedBufferPageCommitmentEXT", 1827 },
   { "glNamedBufferStorage", 1829 },
   { "glNamedBufferStorageEXT", 1830 },
   { "glNamedBufferStorageExternalEXT", 1831 },
   { "glNamedBufferStorageMemEXT", 1832 },
   { "glNamedBufferSubData", 1833 },
   { "glNamedBufferSubDataEXT", 1834 },
   { "glNamedCopyBufferSubDataEXT", 1835 },
   { "glNamedFramebufferDrawBuffer", 1836 },
   { "glNamedFramebufferDrawBuffers", 1837 },
   { "glNamedFramebufferParameteri", 1838 },
   { "glNamedFramebufferParameteriEXT", 1839 },
   { "glNamedFramebufferReadBuffer", 1840 },
   { "glNamedFramebufferRenderbuffer", 1841 },
   { "glNamedFramebufferRenderbufferEXT", 1842 },
   { "glNamedFramebufferSampleLocationsfvARB", 1843 },
   { "glNamedFramebufferSampleLocationsfvNV", 1844 },
   { "glNamedFramebufferSamplePositionsfvAMD", 1845 },
   { "glNamedFramebufferTexture", 1846 },
   { "glNamedFramebufferTexture1DEXT", 1847 },
   { "glNamedFramebufferTexture2DEXT", 1848 },
   { "glNamedFramebufferTexture3DEXT", 1849 },
   { "glNamedFramebufferTextureEXT", 1850 },
   { "glNamedFramebufferTextureFaceEXT", 1851 },
   { "glNamedFramebufferTextureLayer", 1852 },
   { "glNamedFramebufferTextureLayerEXT", 1853 },
   { "glNamedProgramLocalParameter4dEXT", 1854 },
   { "glNamedProgramLocalParameter4dvEXT", 1855 },
   { "glNamedProgramLocalParameter4fEXT", 1856 },
   { "glNamedProgramLocalParameter4fvEXT", 1857 },
   { "glNamedProgramLocalParameterI4iEXT", 1858 },
   { "glNamedProgramLocalParameterI4ivEXT", 1859 },
   { "glNamedProgramLocalParameterI4uiEXT", 1860 },
   { "glNamedProgramLocalParameterI4uivEXT", 1861 },
   { "glNamedProgramLocalParameters4fvEXT", 1862 },
   { "glNamedProgramLocalParametersI4ivEXT", 1863 },
   { "glNamedProgramLocalParametersI4uivEXT", 1864 },
   { "glNamedProgramStringEXT", 1865 },
   { "glNamedRenderbufferStorage", 1866 },
   { "glNamedRenderbufferStorageEXT", 1867 },
   { "glNamedRenderbufferStorageMultisample", 1868 },
   { "glNamedRenderbufferStorageMultisampleAdvancedAMD", 1869 },
   { "glNamedRenderbufferStorageMultisampleCoverageEXT", 1870 },
   { "glNamedRenderbufferStorageMultisampleEXT", 1871 },
   { "glNamedStringARB", 1872 },
   { "glNewList", 1873 },
   { "glNewObjectBufferATI", 1874 },
   { "glNormal3b", 1875 },
   { "glNormal3bv", 1876 },
   { "glNormal3d", 1877 },
   { "glNormal3dv", 1878 },
   { "glNormal3f", 1879 },
   { "glNormal3fVertex3fSUN", 1880 },
   { "glNormal3fVertex3fvSUN", 1881 },
   { "glNormal3fv", 1882 },
   { "glNormal3hNV", 1883 },
   { "glNormal3hvNV", 1884 },
   { "glNormal3i", 1885 },
   { "glNormal3iv", 1886 },
   { "glNormal3s", 1887 },
   { "glNormal3sv", 1888 },
   { "glNormal3x", 1889 },
   { "glNormal3xOES", 1890 },
   { "glNormal3xvOES", 1891 },
   { "glNormalFormatNV", 1892 },
   { "glNormalP3ui", 1893 },
   { "glNormalP3uiv", 1894 },
   { "glNormalPointer", 1895 },
   { "glNormalPointerEXT", 1896 },
   { "glNormalPointerListIBM", 1897 },
   { "glNormalPointervINTEL", 1898 },
   { "glNormalStream3bATI", 1899 },
   { "glNormalStream3bvATI", 1900 },
   { "glNormalStream3dATI", 1901 },
   { "glNormalStream3dvATI", 1902 },
   { "glNormalStream3fATI", 1903 },
   { "glNormalStream3fvATI", 1904 },
   { "glNormalStream3iATI", 1905 },
   { "glNormalStream3ivATI", 1906 },
   { "glNormalStream3sATI", 1907 },
   { "glNormalStream3svATI", 1908 },
   { "glObjectLabel", 1909 },
   { "glObjectLabelKHR", 1910 },
   { "glObjectLabelOES", 1911 },
   { "glObjectPtrLabel", 1912 },
   { "glObjectPtrLabelKHR", 1913 },
   { "glObjectPtrLabelOES", 1914 },
   { "glObjectPurgeableAPPLE", 1915 },
   { "glObjectUnpurgeableAPPLE", 1916 },
   { "glOrtho", 1917 },
   { "glOrthof", 1918 },
   { "glOrthofOES", 1919 },
   { "glOrthox", 1920 },
   { "glOrthoxOES", 1921 },
   { "glPNTrianglesfATI", 1922 },
   { "glPNTrianglesiATI", 1923 },
   { "glPassTexCoordATI", 1924 },
   { "glPassThrough", 1925 },
   { "glPassThroughxOES", 1926 },
   { "glPatchParameterfv", 1927 },
   { "glPatchParameterfvEXT", 1928 },
   { "glPatchParameterfvNV", 1929 },
   { "glPatchParameteri", 1930 },
   { "glPatchParameteriEXT", 1931 },
   { "glPatchParameteriNV", 1932 },
   { "glPatchParameteriOES", 1933 },
   { "glPathColorGenNV", 1934 },
   { "glPathCommandsNV", 1935 },
   { "glPathCoordsNV", 1936 },
   { "glPathCoverDepthFuncNV", 1937 },
   { "glPathDashArrayNV", 1938 },
   { "glPathFogGenNV", 1939 },
   { "glPathGlyphIndexArrayNV", 1940 },
   { "glPathGlyphIndexRangeNV", 1941 },
   { "glPathGlyphRangeNV", 1942 },
   { "glPathGlyphsNV", 1943 },
   { "glPathMemoryGlyphIndexArrayNV", 1944 },
   { "glPathParameterfNV", 1945 },
   { "glPathParameterfvNV", 1946 },
   { "glPathParameteriNV", 1947 },
   { "glPathParameterivNV", 1948 },
   { "glPathStencilDepthOffsetNV", 1949 },
   { "glPathStencilFuncNV", 1950 },
   { "glPathStringNV", 1951 },
   { "glPathSubCommandsNV", 1952 },
   { "glPathSubCoordsNV", 1953 },
   { "glPathTexGenNV", 1954 },
   { "glPauseTransformFeedback", 1955 },
   { "glPauseTransformFeedbackEXT", 1956 },
   { "glPauseTransformFeedbackNV", 1957 },
   { "glPixelDataRangeNV", 1958 },
   { "glPixelMapfv", 1959 },
   { "glPixelMapuiv", 1960 },
   { "glPixelMapusv", 1961 },
   { "glPixelMapx", 1962 },
   { "glPixelStoref", 1963 },
   { "glPixelStorei", 1964 },
   { "glPixelStorex", 1965 },
   { "glPixelTexGenParameterfSGIS", 1966 },
   { "glPixelTexGenParameterfvSGIS", 1967 },
   { "glPixelTexGenParameteriSGIS", 1968 },
   { "glPixelTexGenParameterivSGIS", 1969 },
   { "glPixelTexGenSGIX", 1970 },
   { "glPixelTransferf", 1971 },
   { "glPixelTransferi", 1972 },
   { "glPixelTransferxOES", 1973 },
   { "glPixelTransformParameterfEXT", 1974 },
   { "glPixelTransformParameterfvEXT", 1975 },
   { "glPixelTransformParameteriEXT", 1976 },
   { "glPixelTransformParameterivEXT", 1977 },
   { "glPixelZoom", 1978 },
   { "glPixelZoomxOES", 1979 },
   { "glPointAlongPathNV", 1980 },
   { "glPointParameterf", 1981 },
   { "glPointParameterfARB", 1982 },
   { "glPointParameterfEXT", 1983 },
   { "glPointParameterfSGIS", 1984 },
   { "glPointParameterfv", 1985 },
   { "glPointParameterfvARB", 1986 },
   { "glPointParameterfvEXT", 1987 },
   { "glPointParameterfvSGIS", 1988 },
   { "glPointParameteri", 1989 },
   { "glPointParameteriNV", 1990 },
   { "glPointParameteriv", 1991 },
   { "glPointParameterivNV", 1992 },
   { "glPointParameterx", 1993 },
   { "glPointParameterxOES", 1994 },
   { "glPointParameterxv", 1995 },
   { "glPointParameterxvOES", 1996 },
   { "glPointSize", 1997 },
   { "glPointSizePointerOES", 1998 },
   { "glPointSizex", 1999 },
   { "glPointSizexOES", 2000 },
   { "glPollAsyncSGIX", 2001 },
   { "glPollInstrumentsSGIX", 2002 },
   { "glPolygonMode", 2003 },
   { "glPolygonModeNV", 2004 },
   { "glPolygonOffset", 2005 },
   { "glPolygonOffsetClamp", 2006 },
   { "glPolygonOffsetClampEXT", 2007 },
   { "glPolygonOffsetEXT", 2008 },
   { "glPolygonOffsetx", 2009 },
   { "glPolygonOffsetxOES", 2010 },
   { "glPolygonStipple", 2011 },
   { "glPopAttrib", 2012 },
   { "glPopClientAttrib", 2013 },
   { "glPopDebugGroup", 2014 },
   { "glPopDebugGroupKHR", 2015 },
   { "glPopDebugGroupOES", 2016 },
   { "glPopGroupMarkerEXT", 2017 },
   { "glPopMatrix", 2018 },
   { "glPopName", 2019 },
   { "glPresentFrameDualFillNV", 2020 },
   { "glPresentFrameKeyedNV", 2021 },
   { "glPrimitiveBoundingBox", 2022 },
   { "glPrimitiveBoundingBoxARB", 2023 },
   { "glPrimitiveBoundingBoxEXT", 2024 },
   { "glPrimitiveBoundingBoxOES", 2025 },
   { "glPrimitiveRestart", 2026 },
   { "glPrimitiveRestartIndex", 2027 },
   { "glPrimitiveRestartIndexNV", 2028 },
   { "glPrimitiveRestartNV", 2029 },
   { "glPrioritizeTextures", 2030 },
   { "glPrioritizeTexturesEXT", 2031 },
   { "glPrioritizeTexturesxOES", 2032 },
   { "glProgramBinary", 2033 },
   { "glProgramBinaryOES", 2034 },
   { "glProgramBufferParametersIivNV", 2035 },
   { "glProgramBufferParametersIuivNV", 2036 },
   { "glProgramBufferParametersfvNV", 2037 },
   { "glProgramEnvParameter4dARB", 2038 },
   { "glProgramEnvParameter4dvARB", 2039 },
   { "glProgramEnvParameter4fARB", 2040 },
   { "glProgramEnvParameter4fvARB", 2041 },
   { "glProgramEnvParameterI4iNV", 2042 },
   { "glProgramEnvParameterI4ivNV", 2043 },
   { "glProgramEnvParameterI4uiNV", 2044 },
   { "glProgramEnvParameterI4uivNV", 2045 },
   { "glProgramEnvParameters4fvEXT", 2046 },
   { "glProgramEnvParametersI4ivNV", 2047 },
   { "glProgramEnvParametersI4uivNV", 2048 },
   { "glProgramLocalParameter4dARB", 2049 },
   { "glProgramLocalParameter4dvARB", 2050 },
   { "glProgramLocalParameter4fARB", 2051 },
   { "glProgramLocalParameter4fvARB", 2052 },
   { "glProgramLocalParameterI4iNV", 2053 },
   { "glProgramLocalParameterI4ivNV", 2054 },
   { "glProgramLocalParameterI4uiNV", 2055 },
   { "glProgramLocalParameterI4uivNV", 2056 },
   { "glProgramLocalParameters4fvEXT", 2057 },
   { "glProgramLocalParametersI4ivNV", 2058 },
   { "glProgramLocalParametersI4uivNV", 2059 },
   { "glProgramNamedParameter4dNV", 2060 },
   { "glProgramNamedParameter4dvNV", 2061 },
   { "glProgramNamedParameter4fNV", 2062 },
   { "glProgramNamedParameter4fvNV", 2063 },
   { "glProgramParameter4dNV", 2064 },
   { "glProgramParameter4dvNV", 2065 },
   { "glProgramParameter4fNV", 2066 },
   { "glProgramParameter4fvNV", 2067 },
   { "glProgramParameteri", 2068 },
   { "glProgramParameteriARB", 2069 },
   { "glProgramParameteriEXT", 2070 },
   { "glProgramParameters4dvNV", 2071 },
   { "glProgramParameters4fvNV", 2072 },
   { "glProgramPathFragmentInputGenNV", 2073 },
   { "glProgramStringARB", 2074 },
   { "glProgramSubroutineParametersuivNV", 2075 },
   { "glProgramUniform1d", 2076 },
   { "glProgramUniform1dEXT", 2077 },
   { "glProgramUniform1dv", 2078 },
   { "glProgramUniform1dvEXT", 2079 },
   { "glProgramUniform1f", 2080 },
   { "glProgramUniform1fEXT", 2081 },
   { "glProgramUniform1fv", 2082 },
   { "glProgramUniform1fvEXT", 2083 },
   { "glProgramUniform1i", 2084 },
   { "glProgramUniform1i64ARB", 2085 },
   { "glProgramUniform1i64NV", 2086 },
   { "glProgramUniform1i64vARB", 2087 },
   { "glProgramUniform1i64vNV", 2088 },
   { "glProgramUniform1iEXT", 2089 },
   { "glProgramUniform1iv", 2090 },
   { "glProgramUniform1ivEXT", 2091 },
   { "glProgramUniform1ui", 2092 },
   { "glProgramUniform1ui64ARB", 2093 },
   { "glProgramUniform1ui64NV", 2094 },
   { "glProgramUniform1ui64vARB", 2095 },
   { "glProgramUniform1ui64vNV", 2096 },
   { "glProgramUniform1uiEXT", 2097 },
   { "glProgramUniform1uiv", 2098 },
   { "glProgramUniform1uivEXT", 2099 },
   { "glProgramUniform2d", 2100 },
   { "glProgramUniform2dEXT", 2101 },
   { "glProgramUniform2dv", 2102 },
   { "glProgramUniform2dvEXT", 2103 },
   { "glProgramUniform2f", 2104 },
   { "glProgramUniform2fEXT", 2105 },
   { "glProgramUniform2fv", 2106 },
   { "glProgramUniform2fvEXT", 2107 },
   { "glProgramUniform2i", 2108 },
   { "glProgramUniform2i64ARB", 2109 },
   { "glProgramUniform2i64NV", 2110 },
   { "glProgramUniform2i64vARB", 2111 },
   { "glProgramUniform2i64vNV", 2112 },
   { "glProgramUniform2iEXT", 2113 },
   { "glProgramUniform2iv", 2114 },
   { "glProgramUniform2ivEXT", 2115 },
   { "glProgramUniform2ui", 2116 },
   { "glProgramUniform2ui64ARB", 2117 },
   { "glProgramUniform2ui64NV", 2118 },
   { "glProgramUniform2ui64vARB", 2119 },
   { "glProgramUniform2ui64vNV", 2120 },
   { "glProgramUniform2uiEXT", 2121 },
   { "glProgramUniform2uiv", 2122 },
   { "glProgramUniform2uivEXT", 2123 },
   { "glProgramUniform3d", 2124 },
   { "glProgramUniform3dEXT", 2125 },
   { "glProgramUniform3dv", 2126 },
   { "glProgramUniform3dvEXT", 2127 },
   { "glProgramUniform3f", 2128 },
   { "glProgramUniform3fEXT", 2129 },
   { "glProgramUniform3fv", 2130 },
   { "glProgramUniform3fvEXT", 2131 },
   { "glProgramUniform3i", 2132 },
   { "glProgramUniform3i64ARB", 2133 },
   { "glProgramUniform3i64NV", 2134 },
   { "glProgramUniform3i64vARB", 2135 },
   { "glProgramUniform3i64vNV", 2136 },
   { "glProgramUniform3iEXT", 2137 },
   { "glProgramUniform3iv", 2138 },
   { "glProgramUniform3ivEXT", 2139 },
   { "glProgramUniform3ui", 2140 },
   { "glProgramUniform3ui64ARB", 2141 },
   { "glProgramUniform3ui64NV", 2142 },
   { "glProgramUniform3ui64vARB", 2143 },
   { "glProgramUniform3ui64vNV", 2144 },
   { "glProgramUniform3uiEXT", 2145 },
   { "glProgramUniform3uiv", 2146 },
   { "glProgramUniform3uivEXT", 2147 },
   { "glProgramUniform4d", 2148 },
   { "glProgramUniform4dEXT", 2149 },
   { "glProgramUniform4dv", 2150 },
   { "glProgramUniform4dvEXT", 2151 },
   { "glProgramUniform4f", 2152 },
   { "glProgramUniform4fEXT", 2153 },
   { "glProgramUniform4fv", 2154 },
   { "glProgramUniform4fvEXT", 2155 },
   { "glProgramUniform4i", 2156 },
   { "glProgramUniform4i64ARB", 2157 },
   { "glProgramUniform4i64NV", 2158 },
   { "glProgramUniform4i64vARB", 2159 },
   { "glProgramUniform4i64vNV", 2160 },
   { "glProgramUniform4iEXT", 2161 },
   { "glProgramUniform4iv", 2162 },
   { "glProgramUniform4ivEXT", 2163 },
   { "glProgramUniform4ui", 2164 },
   { "glProgramUniform4ui64ARB", 2165 },
   { "glProgramUniform4ui64NV", 2166 },
   { "glProgramUniform4ui64vARB", 2167 },
   { "glProgramUniform4ui64vNV", 2168 },
   { "glProgramUniform4uiEXT", 2169 },
   { "glProgramUniform4uiv", 2170 },
   { "glProgramUniform4uivEXT", 2171 },
   { "glProgramUniformHandleui64ARB", 2172 },
   { "glProgramUniformHandleui64IMG", 2173 },
   { "glProgramUniformHandleui64NV", 2174 },
   { "glProgramUniformHandleui64vARB", 2175 },
   { "glProgramUniformHandleui64vIMG", 2176 },
   { "glProgramUniformHandleui64vNV", 2177 },
   { "glProgramUniformMatrix2dv", 2178 },
   { "glProgramUniformMatrix2dvEXT", 2179 },
   { "glProgramUniformMatrix2fv", 2180 },
   { "glProgramUniformMatrix2fvEXT", 2181 },
   { "glProgramUniformMatrix2x3dv", 2182 },
   { "glProgramUniformMatrix2x3dvEXT", 2183 },
   { "glProgramUniformMatrix2x3fv", 2184 },
   { "glProgramUniformMatrix2x3fvEXT", 2185 },
   { "glProgramUniformMatrix2x4dv", 2186 },
   { "glProgramUniformMatrix2x4dvEXT", 2187 },
   { "glProgramUniformMatrix2x4fv", 2188 },
   { "glProgramUniformMatrix2x4fvEXT", 2189 },
   { "glProgramUniformMatrix3dv", 2190 },
   { "glProgramUniformMatrix3dvEXT", 2191 },
   { "glProgramUniformMatrix3fv", 2192 },
   { "glProgramUniformMatrix3fvEXT", 2193 },
   { "glProgramUniformMatrix3x2dv", 2194 },
   { "glProgramUniformMatrix3x2dvEXT", 2195 },
   { "glProgramUniformMatrix3x2fv", 2196 },
   { "glProgramUniformMatrix3x2fvEXT", 2197 },
   { "glProgramUniformMatrix3x4dv", 2198 },
   { "glProgramUniformMatrix3x4dvEXT", 2199 },
   { "glProgramUniformMatrix3x4fv", 2200 },
   { "glProgramUniformMatrix3x4fvEXT", 2201 },
   { "glProgramUniformMatrix4dv", 2202 },
   { "glProgramUniformMatrix4dvEXT", 2203 },
   { "glProgramUniformMatrix4fv", 2204 },
   { "glProgramUniformMatrix4fvEXT", 2205 },
   { "glProgramUniformMatrix4x2dv", 2206 },
   { "glProgramUniformMatrix4x2dvEXT", 2207 },
   { "glProgramUniformMatrix4x2fv", 2208 },
   { "glProgramUniformMatrix4x2fvEXT", 2209 },
   { "glProgramUniformMatrix4x3dv", 2210 },
   { "glProgramUniformMatrix4x3dvEXT", 2211 },
   { "glProgramUniformMatrix4x3fv", 2212 },
   { "glProgramUniformMatrix4x3fvEXT", 2213 },
   { "glProgramUniformui64NV", 2214 },
   { "glProgramUniformui64vNV", 2215 },
   { "glProgramVertexLimitNV", 2216 },
   { "glProvokingVertex", 2217 },
   { "glProvokingVertexEXT", 2218 },
   { "glPushAttrib", 2219 },
   { "glPushClientAttrib", 2220 },
   { "glPushClientAttribDefaultEXT", 2221 },
   { "glPushDebugGroup", 2222 },
   { "glPushDebugGroupKHR", 2223 },
   { "glPushDebugGroupOES", 2224 },
   { "glPushGroupMarkerEXT", 2225 },
   { "glPushMatrix", 2226 },
   { "glPushName", 2227 },
   { "glQueryCounter", 2228 },
   { "glQueryCounterEXT", 2229 },
   { "glQueryCounterNV", 2230 },
   { "glQueryMatrixxOES", 2231 },
   { "glQueryObjectParameteruiAMD", 2232 },
   { "glQueryResourceNV", 2233 },
   { "glQueryResourceTagNV", 2234 },
   { "glRasterPos2d", 2235 },
   { "glRasterPos2dv", 2236 },
   { "glRasterPos2f", 2237 },
   { "glRasterPos2fv", 2238 },
   { "glRasterPos2i", 2239 },
   { "glRasterPos2iv", 2240 },
   { "glRasterPos2s", 2241 },
   { "glRasterPos2sv", 2242 },
   { "glRasterPos2xOES", 2243 },
   { "glRasterPos2xvOES", 2244 },
   { "glRasterPos3d", 2245 },
   { "glRasterPos3dv", 2246 },
   { "glRasterPos3f", 2247 },
   { "glRasterPos3fv", 2248 },
   { "glRasterPos3i", 2249 },
   { "glRasterPos3iv", 2250 },
   { "glRasterPos3s", 2251 },
   { "glRasterPos3sv", 2252 },
   { "glRasterPos3xOES", 2253 },
   { "glRasterPos3xvOES", 2254 },
   { "glRasterPos4d", 2255 },
   { "glRasterPos4dv", 2256 },
   { "glRasterPos4f", 2257 },
   { "glRasterPos4fv", 2258 },
   { "glRasterPos4i", 2259 },
   { "glRasterPos4iv", 2260 },
   { "glRasterPos4s", 2261 },
   { "glRasterPos4sv", 2262 },
   { "glRasterPos4xOES", 2263 },
   { "glRasterPos4xvOES", 2264 },
   { "glRasterSamplesEXT", 2265 },
   { "glReadBuffer", 2266 },
   { "glReadBufferIndexedEXT", 2267 },
   { "glReadBufferNV", 2268 },
   { "glReadInstrumentsSGIX", 2269 },
   { "glReadPixels", 2270 },
   { "glReadnPixels", 2271 },
   { "glReadnPixelsARB", 2272 },
   { "glReadnPixelsEXT", 2273 },
   { "glReadnPixelsKHR", 2274 },
   { "glRectd", 2275 },
   { "glRectdv", 2276 },
   { "glRectf", 2277 },
   { "glRectfv", 2278 },
   { "glRecti", 2279 },
   { "glRectiv", 2280 },
   { "glRects", 2281 },
   { "glRectsv", 2282 },
   { "glRectxOES", 2283 },
   { "glRectxvOES", 2284 },
   { "glReferencePlaneSGIX", 2285 },
   { "glReleaseKeyedMutexWin32EXT", 2286 },
   { "glReleaseShaderCompiler", 2287 },
   { "glRenderGpuMaskNV", 2288 },
   { "glRenderMode", 2289 },
   { "glRenderbufferStorage", 2290 },
   { "glRenderbufferStorageEXT", 2291 },
   { "glRenderbufferStorageMultisample", 2292 },
   { "glRenderbufferStorageMultisampleANGLE", 2293 },
   { "glRenderbufferStorageMultisampleAPPLE", 2294 },
   { "glRenderbufferStorageMultisampleAdvancedAMD", 2295 },
   { "glRenderbufferStorageMultisampleCoverageNV", 2296 },
   { "glRenderbufferStorageMultisampleEXT", 2297 },
   { "glRenderbufferStorageMultisampleIMG", 2298 },
   { "glRenderbufferStorageMultisampleNV", 2299 },
   { "glRenderbufferStorageOES", 2300 },
   { "glReplacementCodePointerSUN", 2301 },
   { "glReplacementCodeubSUN", 2302 },
   { "glReplacementCodeubvSUN", 2303 },
   { "glReplacementCodeuiColor3fVertex3fSUN", 2304 },
   { "glReplacementCodeuiColor3fVertex3fvSUN", 2305 },
   { "glReplacementCodeuiColor4fNormal3fVertex3fSUN", 2306 },
   { "glReplacementCodeuiColor4fNormal3fVertex3fvSUN", 2307 },
   { "glReplacementCodeuiColor4ubVertex3fSUN", 2308 },
   { "glReplacementCodeuiColor4ubVertex3fvSUN", 2309 },
   { "glReplacementCodeuiNormal3fVertex3fSUN", 2310 },
   { "glReplacementCodeuiNormal3fVertex3fvSUN", 2311 },
   { "glReplacementCodeuiSUN", 2312 },
   { "glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fSUN", 2313 },
   { "glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fvSUN", 2314 },
   { "glReplacementCodeuiTexCoord2fNormal3fVertex3fSUN", 2315 },
   { "glReplacementCodeuiTexCoord2fNormal3fVertex3fvSUN", 2316 },
   { "glReplacementCodeuiTexCoord2fVertex3fSUN", 2317 },
   { "glReplacementCodeuiTexCoord2fVertex3fvSUN", 2318 },
   { "glReplacementCodeuiVertex3fSUN", 2319 },
   { "glReplacementCodeuiVertex3fvSUN", 2320 },
   { "glReplacementCodeuivSUN", 2321 },
   { "glReplacementCodeusSUN", 2322 },
   { "glReplacementCodeusvSUN", 2323 },
   { "glRequestResidentProgramsNV", 2324 },
   { "glResetHistogram", 2325 },
   { "glResetHistogramEXT", 2326 },
   { "glResetMemoryObjectParameterNV", 2327 },
   { "glResetMinmax", 2328 },
   { "glResetMinmaxEXT", 2329 },
   { "glResizeBuffersMESA", 2330 },
   { "glResolveDepthValuesNV", 2331 },
   { "glResolveMultisampleFramebufferAPPLE", 2332 },
   { "glResumeTransformFeedback", 2333 },
   { "glResumeTransformFeedbackEXT", 2334 },
   { "glResumeTransformFeedbackNV", 2335 },
   { "glRotated", 2336 },
   { "glRotatef", 2337 },
   { "glRotatex", 2338 },
   { "glRotatexOES", 2339 },
   { "glSampleCoverage", 2340 },
   { "glSampleCoverageARB", 2341 },
   { "glSampleCoveragex", 2342 },
   { "glSampleCoveragexOES", 2343 },
   { "glSampleMapATI", 2344 },
   { "glSampleMaskEXT", 2345 },
   { "glSampleMaskIndexedNV", 2346 },
   { "glSampleMaskSGIS", 2347 },
   { "glSampleMaski", 2348 },
   { "glSamplePatternEXT", 2349 },
   { "glSamplePatternSGIS", 2350 },
   { "glSamplerParameterIiv", 2351 },
   { "glSamplerParameterIivEXT", 2352 },
   { "glSamplerParameterIivOES", 2353 },
   { "glSamplerParameterIuiv", 2354 },
   { "glSamplerParameterIuivEXT", 2355 },
   { "glSamplerParameterIuivOES", 2356 },
   { "glSamplerParameterf", 2357 },
   { "glSamplerParameterfv", 2358 },
   { "glSamplerParameteri", 2359 },
   { "glSamplerParameteriv", 2360 },
   { "glScaled", 2361 },
   { "glScalef", 2362 },
   { "glScalex", 2363 },
   { "glScalexOES", 2364 },
   { "glScissor", 2365 },
   { "glScissorArrayv", 2366 },
   { "glScissorArrayvNV", 2367 },
   { "glScissorArrayvOES", 2368 },
   { "glScissorExclusiveArrayvNV", 2369 },
   { "glScissorExclusiveNV", 2370 },
   { "glScissorIndexed", 2371 },
   { "glScissorIndexedNV", 2372 },
   { "glScissorIndexedOES", 2373 },
   { "glScissorIndexedv", 2374 },
   { "glScissorIndexedvNV", 2375 },
   { "glScissorIndexedvOES", 2376 },
   { "glSecondaryColor3b", 2377 },
   { "glSecondaryColor3bEXT", 2378 },
   { "glSecondaryColor3bv", 2379 },
   { "glSecondaryColor3bvEXT", 2380 },
   { "glSecondaryColor3d", 2381 },
   { "glSecondaryColor3dEXT", 2382 },
   { "glSecondaryColor3dv", 2383 },
   { "glSecondaryColor3dvEXT", 2384 },
   { "glSecondaryColor3f", 2385 },
   { "glSecondaryColor3fEXT", 2386 },
   { "glSecondaryColor3fv", 2387 },
   { "glSecondaryColor3fvEXT", 2388 },
   { "glSecondaryColor3hNV", 2389 },
   { "glSecondaryColor3hvNV", 2390 },
   { "glSecondaryColor3i", 2391 },
   { "glSecondaryColor3iEXT", 2392 },
   { "glSecondaryColor3iv", 2393 },
   { "glSecondaryColor3ivEXT", 2394 },
   { "glSecondaryColor3s", 2395 },
   { "glSecondaryColor3sEXT", 2396 },
   { "glSecondaryColor3sv", 2397 },
   { "glSecondaryColor3svEXT", 2398 },
   { "glSecondaryColor3ub", 2399 },
   { "glSecondaryColor3ubEXT", 2400 },
   { "glSecondaryColor3ubv", 2401 },
   { "glSecondaryColor3ubvEXT", 2402 },
   { "glSecondaryColor3ui", 2403 },
   { "glSecondaryColor3uiEXT", 2404 },
   { "glSecondaryColor3uiv", 2405 },
   { "glSecondaryColor3uivEXT", 2406 },
   { "glSecondaryColor3us", 2407 },
   { "glSecondaryColor3usEXT", 2408 },
   { "glSecondaryColor3usv", 2409 },
   { "glSecondaryColor3usvEXT", 2410 },
   { "glSecondaryColorFormatNV", 2411 },
   { "glSecondaryColorP3ui", 2412 },
   { "glSecondaryColorP3uiv", 2413 },
   { "glSecondaryColorPointer", 2414 },
   { "glSecondaryColorPointerEXT", 2415 },
   { "glSecondaryColorPointerListIBM", 2416 },
   { "glSelectBuffer", 2417 },
   { "glSelectPerfMonitorCountersAMD", 2418 },
   { "glSemaphoreParameterui64vEXT", 2420 },
   { "glSeparableFilter2D", 2421 },
   { "glSeparableFilter2DEXT", 2422 },
   { "glSetFenceAPPLE", 2423 },
   { "glSetFenceNV", 2424 },
   { "glSetFragmentShaderConstantATI", 2425 },
   { "glSetInvariantEXT", 2426 },
   { "glSetLocalConstantEXT", 2427 },
   { "glSetMultisamplefvAMD", 2428 },
   { "glShadeModel", 2429 },
   { "glShaderBinary", 2430 },
   { "glShaderOp1EXT", 2431 },
   { "glShaderOp2EXT", 2432 },
   { "glShaderOp3EXT", 2433 },
   { "glShaderSource", 2434 },
   { "glShaderSourceARB", 2435 },
   { "glShaderStorageBlockBinding", 2436 },
   { "glShadingRateImageBarrierNV", 2439 },
   { "glShadingRateImagePaletteNV", 2440 },
   { "glShadingRateSampleOrderCustomNV", 2442 },
   { "glShadingRateSampleOrderNV", 2443 },
   { "glSharpenTexFuncSGIS", 2444 },
   { "glSignalSemaphoreEXT", 2445 },
   { "glSignalSemaphoreui64NVX", 2446 },
   { "glSignalVkFenceNV", 2447 },
   { "glSignalVkSemaphoreNV", 2448 },
   { "glSpecializeShader", 2449 },
   { "glSpecializeShaderARB", 2450 },
   { "glSpriteParameterfSGIX", 2451 },
   { "glSpriteParameterfvSGIX", 2452 },
   { "glSpriteParameteriSGIX", 2453 },
   { "glSpriteParameterivSGIX", 2454 },
   { "glStartInstrumentsSGIX", 2455 },
   { "glStartTilingQCOM", 2456 },
   { "glStateCaptureNV", 2457 },
   { "glStencilClearTagEXT", 2458 },
   { "glStencilFillPathInstancedNV", 2459 },
   { "glStencilFillPathNV", 2460 },
   { "glStencilFunc", 2461 },
   { "glStencilFuncSeparate", 2462 },
   { "glStencilFuncSeparateATI", 2463 },
   { "glStencilMask", 2464 },
   { "glStencilMaskSeparate", 2465 },
   { "glStencilOp", 2466 },
   { "glStencilOpSeparate", 2467 },
   { "glStencilOpSeparateATI", 2468 },
   { "glStencilOpValueAMD", 2469 },
   { "glStencilStrokePathInstancedNV", 2470 },
   { "glStencilStrokePathNV", 2471 },
   { "glStencilThenCoverFillPathInstancedNV", 2472 },
   { "glStencilThenCoverFillPathNV", 2473 },
   { "glStencilThenCoverStrokePathInstancedNV", 2474 },
   { "glStencilThenCoverStrokePathNV", 2475 },
   { "glStopInstrumentsSGIX", 2476 },
   { "glStringMarkerGREMEDY", 2477 },
   { "glSubpixelPrecisionBiasNV", 2478 },
   { "glSwizzleEXT", 2479 },
   { "glSyncTextureINTEL", 2480 },
   { "glTagSampleBufferSGIX", 2481 },
   { "glTangent3bEXT", 2482 },
   { "glTangent3bvEXT", 2483 },
   { "glTangent3dEXT", 2484 },
   { "glTangent3dvEXT", 2485 },
   { "glTangent3fEXT", 2486 },
   { "glTangent3fvEXT", 2487 },
   { "glTangent3iEXT", 2488 },
   { "glTangent3ivEXT", 2489 },
   { "glTangent3sEXT", 2490 },
   { "glTangent3svEXT", 2491 },
   { "glTangentPointerEXT", 2492 },
   { "glTbufferMask3DFX", 2493 },
   { "glTessellationFactorAMD", 2494 },
   { "glTessellationModeAMD", 2495 },
   { "glTestFenceAPPLE", 2496 },
   { "glTestFenceNV", 2497 },
   { "glTestObjectAPPLE", 2498 },
   { "glTexAttachMemoryNV", 2499 },
   { "glTexBuffer", 2500 },
   { "glTexBufferARB", 2501 },
   { "glTexBufferEXT", 2502 },
   { "glTexBufferOES", 2503 },
   { "glTexBufferRange", 2504 },
   { "glTexBufferRangeEXT", 2505 },
   { "glTexBufferRangeOES", 2506 },
   { "glTexBumpParameterfvATI", 2507 },
   { "glTexBumpParameterivATI", 2508 },
   { "glTexCoord1bOES", 2509 },
   { "glTexCoord1bvOES", 2510 },
   { "glTexCoord1d", 2511 },
   { "glTexCoord1dv", 2512 },
   { "glTexCoord1f", 2513 },
   { "glTexCoord1fv", 2514 },
   { "glTexCoord1hNV", 2515 },
   { "glTexCoord1hvNV", 2516 },
   { "glTexCoord1i", 2517 },
   { "glTexCoord1iv", 2518 },
   { "glTexCoord1s", 2519 },
   { "glTexCoord1sv", 2520 },
   { "glTexCoord1xOES", 2521 },
   { "glTexCoord1xvOES", 2522 },
   { "glTexCoord2bOES", 2523 },
   { "glTexCoord2bvOES", 2524 },
   { "glTexCoord2d", 2525 },
   { "glTexCoord2dv", 2526 },
   { "glTexCoord2f", 2527 },
   { "glTexCoord2fColor3fVertex3fSUN", 2528 },
   { "glTexCoord2fColor3fVertex3fvSUN", 2529 },
   { "glTexCoord2fColor4fNormal3fVertex3fSUN", 2530 },
   { "glTexCoord2fColor4fNormal3fVertex3fvSUN", 2531 },
   { "glTexCoord2fColor4ubVertex3fSUN", 2532 },
   { "glTexCoord2fColor4ubVertex3fvSUN", 2533 },
   { "glTexCoord2fNormal3fVertex3fSUN", 2534 },
   { "glTexCoord2fNormal3fVertex3fvSUN", 2535 },
   { "glTexCoord2fVertex3fSUN", 2536 },
   { "glTexCoord2fVertex3fvSUN", 2537 },
   { "glTexCoord2fv", 2538 },
   { "glTexCoord2hNV", 2539 },
   { "glTexCoord2hvNV", 2540 },
   { "glTexCoord2i", 2541 },
   { "glTexCoord2iv", 2542 },
   { "glTexCoord2s", 2543 },
   { "glTexCoord2sv", 2544 },
   { "glTexCoord2xOES", 2545 },
   { "glTexCoord2xvOES", 2546 },
   { "glTexCoord3bOES", 2547 },
   { "glTexCoord3bvOES", 2548 },
   { "glTexCoord3d", 2549 },
   { "glTexCoord3dv", 2550 },
   { "glTexCoord3f", 2551 },
   { "glTexCoord3fv", 2552 },
   { "glTexCoord3hNV", 2553 },
   { "glTexCoord3hvNV", 2554 },
   { "glTexCoord3i", 2555 },
   { "glTexCoord3iv", 2556 },
   { "glTexCoord3s", 2557 },
   { "glTexCoord3sv", 2558 },
   { "glTexCoord3xOES", 2559 },
   { "glTexCoord3xvOES", 2560 },
   { "glTexCoord4bOES", 2561 },
   { "glTexCoord4bvOES", 2562 },
   { "glTexCoord4d", 2563 },
   { "glTexCoord4dv", 2564 },
   { "glTexCoord4f", 2565 },
   { "glTexCoord4fColor4fNormal3fVertex4fSUN", 2566 },
   { "glTexCoord4fColor4fNormal3fVertex4fvSUN", 2567 },
   { "glTexCoord4fVertex4fSUN", 2568 },
   { "glTexCoord4fVertex4fvSUN", 2569 },
   { "glTexCoord4fv", 2570 },
   { "glTexCoord4hNV", 2571 },
   { "glTexCoord4hvNV", 2572 },
   { "glTexCoord4i", 2573 },
   { "glTexCoord4iv", 2574 },
   { "glTexCoord4s", 2575 },
   { "glTexCoord4sv", 2576 },
   { "glTexCoord4xOES", 2577 },
   { "glTexCoord4xvOES", 2578 },
   { "glTexCoordFormatNV", 2579 },
   { "glTexCoordP1ui", 2580 },
   { "glTexCoordP1uiv", 2581 },
   { "glTexCoordP2ui", 2582 },
   { "glTexCoordP2uiv", 2583 },
   { "glTexCoordP3ui", 2584 },
   { "glTexCoordP3uiv", 2585 },
   { "glTexCoordP4ui", 2586 },
   { "glTexCoordP4uiv", 2587 },
   { "glTexCoordPointer", 2588 },
   { "glTexCoordPointerEXT", 2589 },
   { "glTexCoordPointerListIBM", 2590 },
   { "glTexCoordPointervINTEL", 2591 },
   { "glTexEnvf", 2592 },
   { "glTexEnvfv", 2593 },
   { "glTexEnvi", 2594 },
   { "glTexEnviv", 2595 },
   { "glTexEnvx", 2596 },
   { "glTexEnvxOES", 2597 },
   { "glTexEnvxv", 2598 },
   { "glTexEnvxvOES", 2599 },
   { "glTexFilterFuncSGIS", 2602 },
   { "glTexGend", 2603 },
   { "glTexGendv", 2604 },
   { "glTexGenf", 2605 },
   { "glTexGenfOES", 2606 },
   { "glTexGenfv", 2607 },
   { "glTexGenfvOES", 2608 },
   { "glTexGeni", 2609 },
   { "glTexGeniOES", 2610 },
   { "glTexGeniv", 2611 },
   { "glTexGenivOES", 2612 },
   { "glTexGenxOES", 2613 },
   { "glTexGenxvOES", 2614 },
   { "glTexImage1D", 2615 },
   { "glTexImage2D", 2616 },
   { "glTexImage2DMultisample", 2617 },
   { "glTexImage2DMultisampleCoverageNV", 2618 },
   { "glTexImage3D", 2619 },
   { "glTexImage3DEXT", 2620 },
   { "glTexImage3DMultisample", 2621 },
   { "glTexImage3DMultisampleCoverageNV", 2622 },
   { "glTexImage3DNV", 2623 },
   { "glTexImage3DOES", 2624 },
   { "glTexImage4DSGIS", 2625 },
   { "glTexPageCommitmentARB", 2626 },
   { "glTexPageCommitmentEXT", 2627 },
   { "glTexParameterIiv", 2629 },
   { "glTexParameterIivEXT", 2630 },
   { "glTexParameterIivOES", 2631 },
   { "glTexParameterIuiv", 2632 },
   { "glTexParameterIuivEXT", 2633 },
   { "glTexParameterIuivOES", 2634 },
   { "glTexParameterf", 2635 },
   { "glTexParameterfv", 2636 },
   { "glTexParameteri", 2637 },
   { "glTexParameteriv", 2638 },
   { "glTexParameterx", 2639 },
   { "glTexParameterxOES", 2640 },
   { "glTexParameterxv", 2641 },
   { "glTexParameterxvOES", 2642 },
   { "glTexRenderbufferNV", 2643 },
   { "glTexStorage1D", 2644 },
   { "glTexStorage1DEXT", 2645 },
   { "glTexStorage2D", 2646 },
   { "glTexStorage2DEXT", 2647 },
   { "glTexStorage2DMultisample", 2648 },
   { "glTexStorage3D", 2649 },
   { "glTexStorage3DEXT", 2650 },
   { "glTexStorage3DMultisample", 2651 },
   { "glTexStorage3DMultisampleOES", 2652 },
   { "glTexStorageMem1DEXT", 2655 },
   { "glTexStorageMem2DEXT", 2656 },
   { "glTexStorageMem2DMultisampleEXT", 2657 },
   { "glTexStorageMem3DEXT", 2658 },
   { "glTexStorageMem3DMultisampleEXT", 2659 },
   { "glTexStorageSparseAMD", 2660 },
   { "glTexSubImage1D", 2661 },
   { "glTexSubImage1DEXT", 2662 },
   { "glTexSubImage2D", 2663 },
   { "glTexSubImage2DEXT", 2664 },
   { "glTexSubImage3D", 2665 },
   { "glTexSubImage3DEXT", 2666 },
   { "glTexSubImage3DNV", 2667 },
   { "glTexSubImage3DOES", 2668 },
   { "glTexSubImage4DSGIS", 2669 },
   { "glTextureAttachMemoryNV", 2670 },
   { "glTextureBarrier", 2671 },
   { "glTextureBarrierNV", 2672 },
   { "glTextureBuffer", 2673 },
   { "glTextureBufferEXT", 2674 },
   { "glTextureBufferRange", 2675 },
   { "glTextureBufferRangeEXT", 2676 },
   { "glTextureColorMaskSGIS", 2677 },
   { "glTextureFoveationParametersQCOM", 2678 },
   { "glTextureImage1DEXT", 2679 },
   { "glTextureImage2DEXT", 2680 },
   { "glTextureImage2DMultisampleCoverageNV", 2681 },
   { "glTextureImage2DMultisampleNV", 2682 },
   { "glTextureImage3DEXT", 2683 },
   { "glTextureImage3DMultisampleCoverageNV", 2684 },
   { "glTextureImage3DMultisampleNV", 2685 },
   { "glTextureLightEXT", 2686 },
   { "glTextureMaterialEXT", 2687 },
   { "glTextureNormalEXT", 2688 },
   { "glTexturePageCommitmentEXT", 2689 },
   { "glTextureParameterIiv", 2691 },
   { "glTextureParameterIivEXT", 2692 },
   { "glTextureParameterIuiv", 2693 },
   { "glTextureParameterIuivEXT", 2694 },
   { "glTextureParameterf", 2695 },
   { "glTextureParameterfEXT", 2696 },
   { "glTextureParameterfv", 2697 },
   { "glTextureParameterfvEXT", 2698 },
   { "glTextureParameteri", 2699 },
   { "glTextureParameteriEXT", 2700 },
   { "glTextureParameteriv", 2701 },
   { "glTextureParameterivEXT", 2702 },
   { "glTextureRangeAPPLE", 2703 },
   { "glTextureRenderbufferEXT", 2704 },
   { "glTextureStorage1D", 2705 },
   { "glTextureStorage1DEXT", 2706 },
   { "glTextureStorage2D", 2707 },
   { "glTextureStorage2DEXT", 2708 },
   { "glTextureStorage2DMultisample", 2709 },
   { "glTextureStorage2DMultisampleEXT", 2710 },
   { "glTextureStorage3D", 2711 },
   { "glTextureStorage3DEXT", 2712 },
   { "glTextureStorage3DMultisample", 2713 },
   { "glTextureStorage3DMultisampleEXT", 2714 },
   { "glTextureStorageMem1DEXT", 2715 },
   { "glTextureStorageMem2DEXT", 2716 },
   { "glTextureStorageMem2DMultisampleEXT", 2717 },
   { "glTextureStorageMem3DEXT", 2718 },
   { "glTextureStorageMem3DMultisampleEXT", 2719 },
   { "glTextureStorageSparseAMD", 2720 },
   { "glTextureSubImage1D", 2721 },
   { "glTextureSubImage1DEXT", 2722 },
   { "glTextureSubImage2D", 2723 },
   { "glTextureSubImage2DEXT", 2724 },
   { "glTextureSubImage3D", 2725 },
   { "glTextureSubImage3DEXT", 2726 },
   { "glTextureView", 2727 },
   { "glTextureViewEXT", 2728 },
   { "glTextureViewOES", 2729 },
   { "glTrackMatrixNV", 2730 },
   { "glTransformFeedbackAttribsNV", 2731 },
   { "glTransformFeedbackBufferBase", 2732 },
   { "glTransformFeedbackBufferRange", 2733 },
   { "glTransformFeedbackStreamAttribsNV", 2734 },
   { "glTransformFeedbackVaryings", 2735 },
   { "glTransformFeedbackVaryingsEXT", 2736 },
   { "glTransformFeedbackVaryingsNV", 2737 },
   { "glTransformPathNV", 2738 },
   { "glTranslated", 2739 },
   { "glTranslatef", 2740 },
   { "glTranslatex", 2741 },
   { "glTranslatexOES", 2742 },
   { "glUniform1d", 2743 },
   { "glUniform1dv", 2744 },
   { "glUniform1f", 2745 },
   { "glUniform1fARB", 2746 },
   { "glUniform1fv", 2747 },
   { "glUniform1fvARB", 2748 },
   { "glUniform1i", 2749 },
   { "glUniform1i64ARB", 2750 },
   { "glUniform1i64NV", 2751 },
   { "glUniform1i64vARB", 2752 },
   { "glUniform1i64vNV", 2753 },
   { "glUniform1iARB", 2754 },
   { "glUniform1iv", 2755 },
   { "glUniform1ivARB", 2756 },
   { "glUniform1ui", 2757 },
   { "glUniform1ui64ARB", 2758 },
   { "glUniform1ui64NV", 2759 },
   { "glUniform1ui64vARB", 2760 },
   { "glUniform1ui64vNV", 2761 },
   { "glUniform1uiEXT", 2762 },
   { "glUniform1uiv", 2763 },
   { "glUniform1uivEXT", 2764 },
   { "glUniform2d", 2765 },
   { "glUniform2dv", 2766 },
   { "glUniform2f", 2767 },
   { "glUniform2fARB", 2768 },
   { "glUniform2fv", 2769 },
   { "glUniform2fvARB", 2770 },
   { "glUniform2i", 2771 },
   { "glUniform2i64ARB", 2772 },
   { "glUniform2i64NV", 2773 },
   { "glUniform2i64vARB", 2774 },
   { "glUniform2i64vNV", 2775 },
   { "glUniform2iARB", 2776 },
   { "glUniform2iv", 2777 },
   { "glUniform2ivARB", 2778 },
   { "glUniform2ui", 2779 },
   { "glUniform2ui64ARB", 2780 },
   { "glUniform2ui64NV", 2781 },
   { "glUniform2ui64vARB", 2782 },
   { "glUniform2ui64vNV", 2783 },
   { "glUniform2uiEXT", 2784 },
   { "glUniform2uiv", 2785 },
   { "glUniform2uivEXT", 2786 },
   { "glUniform3d", 2787 },
   { "glUniform3dv", 2788 },
   { "glUniform3f", 2789 },
   { "glUniform3fARB", 2790 },
   { "glUniform3fv", 2791 },
   { "glUniform3fvARB", 2792 },
   { "glUniform3i", 2793 },
   { "glUniform3i64ARB", 2794 },
   { "glUniform3i64NV", 2795 },
   { "glUniform3i64vARB", 2796 },
   { "glUniform3i64vNV", 2797 },
   { "glUniform3iARB", 2798 },
   { "glUniform3iv", 2799 },
   { "glUniform3ivARB", 2800 },
   { "glUniform3ui", 2801 },
   { "glUniform3ui64ARB", 2802 },
   { "glUniform3ui64NV", 2803 },
   { "glUniform3ui64vARB", 2804 },
   { "glUniform3ui64vNV", 2805 },
   { "glUniform3uiEXT", 2806 },
   { "glUniform3uiv", 2807 },
   { "glUniform3uivEXT", 2808 },
   { "glUniform4d", 2809 },
   { "glUniform4dv", 2810 },
   { "glUniform4f", 2811 },
   { "glUniform4fARB", 2812 },
   { "glUniform4fv", 2813 },
   { "glUniform4fvARB", 2814 },
   { "glUniform4i", 2815 },
   { "glUniform4i64ARB", 2816 },
   { "glUniform4i64NV", 2817 },
   { "glUniform4i64vARB", 2818 },
   { "glUniform4i64vNV", 2819 },
   { "glUniform4iARB", 2820 },
   { "glUniform4iv", 2821 },
   { "glUniform4ivARB", 2822 },
   { "glUniform4ui", 2823 },
   { "glUniform4ui64ARB", 2824 },
   { "glUniform4ui64NV", 2825 },
   { "glUniform4ui64vARB", 2826 },
   { "glUniform4ui64vNV", 2827 },
   { "glUniform4uiEXT", 2828 },
   { "glUniform4uiv", 2829 },
   { "glUniform4uivEXT", 2830 },
   { "glUniformBlockBinding", 2831 },
   { "glUniformBufferEXT", 2832 },
   { "glUniformHandleui64ARB", 2833 },
   { "glUniformHandleui64IMG", 2834 },
   { "glUniformHandleui64NV", 2835 },
   { "glUniformHandleui64vARB", 2836 },
   { "glUniformHandleui64vIMG", 2837 },
   { "glUniformHandleui64vNV", 2838 },
   { "glUniformMatrix2dv", 2839 },
   { "glUniformMatrix2fv", 2840 },
   { "glUniformMatrix2fvARB", 2841 },
   { "glUniformMatrix2x3dv", 2842 },
   { "glUniformMatrix2x3fv", 2843 },
   { "glUniformMatrix2x3fvNV", 2844 },
   { "glUniformMatrix2x4dv", 2845 },
   { "glUniformMatrix2x4fv", 2846 },
   { "glUniformMatrix2x4fvNV", 2847 },
   { "glUniformMatrix3dv", 2848 },
   { "glUniformMatrix3fv", 2849 },
   { "glUniformMatrix3fvARB", 2850 },
   { "glUniformMatrix3x2dv", 2851 },
   { "glUniformMatrix3x2fv", 2852 },
   { "glUniformMatrix3x2fvNV", 2853 },
   { "glUniformMatrix3x4dv", 2854 },
   { "glUniformMatrix3x4fv", 2855 },
   { "glUniformMatrix3x4fvNV", 2856 },
   { "glUniformMatrix4dv", 2857 },
   { "glUniformMatrix4fv", 2858 },
   { "glUniformMatrix4fvARB", 2859 },
   { "glUniformMatrix4x2dv", 2860 },
   { "glUniformMatrix4x2fv", 2861 },
   { "glUniformMatrix4x2fvNV", 2862 },
   { "glUniformMatrix4x3dv", 2863 },
   { "glUniformMatrix4x3fv", 2864 },
   { "glUniformMatrix4x3fvNV", 2865 },
   { "glUniformSubroutinesuiv", 2866 },
   { "glUniformui64NV", 2867 },
   { "glUniformui64vNV", 2868 },
   { "glUnlockArraysEXT", 2869 },
   { "glUnmapBuffer", 2870 },
   { "glUnmapBufferARB", 2871 },
   { "glUnmapBufferOES", 2872 },
   { "glUnmapNamedBuffer", 2873 },
   { "glUnmapNamedBufferEXT", 2874 },
   { "glUnmapObjectBufferATI", 2875 },
   { "glUnmapTexture2DINTEL", 2876 },
   { "glUpdateObjectBufferATI", 2877 },
   { "glUploadGpuMaskNVX", 2878 },
   { "glUseProgram", 2879 },
   { "glUseProgramObjectARB", 2880 },
   { "glUseProgramStages", 2881 },
   { "glUseProgramStagesEXT", 2882 },
   { "glUseShaderProgramEXT", 2883 },
   { "glVDPAUFiniNV", 2884 },
   { "glVDPAUGetSurfaceivNV", 2885 },
   { "glVDPAUInitNV", 2886 },
   { "glVDPAUIsSurfaceNV", 2887 },
   { "glVDPAUMapSurfacesNV", 2888 },
   { "glVDPAURegisterOutputSurfaceNV", 2889 },
   { "glVDPAURegisterVideoSurfaceNV", 2890 },
   { "glVDPAURegisterVideoSurfaceWithPictureStructureNV", 2891 },
   { "glVDPAUSurfaceAccessNV", 2892 },
   { "glVDPAUUnmapSurfacesNV", 2893 },
   { "glVDPAUUnregisterSurfaceNV", 2894 },
   { "glValidBackBufferHintAutodesk", 2895 },
   { "glValidateProgram", 2896 },
   { "glValidateProgramARB", 2897 },
   { "glValidateProgramPipeline", 2898 },
   { "glValidateProgramPipelineEXT", 2899 },
   { "glVariantArrayObjectATI", 2900 },
   { "glVariantPointerEXT", 2901 },
   { "glVariantbvEXT", 2902 },
   { "glVariantdvEXT", 2903 },
   { "glVariantfvEXT", 2904 },
   { "glVariantivEXT", 2905 },
   { "glVariantsvEXT", 2906 },
   { "glVariantubvEXT", 2907 },
   { "glVariantuivEXT", 2908 },
   { "glVariantusvEXT", 2909 },
   { "glVertex2bOES", 2910 },
   { "glVertex2bvOES", 2911 },
   { "glVertex2d", 2912 },
   { "glVertex2dv", 2913 },
   { "glVertex2f", 2914 },
   { "glVertex2fv", 2915 },
   { "glVertex2hNV", 2916 },
   { "glVertex2hvNV", 2917 },
   { "glVertex2i", 2918 },
   { "glVertex2iv", 2919 },
   { "glVertex2s", 2920 },
   { "glVertex2sv", 2921 },
   { "glVertex2xOES", 2922 },
   { "glVertex2xvOES", 2923 },
   { "glVertex3bOES", 2924 },
   { "glVertex3bvOES", 2925 },
   { "glVertex3d", 2926 },
   { "glVertex3dv", 2927 },
   { "glVertex3f", 2928 },
   { "glVertex3fv", 2929 },
   { "glVertex3hNV", 2930 },
   { "glVertex3hvNV", 2931 },
   { "glVertex3i", 2932 },
   { "glVertex3iv", 2933 },
   { "glVertex3s", 2934 },
   { "glVertex3sv", 2935 },
   { "glVertex3xOES", 2936 },
   { "glVertex3xvOES", 2937 },
   { "glVertex4bOES", 2938 },
   { "glVertex4bvOES", 2939 },
   { "glVertex4d", 2940 },
   { "glVertex4dv", 2941 },
   { "glVertex4f", 2942 },
   { "glVertex4fv", 2943 },
   { "glVertex4hNV", 2944 },
   { "glVertex4hvNV", 2945 },
   { "glVertex4i", 2946 },
   { "glVertex4iv", 2947 },
   { "glVertex4s", 2948 },
   { "glVertex4sv", 2949 },
   { "glVertex4xOES", 2950 },
   { "glVertex4xvOES", 2951 },
   { "glVertexArrayAttribBinding", 2952 },
   { "glVertexArrayAttribFormat", 2953 },
   { "glVertexArrayAttribIFormat", 2954 },
   { "glVertexArrayAttribLFormat", 2955 },
   { "glVertexArrayBindVertexBufferEXT", 2956 },
   { "glVertexArrayBindingDivisor", 2957 },
   { "glVertexArrayColorOffsetEXT", 2958 },
   { "glVertexArrayEdgeFlagOffsetEXT", 2959 },
   { "glVertexArrayElementBuffer", 2960 },
   { "glVertexArrayFogCoordOffsetEXT", 2961 },
   { "glVertexArrayIndexOffsetEXT", 2962 },
   { "glVertexArrayMultiTexCoordOffsetEXT", 2963 },
   { "glVertexArrayNormalOffsetEXT", 2964 },
   { "glVertexArrayParameteriAPPLE", 2965 },
   { "glVertexArrayRangeAPPLE", 2966 },
   { "glVertexArrayRangeNV", 2967 },
   { "glVertexArraySecondaryColorOffsetEXT", 2968 },
   { "glVertexArrayTexCoordOffsetEXT", 2969 },
   { "glVertexArrayVertexAttribBindingEXT", 2970 },
   { "glVertexArrayVertexAttribDivisorEXT", 2971 },
   { "glVertexArrayVertexAttribFormatEXT", 2972 },
   { "glVertexArrayVertexAttribIFormatEXT", 2973 },
   { "glVertexArrayVertexAttribIOffsetEXT", 2974 },
   { "glVertexArrayVertexAttribLFormatEXT", 2975 },
   { "glVertexArrayVertexAttribLOffsetEXT", 2976 },
   { "glVertexArrayVertexAttribOffsetEXT", 2977 },
   { "glVertexArrayVertexBindingDivisorEXT", 2978 },
   { "glVertexArrayVertexBuffer", 2979 },
   { "glVertexArrayVertexBuffers", 2980 },
   { "glVertexArrayVertexOffsetEXT", 2981 },
   { "glVertexAttrib1d", 2982 },
   { "glVertexAttrib1dARB", 2983 },
   { "glVertexAttrib1dNV", 2984 },
   { "glVertexAttrib1dv", 2985 },
   { "glVertexAttrib1dvARB", 2986 },
   { "glVertexAttrib1dvNV", 2987 },
   { "glVertexAttrib1f", 2988 },
   { "glVertexAttrib1fARB", 2989 },
   { "glVertexAttrib1fNV", 2990 },
   { "glVertexAttrib1fv", 2991 },
   { "glVertexAttrib1fvARB", 2992 },
   { "glVertexAttrib1fvNV", 2993 },
   { "glVertexAttrib1hNV", 2994 },
   { "glVertexAttrib1hvNV", 2995 },
   { "glVertexAttrib1s", 2996 },
   { "glVertexAttrib1sARB", 2997 },
   { "glVertexAttrib1sNV", 2998 },
   { "glVertexAttrib1sv", 2999 },
   { "glVertexAttrib1svARB", 3000 },
   { "glVertexAttrib1svNV", 3001 },
   { "glVertexAttrib2d", 3002 },
   { "glVertexAttrib2dARB", 3003 },
   { "glVertexAttrib2dNV", 3004 },
   { "glVertexAttrib2dv", 3005 },
   { "glVertexAttrib2dvARB", 3006 },
   { "glVertexAttrib2dvNV", 3007 },
   { "glVertexAttrib2f", 3008 },
   { "glVertexAttrib2fARB", 3009 },
   { "glVertexAttrib2fNV", 3010 },
   { "glVertexAttrib2fv", 3011 },
   { "glVertexAttrib2fvARB", 3012 },
   { "glVertexAttrib2fvNV", 3013 },
   { "glVertexAttrib2hNV", 3014 },
   { "glVertexAttrib2hvNV", 3015 },
   { "glVertexAttrib2s", 3016 },
   { "glVertexAttrib2sARB", 3017 },
   { "glVertexAttrib2sNV", 3018 },
   { "glVertexAttrib2sv", 3019 },
   { "glVertexAttrib2svARB", 3020 },
   { "glVertexAttrib2svNV", 3021 },
   { "glVertexAttrib3d", 3022 },
   { "glVertexAttrib3dARB", 3023 },
   { "glVertexAttrib3dNV", 3024 },
   { "glVertexAttrib3dv", 3025 },
   { "glVertexAttrib3dvARB", 3026 },
   { "glVertexAttrib3dvNV", 3027 },
   { "glVertexAttrib3f", 3028 },
   { "glVertexAttrib3fARB", 3029 },
   { "glVertexAttrib3fNV", 3030 },
   { "glVertexAttrib3fv", 3031 },
   { "glVertexAttrib3fvARB", 3032 },
   { "glVertexAttrib3fvNV", 3033 },
   { "glVertexAttrib3hNV", 3034 },
   { "glVertexAttrib3hvNV", 3035 },
   { "glVertexAttrib3s", 3036 },
   { "glVertexAttrib3sARB", 3037 },
   { "glVertexAttrib3sNV", 3038 },
   { "glVertexAttrib3sv", 3039 },
   { "glVertexAttrib3svARB", 3040 },
   { "glVertexAttrib3svNV", 3041 },
   { "glVertexAttrib4Nbv", 3042 },
   { "glVertexAttrib4NbvARB", 3043 },
   { "glVertexAttrib4Niv", 3044 },
   { "glVertexAttrib4NivARB", 3045 },
   { "glVertexAttrib4Nsv", 3046 },
   { "glVertexAttrib4NsvARB", 3047 },
   { "glVertexAttrib4Nub", 3048 },
   { "glVertexAttrib4NubARB", 3049 },
   { "glVertexAttrib4Nubv", 3050 },
   { "glVertexAttrib4NubvARB", 3051 },
   { "glVertexAttrib4Nuiv", 3052 },
   { "glVertexAttrib4NuivARB", 3053 },
   { "glVertexAttrib4Nusv", 3054 },
   { "glVertexAttrib4NusvARB", 3055 },
   { "glVertexAttrib4bv", 3056 },
   { "glVertexAttrib4bvARB", 3057 },
   { "glVertexAttrib4d", 3058 },
   { "glVertexAttrib4dARB", 3059 },
   { "glVertexAttrib4dNV", 3060 },
   { "glVertexAttrib4dv", 3061 },
   { "glVertexAttrib4dvARB", 3062 },
   { "glVertexAttrib4dvNV", 3063 },
   { "glVertexAttrib4f", 3064 },
   { "glVertexAttrib4fARB", 3065 },
   { "glVertexAttrib4fNV", 3066 },
   { "glVertexAttrib4fv", 3067 },
   { "glVertexAttrib4fvARB", 3068 },
   { "glVertexAttrib4fvNV", 3069 },
   { "glVertexAttrib4hNV", 3070 },
   { "glVertexAttrib4hvNV", 3071 },
   { "glVertexAttrib4iv", 3072 },
   { "glVertexAttrib4ivARB", 3073 },
   { "glVertexAttrib4s", 3074 },
   { "glVertexAttrib4sARB", 3075 },
   { "glVertexAttrib4sNV", 3076 },
   { "glVertexAttrib4sv", 3077 },
   { "glVertexAttrib4svARB", 3078 },
   { "glVertexAttrib4svNV", 3079 },
   { "glVertexAttrib4ubNV", 3080 },
   { "glVertexAttrib4ubv", 3081 },
   { "glVertexAttrib4ubvARB", 3082 },
   { "glVertexAttrib4ubvNV", 3083 },
   { "glVertexAttrib4uiv", 3084 },
   { "glVertexAttrib4uivARB", 3085 },
   { "glVertexAttrib4usv", 3086 },
   { "glVertexAttrib4usvARB", 3087 },
   { "glVertexAttribArrayObjectATI", 3088 },
   { "glVertexAttribBinding", 3089 },
   { "glVertexAttribDivisor", 3090 },
   { "glVertexAttribDivisorANGLE", 3091 },
   { "glVertexAttribDivisorARB", 3092 },
   { "glVertexAttribDivisorEXT", 3093 },
   { "glVertexAttribDivisorNV", 3094 },
   { "glVertexAttribFormat", 3095 },
   { "glVertexAttribFormatNV", 3096 },
   { "glVertexAttribI1i", 3097 },
   { "glVertexAttribI1iEXT", 3098 },
   { "glVertexAttribI1iv", 3099 },
   { "glVertexAttribI1ivEXT", 3100 },
   { "glVertexAttribI1ui", 3101 },
   { "glVertexAttribI1uiEXT", 3102 },
   { "glVertexAttribI1uiv", 3103 },
   { "glVertexAttribI1uivEXT", 3104 },
   { "glVertexAttribI2i", 3105 },
   { "glVertexAttribI2iEXT", 3106 },
   { "glVertexAttribI2iv", 3107 },
   { "glVertexAttribI2ivEXT", 3108 },
   { "glVertexAttribI2ui", 3109 },
   { "glVertexAttribI2uiEXT", 3110 },
   { "glVertexAttribI2uiv", 3111 },
   { "glVertexAttribI2uivEXT", 3112 },
   { "glVertexAttribI3i", 3113 },
   { "glVertexAttribI3iEXT", 3114 },
   { "glVertexAttribI3iv", 3115 },
   { "glVertexAttribI3ivEXT", 3116 },
   { "glVertexAttribI3ui", 3117 },
   { "glVertexAttribI3uiEXT", 3118 },
   { "glVertexAttribI3uiv", 3119 },
   { "glVertexAttribI3uivEXT", 3120 },
   { "glVertexAttribI4bv", 3121 },
   { "glVertexAttribI4bvEXT", 3122 },
   { "glVertexAttribI4i", 3123 },
   { "glVertexAttribI4iEXT", 3124 },
   { "glVertexAttribI4iv", 3125 },
   { "glVertexAttribI4ivEXT", 3126 },
   { "glVertexAttribI4sv", 3127 },
   { "glVertexAttribI4svEXT", 3128 },
   { "glVertexAttribI4ubv", 3129 },
   { "glVertexAttribI4ubvEXT", 3130 },
   { "glVertexAttribI4ui", 3131 },
   { "glVertexAttribI4uiEXT", 3132 },
   { "glVertexAttribI4uiv", 3133 },
   { "glVertexAttribI4uivEXT", 3134 },
   { "glVertexAttribI4usv", 3135 },
   { "glVertexAttribI4usvEXT", 3136 },
   { "glVertexAttribIFormat", 3137 },
   { "glVertexAttribIFormatNV", 3138 },
   { "glVertexAttribIPointer", 3139 },
   { "glVertexAttribIPointerEXT", 3140 },
   { "glVertexAttribL1d", 3141 },
   { "glVertexAttribL1dEXT", 3142 },
   { "glVertexAttribL1dv", 3143 },
   { "glVertexAttribL1dvEXT", 3144 },
   { "glVertexAttribL1i64NV", 3145 },
   { "glVertexAttribL1i64vNV", 3146 },
   { "glVertexAttribL1ui64ARB", 3147 },
   { "glVertexAttribL1ui64NV", 3148 },
   { "glVertexAttribL1ui64vARB", 3149 },
   { "glVertexAttribL1ui64vNV", 3150 },
   { "glVertexAttribL2d", 3151 },
   { "glVertexAttribL2dEXT", 3152 },
   { "glVertexAttribL2dv", 3153 },
   { "glVertexAttribL2dvEXT", 3154 },
   { "glVertexAttribL2i64NV", 3155 },
   { "glVertexAttribL2i64vNV", 3156 },
   { "glVertexAttribL2ui64NV", 3157 },
   { "glVertexAttribL2ui64vNV", 3158 },
   { "glVertexAttribL3d", 3159 },
   { "glVertexAttribL3dEXT", 3160 },
   { "glVertexAttribL3dv", 3161 },
   { "glVertexAttribL3dvEXT", 3162 },
   { "glVertexAttribL3i64NV", 3163 },
   { "glVertexAttribL3i64vNV", 3164 },
   { "glVertexAttribL3ui64NV", 3165 },
   { "glVertexAttribL3ui64vNV", 3166 },
   { "glVertexAttribL4d", 3167 },
   { "glVertexAttribL4dEXT", 3168 },
   { "glVertexAttribL4dv", 3169 },
   { "glVertexAttribL4dvEXT", 3170 },
   { "glVertexAttribL4i64NV", 3171 },
   { "glVertexAttribL4i64vNV", 3172 },
   { "glVertexAttribL4ui64NV", 3173 },
   { "glVertexAttribL4ui64vNV", 3174 },
   { "glVertexAttribLFormat", 3175 },
   { "glVertexAttribLFormatNV", 3176 },
   { "glVertexAttribLPointer", 3177 },
   { "glVertexAttribLPointerEXT", 3178 },
   { "glVertexAttribP1ui", 3179 },
   { "glVertexAttribP1uiv", 3180 },
   { "glVertexAttribP2ui", 3181 },
   { "glVertexAttribP2uiv", 3182 },
   { "glVertexAttribP3ui", 3183 },
   { "glVertexAttribP3uiv", 3184 },
   { "glVertexAttribP4ui", 3185 },
   { "glVertexAttribP4uiv", 3186 },
   { "glVertexAttribParameteriAMD", 3187 },
   { "glVertexAttribPointer", 3188 },
   { "glVertexAttribPointerARB", 3189 },
   { "glVertexAttribPointerNV", 3190 },
   { "glVertexAttribs1dvNV", 3191 },
   { "glVertexAttribs1fvNV", 3192 },
   { "glVertexAttribs1hvNV", 3193 },
   { "glVertexAttribs1svNV", 3194 },
   { "glVertexAttribs2dvNV", 3195 },
   { "glVertexAttribs2fvNV", 3196 },
   { "glVertexAttribs2hvNV", 3197 },
   { "glVertexAttribs2svNV", 3198 },
   { "glVertexAttribs3dvNV", 3199 },
   { "glVertexAttribs3fvNV", 3200 },
   { "glVertexAttribs3hvNV", 3201 },
   { "glVertexAttribs3svNV", 3202 },
   { "glVertexAttribs4dvNV", 3203 },
   { "glVertexAttribs4fvNV", 3204 },
   { "glVertexAttribs4hvNV", 3205 },
   { "glVertexAttribs4svNV", 3206 },
   { "glVertexAttribs4ubvNV", 3207 },
   { "glVertexBindingDivisor", 3208 },
   { "glVertexBlendARB", 3209 },
   { "glVertexBlendEnvfATI", 3210 },
   { "glVertexBlendEnviATI", 3211 },
   { "glVertexFormatNV", 3212 },
   { "glVertexP2ui", 3213 },
   { "glVertexP2uiv", 3214 },
   { "glVertexP3ui", 3215 },
   { "glVertexP3uiv", 3216 },
   { "glVertexP4ui", 3217 },
   { "glVertexP4uiv", 3218 },
   { "glVertexPointer", 3219 },
   { "glVertexPointerEXT", 3220 },
   { "glVertexPointerListIBM", 3221 },
   { "glVertexPointervINTEL", 3222 },
   { "glVertexStream1dATI", 3223 },
   { "glVertexStream1dvATI", 3224 },
   { "glVertexStream1fATI", 3225 },
   { "glVertexStream1fvATI", 3226 },
   { "glVertexStream1iATI", 3227 },
   { "glVertexStream1ivATI", 3228 },
   { "glVertexStream1sATI", 3229 },
   { "glVertexStream1svATI", 3230 },
   { "glVertexStream2dATI", 3231 },
   { "glVertexStream2dvATI", 3232 },
   { "glVertexStream2fATI", 3233 },
   { "glVertexStream2fvATI", 3234 },
   { "glVertexStream2iATI", 3235 },
   { "glVertexStream2ivATI", 3236 },
   { "glVertexStream2sATI", 3237 },
   { "glVertexStream2svATI", 3238 },
   { "glVertexStream3dATI", 3239 },
   { "glVertexStream3dvATI", 3240 },
   { "glVertexStream3fATI", 3241 },
   { "glVertexStream3fvATI", 3242 },
   { "glVertexStream3iATI", 3243 },
   { "glVertexStream3ivATI", 3244 },
   { "glVertexStream3sATI", 3245 },
   { "glVertexStream3svATI", 3246 },
   { "glVertexStream4dATI", 3247 },
   { "glVertexStream4dvATI", 3248 },
   { "glVertexStream4fATI", 3249 },
   { "glVertexStream4fvATI", 3250 },
   { "glVertexStream4iATI", 3251 },
   { "glVertexStream4ivATI", 3252 },
   { "glVertexStream4sATI", 3253 },
   { "glVertexStream4svATI", 3254 },
   { "glVertexWeightPointerEXT", 3255 },
   { "glVertexWeightfEXT", 3256 },
   { "glVertexWeightfvEXT", 3257 },
   { "glVertexWeighthNV", 3258 },
   { "glVertexWeighthvNV", 3259 },
   { "glVideoCaptureNV", 3260 },
   { "glVideoCaptureStreamParameterdvNV", 3261 },
   { "glVideoCaptureStreamParameterfvNV", 3262 },
   { "glVideoCaptureStreamParameterivNV", 3263 },
   { "glViewport", 3264 },
   { "glViewportArrayv", 3265 },
   { "glViewportArrayvNV", 3266 },
   { "glViewportArrayvOES", 3267 },
   { "glViewportIndexedf", 3268 },
   { "glViewportIndexedfNV", 3269 },
   { "glViewportIndexedfOES", 3270 },
   { "glViewportIndexedfv", 3271 },
   { "glViewportIndexedfvNV", 3272 },
   { "glViewportIndexedfvOES", 3273 },
   { "glViewportPositionWScaleNV", 3274 },
   { "glViewportSwizzleNV", 3275 },
   { "glWaitSemaphoreEXT", 3276 },
   { "glWaitSemaphoreui64NVX", 3277 },
   { "glWaitSync", 3278 },
   { "glWaitSyncAPPLE", 3279 },
   { "glWaitSyncValueuiNVX", 3280 },
   { "glWaitVkSemaphoreNV", 3281 },
   { "glWeightPathsNV", 3282 },
   { "glWeightPointerARB", 3283 },
   { "glWeightPointerOES", 3284 },
   { "glWeightbvARB", 3285 },
   { "glWeightdvARB", 3286 },
   { "glWeightfvARB", 3287 },
   { "glWeightivARB", 3288 },
   { "glWeightsvARB", 3289 },
   { "glWeightubvARB", 3290 },
   { "glWeightuivARB", 3291 },
   { "glWeightusvARB", 3292 },
   { "glWindowBackBufferHintAutodesk", 3293 },
   { "glWindowPos2d", 3294 },
   { "glWindowPos2dARB", 3295 },
   { "glWindowPos2dMESA", 3296 },
   { "glWindowPos2dv", 3297 },
   { "glWindowPos2dvARB", 3298 },
   { "glWindowPos2dvMESA", 3299 },
   { "glWindowPos2f", 3300 },
   { "glWindowPos2fARB", 3301 },
   { "glWindowPos2fMESA", 3302 },
   { "glWindowPos2fv", 3303 },
   { "glWindowPos2fvARB", 3304 },
   { "glWindowPos2fvMESA", 3305 },
   { "glWindowPos2i", 3306 },
   { "glWindowPos2iARB", 3307 },
   { "glWindowPos2iMESA", 3308 },
   { "glWindowPos2iv", 3309 },
   { "glWindowPos2ivARB", 3310 },
   { "glWindowPos2ivMESA", 3311 },
   { "glWindowPos2s", 3312 },
   { "glWindowPos2sARB", 3313 },
   { "glWindowPos2sMESA", 3314 },
   { "glWindowPos2sv", 3315 },
   { "glWindowPos2svARB", 3316 },
   { "glWindowPos2svMESA", 3317 },
   { "glWindowPos3d", 3318 },
   { "glWindowPos3dARB", 3319 },
   { "glWindowPos3dMESA", 3320 },
   { "glWindowPos3dv", 3321 },
   { "glWindowPos3dvARB", 3322 },
   { "glWindowPos3dvMESA", 3323 },
   { "glWindowPos3f", 3324 },
   { "glWindowPos3fARB", 3325 },
   { "glWindowPos3fMESA", 3326 },
   { "glWindowPos3fv", 3327 },
   { "glWindowPos3fvARB", 3328 },
   { "glWindowPos3fvMESA", 3329 },
   { "glWindowPos3i", 3330 },
   { "glWindowPos3iARB", 3331 },
   { "glWindowPos3iMESA", 3332 },
   { "glWindowPos3iv", 3333 },
   { "glWindowPos3ivARB", 3334 },
   { "glWindowPos3ivMESA", 3335 },
   { "glWindowPos3s", 3336 },
   { "glWindowPos3sARB", 3337 },
   { "glWindowPos3sMESA", 3338 },
   { "glWindowPos3sv", 3339 },
   { "glWindowPos3svARB", 3340 },
   { "glWindowPos3svMESA", 3341 },
   { "glWindowPos4dMESA", 3342 },
   { "glWindowPos4dvMESA", 3343 },
   { "glWindowPos4fMESA", 3344 },
   { "glWindowPos4fvMESA", 3345 },
   { "glWindowPos4iMESA", 3346 },
   { "glWindowPos4ivMESA", 3347 },
   { "glWindowPos4sMESA", 3348 },
   { "glWindowPos4svMESA", 3349 },
   { "glWindowRectanglesEXT", 3350 },
   { "glWriteMaskEXT", 3351 },
};
#undef MAPI_TMP_PUBLIC_STUBS
#endif /* MAPI_TMP_PUBLIC_STUBS */

#ifdef MAPI_TMP_PUBLIC_ENTRIES
GLAPI void APIENTRY glAccum(GLenum op, GLfloat value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[0];
   ((void (APIENTRY *)(GLenum op, GLfloat value)) _func)(op, value);
}

GLAPI void APIENTRY glAccumxOES(GLenum op, GLfixed value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1];
   ((void (APIENTRY *)(GLenum op, GLfixed value)) _func)(op, value);
}

GLAPI GLboolean APIENTRY glAcquireKeyedMutexWin32EXT(GLuint memory, GLuint64 key, GLuint timeout)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2];
   return ((GLboolean (APIENTRY *)(GLuint memory, GLuint64 key, GLuint timeout)) _func)(memory, key, timeout);
}

GLAPI void APIENTRY glActiveProgramEXT(GLuint program)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3];
   ((void (APIENTRY *)(GLuint program)) _func)(program);
}

GLAPI void APIENTRY glActiveShaderProgram(GLuint pipeline, GLuint program)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[4];
   ((void (APIENTRY *)(GLuint pipeline, GLuint program)) _func)(pipeline, program);
}

GLAPI void APIENTRY glActiveShaderProgramEXT(GLuint pipeline, GLuint program)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[5];
   ((void (APIENTRY *)(GLuint pipeline, GLuint program)) _func)(pipeline, program);
}

GLAPI void APIENTRY glActiveStencilFaceEXT(GLenum face)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[6];
   ((void (APIENTRY *)(GLenum face)) _func)(face);
}

GLAPI void APIENTRY glActiveTexture(GLenum texture)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[7];
   ((void (APIENTRY *)(GLenum texture)) _func)(texture);
}

GLAPI void APIENTRY glActiveTextureARB(GLenum texture)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[8];
   ((void (APIENTRY *)(GLenum texture)) _func)(texture);
}

GLAPI void APIENTRY glActiveVaryingNV(GLuint program, const GLchar *name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[9];
   ((void (APIENTRY *)(GLuint program, const GLchar *name)) _func)(program, name);
}

GLAPI void APIENTRY glAlphaFragmentOp1ATI(GLenum op, GLuint dst, GLuint dstMod, GLuint arg1, GLuint arg1Rep, GLuint arg1Mod)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[10];
   ((void (APIENTRY *)(GLenum op, GLuint dst, GLuint dstMod, GLuint arg1, GLuint arg1Rep, GLuint arg1Mod)) _func)(op, dst, dstMod, arg1, arg1Rep, arg1Mod);
}

GLAPI void APIENTRY glAlphaFragmentOp2ATI(GLenum op, GLuint dst, GLuint dstMod, GLuint arg1, GLuint arg1Rep, GLuint arg1Mod, GLuint arg2, GLuint arg2Rep, GLuint arg2Mod)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[11];
   ((void (APIENTRY *)(GLenum op, GLuint dst, GLuint dstMod, GLuint arg1, GLuint arg1Rep, GLuint arg1Mod, GLuint arg2, GLuint arg2Rep, GLuint arg2Mod)) _func)(op, dst, dstMod, arg1, arg1Rep, arg1Mod, arg2, arg2Rep, arg2Mod);
}

GLAPI void APIENTRY glAlphaFragmentOp3ATI(GLenum op, GLuint dst, GLuint dstMod, GLuint arg1, GLuint arg1Rep, GLuint arg1Mod, GLuint arg2, GLuint arg2Rep, GLuint arg2Mod, GLuint arg3, GLuint arg3Rep, GLuint arg3Mod)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[12];
   ((void (APIENTRY *)(GLenum op, GLuint dst, GLuint dstMod, GLuint arg1, GLuint arg1Rep, GLuint arg1Mod, GLuint arg2, GLuint arg2Rep, GLuint arg2Mod, GLuint arg3, GLuint arg3Rep, GLuint arg3Mod)) _func)(op, dst, dstMod, arg1, arg1Rep, arg1Mod, arg2, arg2Rep, arg2Mod, arg3, arg3Rep, arg3Mod);
}

GLAPI void APIENTRY glAlphaFunc(GLenum func, GLfloat ref)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[13];
   ((void (APIENTRY *)(GLenum func, GLfloat ref)) _func)(func, ref);
}

GLAPI void APIENTRY glAlphaFuncQCOM(GLenum func, GLclampf ref)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[14];
   ((void (APIENTRY *)(GLenum func, GLclampf ref)) _func)(func, ref);
}

GLAPI void APIENTRY glAlphaFuncx(GLenum func, GLfixed ref)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[15];
   ((void (APIENTRY *)(GLenum func, GLfixed ref)) _func)(func, ref);
}

GLAPI void APIENTRY glAlphaFuncxOES(GLenum func, GLfixed ref)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[16];
   ((void (APIENTRY *)(GLenum func, GLfixed ref)) _func)(func, ref);
}

GLAPI void APIENTRY glAlphaToCoverageDitherControlNV(GLenum mode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[17];
   ((void (APIENTRY *)(GLenum mode)) _func)(mode);
}

GLAPI void APIENTRY glApplyFramebufferAttachmentCMAAINTEL(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[18];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glApplyTextureEXT(GLenum mode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[19];
   ((void (APIENTRY *)(GLenum mode)) _func)(mode);
}

GLAPI GLboolean APIENTRY glAreProgramsResidentNV(GLsizei n, const GLuint *programs, GLboolean *residences)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[20];
   return ((GLboolean (APIENTRY *)(GLsizei n, const GLuint *programs, GLboolean *residences)) _func)(n, programs, residences);
}

GLAPI GLboolean APIENTRY glAreTexturesResident(GLsizei n, const GLuint *textures, GLboolean *residences)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[21];
   return ((GLboolean (APIENTRY *)(GLsizei n, const GLuint *textures, GLboolean *residences)) _func)(n, textures, residences);
}

GLAPI GLboolean APIENTRY glAreTexturesResidentEXT(GLsizei n, const GLuint *textures, GLboolean *residences)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[22];
   return ((GLboolean (APIENTRY *)(GLsizei n, const GLuint *textures, GLboolean *residences)) _func)(n, textures, residences);
}

GLAPI void APIENTRY glArrayElement(GLint i)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[23];
   ((void (APIENTRY *)(GLint i)) _func)(i);
}

GLAPI void APIENTRY glArrayElementEXT(GLint i)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[24];
   ((void (APIENTRY *)(GLint i)) _func)(i);
}

GLAPI void APIENTRY glArrayObjectATI(GLenum array, GLint size, GLenum type, GLsizei stride, GLuint buffer, GLuint offset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[25];
   ((void (APIENTRY *)(GLenum array, GLint size, GLenum type, GLsizei stride, GLuint buffer, GLuint offset)) _func)(array, size, type, stride, buffer, offset);
}

GLAPI GLuint APIENTRY glAsyncCopyBufferSubDataNVX(GLsizei waitSemaphoreCount, const GLuint *waitSemaphoreArray, const GLuint64 *fenceValueArray, GLuint readGpu, GLbitfield writeGpuMask, GLuint readBuffer, GLuint writeBuffer, GLintptr readOffset, GLintptr writeOffset, GLsizeiptr size, GLsizei signalSemaphoreCount, const GLuint *signalSemaphoreArray, const GLuint64 *signalValueArray)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[26];
   return ((GLuint (APIENTRY *)(GLsizei waitSemaphoreCount, const GLuint *waitSemaphoreArray, const GLuint64 *fenceValueArray, GLuint readGpu, GLbitfield writeGpuMask, GLuint readBuffer, GLuint writeBuffer, GLintptr readOffset, GLintptr writeOffset, GLsizeiptr size, GLsizei signalSemaphoreCount, const GLuint *signalSemaphoreArray, const GLuint64 *signalValueArray)) _func)(waitSemaphoreCount, waitSemaphoreArray, fenceValueArray, readGpu, writeGpuMask, readBuffer, writeBuffer, readOffset, writeOffset, size, signalSemaphoreCount, signalSemaphoreArray, signalValueArray);
}

GLAPI GLuint APIENTRY glAsyncCopyImageSubDataNVX(GLsizei waitSemaphoreCount, const GLuint *waitSemaphoreArray, const GLuint64 *waitValueArray, GLuint srcGpu, GLbitfield dstGpuMask, GLuint srcName, GLenum srcTarget, GLint srcLevel, GLint srcX, GLint srcY, GLint srcZ, GLuint dstName, GLenum dstTarget, GLint dstLevel, GLint dstX, GLint dstY, GLint dstZ, GLsizei srcWidth, GLsizei srcHeight, GLsizei srcDepth, GLsizei signalSemaphoreCount, const GLuint *signalSemaphoreArray, const GLuint64 *signalValueArray)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[27];
   return ((GLuint (APIENTRY *)(GLsizei waitSemaphoreCount, const GLuint *waitSemaphoreArray, const GLuint64 *waitValueArray, GLuint srcGpu, GLbitfield dstGpuMask, GLuint srcName, GLenum srcTarget, GLint srcLevel, GLint srcX, GLint srcY, GLint srcZ, GLuint dstName, GLenum dstTarget, GLint dstLevel, GLint dstX, GLint dstY, GLint dstZ, GLsizei srcWidth, GLsizei srcHeight, GLsizei srcDepth, GLsizei signalSemaphoreCount, const GLuint *signalSemaphoreArray, const GLuint64 *signalValueArray)) _func)(waitSemaphoreCount, waitSemaphoreArray, waitValueArray, srcGpu, dstGpuMask, srcName, srcTarget, srcLevel, srcX, srcY, srcZ, dstName, dstTarget, dstLevel, dstX, dstY, dstZ, srcWidth, srcHeight, srcDepth, signalSemaphoreCount, signalSemaphoreArray, signalValueArray);
}

GLAPI void APIENTRY glAsyncMarkerSGIX(GLuint marker)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[28];
   ((void (APIENTRY *)(GLuint marker)) _func)(marker);
}

GLAPI void APIENTRY glAttachObjectARB(GLhandleARB containerObj, GLhandleARB obj)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[29];
   ((void (APIENTRY *)(GLhandleARB containerObj, GLhandleARB obj)) _func)(containerObj, obj);
}

GLAPI void APIENTRY glAttachShader(GLuint program, GLuint shader)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[30];
   ((void (APIENTRY *)(GLuint program, GLuint shader)) _func)(program, shader);
}

GLAPI void APIENTRY glBegin(GLenum mode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[31];
   ((void (APIENTRY *)(GLenum mode)) _func)(mode);
}

GLAPI void APIENTRY glBeginConditionalRender(GLuint id, GLenum mode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[32];
   ((void (APIENTRY *)(GLuint id, GLenum mode)) _func)(id, mode);
}

GLAPI void APIENTRY glBeginConditionalRenderNV(GLuint id, GLenum mode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[33];
   ((void (APIENTRY *)(GLuint id, GLenum mode)) _func)(id, mode);
}

GLAPI void APIENTRY glBeginConditionalRenderNVX(GLuint id)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[34];
   ((void (APIENTRY *)(GLuint id)) _func)(id);
}

GLAPI void APIENTRY glBeginFragmentShaderATI(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[35];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glBeginOcclusionQueryNV(GLuint id)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[36];
   ((void (APIENTRY *)(GLuint id)) _func)(id);
}

GLAPI void APIENTRY glBeginPerfMonitorAMD(GLuint monitor)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[37];
   ((void (APIENTRY *)(GLuint monitor)) _func)(monitor);
}

GLAPI void APIENTRY glBeginPerfQueryINTEL(GLuint queryHandle)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[38];
   ((void (APIENTRY *)(GLuint queryHandle)) _func)(queryHandle);
}

GLAPI void APIENTRY glBeginQuery(GLenum target, GLuint id)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[39];
   ((void (APIENTRY *)(GLenum target, GLuint id)) _func)(target, id);
}

GLAPI void APIENTRY glBeginQueryARB(GLenum target, GLuint id)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[40];
   ((void (APIENTRY *)(GLenum target, GLuint id)) _func)(target, id);
}

GLAPI void APIENTRY glBeginQueryEXT(GLenum target, GLuint id)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[41];
   ((void (APIENTRY *)(GLenum target, GLuint id)) _func)(target, id);
}

GLAPI void APIENTRY glBeginQueryIndexed(GLenum target, GLuint index, GLuint id)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[42];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLuint id)) _func)(target, index, id);
}

GLAPI void APIENTRY glBeginTransformFeedback(GLenum primitiveMode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[43];
   ((void (APIENTRY *)(GLenum primitiveMode)) _func)(primitiveMode);
}

GLAPI void APIENTRY glBeginTransformFeedbackEXT(GLenum primitiveMode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[44];
   ((void (APIENTRY *)(GLenum primitiveMode)) _func)(primitiveMode);
}

GLAPI void APIENTRY glBeginTransformFeedbackNV(GLenum primitiveMode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[45];
   ((void (APIENTRY *)(GLenum primitiveMode)) _func)(primitiveMode);
}

GLAPI void APIENTRY glBeginVertexShaderEXT(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[46];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glBeginVideoCaptureNV(GLuint video_capture_slot)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[47];
   ((void (APIENTRY *)(GLuint video_capture_slot)) _func)(video_capture_slot);
}

GLAPI void APIENTRY glBindANCCaptureStreamBufferNVX(GLuint video_capture_slot, GLuint stream, GLuint link, GLenum frame_region, GLenum anc_region, GLintptr offset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[48];
   ((void (APIENTRY *)(GLuint video_capture_slot, GLuint stream, GLuint link, GLenum frame_region, GLenum anc_region, GLintptr offset)) _func)(video_capture_slot, stream, link, frame_region, anc_region, offset);
}

GLAPI void APIENTRY glBindAttribLocation(GLuint program, GLuint index, const GLchar *name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[49];
   ((void (APIENTRY *)(GLuint program, GLuint index, const GLchar *name)) _func)(program, index, name);
}

GLAPI void APIENTRY glBindAttribLocationARB(GLhandleARB programObj, GLuint index, const GLcharARB *name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[50];
   ((void (APIENTRY *)(GLhandleARB programObj, GLuint index, const GLcharARB *name)) _func)(programObj, index, name);
}

GLAPI void APIENTRY glBindBuffer(GLenum target, GLuint buffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[51];
   ((void (APIENTRY *)(GLenum target, GLuint buffer)) _func)(target, buffer);
}

GLAPI void APIENTRY glBindBufferARB(GLenum target, GLuint buffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[52];
   ((void (APIENTRY *)(GLenum target, GLuint buffer)) _func)(target, buffer);
}

GLAPI void APIENTRY glBindBufferBase(GLenum target, GLuint index, GLuint buffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[53];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLuint buffer)) _func)(target, index, buffer);
}

GLAPI void APIENTRY glBindBufferBaseEXT(GLenum target, GLuint index, GLuint buffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[54];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLuint buffer)) _func)(target, index, buffer);
}

GLAPI void APIENTRY glBindBufferBaseNV(GLenum target, GLuint index, GLuint buffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[55];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLuint buffer)) _func)(target, index, buffer);
}

GLAPI void APIENTRY glBindBufferOffsetEXT(GLenum target, GLuint index, GLuint buffer, GLintptr offset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[56];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLuint buffer, GLintptr offset)) _func)(target, index, buffer, offset);
}

GLAPI void APIENTRY glBindBufferOffsetNV(GLenum target, GLuint index, GLuint buffer, GLintptr offset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[57];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLuint buffer, GLintptr offset)) _func)(target, index, buffer, offset);
}

GLAPI void APIENTRY glBindBufferRange(GLenum target, GLuint index, GLuint buffer, GLintptr offset, GLsizeiptr size)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[58];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLuint buffer, GLintptr offset, GLsizeiptr size)) _func)(target, index, buffer, offset, size);
}

GLAPI void APIENTRY glBindBufferRangeEXT(GLenum target, GLuint index, GLuint buffer, GLintptr offset, GLsizeiptr size)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[59];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLuint buffer, GLintptr offset, GLsizeiptr size)) _func)(target, index, buffer, offset, size);
}

GLAPI void APIENTRY glBindBufferRangeNV(GLenum target, GLuint index, GLuint buffer, GLintptr offset, GLsizeiptr size)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[60];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLuint buffer, GLintptr offset, GLsizeiptr size)) _func)(target, index, buffer, offset, size);
}

GLAPI void APIENTRY glBindBuffersBase(GLenum target, GLuint first, GLsizei count, const GLuint *buffers)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[61];
   ((void (APIENTRY *)(GLenum target, GLuint first, GLsizei count, const GLuint *buffers)) _func)(target, first, count, buffers);
}

GLAPI void APIENTRY glBindBuffersRange(GLenum target, GLuint first, GLsizei count, const GLuint *buffers, const GLintptr *offsets, const GLsizeiptr *sizes)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[62];
   ((void (APIENTRY *)(GLenum target, GLuint first, GLsizei count, const GLuint *buffers, const GLintptr *offsets, const GLsizeiptr *sizes)) _func)(target, first, count, buffers, offsets, sizes);
}

GLAPI void APIENTRY glBindFragDataLocation(GLuint program, GLuint color, const GLchar *name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[63];
   ((void (APIENTRY *)(GLuint program, GLuint color, const GLchar *name)) _func)(program, color, name);
}

GLAPI void APIENTRY glBindFragDataLocationEXT(GLuint program, GLuint color, const GLchar *name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[64];
   ((void (APIENTRY *)(GLuint program, GLuint color, const GLchar *name)) _func)(program, color, name);
}

GLAPI void APIENTRY glBindFragDataLocationIndexed(GLuint program, GLuint colorNumber, GLuint index, const GLchar *name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[65];
   ((void (APIENTRY *)(GLuint program, GLuint colorNumber, GLuint index, const GLchar *name)) _func)(program, colorNumber, index, name);
}

GLAPI void APIENTRY glBindFragDataLocationIndexedEXT(GLuint program, GLuint colorNumber, GLuint index, const GLchar *name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[66];
   ((void (APIENTRY *)(GLuint program, GLuint colorNumber, GLuint index, const GLchar *name)) _func)(program, colorNumber, index, name);
}

GLAPI void APIENTRY glBindFragmentShaderATI(GLuint id)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[67];
   ((void (APIENTRY *)(GLuint id)) _func)(id);
}

GLAPI void APIENTRY glBindFramebuffer(GLenum target, GLuint framebuffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[68];
   ((void (APIENTRY *)(GLenum target, GLuint framebuffer)) _func)(target, framebuffer);
}

GLAPI void APIENTRY glBindFramebufferEXT(GLenum target, GLuint framebuffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[69];
   ((void (APIENTRY *)(GLenum target, GLuint framebuffer)) _func)(target, framebuffer);
}

GLAPI void APIENTRY glBindFramebufferOES(GLenum target, GLuint framebuffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[70];
   ((void (APIENTRY *)(GLenum target, GLuint framebuffer)) _func)(target, framebuffer);
}

GLAPI void APIENTRY glBindImageTexture(GLuint unit, GLuint texture, GLint level, GLboolean layered, GLint layer, GLenum access, GLenum format)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[71];
   ((void (APIENTRY *)(GLuint unit, GLuint texture, GLint level, GLboolean layered, GLint layer, GLenum access, GLenum format)) _func)(unit, texture, level, layered, layer, access, format);
}

GLAPI void APIENTRY glBindImageTextureEXT(GLuint index, GLuint texture, GLint level, GLboolean layered, GLint layer, GLenum access, GLint format)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[72];
   ((void (APIENTRY *)(GLuint index, GLuint texture, GLint level, GLboolean layered, GLint layer, GLenum access, GLint format)) _func)(index, texture, level, layered, layer, access, format);
}

GLAPI void APIENTRY glBindImageTextures(GLuint first, GLsizei count, const GLuint *textures)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[73];
   ((void (APIENTRY *)(GLuint first, GLsizei count, const GLuint *textures)) _func)(first, count, textures);
}

GLAPI GLuint APIENTRY glBindLightParameterEXT(GLenum light, GLenum value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[74];
   return ((GLuint (APIENTRY *)(GLenum light, GLenum value)) _func)(light, value);
}

GLAPI GLuint APIENTRY glBindMaterialParameterEXT(GLenum face, GLenum value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[75];
   return ((GLuint (APIENTRY *)(GLenum face, GLenum value)) _func)(face, value);
}

GLAPI void APIENTRY glBindMultiTextureEXT(GLenum texunit, GLenum target, GLuint texture)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[76];
   ((void (APIENTRY *)(GLenum texunit, GLenum target, GLuint texture)) _func)(texunit, target, texture);
}

GLAPI GLuint APIENTRY glBindParameterEXT(GLenum value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[77];
   return ((GLuint (APIENTRY *)(GLenum value)) _func)(value);
}

GLAPI void APIENTRY glBindProgramARB(GLenum target, GLuint program)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[78];
   ((void (APIENTRY *)(GLenum target, GLuint program)) _func)(target, program);
}

GLAPI void APIENTRY glBindProgramNV(GLenum target, GLuint id)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[79];
   ((void (APIENTRY *)(GLenum target, GLuint id)) _func)(target, id);
}

GLAPI void APIENTRY glBindProgramPipeline(GLuint pipeline)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[80];
   ((void (APIENTRY *)(GLuint pipeline)) _func)(pipeline);
}

GLAPI void APIENTRY glBindProgramPipelineEXT(GLuint pipeline)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[81];
   ((void (APIENTRY *)(GLuint pipeline)) _func)(pipeline);
}

GLAPI void APIENTRY glBindRenderbuffer(GLenum target, GLuint renderbuffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[82];
   ((void (APIENTRY *)(GLenum target, GLuint renderbuffer)) _func)(target, renderbuffer);
}

GLAPI void APIENTRY glBindRenderbufferEXT(GLenum target, GLuint renderbuffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[83];
   ((void (APIENTRY *)(GLenum target, GLuint renderbuffer)) _func)(target, renderbuffer);
}

GLAPI void APIENTRY glBindRenderbufferOES(GLenum target, GLuint renderbuffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[84];
   ((void (APIENTRY *)(GLenum target, GLuint renderbuffer)) _func)(target, renderbuffer);
}

GLAPI void APIENTRY glBindSampler(GLuint unit, GLuint sampler)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[85];
   ((void (APIENTRY *)(GLuint unit, GLuint sampler)) _func)(unit, sampler);
}

GLAPI void APIENTRY glBindSamplers(GLuint first, GLsizei count, const GLuint *samplers)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[86];
   ((void (APIENTRY *)(GLuint first, GLsizei count, const GLuint *samplers)) _func)(first, count, samplers);
}

GLAPI void APIENTRY glBindShadingRateImageNV(GLuint texture)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[87];
   ((void (APIENTRY *)(GLuint texture)) _func)(texture);
}

GLAPI GLuint APIENTRY glBindTexGenParameterEXT(GLenum unit, GLenum coord, GLenum value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[88];
   return ((GLuint (APIENTRY *)(GLenum unit, GLenum coord, GLenum value)) _func)(unit, coord, value);
}

GLAPI void APIENTRY glBindTexture(GLenum target, GLuint texture)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[89];
   ((void (APIENTRY *)(GLenum target, GLuint texture)) _func)(target, texture);
}

GLAPI void APIENTRY glBindTextureEXT(GLenum target, GLuint texture)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[90];
   ((void (APIENTRY *)(GLenum target, GLuint texture)) _func)(target, texture);
}

GLAPI void APIENTRY glBindTextureUnit(GLuint unit, GLuint texture)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[91];
   ((void (APIENTRY *)(GLuint unit, GLuint texture)) _func)(unit, texture);
}

GLAPI GLuint APIENTRY glBindTextureUnitParameterEXT(GLenum unit, GLenum value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[92];
   return ((GLuint (APIENTRY *)(GLenum unit, GLenum value)) _func)(unit, value);
}

GLAPI void APIENTRY glBindTextures(GLuint first, GLsizei count, const GLuint *textures)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[93];
   ((void (APIENTRY *)(GLuint first, GLsizei count, const GLuint *textures)) _func)(first, count, textures);
}

GLAPI void APIENTRY glBindTransformFeedback(GLenum target, GLuint id)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[94];
   ((void (APIENTRY *)(GLenum target, GLuint id)) _func)(target, id);
}

GLAPI void APIENTRY glBindTransformFeedbackEXT(GLenum target, GLuint id)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[95];
   ((void (APIENTRY *)(GLenum target, GLuint id)) _func)(target, id);
}

GLAPI void APIENTRY glBindTransformFeedbackNV(GLenum target, GLuint id)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[96];
   ((void (APIENTRY *)(GLenum target, GLuint id)) _func)(target, id);
}

GLAPI void APIENTRY glBindVertexArray(GLuint array)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[97];
   ((void (APIENTRY *)(GLuint array)) _func)(array);
}

GLAPI void APIENTRY glBindVertexArrayAPPLE(GLuint array)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[98];
   ((void (APIENTRY *)(GLuint array)) _func)(array);
}

GLAPI void APIENTRY glBindVertexArrayOES(GLuint array)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[99];
   ((void (APIENTRY *)(GLuint array)) _func)(array);
}

GLAPI void APIENTRY glBindVertexBuffer(GLuint bindingindex, GLuint buffer, GLintptr offset, GLsizei stride)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[100];
   ((void (APIENTRY *)(GLuint bindingindex, GLuint buffer, GLintptr offset, GLsizei stride)) _func)(bindingindex, buffer, offset, stride);
}

GLAPI void APIENTRY glBindVertexBuffers(GLuint first, GLsizei count, const GLuint *buffers, const GLintptr *offsets, const GLsizei *strides)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[101];
   ((void (APIENTRY *)(GLuint first, GLsizei count, const GLuint *buffers, const GLintptr *offsets, const GLsizei *strides)) _func)(first, count, buffers, offsets, strides);
}

GLAPI void APIENTRY glBindVertexShaderEXT(GLuint id)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[102];
   ((void (APIENTRY *)(GLuint id)) _func)(id);
}

GLAPI void APIENTRY glBindVideoCaptureStreamBufferNV(GLuint video_capture_slot, GLuint stream, GLenum frame_region, GLintptr offset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[103];
   ((void (APIENTRY *)(GLuint video_capture_slot, GLuint stream, GLenum frame_region, GLintptr offset)) _func)(video_capture_slot, stream, frame_region, offset);
}

GLAPI void APIENTRY glBindVideoCaptureStreamTextureNV(GLuint video_capture_slot, GLuint stream, GLenum frame_region, GLenum target, GLuint texture)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[104];
   ((void (APIENTRY *)(GLuint video_capture_slot, GLuint stream, GLenum frame_region, GLenum target, GLuint texture)) _func)(video_capture_slot, stream, frame_region, target, texture);
}

GLAPI void APIENTRY glBinormal3bEXT(GLbyte bx, GLbyte by, GLbyte bz)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[105];
   ((void (APIENTRY *)(GLbyte bx, GLbyte by, GLbyte bz)) _func)(bx, by, bz);
}

GLAPI void APIENTRY glBinormal3bvEXT(const GLbyte *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[106];
   ((void (APIENTRY *)(const GLbyte *v)) _func)(v);
}

GLAPI void APIENTRY glBinormal3dEXT(GLdouble bx, GLdouble by, GLdouble bz)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[107];
   ((void (APIENTRY *)(GLdouble bx, GLdouble by, GLdouble bz)) _func)(bx, by, bz);
}

GLAPI void APIENTRY glBinormal3dvEXT(const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[108];
   ((void (APIENTRY *)(const GLdouble *v)) _func)(v);
}

GLAPI void APIENTRY glBinormal3fEXT(GLfloat bx, GLfloat by, GLfloat bz)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[109];
   ((void (APIENTRY *)(GLfloat bx, GLfloat by, GLfloat bz)) _func)(bx, by, bz);
}

GLAPI void APIENTRY glBinormal3fvEXT(const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[110];
   ((void (APIENTRY *)(const GLfloat *v)) _func)(v);
}

GLAPI void APIENTRY glBinormal3iEXT(GLint bx, GLint by, GLint bz)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[111];
   ((void (APIENTRY *)(GLint bx, GLint by, GLint bz)) _func)(bx, by, bz);
}

GLAPI void APIENTRY glBinormal3ivEXT(const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[112];
   ((void (APIENTRY *)(const GLint *v)) _func)(v);
}

GLAPI void APIENTRY glBinormal3sEXT(GLshort bx, GLshort by, GLshort bz)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[113];
   ((void (APIENTRY *)(GLshort bx, GLshort by, GLshort bz)) _func)(bx, by, bz);
}

GLAPI void APIENTRY glBinormal3svEXT(const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[114];
   ((void (APIENTRY *)(const GLshort *v)) _func)(v);
}

GLAPI void APIENTRY glBinormalPointerEXT(GLenum type, GLsizei stride, const void *pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[115];
   ((void (APIENTRY *)(GLenum type, GLsizei stride, const void *pointer)) _func)(type, stride, pointer);
}

GLAPI void APIENTRY glBitmap(GLsizei width, GLsizei height, GLfloat xorig, GLfloat yorig, GLfloat xmove, GLfloat ymove, const GLubyte *bitmap)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[116];
   ((void (APIENTRY *)(GLsizei width, GLsizei height, GLfloat xorig, GLfloat yorig, GLfloat xmove, GLfloat ymove, const GLubyte *bitmap)) _func)(width, height, xorig, yorig, xmove, ymove, bitmap);
}

GLAPI void APIENTRY glBitmapxOES(GLsizei width, GLsizei height, GLfixed xorig, GLfixed yorig, GLfixed xmove, GLfixed ymove, const GLubyte *bitmap)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[117];
   ((void (APIENTRY *)(GLsizei width, GLsizei height, GLfixed xorig, GLfixed yorig, GLfixed xmove, GLfixed ymove, const GLubyte *bitmap)) _func)(width, height, xorig, yorig, xmove, ymove, bitmap);
}

GLAPI void APIENTRY glBlendBarrier(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[118];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glBlendBarrierKHR(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[119];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glBlendBarrierNV(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[120];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glBlendColor(GLfloat red, GLfloat green, GLfloat blue, GLfloat alpha)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[121];
   ((void (APIENTRY *)(GLfloat red, GLfloat green, GLfloat blue, GLfloat alpha)) _func)(red, green, blue, alpha);
}

GLAPI void APIENTRY glBlendColorEXT(GLfloat red, GLfloat green, GLfloat blue, GLfloat alpha)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[122];
   ((void (APIENTRY *)(GLfloat red, GLfloat green, GLfloat blue, GLfloat alpha)) _func)(red, green, blue, alpha);
}

GLAPI void APIENTRY glBlendColorxOES(GLfixed red, GLfixed green, GLfixed blue, GLfixed alpha)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[123];
   ((void (APIENTRY *)(GLfixed red, GLfixed green, GLfixed blue, GLfixed alpha)) _func)(red, green, blue, alpha);
}

GLAPI void APIENTRY glBlendEquation(GLenum mode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[124];
   ((void (APIENTRY *)(GLenum mode)) _func)(mode);
}

GLAPI void APIENTRY glBlendEquationEXT(GLenum mode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[125];
   ((void (APIENTRY *)(GLenum mode)) _func)(mode);
}

GLAPI void APIENTRY glBlendEquationIndexedAMD(GLuint buf, GLenum mode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[126];
   ((void (APIENTRY *)(GLuint buf, GLenum mode)) _func)(buf, mode);
}

GLAPI void APIENTRY glBlendEquationOES(GLenum mode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[127];
   ((void (APIENTRY *)(GLenum mode)) _func)(mode);
}

GLAPI void APIENTRY glBlendEquationSeparate(GLenum modeRGB, GLenum modeAlpha)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[128];
   ((void (APIENTRY *)(GLenum modeRGB, GLenum modeAlpha)) _func)(modeRGB, modeAlpha);
}

GLAPI void APIENTRY glBlendEquationSeparateEXT(GLenum modeRGB, GLenum modeAlpha)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[129];
   ((void (APIENTRY *)(GLenum modeRGB, GLenum modeAlpha)) _func)(modeRGB, modeAlpha);
}

GLAPI void APIENTRY glBlendEquationSeparateIndexedAMD(GLuint buf, GLenum modeRGB, GLenum modeAlpha)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[130];
   ((void (APIENTRY *)(GLuint buf, GLenum modeRGB, GLenum modeAlpha)) _func)(buf, modeRGB, modeAlpha);
}

GLAPI void APIENTRY glBlendEquationSeparateOES(GLenum modeRGB, GLenum modeAlpha)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[131];
   ((void (APIENTRY *)(GLenum modeRGB, GLenum modeAlpha)) _func)(modeRGB, modeAlpha);
}

GLAPI void APIENTRY glBlendEquationSeparatei(GLuint buf, GLenum modeRGB, GLenum modeAlpha)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[132];
   ((void (APIENTRY *)(GLuint buf, GLenum modeRGB, GLenum modeAlpha)) _func)(buf, modeRGB, modeAlpha);
}

GLAPI void APIENTRY glBlendEquationSeparateiARB(GLuint buf, GLenum modeRGB, GLenum modeAlpha)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[133];
   ((void (APIENTRY *)(GLuint buf, GLenum modeRGB, GLenum modeAlpha)) _func)(buf, modeRGB, modeAlpha);
}

GLAPI void APIENTRY glBlendEquationSeparateiEXT(GLuint buf, GLenum modeRGB, GLenum modeAlpha)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[134];
   ((void (APIENTRY *)(GLuint buf, GLenum modeRGB, GLenum modeAlpha)) _func)(buf, modeRGB, modeAlpha);
}

GLAPI void APIENTRY glBlendEquationSeparateiOES(GLuint buf, GLenum modeRGB, GLenum modeAlpha)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[135];
   ((void (APIENTRY *)(GLuint buf, GLenum modeRGB, GLenum modeAlpha)) _func)(buf, modeRGB, modeAlpha);
}

GLAPI void APIENTRY glBlendEquationi(GLuint buf, GLenum mode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[136];
   ((void (APIENTRY *)(GLuint buf, GLenum mode)) _func)(buf, mode);
}

GLAPI void APIENTRY glBlendEquationiARB(GLuint buf, GLenum mode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[137];
   ((void (APIENTRY *)(GLuint buf, GLenum mode)) _func)(buf, mode);
}

GLAPI void APIENTRY glBlendEquationiEXT(GLuint buf, GLenum mode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[138];
   ((void (APIENTRY *)(GLuint buf, GLenum mode)) _func)(buf, mode);
}

GLAPI void APIENTRY glBlendEquationiOES(GLuint buf, GLenum mode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[139];
   ((void (APIENTRY *)(GLuint buf, GLenum mode)) _func)(buf, mode);
}

GLAPI void APIENTRY glBlendFunc(GLenum sfactor, GLenum dfactor)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[140];
   ((void (APIENTRY *)(GLenum sfactor, GLenum dfactor)) _func)(sfactor, dfactor);
}

GLAPI void APIENTRY glBlendFuncIndexedAMD(GLuint buf, GLenum src, GLenum dst)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[141];
   ((void (APIENTRY *)(GLuint buf, GLenum src, GLenum dst)) _func)(buf, src, dst);
}

GLAPI void APIENTRY glBlendFuncSeparate(GLenum sfactorRGB, GLenum dfactorRGB, GLenum sfactorAlpha, GLenum dfactorAlpha)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[142];
   ((void (APIENTRY *)(GLenum sfactorRGB, GLenum dfactorRGB, GLenum sfactorAlpha, GLenum dfactorAlpha)) _func)(sfactorRGB, dfactorRGB, sfactorAlpha, dfactorAlpha);
}

GLAPI void APIENTRY glBlendFuncSeparateEXT(GLenum sfactorRGB, GLenum dfactorRGB, GLenum sfactorAlpha, GLenum dfactorAlpha)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[143];
   ((void (APIENTRY *)(GLenum sfactorRGB, GLenum dfactorRGB, GLenum sfactorAlpha, GLenum dfactorAlpha)) _func)(sfactorRGB, dfactorRGB, sfactorAlpha, dfactorAlpha);
}

GLAPI void APIENTRY glBlendFuncSeparateINGR(GLenum sfactorRGB, GLenum dfactorRGB, GLenum sfactorAlpha, GLenum dfactorAlpha)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[144];
   ((void (APIENTRY *)(GLenum sfactorRGB, GLenum dfactorRGB, GLenum sfactorAlpha, GLenum dfactorAlpha)) _func)(sfactorRGB, dfactorRGB, sfactorAlpha, dfactorAlpha);
}

GLAPI void APIENTRY glBlendFuncSeparateIndexedAMD(GLuint buf, GLenum srcRGB, GLenum dstRGB, GLenum srcAlpha, GLenum dstAlpha)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[145];
   ((void (APIENTRY *)(GLuint buf, GLenum srcRGB, GLenum dstRGB, GLenum srcAlpha, GLenum dstAlpha)) _func)(buf, srcRGB, dstRGB, srcAlpha, dstAlpha);
}

GLAPI void APIENTRY glBlendFuncSeparateOES(GLenum srcRGB, GLenum dstRGB, GLenum srcAlpha, GLenum dstAlpha)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[146];
   ((void (APIENTRY *)(GLenum srcRGB, GLenum dstRGB, GLenum srcAlpha, GLenum dstAlpha)) _func)(srcRGB, dstRGB, srcAlpha, dstAlpha);
}

GLAPI void APIENTRY glBlendFuncSeparatei(GLuint buf, GLenum srcRGB, GLenum dstRGB, GLenum srcAlpha, GLenum dstAlpha)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[147];
   ((void (APIENTRY *)(GLuint buf, GLenum srcRGB, GLenum dstRGB, GLenum srcAlpha, GLenum dstAlpha)) _func)(buf, srcRGB, dstRGB, srcAlpha, dstAlpha);
}

GLAPI void APIENTRY glBlendFuncSeparateiARB(GLuint buf, GLenum srcRGB, GLenum dstRGB, GLenum srcAlpha, GLenum dstAlpha)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[148];
   ((void (APIENTRY *)(GLuint buf, GLenum srcRGB, GLenum dstRGB, GLenum srcAlpha, GLenum dstAlpha)) _func)(buf, srcRGB, dstRGB, srcAlpha, dstAlpha);
}

GLAPI void APIENTRY glBlendFuncSeparateiEXT(GLuint buf, GLenum srcRGB, GLenum dstRGB, GLenum srcAlpha, GLenum dstAlpha)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[149];
   ((void (APIENTRY *)(GLuint buf, GLenum srcRGB, GLenum dstRGB, GLenum srcAlpha, GLenum dstAlpha)) _func)(buf, srcRGB, dstRGB, srcAlpha, dstAlpha);
}

GLAPI void APIENTRY glBlendFuncSeparateiOES(GLuint buf, GLenum srcRGB, GLenum dstRGB, GLenum srcAlpha, GLenum dstAlpha)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[150];
   ((void (APIENTRY *)(GLuint buf, GLenum srcRGB, GLenum dstRGB, GLenum srcAlpha, GLenum dstAlpha)) _func)(buf, srcRGB, dstRGB, srcAlpha, dstAlpha);
}

GLAPI void APIENTRY glBlendFunci(GLuint buf, GLenum src, GLenum dst)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[151];
   ((void (APIENTRY *)(GLuint buf, GLenum src, GLenum dst)) _func)(buf, src, dst);
}

GLAPI void APIENTRY glBlendFunciARB(GLuint buf, GLenum src, GLenum dst)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[152];
   ((void (APIENTRY *)(GLuint buf, GLenum src, GLenum dst)) _func)(buf, src, dst);
}

GLAPI void APIENTRY glBlendFunciEXT(GLuint buf, GLenum src, GLenum dst)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[153];
   ((void (APIENTRY *)(GLuint buf, GLenum src, GLenum dst)) _func)(buf, src, dst);
}

GLAPI void APIENTRY glBlendFunciOES(GLuint buf, GLenum src, GLenum dst)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[154];
   ((void (APIENTRY *)(GLuint buf, GLenum src, GLenum dst)) _func)(buf, src, dst);
}

GLAPI void APIENTRY glBlendParameteriNV(GLenum pname, GLint value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[155];
   ((void (APIENTRY *)(GLenum pname, GLint value)) _func)(pname, value);
}

GLAPI void APIENTRY glBlitFramebuffer(GLint srcX0, GLint srcY0, GLint srcX1, GLint srcY1, GLint dstX0, GLint dstY0, GLint dstX1, GLint dstY1, GLbitfield mask, GLenum filter)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[156];
   ((void (APIENTRY *)(GLint srcX0, GLint srcY0, GLint srcX1, GLint srcY1, GLint dstX0, GLint dstY0, GLint dstX1, GLint dstY1, GLbitfield mask, GLenum filter)) _func)(srcX0, srcY0, srcX1, srcY1, dstX0, dstY0, dstX1, dstY1, mask, filter);
}

GLAPI void APIENTRY glBlitFramebufferANGLE(GLint srcX0, GLint srcY0, GLint srcX1, GLint srcY1, GLint dstX0, GLint dstY0, GLint dstX1, GLint dstY1, GLbitfield mask, GLenum filter)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[157];
   ((void (APIENTRY *)(GLint srcX0, GLint srcY0, GLint srcX1, GLint srcY1, GLint dstX0, GLint dstY0, GLint dstX1, GLint dstY1, GLbitfield mask, GLenum filter)) _func)(srcX0, srcY0, srcX1, srcY1, dstX0, dstY0, dstX1, dstY1, mask, filter);
}

GLAPI void APIENTRY glBlitFramebufferEXT(GLint srcX0, GLint srcY0, GLint srcX1, GLint srcY1, GLint dstX0, GLint dstY0, GLint dstX1, GLint dstY1, GLbitfield mask, GLenum filter)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[158];
   ((void (APIENTRY *)(GLint srcX0, GLint srcY0, GLint srcX1, GLint srcY1, GLint dstX0, GLint dstY0, GLint dstX1, GLint dstY1, GLbitfield mask, GLenum filter)) _func)(srcX0, srcY0, srcX1, srcY1, dstX0, dstY0, dstX1, dstY1, mask, filter);
}

GLAPI void APIENTRY glBlitFramebufferNV(GLint srcX0, GLint srcY0, GLint srcX1, GLint srcY1, GLint dstX0, GLint dstY0, GLint dstX1, GLint dstY1, GLbitfield mask, GLenum filter)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[159];
   ((void (APIENTRY *)(GLint srcX0, GLint srcY0, GLint srcX1, GLint srcY1, GLint dstX0, GLint dstY0, GLint dstX1, GLint dstY1, GLbitfield mask, GLenum filter)) _func)(srcX0, srcY0, srcX1, srcY1, dstX0, dstY0, dstX1, dstY1, mask, filter);
}

GLAPI void APIENTRY glBlitNamedFramebuffer(GLuint readFramebuffer, GLuint drawFramebuffer, GLint srcX0, GLint srcY0, GLint srcX1, GLint srcY1, GLint dstX0, GLint dstY0, GLint dstX1, GLint dstY1, GLbitfield mask, GLenum filter)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[160];
   ((void (APIENTRY *)(GLuint readFramebuffer, GLuint drawFramebuffer, GLint srcX0, GLint srcY0, GLint srcX1, GLint srcY1, GLint dstX0, GLint dstY0, GLint dstX1, GLint dstY1, GLbitfield mask, GLenum filter)) _func)(readFramebuffer, drawFramebuffer, srcX0, srcY0, srcX1, srcY1, dstX0, dstY0, dstX1, dstY1, mask, filter);
}

GLAPI void APIENTRY glBufferAddressRangeNV(GLenum pname, GLuint index, GLuint64 address, GLsizeiptr length)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[161];
   ((void (APIENTRY *)(GLenum pname, GLuint index, GLuint64 address, GLsizeiptr length)) _func)(pname, index, address, length);
}

GLAPI void APIENTRY glBufferAttachMemoryNV(GLenum target, GLuint memory, GLuint64 offset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[162];
   ((void (APIENTRY *)(GLenum target, GLuint memory, GLuint64 offset)) _func)(target, memory, offset);
}

GLAPI void APIENTRY glBufferData(GLenum target, GLsizeiptr size, const void *data, GLenum usage)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[163];
   ((void (APIENTRY *)(GLenum target, GLsizeiptr size, const void *data, GLenum usage)) _func)(target, size, data, usage);
}

GLAPI void APIENTRY glBufferDataARB(GLenum target, GLsizeiptr size, const void *data, GLenum usage)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[164];
   ((void (APIENTRY *)(GLenum target, GLsizeiptr size, const void *data, GLenum usage)) _func)(target, size, data, usage);
}

GLAPI void APIENTRY glBufferDataSysmem(GLenum target, GLsizeiptr size, const void *data, GLenum usage)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[165];
   ((void (APIENTRY *)(GLenum target, GLsizeiptr size, const void *data, GLenum usage)) _func)(target, size, data, usage);
}

GLAPI void APIENTRY glBufferPageCommitmentARB(GLenum target, GLintptr offset, GLsizeiptr size, GLboolean commit)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[166];
   ((void (APIENTRY *)(GLenum target, GLintptr offset, GLsizeiptr size, GLboolean commit)) _func)(target, offset, size, commit);
}

GLAPI void APIENTRY glBufferParameteriAPPLE(GLenum target, GLenum pname, GLint param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[168];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLint param)) _func)(target, pname, param);
}

GLAPI void APIENTRY glBufferStorage(GLenum target, GLsizeiptr size, const void *data, GLbitfield flags)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[169];
   ((void (APIENTRY *)(GLenum target, GLsizeiptr size, const void *data, GLbitfield flags)) _func)(target, size, data, flags);
}

GLAPI void APIENTRY glBufferStorageEXT(GLenum target, GLsizeiptr size, const void *data, GLbitfield flags)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[170];
   ((void (APIENTRY *)(GLenum target, GLsizeiptr size, const void *data, GLbitfield flags)) _func)(target, size, data, flags);
}

GLAPI void APIENTRY glBufferStorageExternalEXT(GLenum target, GLintptr offset, GLsizeiptr size, GLeglClientBufferEXT clientBuffer, GLbitfield flags)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[171];
   ((void (APIENTRY *)(GLenum target, GLintptr offset, GLsizeiptr size, GLeglClientBufferEXT clientBuffer, GLbitfield flags)) _func)(target, offset, size, clientBuffer, flags);
}

GLAPI void APIENTRY glBufferStorageMemEXT(GLenum target, GLsizeiptr size, GLuint memory, GLuint64 offset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[172];
   ((void (APIENTRY *)(GLenum target, GLsizeiptr size, GLuint memory, GLuint64 offset)) _func)(target, size, memory, offset);
}

GLAPI void APIENTRY glBufferSubData(GLenum target, GLintptr offset, GLsizeiptr size, const void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[173];
   ((void (APIENTRY *)(GLenum target, GLintptr offset, GLsizeiptr size, const void *data)) _func)(target, offset, size, data);
}

GLAPI void APIENTRY glBufferSubDataARB(GLenum target, GLintptr offset, GLsizeiptr size, const void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[174];
   ((void (APIENTRY *)(GLenum target, GLintptr offset, GLsizeiptr size, const void *data)) _func)(target, offset, size, data);
}

GLAPI void APIENTRY glCallCommandListNV(GLuint list)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[175];
   ((void (APIENTRY *)(GLuint list)) _func)(list);
}

GLAPI void APIENTRY glCallList(GLuint list)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[176];
   ((void (APIENTRY *)(GLuint list)) _func)(list);
}

GLAPI void APIENTRY glCallLists(GLsizei n, GLenum type, const void *lists)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[177];
   ((void (APIENTRY *)(GLsizei n, GLenum type, const void *lists)) _func)(n, type, lists);
}

GLAPI GLenum APIENTRY glCheckFramebufferStatus(GLenum target)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[178];
   return ((GLenum (APIENTRY *)(GLenum target)) _func)(target);
}

GLAPI GLenum APIENTRY glCheckFramebufferStatusEXT(GLenum target)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[179];
   return ((GLenum (APIENTRY *)(GLenum target)) _func)(target);
}

GLAPI GLenum APIENTRY glCheckFramebufferStatusOES(GLenum target)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[180];
   return ((GLenum (APIENTRY *)(GLenum target)) _func)(target);
}

GLAPI GLenum APIENTRY glCheckNamedFramebufferStatus(GLuint framebuffer, GLenum target)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[181];
   return ((GLenum (APIENTRY *)(GLuint framebuffer, GLenum target)) _func)(framebuffer, target);
}

GLAPI GLenum APIENTRY glCheckNamedFramebufferStatusEXT(GLuint framebuffer, GLenum target)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[182];
   return ((GLenum (APIENTRY *)(GLuint framebuffer, GLenum target)) _func)(framebuffer, target);
}

GLAPI void APIENTRY glClampColor(GLenum target, GLenum clamp)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[183];
   ((void (APIENTRY *)(GLenum target, GLenum clamp)) _func)(target, clamp);
}

GLAPI void APIENTRY glClampColorARB(GLenum target, GLenum clamp)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[184];
   ((void (APIENTRY *)(GLenum target, GLenum clamp)) _func)(target, clamp);
}

GLAPI void APIENTRY glClear(GLbitfield mask)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[185];
   ((void (APIENTRY *)(GLbitfield mask)) _func)(mask);
}

GLAPI void APIENTRY glClearAccum(GLfloat red, GLfloat green, GLfloat blue, GLfloat alpha)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[186];
   ((void (APIENTRY *)(GLfloat red, GLfloat green, GLfloat blue, GLfloat alpha)) _func)(red, green, blue, alpha);
}

GLAPI void APIENTRY glClearAccumxOES(GLfixed red, GLfixed green, GLfixed blue, GLfixed alpha)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[187];
   ((void (APIENTRY *)(GLfixed red, GLfixed green, GLfixed blue, GLfixed alpha)) _func)(red, green, blue, alpha);
}

GLAPI void APIENTRY glClearBufferData(GLenum target, GLenum internalformat, GLenum format, GLenum type, const void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[188];
   ((void (APIENTRY *)(GLenum target, GLenum internalformat, GLenum format, GLenum type, const void *data)) _func)(target, internalformat, format, type, data);
}

GLAPI void APIENTRY glClearBufferSubData(GLenum target, GLenum internalformat, GLintptr offset, GLsizeiptr size, GLenum format, GLenum type, const void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[189];
   ((void (APIENTRY *)(GLenum target, GLenum internalformat, GLintptr offset, GLsizeiptr size, GLenum format, GLenum type, const void *data)) _func)(target, internalformat, offset, size, format, type, data);
}

GLAPI void APIENTRY glClearBufferfi(GLenum buffer, GLint drawbuffer, GLfloat depth, GLint stencil)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[190];
   ((void (APIENTRY *)(GLenum buffer, GLint drawbuffer, GLfloat depth, GLint stencil)) _func)(buffer, drawbuffer, depth, stencil);
}

GLAPI void APIENTRY glClearBufferfv(GLenum buffer, GLint drawbuffer, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[191];
   ((void (APIENTRY *)(GLenum buffer, GLint drawbuffer, const GLfloat *value)) _func)(buffer, drawbuffer, value);
}

GLAPI void APIENTRY glClearBufferiv(GLenum buffer, GLint drawbuffer, const GLint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[192];
   ((void (APIENTRY *)(GLenum buffer, GLint drawbuffer, const GLint *value)) _func)(buffer, drawbuffer, value);
}

GLAPI void APIENTRY glClearBufferuiv(GLenum buffer, GLint drawbuffer, const GLuint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[193];
   ((void (APIENTRY *)(GLenum buffer, GLint drawbuffer, const GLuint *value)) _func)(buffer, drawbuffer, value);
}

GLAPI void APIENTRY glClearColor(GLfloat red, GLfloat green, GLfloat blue, GLfloat alpha)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[194];
   ((void (APIENTRY *)(GLfloat red, GLfloat green, GLfloat blue, GLfloat alpha)) _func)(red, green, blue, alpha);
}

GLAPI void APIENTRY glClearColorIiEXT(GLint red, GLint green, GLint blue, GLint alpha)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[195];
   ((void (APIENTRY *)(GLint red, GLint green, GLint blue, GLint alpha)) _func)(red, green, blue, alpha);
}

GLAPI void APIENTRY glClearColorIuiEXT(GLuint red, GLuint green, GLuint blue, GLuint alpha)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[196];
   ((void (APIENTRY *)(GLuint red, GLuint green, GLuint blue, GLuint alpha)) _func)(red, green, blue, alpha);
}

GLAPI void APIENTRY glClearColorx(GLfixed red, GLfixed green, GLfixed blue, GLfixed alpha)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[197];
   ((void (APIENTRY *)(GLfixed red, GLfixed green, GLfixed blue, GLfixed alpha)) _func)(red, green, blue, alpha);
}

GLAPI void APIENTRY glClearColorxOES(GLfixed red, GLfixed green, GLfixed blue, GLfixed alpha)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[198];
   ((void (APIENTRY *)(GLfixed red, GLfixed green, GLfixed blue, GLfixed alpha)) _func)(red, green, blue, alpha);
}

GLAPI void APIENTRY glClearDepth(GLdouble depth)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[199];
   ((void (APIENTRY *)(GLdouble depth)) _func)(depth);
}

GLAPI void APIENTRY glClearDepthdNV(GLdouble depth)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[200];
   ((void (APIENTRY *)(GLdouble depth)) _func)(depth);
}

GLAPI void APIENTRY glClearDepthf(GLfloat d)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[201];
   ((void (APIENTRY *)(GLfloat d)) _func)(d);
}

GLAPI void APIENTRY glClearDepthfOES(GLclampf depth)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[202];
   ((void (APIENTRY *)(GLclampf depth)) _func)(depth);
}

GLAPI void APIENTRY glClearDepthx(GLfixed depth)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[203];
   ((void (APIENTRY *)(GLfixed depth)) _func)(depth);
}

GLAPI void APIENTRY glClearDepthxOES(GLfixed depth)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[204];
   ((void (APIENTRY *)(GLfixed depth)) _func)(depth);
}

GLAPI void APIENTRY glClearIndex(GLfloat c)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[205];
   ((void (APIENTRY *)(GLfloat c)) _func)(c);
}

GLAPI void APIENTRY glClearNamedBufferData(GLuint buffer, GLenum internalformat, GLenum format, GLenum type, const void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[206];
   ((void (APIENTRY *)(GLuint buffer, GLenum internalformat, GLenum format, GLenum type, const void *data)) _func)(buffer, internalformat, format, type, data);
}

GLAPI void APIENTRY glClearNamedBufferDataEXT(GLuint buffer, GLenum internalformat, GLenum format, GLenum type, const void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[207];
   ((void (APIENTRY *)(GLuint buffer, GLenum internalformat, GLenum format, GLenum type, const void *data)) _func)(buffer, internalformat, format, type, data);
}

GLAPI void APIENTRY glClearNamedBufferSubData(GLuint buffer, GLenum internalformat, GLintptr offset, GLsizeiptr size, GLenum format, GLenum type, const void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[208];
   ((void (APIENTRY *)(GLuint buffer, GLenum internalformat, GLintptr offset, GLsizeiptr size, GLenum format, GLenum type, const void *data)) _func)(buffer, internalformat, offset, size, format, type, data);
}

GLAPI void APIENTRY glClearNamedBufferSubDataEXT(GLuint buffer, GLenum internalformat, GLsizeiptr offset, GLsizeiptr size, GLenum format, GLenum type, const void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[209];
   ((void (APIENTRY *)(GLuint buffer, GLenum internalformat, GLsizeiptr offset, GLsizeiptr size, GLenum format, GLenum type, const void *data)) _func)(buffer, internalformat, offset, size, format, type, data);
}

GLAPI void APIENTRY glClearNamedFramebufferfi(GLuint framebuffer, GLenum buffer, GLint drawbuffer, GLfloat depth, GLint stencil)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[210];
   ((void (APIENTRY *)(GLuint framebuffer, GLenum buffer, GLint drawbuffer, GLfloat depth, GLint stencil)) _func)(framebuffer, buffer, drawbuffer, depth, stencil);
}

GLAPI void APIENTRY glClearNamedFramebufferfv(GLuint framebuffer, GLenum buffer, GLint drawbuffer, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[211];
   ((void (APIENTRY *)(GLuint framebuffer, GLenum buffer, GLint drawbuffer, const GLfloat *value)) _func)(framebuffer, buffer, drawbuffer, value);
}

GLAPI void APIENTRY glClearNamedFramebufferiv(GLuint framebuffer, GLenum buffer, GLint drawbuffer, const GLint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[212];
   ((void (APIENTRY *)(GLuint framebuffer, GLenum buffer, GLint drawbuffer, const GLint *value)) _func)(framebuffer, buffer, drawbuffer, value);
}

GLAPI void APIENTRY glClearNamedFramebufferuiv(GLuint framebuffer, GLenum buffer, GLint drawbuffer, const GLuint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[213];
   ((void (APIENTRY *)(GLuint framebuffer, GLenum buffer, GLint drawbuffer, const GLuint *value)) _func)(framebuffer, buffer, drawbuffer, value);
}

GLAPI void APIENTRY glClearPixelLocalStorageuiEXT(GLsizei offset, GLsizei n, const GLuint *values)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[214];
   ((void (APIENTRY *)(GLsizei offset, GLsizei n, const GLuint *values)) _func)(offset, n, values);
}

GLAPI void APIENTRY glClearStencil(GLint s)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[215];
   ((void (APIENTRY *)(GLint s)) _func)(s);
}

GLAPI void APIENTRY glClearTexImage(GLuint texture, GLint level, GLenum format, GLenum type, const void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[216];
   ((void (APIENTRY *)(GLuint texture, GLint level, GLenum format, GLenum type, const void *data)) _func)(texture, level, format, type, data);
}

GLAPI void APIENTRY glClearTexImageEXT(GLuint texture, GLint level, GLenum format, GLenum type, const void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[217];
   ((void (APIENTRY *)(GLuint texture, GLint level, GLenum format, GLenum type, const void *data)) _func)(texture, level, format, type, data);
}

GLAPI void APIENTRY glClearTexSubImage(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[218];
   ((void (APIENTRY *)(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void *data)) _func)(texture, level, xoffset, yoffset, zoffset, width, height, depth, format, type, data);
}

GLAPI void APIENTRY glClearTexSubImageEXT(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[219];
   ((void (APIENTRY *)(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void *data)) _func)(texture, level, xoffset, yoffset, zoffset, width, height, depth, format, type, data);
}

GLAPI void APIENTRY glClientActiveTexture(GLenum texture)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[220];
   ((void (APIENTRY *)(GLenum texture)) _func)(texture);
}

GLAPI void APIENTRY glClientActiveTextureARB(GLenum texture)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[221];
   ((void (APIENTRY *)(GLenum texture)) _func)(texture);
}

GLAPI void APIENTRY glClientActiveVertexStreamATI(GLenum stream)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[222];
   ((void (APIENTRY *)(GLenum stream)) _func)(stream);
}

GLAPI void APIENTRY glClientAttribDefaultEXT(GLbitfield mask)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[223];
   ((void (APIENTRY *)(GLbitfield mask)) _func)(mask);
}

GLAPI void APIENTRY glClientWaitSemaphoreui64NVX(GLsizei fenceObjectCount, const GLuint *semaphoreArray, const GLuint64 *fenceValueArray)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[224];
   ((void (APIENTRY *)(GLsizei fenceObjectCount, const GLuint *semaphoreArray, const GLuint64 *fenceValueArray)) _func)(fenceObjectCount, semaphoreArray, fenceValueArray);
}

GLAPI GLenum APIENTRY glClientWaitSync(GLsync sync, GLbitfield flags, GLuint64 timeout)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[225];
   return ((GLenum (APIENTRY *)(GLsync sync, GLbitfield flags, GLuint64 timeout)) _func)(sync, flags, timeout);
}

GLAPI GLenum APIENTRY glClientWaitSyncAPPLE(GLsync sync, GLbitfield flags, GLuint64 timeout)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[226];
   return ((GLenum (APIENTRY *)(GLsync sync, GLbitfield flags, GLuint64 timeout)) _func)(sync, flags, timeout);
}

GLAPI GLenum APIENTRY glClientWaitSyncValueuiNVX(GLsync sync, GLbitfield flags, GLuint64 timeout, GLuint value, GLboolean GEQ)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[227];
   return ((GLenum (APIENTRY *)(GLsync sync, GLbitfield flags, GLuint64 timeout, GLuint value, GLboolean GEQ)) _func)(sync, flags, timeout, value, GEQ);
}

GLAPI void APIENTRY glClipControl(GLenum origin, GLenum depth)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[228];
   ((void (APIENTRY *)(GLenum origin, GLenum depth)) _func)(origin, depth);
}

GLAPI void APIENTRY glClipControlEXT(GLenum origin, GLenum depth)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[229];
   ((void (APIENTRY *)(GLenum origin, GLenum depth)) _func)(origin, depth);
}

GLAPI void APIENTRY glClipPlane(GLenum plane, const GLdouble *equation)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[230];
   ((void (APIENTRY *)(GLenum plane, const GLdouble *equation)) _func)(plane, equation);
}

GLAPI void APIENTRY glClipPlanef(GLenum p, const GLfloat *eqn)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[231];
   ((void (APIENTRY *)(GLenum p, const GLfloat *eqn)) _func)(p, eqn);
}

GLAPI void APIENTRY glClipPlanefIMG(GLenum p, const GLfloat *eqn)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[232];
   ((void (APIENTRY *)(GLenum p, const GLfloat *eqn)) _func)(p, eqn);
}

GLAPI void APIENTRY glClipPlanefOES(GLenum plane, const GLfloat *equation)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[233];
   ((void (APIENTRY *)(GLenum plane, const GLfloat *equation)) _func)(plane, equation);
}

GLAPI void APIENTRY glClipPlanex(GLenum plane, const GLfixed *equation)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[234];
   ((void (APIENTRY *)(GLenum plane, const GLfixed *equation)) _func)(plane, equation);
}

GLAPI void APIENTRY glClipPlanexIMG(GLenum p, const GLfixed *eqn)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[235];
   ((void (APIENTRY *)(GLenum p, const GLfixed *eqn)) _func)(p, eqn);
}

GLAPI void APIENTRY glClipPlanexOES(GLenum plane, const GLfixed *equation)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[236];
   ((void (APIENTRY *)(GLenum plane, const GLfixed *equation)) _func)(plane, equation);
}

GLAPI void APIENTRY glColor3b(GLbyte red, GLbyte green, GLbyte blue)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[237];
   ((void (APIENTRY *)(GLbyte red, GLbyte green, GLbyte blue)) _func)(red, green, blue);
}

GLAPI void APIENTRY glColor3bv(const GLbyte *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[238];
   ((void (APIENTRY *)(const GLbyte *v)) _func)(v);
}

GLAPI void APIENTRY glColor3d(GLdouble red, GLdouble green, GLdouble blue)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[239];
   ((void (APIENTRY *)(GLdouble red, GLdouble green, GLdouble blue)) _func)(red, green, blue);
}

GLAPI void APIENTRY glColor3dv(const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[240];
   ((void (APIENTRY *)(const GLdouble *v)) _func)(v);
}

GLAPI void APIENTRY glColor3f(GLfloat red, GLfloat green, GLfloat blue)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[241];
   ((void (APIENTRY *)(GLfloat red, GLfloat green, GLfloat blue)) _func)(red, green, blue);
}

GLAPI void APIENTRY glColor3fVertex3fSUN(GLfloat r, GLfloat g, GLfloat b, GLfloat x, GLfloat y, GLfloat z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[242];
   ((void (APIENTRY *)(GLfloat r, GLfloat g, GLfloat b, GLfloat x, GLfloat y, GLfloat z)) _func)(r, g, b, x, y, z);
}

GLAPI void APIENTRY glColor3fVertex3fvSUN(const GLfloat *c, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[243];
   ((void (APIENTRY *)(const GLfloat *c, const GLfloat *v)) _func)(c, v);
}

GLAPI void APIENTRY glColor3fv(const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[244];
   ((void (APIENTRY *)(const GLfloat *v)) _func)(v);
}

GLAPI void APIENTRY glColor3hNV(GLhalf red, GLhalf green, GLhalf blue)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[245];
   ((void (APIENTRY *)(GLhalf red, GLhalf green, GLhalf blue)) _func)(red, green, blue);
}

GLAPI void APIENTRY glColor3hvNV(const GLhalf *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[246];
   ((void (APIENTRY *)(const GLhalf *v)) _func)(v);
}

GLAPI void APIENTRY glColor3i(GLint red, GLint green, GLint blue)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[247];
   ((void (APIENTRY *)(GLint red, GLint green, GLint blue)) _func)(red, green, blue);
}

GLAPI void APIENTRY glColor3iv(const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[248];
   ((void (APIENTRY *)(const GLint *v)) _func)(v);
}

GLAPI void APIENTRY glColor3s(GLshort red, GLshort green, GLshort blue)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[249];
   ((void (APIENTRY *)(GLshort red, GLshort green, GLshort blue)) _func)(red, green, blue);
}

GLAPI void APIENTRY glColor3sv(const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[250];
   ((void (APIENTRY *)(const GLshort *v)) _func)(v);
}

GLAPI void APIENTRY glColor3ub(GLubyte red, GLubyte green, GLubyte blue)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[251];
   ((void (APIENTRY *)(GLubyte red, GLubyte green, GLubyte blue)) _func)(red, green, blue);
}

GLAPI void APIENTRY glColor3ubv(const GLubyte *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[252];
   ((void (APIENTRY *)(const GLubyte *v)) _func)(v);
}

GLAPI void APIENTRY glColor3ui(GLuint red, GLuint green, GLuint blue)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[253];
   ((void (APIENTRY *)(GLuint red, GLuint green, GLuint blue)) _func)(red, green, blue);
}

GLAPI void APIENTRY glColor3uiv(const GLuint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[254];
   ((void (APIENTRY *)(const GLuint *v)) _func)(v);
}

GLAPI void APIENTRY glColor3us(GLushort red, GLushort green, GLushort blue)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[255];
   ((void (APIENTRY *)(GLushort red, GLushort green, GLushort blue)) _func)(red, green, blue);
}

GLAPI void APIENTRY glColor3usv(const GLushort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[256];
   ((void (APIENTRY *)(const GLushort *v)) _func)(v);
}

GLAPI void APIENTRY glColor3x(GLfixed red, GLfixed green, GLfixed blue)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[257];
   ((void (APIENTRY *)(GLfixed red, GLfixed green, GLfixed blue)) _func)(red, green, blue);
}

GLAPI void APIENTRY glColor3xOES(GLfixed red, GLfixed green, GLfixed blue)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[258];
   ((void (APIENTRY *)(GLfixed red, GLfixed green, GLfixed blue)) _func)(red, green, blue);
}

GLAPI void APIENTRY glColor3xvOES(const GLfixed *components)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[259];
   ((void (APIENTRY *)(const GLfixed *components)) _func)(components);
}

GLAPI void APIENTRY glColor4b(GLbyte red, GLbyte green, GLbyte blue, GLbyte alpha)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[260];
   ((void (APIENTRY *)(GLbyte red, GLbyte green, GLbyte blue, GLbyte alpha)) _func)(red, green, blue, alpha);
}

GLAPI void APIENTRY glColor4bv(const GLbyte *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[261];
   ((void (APIENTRY *)(const GLbyte *v)) _func)(v);
}

GLAPI void APIENTRY glColor4d(GLdouble red, GLdouble green, GLdouble blue, GLdouble alpha)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[262];
   ((void (APIENTRY *)(GLdouble red, GLdouble green, GLdouble blue, GLdouble alpha)) _func)(red, green, blue, alpha);
}

GLAPI void APIENTRY glColor4dv(const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[263];
   ((void (APIENTRY *)(const GLdouble *v)) _func)(v);
}

GLAPI void APIENTRY glColor4f(GLfloat red, GLfloat green, GLfloat blue, GLfloat alpha)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[264];
   ((void (APIENTRY *)(GLfloat red, GLfloat green, GLfloat blue, GLfloat alpha)) _func)(red, green, blue, alpha);
}

GLAPI void APIENTRY glColor4fNormal3fVertex3fSUN(GLfloat r, GLfloat g, GLfloat b, GLfloat a, GLfloat nx, GLfloat ny, GLfloat nz, GLfloat x, GLfloat y, GLfloat z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[265];
   ((void (APIENTRY *)(GLfloat r, GLfloat g, GLfloat b, GLfloat a, GLfloat nx, GLfloat ny, GLfloat nz, GLfloat x, GLfloat y, GLfloat z)) _func)(r, g, b, a, nx, ny, nz, x, y, z);
}

GLAPI void APIENTRY glColor4fNormal3fVertex3fvSUN(const GLfloat *c, const GLfloat *n, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[266];
   ((void (APIENTRY *)(const GLfloat *c, const GLfloat *n, const GLfloat *v)) _func)(c, n, v);
}

GLAPI void APIENTRY glColor4fv(const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[267];
   ((void (APIENTRY *)(const GLfloat *v)) _func)(v);
}

GLAPI void APIENTRY glColor4hNV(GLhalf red, GLhalf green, GLhalf blue, GLhalf alpha)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[268];
   ((void (APIENTRY *)(GLhalf red, GLhalf green, GLhalf blue, GLhalf alpha)) _func)(red, green, blue, alpha);
}

GLAPI void APIENTRY glColor4hvNV(const GLhalf *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[269];
   ((void (APIENTRY *)(const GLhalf *v)) _func)(v);
}

GLAPI void APIENTRY glColor4i(GLint red, GLint green, GLint blue, GLint alpha)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[270];
   ((void (APIENTRY *)(GLint red, GLint green, GLint blue, GLint alpha)) _func)(red, green, blue, alpha);
}

GLAPI void APIENTRY glColor4iv(const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[271];
   ((void (APIENTRY *)(const GLint *v)) _func)(v);
}

GLAPI void APIENTRY glColor4s(GLshort red, GLshort green, GLshort blue, GLshort alpha)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[272];
   ((void (APIENTRY *)(GLshort red, GLshort green, GLshort blue, GLshort alpha)) _func)(red, green, blue, alpha);
}

GLAPI void APIENTRY glColor4sv(const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[273];
   ((void (APIENTRY *)(const GLshort *v)) _func)(v);
}

GLAPI void APIENTRY glColor4ub(GLubyte red, GLubyte green, GLubyte blue, GLubyte alpha)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[274];
   ((void (APIENTRY *)(GLubyte red, GLubyte green, GLubyte blue, GLubyte alpha)) _func)(red, green, blue, alpha);
}

GLAPI void APIENTRY glColor4ubVertex2fSUN(GLubyte r, GLubyte g, GLubyte b, GLubyte a, GLfloat x, GLfloat y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[275];
   ((void (APIENTRY *)(GLubyte r, GLubyte g, GLubyte b, GLubyte a, GLfloat x, GLfloat y)) _func)(r, g, b, a, x, y);
}

GLAPI void APIENTRY glColor4ubVertex2fvSUN(const GLubyte *c, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[276];
   ((void (APIENTRY *)(const GLubyte *c, const GLfloat *v)) _func)(c, v);
}

GLAPI void APIENTRY glColor4ubVertex3fSUN(GLubyte r, GLubyte g, GLubyte b, GLubyte a, GLfloat x, GLfloat y, GLfloat z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[277];
   ((void (APIENTRY *)(GLubyte r, GLubyte g, GLubyte b, GLubyte a, GLfloat x, GLfloat y, GLfloat z)) _func)(r, g, b, a, x, y, z);
}

GLAPI void APIENTRY glColor4ubVertex3fvSUN(const GLubyte *c, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[278];
   ((void (APIENTRY *)(const GLubyte *c, const GLfloat *v)) _func)(c, v);
}

GLAPI void APIENTRY glColor4ubv(const GLubyte *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[279];
   ((void (APIENTRY *)(const GLubyte *v)) _func)(v);
}

GLAPI void APIENTRY glColor4ui(GLuint red, GLuint green, GLuint blue, GLuint alpha)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[280];
   ((void (APIENTRY *)(GLuint red, GLuint green, GLuint blue, GLuint alpha)) _func)(red, green, blue, alpha);
}

GLAPI void APIENTRY glColor4uiv(const GLuint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[281];
   ((void (APIENTRY *)(const GLuint *v)) _func)(v);
}

GLAPI void APIENTRY glColor4us(GLushort red, GLushort green, GLushort blue, GLushort alpha)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[282];
   ((void (APIENTRY *)(GLushort red, GLushort green, GLushort blue, GLushort alpha)) _func)(red, green, blue, alpha);
}

GLAPI void APIENTRY glColor4usv(const GLushort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[283];
   ((void (APIENTRY *)(const GLushort *v)) _func)(v);
}

GLAPI void APIENTRY glColor4x(GLfixed red, GLfixed green, GLfixed blue, GLfixed alpha)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[284];
   ((void (APIENTRY *)(GLfixed red, GLfixed green, GLfixed blue, GLfixed alpha)) _func)(red, green, blue, alpha);
}

GLAPI void APIENTRY glColor4xOES(GLfixed red, GLfixed green, GLfixed blue, GLfixed alpha)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[285];
   ((void (APIENTRY *)(GLfixed red, GLfixed green, GLfixed blue, GLfixed alpha)) _func)(red, green, blue, alpha);
}

GLAPI void APIENTRY glColor4xvOES(const GLfixed *components)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[286];
   ((void (APIENTRY *)(const GLfixed *components)) _func)(components);
}

GLAPI void APIENTRY glColorFormatNV(GLint size, GLenum type, GLsizei stride)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[287];
   ((void (APIENTRY *)(GLint size, GLenum type, GLsizei stride)) _func)(size, type, stride);
}

GLAPI void APIENTRY glColorFragmentOp1ATI(GLenum op, GLuint dst, GLuint dstMask, GLuint dstMod, GLuint arg1, GLuint arg1Rep, GLuint arg1Mod)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[288];
   ((void (APIENTRY *)(GLenum op, GLuint dst, GLuint dstMask, GLuint dstMod, GLuint arg1, GLuint arg1Rep, GLuint arg1Mod)) _func)(op, dst, dstMask, dstMod, arg1, arg1Rep, arg1Mod);
}

GLAPI void APIENTRY glColorFragmentOp2ATI(GLenum op, GLuint dst, GLuint dstMask, GLuint dstMod, GLuint arg1, GLuint arg1Rep, GLuint arg1Mod, GLuint arg2, GLuint arg2Rep, GLuint arg2Mod)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[289];
   ((void (APIENTRY *)(GLenum op, GLuint dst, GLuint dstMask, GLuint dstMod, GLuint arg1, GLuint arg1Rep, GLuint arg1Mod, GLuint arg2, GLuint arg2Rep, GLuint arg2Mod)) _func)(op, dst, dstMask, dstMod, arg1, arg1Rep, arg1Mod, arg2, arg2Rep, arg2Mod);
}

GLAPI void APIENTRY glColorFragmentOp3ATI(GLenum op, GLuint dst, GLuint dstMask, GLuint dstMod, GLuint arg1, GLuint arg1Rep, GLuint arg1Mod, GLuint arg2, GLuint arg2Rep, GLuint arg2Mod, GLuint arg3, GLuint arg3Rep, GLuint arg3Mod)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[290];
   ((void (APIENTRY *)(GLenum op, GLuint dst, GLuint dstMask, GLuint dstMod, GLuint arg1, GLuint arg1Rep, GLuint arg1Mod, GLuint arg2, GLuint arg2Rep, GLuint arg2Mod, GLuint arg3, GLuint arg3Rep, GLuint arg3Mod)) _func)(op, dst, dstMask, dstMod, arg1, arg1Rep, arg1Mod, arg2, arg2Rep, arg2Mod, arg3, arg3Rep, arg3Mod);
}

GLAPI void APIENTRY glColorMask(GLboolean red, GLboolean green, GLboolean blue, GLboolean alpha)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[291];
   ((void (APIENTRY *)(GLboolean red, GLboolean green, GLboolean blue, GLboolean alpha)) _func)(red, green, blue, alpha);
}

GLAPI void APIENTRY glColorMaskIndexedEXT(GLuint index, GLboolean r, GLboolean g, GLboolean b, GLboolean a)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[292];
   ((void (APIENTRY *)(GLuint index, GLboolean r, GLboolean g, GLboolean b, GLboolean a)) _func)(index, r, g, b, a);
}

GLAPI void APIENTRY glColorMaski(GLuint index, GLboolean r, GLboolean g, GLboolean b, GLboolean a)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[293];
   ((void (APIENTRY *)(GLuint index, GLboolean r, GLboolean g, GLboolean b, GLboolean a)) _func)(index, r, g, b, a);
}

GLAPI void APIENTRY glColorMaskiEXT(GLuint index, GLboolean r, GLboolean g, GLboolean b, GLboolean a)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[294];
   ((void (APIENTRY *)(GLuint index, GLboolean r, GLboolean g, GLboolean b, GLboolean a)) _func)(index, r, g, b, a);
}

GLAPI void APIENTRY glColorMaskiOES(GLuint index, GLboolean r, GLboolean g, GLboolean b, GLboolean a)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[295];
   ((void (APIENTRY *)(GLuint index, GLboolean r, GLboolean g, GLboolean b, GLboolean a)) _func)(index, r, g, b, a);
}

GLAPI void APIENTRY glColorMaterial(GLenum face, GLenum mode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[296];
   ((void (APIENTRY *)(GLenum face, GLenum mode)) _func)(face, mode);
}

GLAPI void APIENTRY glColorP3ui(GLenum type, GLuint color)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[297];
   ((void (APIENTRY *)(GLenum type, GLuint color)) _func)(type, color);
}

GLAPI void APIENTRY glColorP3uiv(GLenum type, const GLuint *color)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[298];
   ((void (APIENTRY *)(GLenum type, const GLuint *color)) _func)(type, color);
}

GLAPI void APIENTRY glColorP4ui(GLenum type, GLuint color)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[299];
   ((void (APIENTRY *)(GLenum type, GLuint color)) _func)(type, color);
}

GLAPI void APIENTRY glColorP4uiv(GLenum type, const GLuint *color)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[300];
   ((void (APIENTRY *)(GLenum type, const GLuint *color)) _func)(type, color);
}

GLAPI void APIENTRY glColorPointer(GLint size, GLenum type, GLsizei stride, const void *pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[301];
   ((void (APIENTRY *)(GLint size, GLenum type, GLsizei stride, const void *pointer)) _func)(size, type, stride, pointer);
}

GLAPI void APIENTRY glColorPointerEXT(GLint size, GLenum type, GLsizei stride, GLsizei count, const void *pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[302];
   ((void (APIENTRY *)(GLint size, GLenum type, GLsizei stride, GLsizei count, const void *pointer)) _func)(size, type, stride, count, pointer);
}

GLAPI void APIENTRY glColorPointerListIBM(GLint size, GLenum type, GLint stride, const void **pointer, GLint ptrstride)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[303];
   ((void (APIENTRY *)(GLint size, GLenum type, GLint stride, const void **pointer, GLint ptrstride)) _func)(size, type, stride, pointer, ptrstride);
}

GLAPI void APIENTRY glColorPointervINTEL(GLint size, GLenum type, const void **pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[304];
   ((void (APIENTRY *)(GLint size, GLenum type, const void **pointer)) _func)(size, type, pointer);
}

GLAPI void APIENTRY glColorSubTable(GLenum target, GLsizei start, GLsizei count, GLenum format, GLenum type, const void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[305];
   ((void (APIENTRY *)(GLenum target, GLsizei start, GLsizei count, GLenum format, GLenum type, const void *data)) _func)(target, start, count, format, type, data);
}

GLAPI void APIENTRY glColorSubTableEXT(GLenum target, GLsizei start, GLsizei count, GLenum format, GLenum type, const void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[306];
   ((void (APIENTRY *)(GLenum target, GLsizei start, GLsizei count, GLenum format, GLenum type, const void *data)) _func)(target, start, count, format, type, data);
}

GLAPI void APIENTRY glColorTable(GLenum target, GLenum internalformat, GLsizei width, GLenum format, GLenum type, const void *table)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[307];
   ((void (APIENTRY *)(GLenum target, GLenum internalformat, GLsizei width, GLenum format, GLenum type, const void *table)) _func)(target, internalformat, width, format, type, table);
}

GLAPI void APIENTRY glColorTableEXT(GLenum target, GLenum internalFormat, GLsizei width, GLenum format, GLenum type, const void *table)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[308];
   ((void (APIENTRY *)(GLenum target, GLenum internalFormat, GLsizei width, GLenum format, GLenum type, const void *table)) _func)(target, internalFormat, width, format, type, table);
}

GLAPI void APIENTRY glColorTableParameterfv(GLenum target, GLenum pname, const GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[309];
   ((void (APIENTRY *)(GLenum target, GLenum pname, const GLfloat *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glColorTableParameterfvSGI(GLenum target, GLenum pname, const GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[310];
   ((void (APIENTRY *)(GLenum target, GLenum pname, const GLfloat *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glColorTableParameteriv(GLenum target, GLenum pname, const GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[311];
   ((void (APIENTRY *)(GLenum target, GLenum pname, const GLint *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glColorTableParameterivSGI(GLenum target, GLenum pname, const GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[312];
   ((void (APIENTRY *)(GLenum target, GLenum pname, const GLint *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glColorTableSGI(GLenum target, GLenum internalformat, GLsizei width, GLenum format, GLenum type, const void *table)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[313];
   ((void (APIENTRY *)(GLenum target, GLenum internalformat, GLsizei width, GLenum format, GLenum type, const void *table)) _func)(target, internalformat, width, format, type, table);
}

GLAPI void APIENTRY glCombinerInputNV(GLenum stage, GLenum portion, GLenum variable, GLenum input, GLenum mapping, GLenum componentUsage)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[314];
   ((void (APIENTRY *)(GLenum stage, GLenum portion, GLenum variable, GLenum input, GLenum mapping, GLenum componentUsage)) _func)(stage, portion, variable, input, mapping, componentUsage);
}

GLAPI void APIENTRY glCombinerOutputNV(GLenum stage, GLenum portion, GLenum abOutput, GLenum cdOutput, GLenum sumOutput, GLenum scale, GLenum bias, GLboolean abDotProduct, GLboolean cdDotProduct, GLboolean muxSum)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[315];
   ((void (APIENTRY *)(GLenum stage, GLenum portion, GLenum abOutput, GLenum cdOutput, GLenum sumOutput, GLenum scale, GLenum bias, GLboolean abDotProduct, GLboolean cdDotProduct, GLboolean muxSum)) _func)(stage, portion, abOutput, cdOutput, sumOutput, scale, bias, abDotProduct, cdDotProduct, muxSum);
}

GLAPI void APIENTRY glCombinerParameterfNV(GLenum pname, GLfloat param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[316];
   ((void (APIENTRY *)(GLenum pname, GLfloat param)) _func)(pname, param);
}

GLAPI void APIENTRY glCombinerParameterfvNV(GLenum pname, const GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[317];
   ((void (APIENTRY *)(GLenum pname, const GLfloat *params)) _func)(pname, params);
}

GLAPI void APIENTRY glCombinerParameteriNV(GLenum pname, GLint param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[318];
   ((void (APIENTRY *)(GLenum pname, GLint param)) _func)(pname, param);
}

GLAPI void APIENTRY glCombinerParameterivNV(GLenum pname, const GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[319];
   ((void (APIENTRY *)(GLenum pname, const GLint *params)) _func)(pname, params);
}

GLAPI void APIENTRY glCombinerStageParameterfvNV(GLenum stage, GLenum pname, const GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[320];
   ((void (APIENTRY *)(GLenum stage, GLenum pname, const GLfloat *params)) _func)(stage, pname, params);
}

GLAPI void APIENTRY glCommandListSegmentsNV(GLuint list, GLuint segments)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[321];
   ((void (APIENTRY *)(GLuint list, GLuint segments)) _func)(list, segments);
}

GLAPI void APIENTRY glCompileCommandListNV(GLuint list)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[322];
   ((void (APIENTRY *)(GLuint list)) _func)(list);
}

GLAPI void APIENTRY glCompileShader(GLuint shader)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[323];
   ((void (APIENTRY *)(GLuint shader)) _func)(shader);
}

GLAPI void APIENTRY glCompileShaderARB(GLhandleARB shaderObj)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[324];
   ((void (APIENTRY *)(GLhandleARB shaderObj)) _func)(shaderObj);
}

GLAPI void APIENTRY glCompileShaderIncludeARB(GLuint shader, GLsizei count, const GLchar *const *path, const GLint *length)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[325];
   ((void (APIENTRY *)(GLuint shader, GLsizei count, const GLchar *const *path, const GLint *length)) _func)(shader, count, path, length);
}

GLAPI void APIENTRY glCompressedMultiTexImage1DEXT(GLenum texunit, GLenum target, GLint level, GLenum internalformat, GLsizei width, GLint border, GLsizei imageSize, const void *bits)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[326];
   ((void (APIENTRY *)(GLenum texunit, GLenum target, GLint level, GLenum internalformat, GLsizei width, GLint border, GLsizei imageSize, const void *bits)) _func)(texunit, target, level, internalformat, width, border, imageSize, bits);
}

GLAPI void APIENTRY glCompressedMultiTexImage2DEXT(GLenum texunit, GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLint border, GLsizei imageSize, const void *bits)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[327];
   ((void (APIENTRY *)(GLenum texunit, GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLint border, GLsizei imageSize, const void *bits)) _func)(texunit, target, level, internalformat, width, height, border, imageSize, bits);
}

GLAPI void APIENTRY glCompressedMultiTexImage3DEXT(GLenum texunit, GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLsizei imageSize, const void *bits)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[328];
   ((void (APIENTRY *)(GLenum texunit, GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLsizei imageSize, const void *bits)) _func)(texunit, target, level, internalformat, width, height, depth, border, imageSize, bits);
}

GLAPI void APIENTRY glCompressedMultiTexSubImage1DEXT(GLenum texunit, GLenum target, GLint level, GLint xoffset, GLsizei width, GLenum format, GLsizei imageSize, const void *bits)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[329];
   ((void (APIENTRY *)(GLenum texunit, GLenum target, GLint level, GLint xoffset, GLsizei width, GLenum format, GLsizei imageSize, const void *bits)) _func)(texunit, target, level, xoffset, width, format, imageSize, bits);
}

GLAPI void APIENTRY glCompressedMultiTexSubImage2DEXT(GLenum texunit, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLsizei imageSize, const void *bits)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[330];
   ((void (APIENTRY *)(GLenum texunit, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLsizei imageSize, const void *bits)) _func)(texunit, target, level, xoffset, yoffset, width, height, format, imageSize, bits);
}

GLAPI void APIENTRY glCompressedMultiTexSubImage3DEXT(GLenum texunit, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLsizei imageSize, const void *bits)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[331];
   ((void (APIENTRY *)(GLenum texunit, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLsizei imageSize, const void *bits)) _func)(texunit, target, level, xoffset, yoffset, zoffset, width, height, depth, format, imageSize, bits);
}

GLAPI void APIENTRY glCompressedTexImage1D(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLint border, GLsizei imageSize, const void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[332];
   ((void (APIENTRY *)(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLint border, GLsizei imageSize, const void *data)) _func)(target, level, internalformat, width, border, imageSize, data);
}

GLAPI void APIENTRY glCompressedTexImage1DARB(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLint border, GLsizei imageSize, const void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[333];
   ((void (APIENTRY *)(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLint border, GLsizei imageSize, const void *data)) _func)(target, level, internalformat, width, border, imageSize, data);
}

GLAPI void APIENTRY glCompressedTexImage2D(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLint border, GLsizei imageSize, const void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[334];
   ((void (APIENTRY *)(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLint border, GLsizei imageSize, const void *data)) _func)(target, level, internalformat, width, height, border, imageSize, data);
}

GLAPI void APIENTRY glCompressedTexImage2DARB(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLint border, GLsizei imageSize, const void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[335];
   ((void (APIENTRY *)(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLint border, GLsizei imageSize, const void *data)) _func)(target, level, internalformat, width, height, border, imageSize, data);
}

GLAPI void APIENTRY glCompressedTexImage3D(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLsizei imageSize, const void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[336];
   ((void (APIENTRY *)(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLsizei imageSize, const void *data)) _func)(target, level, internalformat, width, height, depth, border, imageSize, data);
}

GLAPI void APIENTRY glCompressedTexImage3DARB(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLsizei imageSize, const void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[337];
   ((void (APIENTRY *)(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLsizei imageSize, const void *data)) _func)(target, level, internalformat, width, height, depth, border, imageSize, data);
}

GLAPI void APIENTRY glCompressedTexImage3DNV(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLsizei imageSize, const void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[338];
   ((void (APIENTRY *)(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLsizei imageSize, const void *data)) _func)(target, level, internalformat, width, height, depth, border, imageSize, data);
}

GLAPI void APIENTRY glCompressedTexImage3DOES(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLsizei imageSize, const void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[339];
   ((void (APIENTRY *)(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLsizei imageSize, const void *data)) _func)(target, level, internalformat, width, height, depth, border, imageSize, data);
}

GLAPI void APIENTRY glCompressedTexSubImage1D(GLenum target, GLint level, GLint xoffset, GLsizei width, GLenum format, GLsizei imageSize, const void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[340];
   ((void (APIENTRY *)(GLenum target, GLint level, GLint xoffset, GLsizei width, GLenum format, GLsizei imageSize, const void *data)) _func)(target, level, xoffset, width, format, imageSize, data);
}

GLAPI void APIENTRY glCompressedTexSubImage1DARB(GLenum target, GLint level, GLint xoffset, GLsizei width, GLenum format, GLsizei imageSize, const void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[341];
   ((void (APIENTRY *)(GLenum target, GLint level, GLint xoffset, GLsizei width, GLenum format, GLsizei imageSize, const void *data)) _func)(target, level, xoffset, width, format, imageSize, data);
}

GLAPI void APIENTRY glCompressedTexSubImage2D(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLsizei imageSize, const void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[342];
   ((void (APIENTRY *)(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLsizei imageSize, const void *data)) _func)(target, level, xoffset, yoffset, width, height, format, imageSize, data);
}

GLAPI void APIENTRY glCompressedTexSubImage2DARB(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLsizei imageSize, const void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[343];
   ((void (APIENTRY *)(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLsizei imageSize, const void *data)) _func)(target, level, xoffset, yoffset, width, height, format, imageSize, data);
}

GLAPI void APIENTRY glCompressedTexSubImage3D(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLsizei imageSize, const void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[344];
   ((void (APIENTRY *)(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLsizei imageSize, const void *data)) _func)(target, level, xoffset, yoffset, zoffset, width, height, depth, format, imageSize, data);
}

GLAPI void APIENTRY glCompressedTexSubImage3DARB(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLsizei imageSize, const void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[345];
   ((void (APIENTRY *)(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLsizei imageSize, const void *data)) _func)(target, level, xoffset, yoffset, zoffset, width, height, depth, format, imageSize, data);
}

GLAPI void APIENTRY glCompressedTexSubImage3DNV(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLsizei imageSize, const void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[346];
   ((void (APIENTRY *)(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLsizei imageSize, const void *data)) _func)(target, level, xoffset, yoffset, zoffset, width, height, depth, format, imageSize, data);
}

GLAPI void APIENTRY glCompressedTexSubImage3DOES(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLsizei imageSize, const void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[347];
   ((void (APIENTRY *)(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLsizei imageSize, const void *data)) _func)(target, level, xoffset, yoffset, zoffset, width, height, depth, format, imageSize, data);
}

GLAPI void APIENTRY glCompressedTextureImage1DEXT(GLuint texture, GLenum target, GLint level, GLenum internalformat, GLsizei width, GLint border, GLsizei imageSize, const void *bits)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[348];
   ((void (APIENTRY *)(GLuint texture, GLenum target, GLint level, GLenum internalformat, GLsizei width, GLint border, GLsizei imageSize, const void *bits)) _func)(texture, target, level, internalformat, width, border, imageSize, bits);
}

GLAPI void APIENTRY glCompressedTextureImage2DEXT(GLuint texture, GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLint border, GLsizei imageSize, const void *bits)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[349];
   ((void (APIENTRY *)(GLuint texture, GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLint border, GLsizei imageSize, const void *bits)) _func)(texture, target, level, internalformat, width, height, border, imageSize, bits);
}

GLAPI void APIENTRY glCompressedTextureImage3DEXT(GLuint texture, GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLsizei imageSize, const void *bits)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[350];
   ((void (APIENTRY *)(GLuint texture, GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLsizei imageSize, const void *bits)) _func)(texture, target, level, internalformat, width, height, depth, border, imageSize, bits);
}

GLAPI void APIENTRY glCompressedTextureSubImage1D(GLuint texture, GLint level, GLint xoffset, GLsizei width, GLenum format, GLsizei imageSize, const void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[351];
   ((void (APIENTRY *)(GLuint texture, GLint level, GLint xoffset, GLsizei width, GLenum format, GLsizei imageSize, const void *data)) _func)(texture, level, xoffset, width, format, imageSize, data);
}

GLAPI void APIENTRY glCompressedTextureSubImage1DEXT(GLuint texture, GLenum target, GLint level, GLint xoffset, GLsizei width, GLenum format, GLsizei imageSize, const void *bits)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[352];
   ((void (APIENTRY *)(GLuint texture, GLenum target, GLint level, GLint xoffset, GLsizei width, GLenum format, GLsizei imageSize, const void *bits)) _func)(texture, target, level, xoffset, width, format, imageSize, bits);
}

GLAPI void APIENTRY glCompressedTextureSubImage2D(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLsizei imageSize, const void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[353];
   ((void (APIENTRY *)(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLsizei imageSize, const void *data)) _func)(texture, level, xoffset, yoffset, width, height, format, imageSize, data);
}

GLAPI void APIENTRY glCompressedTextureSubImage2DEXT(GLuint texture, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLsizei imageSize, const void *bits)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[354];
   ((void (APIENTRY *)(GLuint texture, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLsizei imageSize, const void *bits)) _func)(texture, target, level, xoffset, yoffset, width, height, format, imageSize, bits);
}

GLAPI void APIENTRY glCompressedTextureSubImage3D(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLsizei imageSize, const void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[355];
   ((void (APIENTRY *)(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLsizei imageSize, const void *data)) _func)(texture, level, xoffset, yoffset, zoffset, width, height, depth, format, imageSize, data);
}

GLAPI void APIENTRY glCompressedTextureSubImage3DEXT(GLuint texture, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLsizei imageSize, const void *bits)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[356];
   ((void (APIENTRY *)(GLuint texture, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLsizei imageSize, const void *bits)) _func)(texture, target, level, xoffset, yoffset, zoffset, width, height, depth, format, imageSize, bits);
}

GLAPI void APIENTRY glConservativeRasterParameterfNV(GLenum pname, GLfloat value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[357];
   ((void (APIENTRY *)(GLenum pname, GLfloat value)) _func)(pname, value);
}

GLAPI void APIENTRY glConservativeRasterParameteriNV(GLenum pname, GLint param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[358];
   ((void (APIENTRY *)(GLenum pname, GLint param)) _func)(pname, param);
}

GLAPI void APIENTRY glConvolutionFilter1D(GLenum target, GLenum internalformat, GLsizei width, GLenum format, GLenum type, const void *image)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[359];
   ((void (APIENTRY *)(GLenum target, GLenum internalformat, GLsizei width, GLenum format, GLenum type, const void *image)) _func)(target, internalformat, width, format, type, image);
}

GLAPI void APIENTRY glConvolutionFilter1DEXT(GLenum target, GLenum internalformat, GLsizei width, GLenum format, GLenum type, const void *image)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[360];
   ((void (APIENTRY *)(GLenum target, GLenum internalformat, GLsizei width, GLenum format, GLenum type, const void *image)) _func)(target, internalformat, width, format, type, image);
}

GLAPI void APIENTRY glConvolutionFilter2D(GLenum target, GLenum internalformat, GLsizei width, GLsizei height, GLenum format, GLenum type, const void *image)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[361];
   ((void (APIENTRY *)(GLenum target, GLenum internalformat, GLsizei width, GLsizei height, GLenum format, GLenum type, const void *image)) _func)(target, internalformat, width, height, format, type, image);
}

GLAPI void APIENTRY glConvolutionFilter2DEXT(GLenum target, GLenum internalformat, GLsizei width, GLsizei height, GLenum format, GLenum type, const void *image)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[362];
   ((void (APIENTRY *)(GLenum target, GLenum internalformat, GLsizei width, GLsizei height, GLenum format, GLenum type, const void *image)) _func)(target, internalformat, width, height, format, type, image);
}

GLAPI void APIENTRY glConvolutionParameterf(GLenum target, GLenum pname, GLfloat params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[363];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLfloat params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glConvolutionParameterfEXT(GLenum target, GLenum pname, GLfloat params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[364];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLfloat params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glConvolutionParameterfv(GLenum target, GLenum pname, const GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[365];
   ((void (APIENTRY *)(GLenum target, GLenum pname, const GLfloat *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glConvolutionParameterfvEXT(GLenum target, GLenum pname, const GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[366];
   ((void (APIENTRY *)(GLenum target, GLenum pname, const GLfloat *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glConvolutionParameteri(GLenum target, GLenum pname, GLint params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[367];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLint params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glConvolutionParameteriEXT(GLenum target, GLenum pname, GLint params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[368];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLint params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glConvolutionParameteriv(GLenum target, GLenum pname, const GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[369];
   ((void (APIENTRY *)(GLenum target, GLenum pname, const GLint *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glConvolutionParameterivEXT(GLenum target, GLenum pname, const GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[370];
   ((void (APIENTRY *)(GLenum target, GLenum pname, const GLint *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glConvolutionParameterxOES(GLenum target, GLenum pname, GLfixed param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[371];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLfixed param)) _func)(target, pname, param);
}

GLAPI void APIENTRY glConvolutionParameterxvOES(GLenum target, GLenum pname, const GLfixed *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[372];
   ((void (APIENTRY *)(GLenum target, GLenum pname, const GLfixed *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glCopyBufferSubData(GLenum readTarget, GLenum writeTarget, GLintptr readOffset, GLintptr writeOffset, GLsizeiptr size)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[373];
   ((void (APIENTRY *)(GLenum readTarget, GLenum writeTarget, GLintptr readOffset, GLintptr writeOffset, GLsizeiptr size)) _func)(readTarget, writeTarget, readOffset, writeOffset, size);
}

GLAPI void APIENTRY glCopyBufferSubDataNV(GLenum readTarget, GLenum writeTarget, GLintptr readOffset, GLintptr writeOffset, GLsizeiptr size)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[374];
   ((void (APIENTRY *)(GLenum readTarget, GLenum writeTarget, GLintptr readOffset, GLintptr writeOffset, GLsizeiptr size)) _func)(readTarget, writeTarget, readOffset, writeOffset, size);
}

GLAPI void APIENTRY glCopyColorSubTable(GLenum target, GLsizei start, GLint x, GLint y, GLsizei width)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[375];
   ((void (APIENTRY *)(GLenum target, GLsizei start, GLint x, GLint y, GLsizei width)) _func)(target, start, x, y, width);
}

GLAPI void APIENTRY glCopyColorSubTableEXT(GLenum target, GLsizei start, GLint x, GLint y, GLsizei width)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[376];
   ((void (APIENTRY *)(GLenum target, GLsizei start, GLint x, GLint y, GLsizei width)) _func)(target, start, x, y, width);
}

GLAPI void APIENTRY glCopyColorTable(GLenum target, GLenum internalformat, GLint x, GLint y, GLsizei width)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[377];
   ((void (APIENTRY *)(GLenum target, GLenum internalformat, GLint x, GLint y, GLsizei width)) _func)(target, internalformat, x, y, width);
}

GLAPI void APIENTRY glCopyColorTableSGI(GLenum target, GLenum internalformat, GLint x, GLint y, GLsizei width)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[378];
   ((void (APIENTRY *)(GLenum target, GLenum internalformat, GLint x, GLint y, GLsizei width)) _func)(target, internalformat, x, y, width);
}

GLAPI void APIENTRY glCopyConvolutionFilter1D(GLenum target, GLenum internalformat, GLint x, GLint y, GLsizei width)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[379];
   ((void (APIENTRY *)(GLenum target, GLenum internalformat, GLint x, GLint y, GLsizei width)) _func)(target, internalformat, x, y, width);
}

GLAPI void APIENTRY glCopyConvolutionFilter1DEXT(GLenum target, GLenum internalformat, GLint x, GLint y, GLsizei width)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[380];
   ((void (APIENTRY *)(GLenum target, GLenum internalformat, GLint x, GLint y, GLsizei width)) _func)(target, internalformat, x, y, width);
}

GLAPI void APIENTRY glCopyConvolutionFilter2D(GLenum target, GLenum internalformat, GLint x, GLint y, GLsizei width, GLsizei height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[381];
   ((void (APIENTRY *)(GLenum target, GLenum internalformat, GLint x, GLint y, GLsizei width, GLsizei height)) _func)(target, internalformat, x, y, width, height);
}

GLAPI void APIENTRY glCopyConvolutionFilter2DEXT(GLenum target, GLenum internalformat, GLint x, GLint y, GLsizei width, GLsizei height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[382];
   ((void (APIENTRY *)(GLenum target, GLenum internalformat, GLint x, GLint y, GLsizei width, GLsizei height)) _func)(target, internalformat, x, y, width, height);
}

GLAPI void APIENTRY glCopyImageSubData(GLuint srcName, GLenum srcTarget, GLint srcLevel, GLint srcX, GLint srcY, GLint srcZ, GLuint dstName, GLenum dstTarget, GLint dstLevel, GLint dstX, GLint dstY, GLint dstZ, GLsizei srcWidth, GLsizei srcHeight, GLsizei srcDepth)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[383];
   ((void (APIENTRY *)(GLuint srcName, GLenum srcTarget, GLint srcLevel, GLint srcX, GLint srcY, GLint srcZ, GLuint dstName, GLenum dstTarget, GLint dstLevel, GLint dstX, GLint dstY, GLint dstZ, GLsizei srcWidth, GLsizei srcHeight, GLsizei srcDepth)) _func)(srcName, srcTarget, srcLevel, srcX, srcY, srcZ, dstName, dstTarget, dstLevel, dstX, dstY, dstZ, srcWidth, srcHeight, srcDepth);
}

GLAPI void APIENTRY glCopyImageSubDataEXT(GLuint srcName, GLenum srcTarget, GLint srcLevel, GLint srcX, GLint srcY, GLint srcZ, GLuint dstName, GLenum dstTarget, GLint dstLevel, GLint dstX, GLint dstY, GLint dstZ, GLsizei srcWidth, GLsizei srcHeight, GLsizei srcDepth)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[384];
   ((void (APIENTRY *)(GLuint srcName, GLenum srcTarget, GLint srcLevel, GLint srcX, GLint srcY, GLint srcZ, GLuint dstName, GLenum dstTarget, GLint dstLevel, GLint dstX, GLint dstY, GLint dstZ, GLsizei srcWidth, GLsizei srcHeight, GLsizei srcDepth)) _func)(srcName, srcTarget, srcLevel, srcX, srcY, srcZ, dstName, dstTarget, dstLevel, dstX, dstY, dstZ, srcWidth, srcHeight, srcDepth);
}

GLAPI void APIENTRY glCopyImageSubDataNV(GLuint srcName, GLenum srcTarget, GLint srcLevel, GLint srcX, GLint srcY, GLint srcZ, GLuint dstName, GLenum dstTarget, GLint dstLevel, GLint dstX, GLint dstY, GLint dstZ, GLsizei width, GLsizei height, GLsizei depth)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[385];
   ((void (APIENTRY *)(GLuint srcName, GLenum srcTarget, GLint srcLevel, GLint srcX, GLint srcY, GLint srcZ, GLuint dstName, GLenum dstTarget, GLint dstLevel, GLint dstX, GLint dstY, GLint dstZ, GLsizei width, GLsizei height, GLsizei depth)) _func)(srcName, srcTarget, srcLevel, srcX, srcY, srcZ, dstName, dstTarget, dstLevel, dstX, dstY, dstZ, width, height, depth);
}

GLAPI void APIENTRY glCopyImageSubDataOES(GLuint srcName, GLenum srcTarget, GLint srcLevel, GLint srcX, GLint srcY, GLint srcZ, GLuint dstName, GLenum dstTarget, GLint dstLevel, GLint dstX, GLint dstY, GLint dstZ, GLsizei srcWidth, GLsizei srcHeight, GLsizei srcDepth)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[386];
   ((void (APIENTRY *)(GLuint srcName, GLenum srcTarget, GLint srcLevel, GLint srcX, GLint srcY, GLint srcZ, GLuint dstName, GLenum dstTarget, GLint dstLevel, GLint dstX, GLint dstY, GLint dstZ, GLsizei srcWidth, GLsizei srcHeight, GLsizei srcDepth)) _func)(srcName, srcTarget, srcLevel, srcX, srcY, srcZ, dstName, dstTarget, dstLevel, dstX, dstY, dstZ, srcWidth, srcHeight, srcDepth);
}

GLAPI void APIENTRY glCopyMultiTexImage1DEXT(GLenum texunit, GLenum target, GLint level, GLenum internalformat, GLint x, GLint y, GLsizei width, GLint border)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[387];
   ((void (APIENTRY *)(GLenum texunit, GLenum target, GLint level, GLenum internalformat, GLint x, GLint y, GLsizei width, GLint border)) _func)(texunit, target, level, internalformat, x, y, width, border);
}

GLAPI void APIENTRY glCopyMultiTexImage2DEXT(GLenum texunit, GLenum target, GLint level, GLenum internalformat, GLint x, GLint y, GLsizei width, GLsizei height, GLint border)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[388];
   ((void (APIENTRY *)(GLenum texunit, GLenum target, GLint level, GLenum internalformat, GLint x, GLint y, GLsizei width, GLsizei height, GLint border)) _func)(texunit, target, level, internalformat, x, y, width, height, border);
}

GLAPI void APIENTRY glCopyMultiTexSubImage1DEXT(GLenum texunit, GLenum target, GLint level, GLint xoffset, GLint x, GLint y, GLsizei width)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[389];
   ((void (APIENTRY *)(GLenum texunit, GLenum target, GLint level, GLint xoffset, GLint x, GLint y, GLsizei width)) _func)(texunit, target, level, xoffset, x, y, width);
}

GLAPI void APIENTRY glCopyMultiTexSubImage2DEXT(GLenum texunit, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint x, GLint y, GLsizei width, GLsizei height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[390];
   ((void (APIENTRY *)(GLenum texunit, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint x, GLint y, GLsizei width, GLsizei height)) _func)(texunit, target, level, xoffset, yoffset, x, y, width, height);
}

GLAPI void APIENTRY glCopyMultiTexSubImage3DEXT(GLenum texunit, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLint x, GLint y, GLsizei width, GLsizei height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[391];
   ((void (APIENTRY *)(GLenum texunit, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLint x, GLint y, GLsizei width, GLsizei height)) _func)(texunit, target, level, xoffset, yoffset, zoffset, x, y, width, height);
}

GLAPI void APIENTRY glCopyNamedBufferSubData(GLuint readBuffer, GLuint writeBuffer, GLintptr readOffset, GLintptr writeOffset, GLsizeiptr size)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[392];
   ((void (APIENTRY *)(GLuint readBuffer, GLuint writeBuffer, GLintptr readOffset, GLintptr writeOffset, GLsizeiptr size)) _func)(readBuffer, writeBuffer, readOffset, writeOffset, size);
}

GLAPI void APIENTRY glCopyPathNV(GLuint resultPath, GLuint srcPath)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[393];
   ((void (APIENTRY *)(GLuint resultPath, GLuint srcPath)) _func)(resultPath, srcPath);
}

GLAPI void APIENTRY glCopyPixels(GLint x, GLint y, GLsizei width, GLsizei height, GLenum type)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[394];
   ((void (APIENTRY *)(GLint x, GLint y, GLsizei width, GLsizei height, GLenum type)) _func)(x, y, width, height, type);
}

GLAPI void APIENTRY glCopyTexImage1D(GLenum target, GLint level, GLenum internalformat, GLint x, GLint y, GLsizei width, GLint border)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[395];
   ((void (APIENTRY *)(GLenum target, GLint level, GLenum internalformat, GLint x, GLint y, GLsizei width, GLint border)) _func)(target, level, internalformat, x, y, width, border);
}

GLAPI void APIENTRY glCopyTexImage1DEXT(GLenum target, GLint level, GLenum internalformat, GLint x, GLint y, GLsizei width, GLint border)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[396];
   ((void (APIENTRY *)(GLenum target, GLint level, GLenum internalformat, GLint x, GLint y, GLsizei width, GLint border)) _func)(target, level, internalformat, x, y, width, border);
}

GLAPI void APIENTRY glCopyTexImage2D(GLenum target, GLint level, GLenum internalformat, GLint x, GLint y, GLsizei width, GLsizei height, GLint border)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[397];
   ((void (APIENTRY *)(GLenum target, GLint level, GLenum internalformat, GLint x, GLint y, GLsizei width, GLsizei height, GLint border)) _func)(target, level, internalformat, x, y, width, height, border);
}

GLAPI void APIENTRY glCopyTexImage2DEXT(GLenum target, GLint level, GLenum internalformat, GLint x, GLint y, GLsizei width, GLsizei height, GLint border)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[398];
   ((void (APIENTRY *)(GLenum target, GLint level, GLenum internalformat, GLint x, GLint y, GLsizei width, GLsizei height, GLint border)) _func)(target, level, internalformat, x, y, width, height, border);
}

GLAPI void APIENTRY glCopyTexSubImage1D(GLenum target, GLint level, GLint xoffset, GLint x, GLint y, GLsizei width)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[399];
   ((void (APIENTRY *)(GLenum target, GLint level, GLint xoffset, GLint x, GLint y, GLsizei width)) _func)(target, level, xoffset, x, y, width);
}

GLAPI void APIENTRY glCopyTexSubImage1DEXT(GLenum target, GLint level, GLint xoffset, GLint x, GLint y, GLsizei width)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[400];
   ((void (APIENTRY *)(GLenum target, GLint level, GLint xoffset, GLint x, GLint y, GLsizei width)) _func)(target, level, xoffset, x, y, width);
}

GLAPI void APIENTRY glCopyTexSubImage2D(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint x, GLint y, GLsizei width, GLsizei height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[401];
   ((void (APIENTRY *)(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint x, GLint y, GLsizei width, GLsizei height)) _func)(target, level, xoffset, yoffset, x, y, width, height);
}

GLAPI void APIENTRY glCopyTexSubImage2DEXT(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint x, GLint y, GLsizei width, GLsizei height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[402];
   ((void (APIENTRY *)(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint x, GLint y, GLsizei width, GLsizei height)) _func)(target, level, xoffset, yoffset, x, y, width, height);
}

GLAPI void APIENTRY glCopyTexSubImage3D(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLint x, GLint y, GLsizei width, GLsizei height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[403];
   ((void (APIENTRY *)(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLint x, GLint y, GLsizei width, GLsizei height)) _func)(target, level, xoffset, yoffset, zoffset, x, y, width, height);
}

GLAPI void APIENTRY glCopyTexSubImage3DEXT(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLint x, GLint y, GLsizei width, GLsizei height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[404];
   ((void (APIENTRY *)(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLint x, GLint y, GLsizei width, GLsizei height)) _func)(target, level, xoffset, yoffset, zoffset, x, y, width, height);
}

GLAPI void APIENTRY glCopyTexSubImage3DNV(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLint x, GLint y, GLsizei width, GLsizei height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[405];
   ((void (APIENTRY *)(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLint x, GLint y, GLsizei width, GLsizei height)) _func)(target, level, xoffset, yoffset, zoffset, x, y, width, height);
}

GLAPI void APIENTRY glCopyTexSubImage3DOES(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLint x, GLint y, GLsizei width, GLsizei height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[406];
   ((void (APIENTRY *)(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLint x, GLint y, GLsizei width, GLsizei height)) _func)(target, level, xoffset, yoffset, zoffset, x, y, width, height);
}

GLAPI void APIENTRY glCopyTextureImage1DEXT(GLuint texture, GLenum target, GLint level, GLenum internalformat, GLint x, GLint y, GLsizei width, GLint border)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[407];
   ((void (APIENTRY *)(GLuint texture, GLenum target, GLint level, GLenum internalformat, GLint x, GLint y, GLsizei width, GLint border)) _func)(texture, target, level, internalformat, x, y, width, border);
}

GLAPI void APIENTRY glCopyTextureImage2DEXT(GLuint texture, GLenum target, GLint level, GLenum internalformat, GLint x, GLint y, GLsizei width, GLsizei height, GLint border)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[408];
   ((void (APIENTRY *)(GLuint texture, GLenum target, GLint level, GLenum internalformat, GLint x, GLint y, GLsizei width, GLsizei height, GLint border)) _func)(texture, target, level, internalformat, x, y, width, height, border);
}

GLAPI void APIENTRY glCopyTextureLevelsAPPLE(GLuint destinationTexture, GLuint sourceTexture, GLint sourceBaseLevel, GLsizei sourceLevelCount)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[409];
   ((void (APIENTRY *)(GLuint destinationTexture, GLuint sourceTexture, GLint sourceBaseLevel, GLsizei sourceLevelCount)) _func)(destinationTexture, sourceTexture, sourceBaseLevel, sourceLevelCount);
}

GLAPI void APIENTRY glCopyTextureSubImage1D(GLuint texture, GLint level, GLint xoffset, GLint x, GLint y, GLsizei width)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[410];
   ((void (APIENTRY *)(GLuint texture, GLint level, GLint xoffset, GLint x, GLint y, GLsizei width)) _func)(texture, level, xoffset, x, y, width);
}

GLAPI void APIENTRY glCopyTextureSubImage1DEXT(GLuint texture, GLenum target, GLint level, GLint xoffset, GLint x, GLint y, GLsizei width)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[411];
   ((void (APIENTRY *)(GLuint texture, GLenum target, GLint level, GLint xoffset, GLint x, GLint y, GLsizei width)) _func)(texture, target, level, xoffset, x, y, width);
}

GLAPI void APIENTRY glCopyTextureSubImage2D(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint x, GLint y, GLsizei width, GLsizei height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[412];
   ((void (APIENTRY *)(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint x, GLint y, GLsizei width, GLsizei height)) _func)(texture, level, xoffset, yoffset, x, y, width, height);
}

GLAPI void APIENTRY glCopyTextureSubImage2DEXT(GLuint texture, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint x, GLint y, GLsizei width, GLsizei height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[413];
   ((void (APIENTRY *)(GLuint texture, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint x, GLint y, GLsizei width, GLsizei height)) _func)(texture, target, level, xoffset, yoffset, x, y, width, height);
}

GLAPI void APIENTRY glCopyTextureSubImage3D(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLint x, GLint y, GLsizei width, GLsizei height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[414];
   ((void (APIENTRY *)(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLint x, GLint y, GLsizei width, GLsizei height)) _func)(texture, level, xoffset, yoffset, zoffset, x, y, width, height);
}

GLAPI void APIENTRY glCopyTextureSubImage3DEXT(GLuint texture, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLint x, GLint y, GLsizei width, GLsizei height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[415];
   ((void (APIENTRY *)(GLuint texture, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLint x, GLint y, GLsizei width, GLsizei height)) _func)(texture, target, level, xoffset, yoffset, zoffset, x, y, width, height);
}

GLAPI void APIENTRY glCoverFillPathInstancedNV(GLsizei numPaths, GLenum pathNameType, const void *paths, GLuint pathBase, GLenum coverMode, GLenum transformType, const GLfloat *transformValues)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[416];
   ((void (APIENTRY *)(GLsizei numPaths, GLenum pathNameType, const void *paths, GLuint pathBase, GLenum coverMode, GLenum transformType, const GLfloat *transformValues)) _func)(numPaths, pathNameType, paths, pathBase, coverMode, transformType, transformValues);
}

GLAPI void APIENTRY glCoverFillPathNV(GLuint path, GLenum coverMode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[417];
   ((void (APIENTRY *)(GLuint path, GLenum coverMode)) _func)(path, coverMode);
}

GLAPI void APIENTRY glCoverStrokePathInstancedNV(GLsizei numPaths, GLenum pathNameType, const void *paths, GLuint pathBase, GLenum coverMode, GLenum transformType, const GLfloat *transformValues)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[418];
   ((void (APIENTRY *)(GLsizei numPaths, GLenum pathNameType, const void *paths, GLuint pathBase, GLenum coverMode, GLenum transformType, const GLfloat *transformValues)) _func)(numPaths, pathNameType, paths, pathBase, coverMode, transformType, transformValues);
}

GLAPI void APIENTRY glCoverStrokePathNV(GLuint path, GLenum coverMode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[419];
   ((void (APIENTRY *)(GLuint path, GLenum coverMode)) _func)(path, coverMode);
}

GLAPI void APIENTRY glCoverageMaskNV(GLboolean mask)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[420];
   ((void (APIENTRY *)(GLboolean mask)) _func)(mask);
}

GLAPI void APIENTRY glCoverageModulationNV(GLenum components)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[421];
   ((void (APIENTRY *)(GLenum components)) _func)(components);
}

GLAPI void APIENTRY glCoverageModulationTableNV(GLsizei n, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[422];
   ((void (APIENTRY *)(GLsizei n, const GLfloat *v)) _func)(n, v);
}

GLAPI void APIENTRY glCoverageOperationNV(GLenum operation)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[423];
   ((void (APIENTRY *)(GLenum operation)) _func)(operation);
}

GLAPI void APIENTRY glCreateBuffers(GLsizei n, GLuint *buffers)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[424];
   ((void (APIENTRY *)(GLsizei n, GLuint *buffers)) _func)(n, buffers);
}

GLAPI void APIENTRY glCreateCommandListsNV(GLsizei n, GLuint *lists)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[425];
   ((void (APIENTRY *)(GLsizei n, GLuint *lists)) _func)(n, lists);
}

GLAPI void APIENTRY glCreateFramebuffers(GLsizei n, GLuint *framebuffers)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[426];
   ((void (APIENTRY *)(GLsizei n, GLuint *framebuffers)) _func)(n, framebuffers);
}

GLAPI void APIENTRY glCreateMemoryObjectsEXT(GLsizei n, GLuint *memoryObjects)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[427];
   ((void (APIENTRY *)(GLsizei n, GLuint *memoryObjects)) _func)(n, memoryObjects);
}

GLAPI void APIENTRY glCreatePerfQueryINTEL(GLuint queryId, GLuint *queryHandle)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[428];
   ((void (APIENTRY *)(GLuint queryId, GLuint *queryHandle)) _func)(queryId, queryHandle);
}

GLAPI GLuint APIENTRY glCreateProgram(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[429];
   return ((GLuint (APIENTRY *)(void)) _func)();
}

GLAPI GLhandleARB APIENTRY glCreateProgramObjectARB(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[430];
   return ((GLhandleARB (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glCreateProgramPipelines(GLsizei n, GLuint *pipelines)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[431];
   ((void (APIENTRY *)(GLsizei n, GLuint *pipelines)) _func)(n, pipelines);
}

GLAPI GLuint APIENTRY glCreateProgressFenceNVX(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[432];
   return ((GLuint (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glCreateQueries(GLenum target, GLsizei n, GLuint *ids)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[433];
   ((void (APIENTRY *)(GLenum target, GLsizei n, GLuint *ids)) _func)(target, n, ids);
}

GLAPI void APIENTRY glCreateRenderbuffers(GLsizei n, GLuint *renderbuffers)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[434];
   ((void (APIENTRY *)(GLsizei n, GLuint *renderbuffers)) _func)(n, renderbuffers);
}

GLAPI void APIENTRY glCreateSamplers(GLsizei n, GLuint *samplers)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[435];
   ((void (APIENTRY *)(GLsizei n, GLuint *samplers)) _func)(n, samplers);
}

GLAPI GLuint APIENTRY glCreateShader(GLenum type)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[437];
   return ((GLuint (APIENTRY *)(GLenum type)) _func)(type);
}

GLAPI GLhandleARB APIENTRY glCreateShaderObjectARB(GLenum shaderType)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[438];
   return ((GLhandleARB (APIENTRY *)(GLenum shaderType)) _func)(shaderType);
}

GLAPI GLuint APIENTRY glCreateShaderProgramEXT(GLenum type, const GLchar *string)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[439];
   return ((GLuint (APIENTRY *)(GLenum type, const GLchar *string)) _func)(type, string);
}

GLAPI GLuint APIENTRY glCreateShaderProgramv(GLenum type, GLsizei count, const GLchar *const *strings)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[440];
   return ((GLuint (APIENTRY *)(GLenum type, GLsizei count, const GLchar *const *strings)) _func)(type, count, strings);
}

GLAPI GLuint APIENTRY glCreateShaderProgramvEXT(GLenum type, GLsizei count, const GLchar **strings)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[441];
   return ((GLuint (APIENTRY *)(GLenum type, GLsizei count, const GLchar **strings)) _func)(type, count, strings);
}

GLAPI void APIENTRY glCreateStatesNV(GLsizei n, GLuint *states)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[442];
   ((void (APIENTRY *)(GLsizei n, GLuint *states)) _func)(n, states);
}

GLAPI GLsync APIENTRY glCreateSyncFromCLeventARB(struct _cl_context *context, struct _cl_event *event, GLbitfield flags)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[443];
   return ((GLsync (APIENTRY *)(struct _cl_context *context, struct _cl_event *event, GLbitfield flags)) _func)(context, event, flags);
}

GLAPI void APIENTRY glCreateTextures(GLenum target, GLsizei n, GLuint *textures)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[444];
   ((void (APIENTRY *)(GLenum target, GLsizei n, GLuint *textures)) _func)(target, n, textures);
}

GLAPI void APIENTRY glCreateTransformFeedbacks(GLsizei n, GLuint *ids)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[445];
   ((void (APIENTRY *)(GLsizei n, GLuint *ids)) _func)(n, ids);
}

GLAPI void APIENTRY glCreateVertexArrays(GLsizei n, GLuint *arrays)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[446];
   ((void (APIENTRY *)(GLsizei n, GLuint *arrays)) _func)(n, arrays);
}

GLAPI void APIENTRY glCullFace(GLenum mode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[447];
   ((void (APIENTRY *)(GLenum mode)) _func)(mode);
}

GLAPI void APIENTRY glCullParameterdvEXT(GLenum pname, GLdouble *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[448];
   ((void (APIENTRY *)(GLenum pname, GLdouble *params)) _func)(pname, params);
}

GLAPI void APIENTRY glCullParameterfvEXT(GLenum pname, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[449];
   ((void (APIENTRY *)(GLenum pname, GLfloat *params)) _func)(pname, params);
}

GLAPI void APIENTRY glCurrentPaletteMatrixARB(GLint index)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[450];
   ((void (APIENTRY *)(GLint index)) _func)(index);
}

GLAPI void APIENTRY glCurrentPaletteMatrixOES(GLuint matrixpaletteindex)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[451];
   ((void (APIENTRY *)(GLuint matrixpaletteindex)) _func)(matrixpaletteindex);
}

GLAPI void APIENTRY glDebugMessageCallback(GLDEBUGPROC callback, const void *userParam)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[452];
   ((void (APIENTRY *)(GLDEBUGPROC callback, const void *userParam)) _func)(callback, userParam);
}

GLAPI void APIENTRY glDebugMessageCallbackAMD(GLDEBUGPROCAMD callback, void *userParam)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[453];
   ((void (APIENTRY *)(GLDEBUGPROCAMD callback, void *userParam)) _func)(callback, userParam);
}

GLAPI void APIENTRY glDebugMessageCallbackARB(GLDEBUGPROCARB callback, const void *userParam)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[454];
   ((void (APIENTRY *)(GLDEBUGPROCARB callback, const void *userParam)) _func)(callback, userParam);
}

GLAPI void APIENTRY glDebugMessageCallbackKHR(GLDEBUGPROCKHR callback, const void *userParam)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[455];
   ((void (APIENTRY *)(GLDEBUGPROCKHR callback, const void *userParam)) _func)(callback, userParam);
}

GLAPI void APIENTRY glDebugMessageCallbackOES(GLDEBUGPROC callback, const void *userParam)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[456];
   ((void (APIENTRY *)(GLDEBUGPROC callback, const void *userParam)) _func)(callback, userParam);
}

GLAPI void APIENTRY glDebugMessageControl(GLenum source, GLenum type, GLenum severity, GLsizei count, const GLuint *ids, GLboolean enabled)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[457];
   ((void (APIENTRY *)(GLenum source, GLenum type, GLenum severity, GLsizei count, const GLuint *ids, GLboolean enabled)) _func)(source, type, severity, count, ids, enabled);
}

GLAPI void APIENTRY glDebugMessageControlARB(GLenum source, GLenum type, GLenum severity, GLsizei count, const GLuint *ids, GLboolean enabled)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[458];
   ((void (APIENTRY *)(GLenum source, GLenum type, GLenum severity, GLsizei count, const GLuint *ids, GLboolean enabled)) _func)(source, type, severity, count, ids, enabled);
}

GLAPI void APIENTRY glDebugMessageControlKHR(GLenum source, GLenum type, GLenum severity, GLsizei count, const GLuint *ids, GLboolean enabled)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[459];
   ((void (APIENTRY *)(GLenum source, GLenum type, GLenum severity, GLsizei count, const GLuint *ids, GLboolean enabled)) _func)(source, type, severity, count, ids, enabled);
}

GLAPI void APIENTRY glDebugMessageControlOES(GLenum source, GLenum type, GLenum severity, GLsizei count, const GLuint *ids, GLboolean enabled)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[460];
   ((void (APIENTRY *)(GLenum source, GLenum type, GLenum severity, GLsizei count, const GLuint *ids, GLboolean enabled)) _func)(source, type, severity, count, ids, enabled);
}

GLAPI void APIENTRY glDebugMessageEnableAMD(GLenum category, GLenum severity, GLsizei count, const GLuint *ids, GLboolean enabled)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[461];
   ((void (APIENTRY *)(GLenum category, GLenum severity, GLsizei count, const GLuint *ids, GLboolean enabled)) _func)(category, severity, count, ids, enabled);
}

GLAPI void APIENTRY glDebugMessageInsert(GLenum source, GLenum type, GLuint id, GLenum severity, GLsizei length, const GLchar *buf)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[462];
   ((void (APIENTRY *)(GLenum source, GLenum type, GLuint id, GLenum severity, GLsizei length, const GLchar *buf)) _func)(source, type, id, severity, length, buf);
}

GLAPI void APIENTRY glDebugMessageInsertAMD(GLenum category, GLenum severity, GLuint id, GLsizei length, const GLchar *buf)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[463];
   ((void (APIENTRY *)(GLenum category, GLenum severity, GLuint id, GLsizei length, const GLchar *buf)) _func)(category, severity, id, length, buf);
}

GLAPI void APIENTRY glDebugMessageInsertARB(GLenum source, GLenum type, GLuint id, GLenum severity, GLsizei length, const GLchar *buf)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[464];
   ((void (APIENTRY *)(GLenum source, GLenum type, GLuint id, GLenum severity, GLsizei length, const GLchar *buf)) _func)(source, type, id, severity, length, buf);
}

GLAPI void APIENTRY glDebugMessageInsertKHR(GLenum source, GLenum type, GLuint id, GLenum severity, GLsizei length, const GLchar *buf)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[465];
   ((void (APIENTRY *)(GLenum source, GLenum type, GLuint id, GLenum severity, GLsizei length, const GLchar *buf)) _func)(source, type, id, severity, length, buf);
}

GLAPI void APIENTRY glDebugMessageInsertOES(GLenum source, GLenum type, GLuint id, GLenum severity, GLsizei length, const GLchar *buf)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[466];
   ((void (APIENTRY *)(GLenum source, GLenum type, GLuint id, GLenum severity, GLsizei length, const GLchar *buf)) _func)(source, type, id, severity, length, buf);
}

GLAPI void APIENTRY glDeformSGIX(GLbitfield mask)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[467];
   ((void (APIENTRY *)(GLbitfield mask)) _func)(mask);
}

GLAPI void APIENTRY glDeformationMap3dSGIX(GLenum target, GLdouble u1, GLdouble u2, GLint ustride, GLint uorder, GLdouble v1, GLdouble v2, GLint vstride, GLint vorder, GLdouble w1, GLdouble w2, GLint wstride, GLint worder, const GLdouble *points)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[468];
   ((void (APIENTRY *)(GLenum target, GLdouble u1, GLdouble u2, GLint ustride, GLint uorder, GLdouble v1, GLdouble v2, GLint vstride, GLint vorder, GLdouble w1, GLdouble w2, GLint wstride, GLint worder, const GLdouble *points)) _func)(target, u1, u2, ustride, uorder, v1, v2, vstride, vorder, w1, w2, wstride, worder, points);
}

GLAPI void APIENTRY glDeformationMap3fSGIX(GLenum target, GLfloat u1, GLfloat u2, GLint ustride, GLint uorder, GLfloat v1, GLfloat v2, GLint vstride, GLint vorder, GLfloat w1, GLfloat w2, GLint wstride, GLint worder, const GLfloat *points)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[469];
   ((void (APIENTRY *)(GLenum target, GLfloat u1, GLfloat u2, GLint ustride, GLint uorder, GLfloat v1, GLfloat v2, GLint vstride, GLint vorder, GLfloat w1, GLfloat w2, GLint wstride, GLint worder, const GLfloat *points)) _func)(target, u1, u2, ustride, uorder, v1, v2, vstride, vorder, w1, w2, wstride, worder, points);
}

GLAPI void APIENTRY glDeleteAsyncMarkersSGIX(GLuint marker, GLsizei range)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[470];
   ((void (APIENTRY *)(GLuint marker, GLsizei range)) _func)(marker, range);
}

GLAPI void APIENTRY glDeleteBuffers(GLsizei n, const GLuint *buffers)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[471];
   ((void (APIENTRY *)(GLsizei n, const GLuint *buffers)) _func)(n, buffers);
}

GLAPI void APIENTRY glDeleteBuffersARB(GLsizei n, const GLuint *buffers)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[472];
   ((void (APIENTRY *)(GLsizei n, const GLuint *buffers)) _func)(n, buffers);
}

GLAPI void APIENTRY glDeleteCommandListsNV(GLsizei n, const GLuint *lists)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[473];
   ((void (APIENTRY *)(GLsizei n, const GLuint *lists)) _func)(n, lists);
}

GLAPI void APIENTRY glDeleteFencesAPPLE(GLsizei n, const GLuint *fences)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[474];
   ((void (APIENTRY *)(GLsizei n, const GLuint *fences)) _func)(n, fences);
}

GLAPI void APIENTRY glDeleteFencesNV(GLsizei n, const GLuint *fences)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[475];
   ((void (APIENTRY *)(GLsizei n, const GLuint *fences)) _func)(n, fences);
}

GLAPI void APIENTRY glDeleteFragmentShaderATI(GLuint id)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[476];
   ((void (APIENTRY *)(GLuint id)) _func)(id);
}

GLAPI void APIENTRY glDeleteFramebuffers(GLsizei n, const GLuint *framebuffers)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[477];
   ((void (APIENTRY *)(GLsizei n, const GLuint *framebuffers)) _func)(n, framebuffers);
}

GLAPI void APIENTRY glDeleteFramebuffersEXT(GLsizei n, const GLuint *framebuffers)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[478];
   ((void (APIENTRY *)(GLsizei n, const GLuint *framebuffers)) _func)(n, framebuffers);
}

GLAPI void APIENTRY glDeleteFramebuffersOES(GLsizei n, const GLuint *framebuffers)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[479];
   ((void (APIENTRY *)(GLsizei n, const GLuint *framebuffers)) _func)(n, framebuffers);
}

GLAPI void APIENTRY glDeleteLists(GLuint list, GLsizei range)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[480];
   ((void (APIENTRY *)(GLuint list, GLsizei range)) _func)(list, range);
}

GLAPI void APIENTRY glDeleteMemoryObjectsEXT(GLsizei n, const GLuint *memoryObjects)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[481];
   ((void (APIENTRY *)(GLsizei n, const GLuint *memoryObjects)) _func)(n, memoryObjects);
}

GLAPI void APIENTRY glDeleteNamedStringARB(GLint namelen, const GLchar *name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[482];
   ((void (APIENTRY *)(GLint namelen, const GLchar *name)) _func)(namelen, name);
}

GLAPI void APIENTRY glDeleteNamesAMD(GLenum identifier, GLuint num, const GLuint *names)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[483];
   ((void (APIENTRY *)(GLenum identifier, GLuint num, const GLuint *names)) _func)(identifier, num, names);
}

GLAPI void APIENTRY glDeleteObjectARB(GLhandleARB obj)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[484];
   ((void (APIENTRY *)(GLhandleARB obj)) _func)(obj);
}

GLAPI void APIENTRY glDeleteOcclusionQueriesNV(GLsizei n, const GLuint *ids)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[485];
   ((void (APIENTRY *)(GLsizei n, const GLuint *ids)) _func)(n, ids);
}

GLAPI void APIENTRY glDeletePathsNV(GLuint path, GLsizei range)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[486];
   ((void (APIENTRY *)(GLuint path, GLsizei range)) _func)(path, range);
}

GLAPI void APIENTRY glDeletePerfMonitorsAMD(GLsizei n, GLuint *monitors)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[487];
   ((void (APIENTRY *)(GLsizei n, GLuint *monitors)) _func)(n, monitors);
}

GLAPI void APIENTRY glDeletePerfQueryINTEL(GLuint queryHandle)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[488];
   ((void (APIENTRY *)(GLuint queryHandle)) _func)(queryHandle);
}

GLAPI void APIENTRY glDeleteProgram(GLuint program)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[489];
   ((void (APIENTRY *)(GLuint program)) _func)(program);
}

GLAPI void APIENTRY glDeleteProgramPipelines(GLsizei n, const GLuint *pipelines)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[490];
   ((void (APIENTRY *)(GLsizei n, const GLuint *pipelines)) _func)(n, pipelines);
}

GLAPI void APIENTRY glDeleteProgramPipelinesEXT(GLsizei n, const GLuint *pipelines)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[491];
   ((void (APIENTRY *)(GLsizei n, const GLuint *pipelines)) _func)(n, pipelines);
}

GLAPI void APIENTRY glDeleteProgramsARB(GLsizei n, const GLuint *programs)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[492];
   ((void (APIENTRY *)(GLsizei n, const GLuint *programs)) _func)(n, programs);
}

GLAPI void APIENTRY glDeleteProgramsNV(GLsizei n, const GLuint *programs)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[493];
   ((void (APIENTRY *)(GLsizei n, const GLuint *programs)) _func)(n, programs);
}

GLAPI void APIENTRY glDeleteQueries(GLsizei n, const GLuint *ids)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[494];
   ((void (APIENTRY *)(GLsizei n, const GLuint *ids)) _func)(n, ids);
}

GLAPI void APIENTRY glDeleteQueriesARB(GLsizei n, const GLuint *ids)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[495];
   ((void (APIENTRY *)(GLsizei n, const GLuint *ids)) _func)(n, ids);
}

GLAPI void APIENTRY glDeleteQueriesEXT(GLsizei n, const GLuint *ids)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[496];
   ((void (APIENTRY *)(GLsizei n, const GLuint *ids)) _func)(n, ids);
}

GLAPI void APIENTRY glDeleteQueryResourceTagNV(GLsizei n, const GLint *tagIds)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[497];
   ((void (APIENTRY *)(GLsizei n, const GLint *tagIds)) _func)(n, tagIds);
}

GLAPI void APIENTRY glDeleteRenderbuffers(GLsizei n, const GLuint *renderbuffers)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[498];
   ((void (APIENTRY *)(GLsizei n, const GLuint *renderbuffers)) _func)(n, renderbuffers);
}

GLAPI void APIENTRY glDeleteRenderbuffersEXT(GLsizei n, const GLuint *renderbuffers)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[499];
   ((void (APIENTRY *)(GLsizei n, const GLuint *renderbuffers)) _func)(n, renderbuffers);
}

GLAPI void APIENTRY glDeleteRenderbuffersOES(GLsizei n, const GLuint *renderbuffers)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[500];
   ((void (APIENTRY *)(GLsizei n, const GLuint *renderbuffers)) _func)(n, renderbuffers);
}

GLAPI void APIENTRY glDeleteSamplers(GLsizei count, const GLuint *samplers)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[501];
   ((void (APIENTRY *)(GLsizei count, const GLuint *samplers)) _func)(count, samplers);
}

GLAPI void APIENTRY glDeleteSemaphoresEXT(GLsizei n, const GLuint *semaphores)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[502];
   ((void (APIENTRY *)(GLsizei n, const GLuint *semaphores)) _func)(n, semaphores);
}

GLAPI void APIENTRY glDeleteShader(GLuint shader)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[503];
   ((void (APIENTRY *)(GLuint shader)) _func)(shader);
}

GLAPI void APIENTRY glDeleteStatesNV(GLsizei n, const GLuint *states)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[504];
   ((void (APIENTRY *)(GLsizei n, const GLuint *states)) _func)(n, states);
}

GLAPI void APIENTRY glDeleteSync(GLsync sync)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[505];
   ((void (APIENTRY *)(GLsync sync)) _func)(sync);
}

GLAPI void APIENTRY glDeleteSyncAPPLE(GLsync sync)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[506];
   ((void (APIENTRY *)(GLsync sync)) _func)(sync);
}

GLAPI void APIENTRY glDeleteTextures(GLsizei n, const GLuint *textures)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[507];
   ((void (APIENTRY *)(GLsizei n, const GLuint *textures)) _func)(n, textures);
}

GLAPI void APIENTRY glDeleteTexturesEXT(GLsizei n, const GLuint *textures)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[508];
   ((void (APIENTRY *)(GLsizei n, const GLuint *textures)) _func)(n, textures);
}

GLAPI void APIENTRY glDeleteTransformFeedbacks(GLsizei n, const GLuint *ids)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[509];
   ((void (APIENTRY *)(GLsizei n, const GLuint *ids)) _func)(n, ids);
}

GLAPI void APIENTRY glDeleteTransformFeedbacksEXT(GLsizei n, const GLuint *ids)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[510];
   ((void (APIENTRY *)(GLsizei n, const GLuint *ids)) _func)(n, ids);
}

GLAPI void APIENTRY glDeleteTransformFeedbacksNV(GLsizei n, const GLuint *ids)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[511];
   ((void (APIENTRY *)(GLsizei n, const GLuint *ids)) _func)(n, ids);
}

GLAPI void APIENTRY glDeleteVertexArrays(GLsizei n, const GLuint *arrays)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[512];
   ((void (APIENTRY *)(GLsizei n, const GLuint *arrays)) _func)(n, arrays);
}

GLAPI void APIENTRY glDeleteVertexArraysAPPLE(GLsizei n, const GLuint *arrays)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[513];
   ((void (APIENTRY *)(GLsizei n, const GLuint *arrays)) _func)(n, arrays);
}

GLAPI void APIENTRY glDeleteVertexArraysOES(GLsizei n, const GLuint *arrays)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[514];
   ((void (APIENTRY *)(GLsizei n, const GLuint *arrays)) _func)(n, arrays);
}

GLAPI void APIENTRY glDeleteVertexShaderEXT(GLuint id)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[515];
   ((void (APIENTRY *)(GLuint id)) _func)(id);
}

GLAPI void APIENTRY glDepthBoundsEXT(GLclampd zmin, GLclampd zmax)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[516];
   ((void (APIENTRY *)(GLclampd zmin, GLclampd zmax)) _func)(zmin, zmax);
}

GLAPI void APIENTRY glDepthBoundsdNV(GLdouble zmin, GLdouble zmax)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[517];
   ((void (APIENTRY *)(GLdouble zmin, GLdouble zmax)) _func)(zmin, zmax);
}

GLAPI void APIENTRY glDepthFunc(GLenum func)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[518];
   ((void (APIENTRY *)(GLenum func)) _func)(func);
}

GLAPI void APIENTRY glDepthMask(GLboolean flag)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[519];
   ((void (APIENTRY *)(GLboolean flag)) _func)(flag);
}

GLAPI void APIENTRY glDepthRange(GLdouble n, GLdouble f)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[520];
   ((void (APIENTRY *)(GLdouble n, GLdouble f)) _func)(n, f);
}

GLAPI void APIENTRY glDepthRangeArraydvNV(GLuint first, GLsizei count, const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[521];
   ((void (APIENTRY *)(GLuint first, GLsizei count, const GLdouble *v)) _func)(first, count, v);
}

GLAPI void APIENTRY glDepthRangeArrayfvNV(GLuint first, GLsizei count, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[522];
   ((void (APIENTRY *)(GLuint first, GLsizei count, const GLfloat *v)) _func)(first, count, v);
}

GLAPI void APIENTRY glDepthRangeArrayfvOES(GLuint first, GLsizei count, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[523];
   ((void (APIENTRY *)(GLuint first, GLsizei count, const GLfloat *v)) _func)(first, count, v);
}

GLAPI void APIENTRY glDepthRangeArrayv(GLuint first, GLsizei count, const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[524];
   ((void (APIENTRY *)(GLuint first, GLsizei count, const GLdouble *v)) _func)(first, count, v);
}

GLAPI void APIENTRY glDepthRangeIndexed(GLuint index, GLdouble n, GLdouble f)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[525];
   ((void (APIENTRY *)(GLuint index, GLdouble n, GLdouble f)) _func)(index, n, f);
}

GLAPI void APIENTRY glDepthRangeIndexeddNV(GLuint index, GLdouble n, GLdouble f)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[526];
   ((void (APIENTRY *)(GLuint index, GLdouble n, GLdouble f)) _func)(index, n, f);
}

GLAPI void APIENTRY glDepthRangeIndexedfNV(GLuint index, GLfloat n, GLfloat f)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[527];
   ((void (APIENTRY *)(GLuint index, GLfloat n, GLfloat f)) _func)(index, n, f);
}

GLAPI void APIENTRY glDepthRangeIndexedfOES(GLuint index, GLfloat n, GLfloat f)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[528];
   ((void (APIENTRY *)(GLuint index, GLfloat n, GLfloat f)) _func)(index, n, f);
}

GLAPI void APIENTRY glDepthRangedNV(GLdouble zNear, GLdouble zFar)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[529];
   ((void (APIENTRY *)(GLdouble zNear, GLdouble zFar)) _func)(zNear, zFar);
}

GLAPI void APIENTRY glDepthRangef(GLfloat n, GLfloat f)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[530];
   ((void (APIENTRY *)(GLfloat n, GLfloat f)) _func)(n, f);
}

GLAPI void APIENTRY glDepthRangefOES(GLclampf n, GLclampf f)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[531];
   ((void (APIENTRY *)(GLclampf n, GLclampf f)) _func)(n, f);
}

GLAPI void APIENTRY glDepthRangex(GLfixed n, GLfixed f)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[532];
   ((void (APIENTRY *)(GLfixed n, GLfixed f)) _func)(n, f);
}

GLAPI void APIENTRY glDepthRangexOES(GLfixed n, GLfixed f)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[533];
   ((void (APIENTRY *)(GLfixed n, GLfixed f)) _func)(n, f);
}

GLAPI void APIENTRY glDetachObjectARB(GLhandleARB containerObj, GLhandleARB attachedObj)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[534];
   ((void (APIENTRY *)(GLhandleARB containerObj, GLhandleARB attachedObj)) _func)(containerObj, attachedObj);
}

GLAPI void APIENTRY glDetachShader(GLuint program, GLuint shader)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[535];
   ((void (APIENTRY *)(GLuint program, GLuint shader)) _func)(program, shader);
}

GLAPI void APIENTRY glDetailTexFuncSGIS(GLenum target, GLsizei n, const GLfloat *points)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[536];
   ((void (APIENTRY *)(GLenum target, GLsizei n, const GLfloat *points)) _func)(target, n, points);
}

GLAPI void APIENTRY glDevtoolsCorrelationIdNVX(GLuint64 id)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[537];
   ((void (APIENTRY *)(GLuint64 id)) _func)(id);
}

GLAPI void APIENTRY glDevtoolsInvokeStreamedCallbackNVX(void *fnptr, void *userdata)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[538];
   ((void (APIENTRY *)(void *fnptr, void *userdata)) _func)(fnptr, userdata);
}

GLAPI void APIENTRY glDisable(GLenum cap)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[539];
   ((void (APIENTRY *)(GLenum cap)) _func)(cap);
}

GLAPI void APIENTRY glDisableClientState(GLenum array)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[540];
   ((void (APIENTRY *)(GLenum array)) _func)(array);
}

GLAPI void APIENTRY glDisableClientStateIndexedEXT(GLenum array, GLuint index)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[541];
   ((void (APIENTRY *)(GLenum array, GLuint index)) _func)(array, index);
}

GLAPI void APIENTRY glDisableClientStateiEXT(GLenum array, GLuint index)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[542];
   ((void (APIENTRY *)(GLenum array, GLuint index)) _func)(array, index);
}

GLAPI void APIENTRY glDisableDriverControlQCOM(GLuint driverControl)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[543];
   ((void (APIENTRY *)(GLuint driverControl)) _func)(driverControl);
}

GLAPI void APIENTRY glDisableIndexedEXT(GLenum target, GLuint index)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[544];
   ((void (APIENTRY *)(GLenum target, GLuint index)) _func)(target, index);
}

GLAPI void APIENTRY glDisableVariantClientStateEXT(GLuint id)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[545];
   ((void (APIENTRY *)(GLuint id)) _func)(id);
}

GLAPI void APIENTRY glDisableVertexArrayAttrib(GLuint vaobj, GLuint index)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[546];
   ((void (APIENTRY *)(GLuint vaobj, GLuint index)) _func)(vaobj, index);
}

GLAPI void APIENTRY glDisableVertexArrayAttribEXT(GLuint vaobj, GLuint index)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[547];
   ((void (APIENTRY *)(GLuint vaobj, GLuint index)) _func)(vaobj, index);
}

GLAPI void APIENTRY glDisableVertexArrayEXT(GLuint vaobj, GLenum array)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[548];
   ((void (APIENTRY *)(GLuint vaobj, GLenum array)) _func)(vaobj, array);
}

GLAPI void APIENTRY glDisableVertexAttribAPPLE(GLuint index, GLenum pname)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[549];
   ((void (APIENTRY *)(GLuint index, GLenum pname)) _func)(index, pname);
}

GLAPI void APIENTRY glDisableVertexAttribArray(GLuint index)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[550];
   ((void (APIENTRY *)(GLuint index)) _func)(index);
}

GLAPI void APIENTRY glDisableVertexAttribArrayARB(GLuint index)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[551];
   ((void (APIENTRY *)(GLuint index)) _func)(index);
}

GLAPI void APIENTRY glDisablei(GLenum target, GLuint index)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[552];
   ((void (APIENTRY *)(GLenum target, GLuint index)) _func)(target, index);
}

GLAPI void APIENTRY glDisableiEXT(GLenum target, GLuint index)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[553];
   ((void (APIENTRY *)(GLenum target, GLuint index)) _func)(target, index);
}

GLAPI void APIENTRY glDisableiNV(GLenum target, GLuint index)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[554];
   ((void (APIENTRY *)(GLenum target, GLuint index)) _func)(target, index);
}

GLAPI void APIENTRY glDisableiOES(GLenum target, GLuint index)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[555];
   ((void (APIENTRY *)(GLenum target, GLuint index)) _func)(target, index);
}

GLAPI void APIENTRY glDiscardFramebufferEXT(GLenum target, GLsizei numAttachments, const GLenum *attachments)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[556];
   ((void (APIENTRY *)(GLenum target, GLsizei numAttachments, const GLenum *attachments)) _func)(target, numAttachments, attachments);
}

GLAPI void APIENTRY glDispatchCompute(GLuint num_groups_x, GLuint num_groups_y, GLuint num_groups_z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[557];
   ((void (APIENTRY *)(GLuint num_groups_x, GLuint num_groups_y, GLuint num_groups_z)) _func)(num_groups_x, num_groups_y, num_groups_z);
}

GLAPI void APIENTRY glDispatchComputeGroupSizeARB(GLuint num_groups_x, GLuint num_groups_y, GLuint num_groups_z, GLuint group_size_x, GLuint group_size_y, GLuint group_size_z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[558];
   ((void (APIENTRY *)(GLuint num_groups_x, GLuint num_groups_y, GLuint num_groups_z, GLuint group_size_x, GLuint group_size_y, GLuint group_size_z)) _func)(num_groups_x, num_groups_y, num_groups_z, group_size_x, group_size_y, group_size_z);
}

GLAPI void APIENTRY glDispatchComputeIndirect(GLintptr indirect)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[559];
   ((void (APIENTRY *)(GLintptr indirect)) _func)(indirect);
}

GLAPI void APIENTRY glDrawArrays(GLenum mode, GLint first, GLsizei count)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[560];
   ((void (APIENTRY *)(GLenum mode, GLint first, GLsizei count)) _func)(mode, first, count);
}

GLAPI void APIENTRY glDrawArraysEXT(GLenum mode, GLint first, GLsizei count)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[561];
   ((void (APIENTRY *)(GLenum mode, GLint first, GLsizei count)) _func)(mode, first, count);
}

GLAPI void APIENTRY glDrawArraysIndirect(GLenum mode, const void *indirect)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[562];
   ((void (APIENTRY *)(GLenum mode, const void *indirect)) _func)(mode, indirect);
}

GLAPI void APIENTRY glDrawArraysInstanced(GLenum mode, GLint first, GLsizei count, GLsizei instancecount)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[563];
   ((void (APIENTRY *)(GLenum mode, GLint first, GLsizei count, GLsizei instancecount)) _func)(mode, first, count, instancecount);
}

GLAPI void APIENTRY glDrawArraysInstancedANGLE(GLenum mode, GLint first, GLsizei count, GLsizei primcount)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[564];
   ((void (APIENTRY *)(GLenum mode, GLint first, GLsizei count, GLsizei primcount)) _func)(mode, first, count, primcount);
}

GLAPI void APIENTRY glDrawArraysInstancedARB(GLenum mode, GLint first, GLsizei count, GLsizei primcount)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[565];
   ((void (APIENTRY *)(GLenum mode, GLint first, GLsizei count, GLsizei primcount)) _func)(mode, first, count, primcount);
}

GLAPI void APIENTRY glDrawArraysInstancedBaseInstance(GLenum mode, GLint first, GLsizei count, GLsizei instancecount, GLuint baseinstance)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[566];
   ((void (APIENTRY *)(GLenum mode, GLint first, GLsizei count, GLsizei instancecount, GLuint baseinstance)) _func)(mode, first, count, instancecount, baseinstance);
}

GLAPI void APIENTRY glDrawArraysInstancedBaseInstanceEXT(GLenum mode, GLint first, GLsizei count, GLsizei instancecount, GLuint baseinstance)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[567];
   ((void (APIENTRY *)(GLenum mode, GLint first, GLsizei count, GLsizei instancecount, GLuint baseinstance)) _func)(mode, first, count, instancecount, baseinstance);
}

GLAPI void APIENTRY glDrawArraysInstancedEXT(GLenum mode, GLint start, GLsizei count, GLsizei primcount)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[568];
   ((void (APIENTRY *)(GLenum mode, GLint start, GLsizei count, GLsizei primcount)) _func)(mode, start, count, primcount);
}

GLAPI void APIENTRY glDrawArraysInstancedNV(GLenum mode, GLint first, GLsizei count, GLsizei primcount)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[569];
   ((void (APIENTRY *)(GLenum mode, GLint first, GLsizei count, GLsizei primcount)) _func)(mode, first, count, primcount);
}

GLAPI void APIENTRY glDrawBuffer(GLenum buf)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[570];
   ((void (APIENTRY *)(GLenum buf)) _func)(buf);
}

GLAPI void APIENTRY glDrawBuffers(GLsizei n, const GLenum *bufs)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[571];
   ((void (APIENTRY *)(GLsizei n, const GLenum *bufs)) _func)(n, bufs);
}

GLAPI void APIENTRY glDrawBuffersARB(GLsizei n, const GLenum *bufs)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[572];
   ((void (APIENTRY *)(GLsizei n, const GLenum *bufs)) _func)(n, bufs);
}

GLAPI void APIENTRY glDrawBuffersATI(GLsizei n, const GLenum *bufs)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[573];
   ((void (APIENTRY *)(GLsizei n, const GLenum *bufs)) _func)(n, bufs);
}

GLAPI void APIENTRY glDrawBuffersEXT(GLsizei n, const GLenum *bufs)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[574];
   ((void (APIENTRY *)(GLsizei n, const GLenum *bufs)) _func)(n, bufs);
}

GLAPI void APIENTRY glDrawBuffersIndexedEXT(GLint n, const GLenum *location, const GLint *indices)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[575];
   ((void (APIENTRY *)(GLint n, const GLenum *location, const GLint *indices)) _func)(n, location, indices);
}

GLAPI void APIENTRY glDrawBuffersNV(GLsizei n, const GLenum *bufs)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[576];
   ((void (APIENTRY *)(GLsizei n, const GLenum *bufs)) _func)(n, bufs);
}

GLAPI void APIENTRY glDrawCommandsAddressNV(GLenum primitiveMode, const GLuint64 *indirects, const GLsizei *sizes, GLuint count)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[577];
   ((void (APIENTRY *)(GLenum primitiveMode, const GLuint64 *indirects, const GLsizei *sizes, GLuint count)) _func)(primitiveMode, indirects, sizes, count);
}

GLAPI void APIENTRY glDrawCommandsNV(GLenum primitiveMode, GLuint buffer, const GLintptr *indirects, const GLsizei *sizes, GLuint count)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[578];
   ((void (APIENTRY *)(GLenum primitiveMode, GLuint buffer, const GLintptr *indirects, const GLsizei *sizes, GLuint count)) _func)(primitiveMode, buffer, indirects, sizes, count);
}

GLAPI void APIENTRY glDrawCommandsStatesAddressNV(const GLuint64 *indirects, const GLsizei *sizes, const GLuint *states, const GLuint *fbos, GLuint count)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[579];
   ((void (APIENTRY *)(const GLuint64 *indirects, const GLsizei *sizes, const GLuint *states, const GLuint *fbos, GLuint count)) _func)(indirects, sizes, states, fbos, count);
}

GLAPI void APIENTRY glDrawCommandsStatesNV(GLuint buffer, const GLintptr *indirects, const GLsizei *sizes, const GLuint *states, const GLuint *fbos, GLuint count)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[580];
   ((void (APIENTRY *)(GLuint buffer, const GLintptr *indirects, const GLsizei *sizes, const GLuint *states, const GLuint *fbos, GLuint count)) _func)(buffer, indirects, sizes, states, fbos, count);
}

GLAPI void APIENTRY glDrawElementArrayAPPLE(GLenum mode, GLint first, GLsizei count)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[581];
   ((void (APIENTRY *)(GLenum mode, GLint first, GLsizei count)) _func)(mode, first, count);
}

GLAPI void APIENTRY glDrawElementArrayATI(GLenum mode, GLsizei count)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[582];
   ((void (APIENTRY *)(GLenum mode, GLsizei count)) _func)(mode, count);
}

GLAPI void APIENTRY glDrawElements(GLenum mode, GLsizei count, GLenum type, const void *indices)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[583];
   ((void (APIENTRY *)(GLenum mode, GLsizei count, GLenum type, const void *indices)) _func)(mode, count, type, indices);
}

GLAPI void APIENTRY glDrawElementsBaseVertex(GLenum mode, GLsizei count, GLenum type, const void *indices, GLint basevertex)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[584];
   ((void (APIENTRY *)(GLenum mode, GLsizei count, GLenum type, const void *indices, GLint basevertex)) _func)(mode, count, type, indices, basevertex);
}

GLAPI void APIENTRY glDrawElementsBaseVertexEXT(GLenum mode, GLsizei count, GLenum type, const void *indices, GLint basevertex)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[585];
   ((void (APIENTRY *)(GLenum mode, GLsizei count, GLenum type, const void *indices, GLint basevertex)) _func)(mode, count, type, indices, basevertex);
}

GLAPI void APIENTRY glDrawElementsBaseVertexOES(GLenum mode, GLsizei count, GLenum type, const void *indices, GLint basevertex)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[586];
   ((void (APIENTRY *)(GLenum mode, GLsizei count, GLenum type, const void *indices, GLint basevertex)) _func)(mode, count, type, indices, basevertex);
}

GLAPI void APIENTRY glDrawElementsIndirect(GLenum mode, GLenum type, const void *indirect)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[587];
   ((void (APIENTRY *)(GLenum mode, GLenum type, const void *indirect)) _func)(mode, type, indirect);
}

GLAPI void APIENTRY glDrawElementsInstanced(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei instancecount)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[588];
   ((void (APIENTRY *)(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei instancecount)) _func)(mode, count, type, indices, instancecount);
}

GLAPI void APIENTRY glDrawElementsInstancedANGLE(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei primcount)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[589];
   ((void (APIENTRY *)(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei primcount)) _func)(mode, count, type, indices, primcount);
}

GLAPI void APIENTRY glDrawElementsInstancedARB(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei primcount)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[590];
   ((void (APIENTRY *)(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei primcount)) _func)(mode, count, type, indices, primcount);
}

GLAPI void APIENTRY glDrawElementsInstancedBaseInstance(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei instancecount, GLuint baseinstance)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[591];
   ((void (APIENTRY *)(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei instancecount, GLuint baseinstance)) _func)(mode, count, type, indices, instancecount, baseinstance);
}

GLAPI void APIENTRY glDrawElementsInstancedBaseInstanceEXT(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei instancecount, GLuint baseinstance)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[592];
   ((void (APIENTRY *)(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei instancecount, GLuint baseinstance)) _func)(mode, count, type, indices, instancecount, baseinstance);
}

GLAPI void APIENTRY glDrawElementsInstancedBaseVertex(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei instancecount, GLint basevertex)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[593];
   ((void (APIENTRY *)(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei instancecount, GLint basevertex)) _func)(mode, count, type, indices, instancecount, basevertex);
}

GLAPI void APIENTRY glDrawElementsInstancedBaseVertexBaseInstance(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei instancecount, GLint basevertex, GLuint baseinstance)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[594];
   ((void (APIENTRY *)(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei instancecount, GLint basevertex, GLuint baseinstance)) _func)(mode, count, type, indices, instancecount, basevertex, baseinstance);
}

GLAPI void APIENTRY glDrawElementsInstancedBaseVertexBaseInstanceEXT(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei instancecount, GLint basevertex, GLuint baseinstance)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[595];
   ((void (APIENTRY *)(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei instancecount, GLint basevertex, GLuint baseinstance)) _func)(mode, count, type, indices, instancecount, basevertex, baseinstance);
}

GLAPI void APIENTRY glDrawElementsInstancedBaseVertexEXT(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei instancecount, GLint basevertex)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[596];
   ((void (APIENTRY *)(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei instancecount, GLint basevertex)) _func)(mode, count, type, indices, instancecount, basevertex);
}

GLAPI void APIENTRY glDrawElementsInstancedBaseVertexOES(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei instancecount, GLint basevertex)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[597];
   ((void (APIENTRY *)(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei instancecount, GLint basevertex)) _func)(mode, count, type, indices, instancecount, basevertex);
}

GLAPI void APIENTRY glDrawElementsInstancedEXT(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei primcount)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[598];
   ((void (APIENTRY *)(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei primcount)) _func)(mode, count, type, indices, primcount);
}

GLAPI void APIENTRY glDrawElementsInstancedNV(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei primcount)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[599];
   ((void (APIENTRY *)(GLenum mode, GLsizei count, GLenum type, const void *indices, GLsizei primcount)) _func)(mode, count, type, indices, primcount);
}

GLAPI void APIENTRY glDrawMeshArraysSUN(GLenum mode, GLint first, GLsizei count, GLsizei width)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[600];
   ((void (APIENTRY *)(GLenum mode, GLint first, GLsizei count, GLsizei width)) _func)(mode, first, count, width);
}

GLAPI void APIENTRY glDrawMeshNV(GLenum mode, GLsizei count, GLenum type, GLsizei stride, const void *indicesTexCoord, const void *indicesNormal, const void *indicesVertex)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[601];
   ((void (APIENTRY *)(GLenum mode, GLsizei count, GLenum type, GLsizei stride, const void *indicesTexCoord, const void *indicesNormal, const void *indicesVertex)) _func)(mode, count, type, stride, indicesTexCoord, indicesNormal, indicesVertex);
}

GLAPI void APIENTRY glDrawMeshTasksIndirectNV(GLintptr indirect)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[602];
   ((void (APIENTRY *)(GLintptr indirect)) _func)(indirect);
}

GLAPI void APIENTRY glDrawMeshTasksNV(GLuint first, GLuint count)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[603];
   ((void (APIENTRY *)(GLuint first, GLuint count)) _func)(first, count);
}

GLAPI void APIENTRY glDrawPixels(GLsizei width, GLsizei height, GLenum format, GLenum type, const void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[604];
   ((void (APIENTRY *)(GLsizei width, GLsizei height, GLenum format, GLenum type, const void *pixels)) _func)(width, height, format, type, pixels);
}

GLAPI void APIENTRY glDrawRangeElementArrayAPPLE(GLenum mode, GLuint start, GLuint end, GLint first, GLsizei count)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[605];
   ((void (APIENTRY *)(GLenum mode, GLuint start, GLuint end, GLint first, GLsizei count)) _func)(mode, start, end, first, count);
}

GLAPI void APIENTRY glDrawRangeElementArrayATI(GLenum mode, GLuint start, GLuint end, GLsizei count)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[606];
   ((void (APIENTRY *)(GLenum mode, GLuint start, GLuint end, GLsizei count)) _func)(mode, start, end, count);
}

GLAPI void APIENTRY glDrawRangeElements(GLenum mode, GLuint start, GLuint end, GLsizei count, GLenum type, const void *indices)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[607];
   ((void (APIENTRY *)(GLenum mode, GLuint start, GLuint end, GLsizei count, GLenum type, const void *indices)) _func)(mode, start, end, count, type, indices);
}

GLAPI void APIENTRY glDrawRangeElementsBaseVertex(GLenum mode, GLuint start, GLuint end, GLsizei count, GLenum type, const void *indices, GLint basevertex)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[608];
   ((void (APIENTRY *)(GLenum mode, GLuint start, GLuint end, GLsizei count, GLenum type, const void *indices, GLint basevertex)) _func)(mode, start, end, count, type, indices, basevertex);
}

GLAPI void APIENTRY glDrawRangeElementsBaseVertexEXT(GLenum mode, GLuint start, GLuint end, GLsizei count, GLenum type, const void *indices, GLint basevertex)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[609];
   ((void (APIENTRY *)(GLenum mode, GLuint start, GLuint end, GLsizei count, GLenum type, const void *indices, GLint basevertex)) _func)(mode, start, end, count, type, indices, basevertex);
}

GLAPI void APIENTRY glDrawRangeElementsBaseVertexOES(GLenum mode, GLuint start, GLuint end, GLsizei count, GLenum type, const void *indices, GLint basevertex)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[610];
   ((void (APIENTRY *)(GLenum mode, GLuint start, GLuint end, GLsizei count, GLenum type, const void *indices, GLint basevertex)) _func)(mode, start, end, count, type, indices, basevertex);
}

GLAPI void APIENTRY glDrawRangeElementsEXT(GLenum mode, GLuint start, GLuint end, GLsizei count, GLenum type, const void *indices)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[611];
   ((void (APIENTRY *)(GLenum mode, GLuint start, GLuint end, GLsizei count, GLenum type, const void *indices)) _func)(mode, start, end, count, type, indices);
}

GLAPI void APIENTRY glDrawTexfOES(GLfloat x, GLfloat y, GLfloat z, GLfloat width, GLfloat height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[612];
   ((void (APIENTRY *)(GLfloat x, GLfloat y, GLfloat z, GLfloat width, GLfloat height)) _func)(x, y, z, width, height);
}

GLAPI void APIENTRY glDrawTexfvOES(const GLfloat *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[613];
   ((void (APIENTRY *)(const GLfloat *coords)) _func)(coords);
}

GLAPI void APIENTRY glDrawTexiOES(GLint x, GLint y, GLint z, GLint width, GLint height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[614];
   ((void (APIENTRY *)(GLint x, GLint y, GLint z, GLint width, GLint height)) _func)(x, y, z, width, height);
}

GLAPI void APIENTRY glDrawTexivOES(const GLint *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[615];
   ((void (APIENTRY *)(const GLint *coords)) _func)(coords);
}

GLAPI void APIENTRY glDrawTexsOES(GLshort x, GLshort y, GLshort z, GLshort width, GLshort height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[616];
   ((void (APIENTRY *)(GLshort x, GLshort y, GLshort z, GLshort width, GLshort height)) _func)(x, y, z, width, height);
}

GLAPI void APIENTRY glDrawTexsvOES(const GLshort *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[617];
   ((void (APIENTRY *)(const GLshort *coords)) _func)(coords);
}

GLAPI void APIENTRY glDrawTextureNV(GLuint texture, GLuint sampler, GLfloat x0, GLfloat y0, GLfloat x1, GLfloat y1, GLfloat z, GLfloat s0, GLfloat t0, GLfloat s1, GLfloat t1)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[618];
   ((void (APIENTRY *)(GLuint texture, GLuint sampler, GLfloat x0, GLfloat y0, GLfloat x1, GLfloat y1, GLfloat z, GLfloat s0, GLfloat t0, GLfloat s1, GLfloat t1)) _func)(texture, sampler, x0, y0, x1, y1, z, s0, t0, s1, t1);
}

GLAPI void APIENTRY glDrawTexxOES(GLfixed x, GLfixed y, GLfixed z, GLfixed width, GLfixed height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[619];
   ((void (APIENTRY *)(GLfixed x, GLfixed y, GLfixed z, GLfixed width, GLfixed height)) _func)(x, y, z, width, height);
}

GLAPI void APIENTRY glDrawTexxvOES(const GLfixed *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[620];
   ((void (APIENTRY *)(const GLfixed *coords)) _func)(coords);
}

GLAPI void APIENTRY glDrawTransformFeedback(GLenum mode, GLuint id)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[621];
   ((void (APIENTRY *)(GLenum mode, GLuint id)) _func)(mode, id);
}

GLAPI void APIENTRY glDrawTransformFeedbackEXT(GLenum mode, GLuint id)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[622];
   ((void (APIENTRY *)(GLenum mode, GLuint id)) _func)(mode, id);
}

GLAPI void APIENTRY glDrawTransformFeedbackInstanced(GLenum mode, GLuint id, GLsizei instancecount)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[623];
   ((void (APIENTRY *)(GLenum mode, GLuint id, GLsizei instancecount)) _func)(mode, id, instancecount);
}

GLAPI void APIENTRY glDrawTransformFeedbackInstancedEXT(GLenum mode, GLuint id, GLsizei instancecount)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[624];
   ((void (APIENTRY *)(GLenum mode, GLuint id, GLsizei instancecount)) _func)(mode, id, instancecount);
}

GLAPI void APIENTRY glDrawTransformFeedbackNV(GLenum mode, GLuint id)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[625];
   ((void (APIENTRY *)(GLenum mode, GLuint id)) _func)(mode, id);
}

GLAPI void APIENTRY glDrawTransformFeedbackStream(GLenum mode, GLuint id, GLuint stream)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[626];
   ((void (APIENTRY *)(GLenum mode, GLuint id, GLuint stream)) _func)(mode, id, stream);
}

GLAPI void APIENTRY glDrawTransformFeedbackStreamInstanced(GLenum mode, GLuint id, GLuint stream, GLsizei instancecount)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[627];
   ((void (APIENTRY *)(GLenum mode, GLuint id, GLuint stream, GLsizei instancecount)) _func)(mode, id, stream, instancecount);
}

GLAPI void APIENTRY glDrawVkImageNV(GLuint64 vkImage, GLuint sampler, GLfloat x0, GLfloat y0, GLfloat x1, GLfloat y1, GLfloat z, GLfloat s0, GLfloat t0, GLfloat s1, GLfloat t1)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[628];
   ((void (APIENTRY *)(GLuint64 vkImage, GLuint sampler, GLfloat x0, GLfloat y0, GLfloat x1, GLfloat y1, GLfloat z, GLfloat s0, GLfloat t0, GLfloat s1, GLfloat t1)) _func)(vkImage, sampler, x0, y0, x1, y1, z, s0, t0, s1, t1);
}

GLAPI void APIENTRY glEGLImageTargetRenderbufferStorageOES(GLenum target, GLeglImageOES image)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[629];
   ((void (APIENTRY *)(GLenum target, GLeglImageOES image)) _func)(target, image);
}

GLAPI void APIENTRY glEGLImageTargetTexStorageEXT(GLenum target, GLeglImageOES image, const GLint *attrib_list)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[630];
   ((void (APIENTRY *)(GLenum target, GLeglImageOES image, const GLint *attrib_list)) _func)(target, image, attrib_list);
}

GLAPI void APIENTRY glEGLImageTargetTexture2DOES(GLenum target, GLeglImageOES image)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[631];
   ((void (APIENTRY *)(GLenum target, GLeglImageOES image)) _func)(target, image);
}

GLAPI void APIENTRY glEGLImageTargetTextureStorageEXT(GLuint texture, GLeglImageOES image, const GLint *attrib_list)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[632];
   ((void (APIENTRY *)(GLuint texture, GLeglImageOES image, const GLint *attrib_list)) _func)(texture, image, attrib_list);
}

GLAPI void APIENTRY glEdgeFlag(GLboolean flag)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[633];
   ((void (APIENTRY *)(GLboolean flag)) _func)(flag);
}

GLAPI void APIENTRY glEdgeFlagFormatNV(GLsizei stride)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[634];
   ((void (APIENTRY *)(GLsizei stride)) _func)(stride);
}

GLAPI void APIENTRY glEdgeFlagPointer(GLsizei stride, const void *pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[635];
   ((void (APIENTRY *)(GLsizei stride, const void *pointer)) _func)(stride, pointer);
}

GLAPI void APIENTRY glEdgeFlagPointerEXT(GLsizei stride, GLsizei count, const GLboolean *pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[636];
   ((void (APIENTRY *)(GLsizei stride, GLsizei count, const GLboolean *pointer)) _func)(stride, count, pointer);
}

GLAPI void APIENTRY glEdgeFlagPointerListIBM(GLint stride, const GLboolean **pointer, GLint ptrstride)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[637];
   ((void (APIENTRY *)(GLint stride, const GLboolean **pointer, GLint ptrstride)) _func)(stride, pointer, ptrstride);
}

GLAPI void APIENTRY glEdgeFlagv(const GLboolean *flag)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[638];
   ((void (APIENTRY *)(const GLboolean *flag)) _func)(flag);
}

GLAPI void APIENTRY glElementPointerAPPLE(GLenum type, const void *pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[639];
   ((void (APIENTRY *)(GLenum type, const void *pointer)) _func)(type, pointer);
}

GLAPI void APIENTRY glElementPointerATI(GLenum type, const void *pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[640];
   ((void (APIENTRY *)(GLenum type, const void *pointer)) _func)(type, pointer);
}

GLAPI void APIENTRY glEnable(GLenum cap)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[641];
   ((void (APIENTRY *)(GLenum cap)) _func)(cap);
}

GLAPI void APIENTRY glEnableClientState(GLenum array)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[642];
   ((void (APIENTRY *)(GLenum array)) _func)(array);
}

GLAPI void APIENTRY glEnableClientStateIndexedEXT(GLenum array, GLuint index)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[643];
   ((void (APIENTRY *)(GLenum array, GLuint index)) _func)(array, index);
}

GLAPI void APIENTRY glEnableClientStateiEXT(GLenum array, GLuint index)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[644];
   ((void (APIENTRY *)(GLenum array, GLuint index)) _func)(array, index);
}

GLAPI void APIENTRY glEnableDriverControlQCOM(GLuint driverControl)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[645];
   ((void (APIENTRY *)(GLuint driverControl)) _func)(driverControl);
}

GLAPI void APIENTRY glEnableIndexedEXT(GLenum target, GLuint index)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[646];
   ((void (APIENTRY *)(GLenum target, GLuint index)) _func)(target, index);
}

GLAPI void APIENTRY glEnableVariantClientStateEXT(GLuint id)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[647];
   ((void (APIENTRY *)(GLuint id)) _func)(id);
}

GLAPI void APIENTRY glEnableVertexArrayAttrib(GLuint vaobj, GLuint index)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[648];
   ((void (APIENTRY *)(GLuint vaobj, GLuint index)) _func)(vaobj, index);
}

GLAPI void APIENTRY glEnableVertexArrayAttribEXT(GLuint vaobj, GLuint index)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[649];
   ((void (APIENTRY *)(GLuint vaobj, GLuint index)) _func)(vaobj, index);
}

GLAPI void APIENTRY glEnableVertexArrayEXT(GLuint vaobj, GLenum array)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[650];
   ((void (APIENTRY *)(GLuint vaobj, GLenum array)) _func)(vaobj, array);
}

GLAPI void APIENTRY glEnableVertexAttribAPPLE(GLuint index, GLenum pname)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[651];
   ((void (APIENTRY *)(GLuint index, GLenum pname)) _func)(index, pname);
}

GLAPI void APIENTRY glEnableVertexAttribArray(GLuint index)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[652];
   ((void (APIENTRY *)(GLuint index)) _func)(index);
}

GLAPI void APIENTRY glEnableVertexAttribArrayARB(GLuint index)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[653];
   ((void (APIENTRY *)(GLuint index)) _func)(index);
}

GLAPI void APIENTRY glEnablei(GLenum target, GLuint index)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[654];
   ((void (APIENTRY *)(GLenum target, GLuint index)) _func)(target, index);
}

GLAPI void APIENTRY glEnableiEXT(GLenum target, GLuint index)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[655];
   ((void (APIENTRY *)(GLenum target, GLuint index)) _func)(target, index);
}

GLAPI void APIENTRY glEnableiNV(GLenum target, GLuint index)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[656];
   ((void (APIENTRY *)(GLenum target, GLuint index)) _func)(target, index);
}

GLAPI void APIENTRY glEnableiOES(GLenum target, GLuint index)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[657];
   ((void (APIENTRY *)(GLenum target, GLuint index)) _func)(target, index);
}

GLAPI void APIENTRY glEnd(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[658];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glEndConditionalRender(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[659];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glEndConditionalRenderNV(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[660];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glEndConditionalRenderNVX(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[661];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glEndFragmentShaderATI(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[662];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glEndList(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[663];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glEndOcclusionQueryNV(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[664];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glEndPerfMonitorAMD(GLuint monitor)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[665];
   ((void (APIENTRY *)(GLuint monitor)) _func)(monitor);
}

GLAPI void APIENTRY glEndPerfQueryINTEL(GLuint queryHandle)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[666];
   ((void (APIENTRY *)(GLuint queryHandle)) _func)(queryHandle);
}

GLAPI void APIENTRY glEndQuery(GLenum target)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[667];
   ((void (APIENTRY *)(GLenum target)) _func)(target);
}

GLAPI void APIENTRY glEndQueryARB(GLenum target)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[668];
   ((void (APIENTRY *)(GLenum target)) _func)(target);
}

GLAPI void APIENTRY glEndQueryEXT(GLenum target)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[669];
   ((void (APIENTRY *)(GLenum target)) _func)(target);
}

GLAPI void APIENTRY glEndQueryIndexed(GLenum target, GLuint index)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[670];
   ((void (APIENTRY *)(GLenum target, GLuint index)) _func)(target, index);
}

GLAPI void APIENTRY glEndTilingQCOM(GLbitfield preserveMask)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[671];
   ((void (APIENTRY *)(GLbitfield preserveMask)) _func)(preserveMask);
}

GLAPI void APIENTRY glEndTransformFeedback(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[672];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glEndTransformFeedbackEXT(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[673];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glEndTransformFeedbackNV(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[674];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glEndVertexShaderEXT(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[675];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glEndVideoCaptureNV(GLuint video_capture_slot)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[676];
   ((void (APIENTRY *)(GLuint video_capture_slot)) _func)(video_capture_slot);
}

GLAPI void APIENTRY glEvalCoord1d(GLdouble u)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[677];
   ((void (APIENTRY *)(GLdouble u)) _func)(u);
}

GLAPI void APIENTRY glEvalCoord1dv(const GLdouble *u)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[678];
   ((void (APIENTRY *)(const GLdouble *u)) _func)(u);
}

GLAPI void APIENTRY glEvalCoord1f(GLfloat u)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[679];
   ((void (APIENTRY *)(GLfloat u)) _func)(u);
}

GLAPI void APIENTRY glEvalCoord1fv(const GLfloat *u)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[680];
   ((void (APIENTRY *)(const GLfloat *u)) _func)(u);
}

GLAPI void APIENTRY glEvalCoord1xOES(GLfixed u)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[681];
   ((void (APIENTRY *)(GLfixed u)) _func)(u);
}

GLAPI void APIENTRY glEvalCoord1xvOES(const GLfixed *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[682];
   ((void (APIENTRY *)(const GLfixed *coords)) _func)(coords);
}

GLAPI void APIENTRY glEvalCoord2d(GLdouble u, GLdouble v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[683];
   ((void (APIENTRY *)(GLdouble u, GLdouble v)) _func)(u, v);
}

GLAPI void APIENTRY glEvalCoord2dv(const GLdouble *u)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[684];
   ((void (APIENTRY *)(const GLdouble *u)) _func)(u);
}

GLAPI void APIENTRY glEvalCoord2f(GLfloat u, GLfloat v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[685];
   ((void (APIENTRY *)(GLfloat u, GLfloat v)) _func)(u, v);
}

GLAPI void APIENTRY glEvalCoord2fv(const GLfloat *u)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[686];
   ((void (APIENTRY *)(const GLfloat *u)) _func)(u);
}

GLAPI void APIENTRY glEvalCoord2xOES(GLfixed u, GLfixed v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[687];
   ((void (APIENTRY *)(GLfixed u, GLfixed v)) _func)(u, v);
}

GLAPI void APIENTRY glEvalCoord2xvOES(const GLfixed *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[688];
   ((void (APIENTRY *)(const GLfixed *coords)) _func)(coords);
}

GLAPI void APIENTRY glEvalMapsNV(GLenum target, GLenum mode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[689];
   ((void (APIENTRY *)(GLenum target, GLenum mode)) _func)(target, mode);
}

GLAPI void APIENTRY glEvalMesh1(GLenum mode, GLint i1, GLint i2)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[690];
   ((void (APIENTRY *)(GLenum mode, GLint i1, GLint i2)) _func)(mode, i1, i2);
}

GLAPI void APIENTRY glEvalMesh2(GLenum mode, GLint i1, GLint i2, GLint j1, GLint j2)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[691];
   ((void (APIENTRY *)(GLenum mode, GLint i1, GLint i2, GLint j1, GLint j2)) _func)(mode, i1, i2, j1, j2);
}

GLAPI void APIENTRY glEvalPoint1(GLint i)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[692];
   ((void (APIENTRY *)(GLint i)) _func)(i);
}

GLAPI void APIENTRY glEvalPoint2(GLint i, GLint j)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[693];
   ((void (APIENTRY *)(GLint i, GLint j)) _func)(i, j);
}

GLAPI void APIENTRY glEvaluateDepthValuesARB(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[694];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glExecuteProgramNV(GLenum target, GLuint id, const GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[695];
   ((void (APIENTRY *)(GLenum target, GLuint id, const GLfloat *params)) _func)(target, id, params);
}

GLAPI void APIENTRY glExtGetBufferPointervQCOM(GLenum target, void **params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[696];
   ((void (APIENTRY *)(GLenum target, void **params)) _func)(target, params);
}

GLAPI void APIENTRY glExtGetBuffersQCOM(GLuint *buffers, GLint maxBuffers, GLint *numBuffers)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[697];
   ((void (APIENTRY *)(GLuint *buffers, GLint maxBuffers, GLint *numBuffers)) _func)(buffers, maxBuffers, numBuffers);
}

GLAPI void APIENTRY glExtGetFramebuffersQCOM(GLuint *framebuffers, GLint maxFramebuffers, GLint *numFramebuffers)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[698];
   ((void (APIENTRY *)(GLuint *framebuffers, GLint maxFramebuffers, GLint *numFramebuffers)) _func)(framebuffers, maxFramebuffers, numFramebuffers);
}

GLAPI void APIENTRY glExtGetProgramBinarySourceQCOM(GLuint program, GLenum shadertype, GLchar *source, GLint *length)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[699];
   ((void (APIENTRY *)(GLuint program, GLenum shadertype, GLchar *source, GLint *length)) _func)(program, shadertype, source, length);
}

GLAPI void APIENTRY glExtGetProgramsQCOM(GLuint *programs, GLint maxPrograms, GLint *numPrograms)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[700];
   ((void (APIENTRY *)(GLuint *programs, GLint maxPrograms, GLint *numPrograms)) _func)(programs, maxPrograms, numPrograms);
}

GLAPI void APIENTRY glExtGetRenderbuffersQCOM(GLuint *renderbuffers, GLint maxRenderbuffers, GLint *numRenderbuffers)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[701];
   ((void (APIENTRY *)(GLuint *renderbuffers, GLint maxRenderbuffers, GLint *numRenderbuffers)) _func)(renderbuffers, maxRenderbuffers, numRenderbuffers);
}

GLAPI void APIENTRY glExtGetShadersQCOM(GLuint *shaders, GLint maxShaders, GLint *numShaders)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[702];
   ((void (APIENTRY *)(GLuint *shaders, GLint maxShaders, GLint *numShaders)) _func)(shaders, maxShaders, numShaders);
}

GLAPI void APIENTRY glExtGetTexLevelParameterivQCOM(GLuint texture, GLenum face, GLint level, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[703];
   ((void (APIENTRY *)(GLuint texture, GLenum face, GLint level, GLenum pname, GLint *params)) _func)(texture, face, level, pname, params);
}

GLAPI void APIENTRY glExtGetTexSubImageQCOM(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, void *texels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[704];
   ((void (APIENTRY *)(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, void *texels)) _func)(target, level, xoffset, yoffset, zoffset, width, height, depth, format, type, texels);
}

GLAPI void APIENTRY glExtGetTexturesQCOM(GLuint *textures, GLint maxTextures, GLint *numTextures)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[705];
   ((void (APIENTRY *)(GLuint *textures, GLint maxTextures, GLint *numTextures)) _func)(textures, maxTextures, numTextures);
}

GLAPI GLboolean APIENTRY glExtIsProgramBinaryQCOM(GLuint program)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[706];
   return ((GLboolean (APIENTRY *)(GLuint program)) _func)(program);
}

GLAPI void APIENTRY glExtTexObjectStateOverrideiQCOM(GLenum target, GLenum pname, GLint param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[707];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLint param)) _func)(target, pname, param);
}

GLAPI void APIENTRY glExtractComponentEXT(GLuint res, GLuint src, GLuint num)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[708];
   ((void (APIENTRY *)(GLuint res, GLuint src, GLuint num)) _func)(res, src, num);
}

GLAPI void APIENTRY glFeedbackBuffer(GLsizei size, GLenum type, GLfloat *buffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[710];
   ((void (APIENTRY *)(GLsizei size, GLenum type, GLfloat *buffer)) _func)(size, type, buffer);
}

GLAPI void APIENTRY glFeedbackBufferxOES(GLsizei n, GLenum type, const GLfixed *buffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[711];
   ((void (APIENTRY *)(GLsizei n, GLenum type, const GLfixed *buffer)) _func)(n, type, buffer);
}

GLAPI GLsync APIENTRY glFenceSync(GLenum condition, GLbitfield flags)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[712];
   return ((GLsync (APIENTRY *)(GLenum condition, GLbitfield flags)) _func)(condition, flags);
}

GLAPI GLsync APIENTRY glFenceSyncAPPLE(GLenum condition, GLbitfield flags)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[713];
   return ((GLsync (APIENTRY *)(GLenum condition, GLbitfield flags)) _func)(condition, flags);
}

GLAPI void APIENTRY glFenceValueuiNVX(GLsync sync, GLenum condition, GLbitfield flags, GLuint value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[714];
   ((void (APIENTRY *)(GLsync sync, GLenum condition, GLbitfield flags, GLuint value)) _func)(sync, condition, flags, value);
}

GLAPI void APIENTRY glFinalCombinerInputNV(GLenum variable, GLenum input, GLenum mapping, GLenum componentUsage)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[715];
   ((void (APIENTRY *)(GLenum variable, GLenum input, GLenum mapping, GLenum componentUsage)) _func)(variable, input, mapping, componentUsage);
}

GLAPI void APIENTRY glFinish(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[716];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI GLint APIENTRY glFinishAsyncSGIX(GLuint *markerp)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[717];
   return ((GLint (APIENTRY *)(GLuint *markerp)) _func)(markerp);
}

GLAPI void APIENTRY glFinishFenceAPPLE(GLuint fence)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[718];
   ((void (APIENTRY *)(GLuint fence)) _func)(fence);
}

GLAPI void APIENTRY glFinishFenceNV(GLuint fence)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[719];
   ((void (APIENTRY *)(GLuint fence)) _func)(fence);
}

GLAPI void APIENTRY glFinishObjectAPPLE(GLenum object, GLint name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[720];
   ((void (APIENTRY *)(GLenum object, GLint name)) _func)(object, name);
}

GLAPI void APIENTRY glFinishTextureSUNX(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[721];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glFlush(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[722];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glFlushMappedBufferRange(GLenum target, GLintptr offset, GLsizeiptr length)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[723];
   ((void (APIENTRY *)(GLenum target, GLintptr offset, GLsizeiptr length)) _func)(target, offset, length);
}

GLAPI void APIENTRY glFlushMappedBufferRangeAPPLE(GLenum target, GLintptr offset, GLsizeiptr size)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[724];
   ((void (APIENTRY *)(GLenum target, GLintptr offset, GLsizeiptr size)) _func)(target, offset, size);
}

GLAPI void APIENTRY glFlushMappedBufferRangeEXT(GLenum target, GLintptr offset, GLsizeiptr length)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[725];
   ((void (APIENTRY *)(GLenum target, GLintptr offset, GLsizeiptr length)) _func)(target, offset, length);
}

GLAPI void APIENTRY glFlushMappedNamedBufferRange(GLuint buffer, GLintptr offset, GLsizeiptr length)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[726];
   ((void (APIENTRY *)(GLuint buffer, GLintptr offset, GLsizeiptr length)) _func)(buffer, offset, length);
}

GLAPI void APIENTRY glFlushMappedNamedBufferRangeEXT(GLuint buffer, GLintptr offset, GLsizeiptr length)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[727];
   ((void (APIENTRY *)(GLuint buffer, GLintptr offset, GLsizeiptr length)) _func)(buffer, offset, length);
}

GLAPI void APIENTRY glFlushPixelDataRangeNV(GLenum target)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[728];
   ((void (APIENTRY *)(GLenum target)) _func)(target);
}

GLAPI void APIENTRY glFlushRasterSGIX(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[729];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glFlushStaticDataIBM(GLenum target)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[730];
   ((void (APIENTRY *)(GLenum target)) _func)(target);
}

GLAPI void APIENTRY glFlushVertexArrayRangeAPPLE(GLsizei length, void *pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[731];
   ((void (APIENTRY *)(GLsizei length, void *pointer)) _func)(length, pointer);
}

GLAPI void APIENTRY glFlushVertexArrayRangeNV(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[732];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glFogCoordFormatNV(GLenum type, GLsizei stride)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[733];
   ((void (APIENTRY *)(GLenum type, GLsizei stride)) _func)(type, stride);
}

GLAPI void APIENTRY glFogCoordPointer(GLenum type, GLsizei stride, const void *pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[734];
   ((void (APIENTRY *)(GLenum type, GLsizei stride, const void *pointer)) _func)(type, stride, pointer);
}

GLAPI void APIENTRY glFogCoordPointerEXT(GLenum type, GLsizei stride, const void *pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[735];
   ((void (APIENTRY *)(GLenum type, GLsizei stride, const void *pointer)) _func)(type, stride, pointer);
}

GLAPI void APIENTRY glFogCoordPointerListIBM(GLenum type, GLint stride, const void **pointer, GLint ptrstride)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[736];
   ((void (APIENTRY *)(GLenum type, GLint stride, const void **pointer, GLint ptrstride)) _func)(type, stride, pointer, ptrstride);
}

GLAPI void APIENTRY glFogCoordd(GLdouble coord)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[737];
   ((void (APIENTRY *)(GLdouble coord)) _func)(coord);
}

GLAPI void APIENTRY glFogCoorddEXT(GLdouble coord)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[738];
   ((void (APIENTRY *)(GLdouble coord)) _func)(coord);
}

GLAPI void APIENTRY glFogCoorddv(const GLdouble *coord)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[739];
   ((void (APIENTRY *)(const GLdouble *coord)) _func)(coord);
}

GLAPI void APIENTRY glFogCoorddvEXT(const GLdouble *coord)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[740];
   ((void (APIENTRY *)(const GLdouble *coord)) _func)(coord);
}

GLAPI void APIENTRY glFogCoordf(GLfloat coord)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[741];
   ((void (APIENTRY *)(GLfloat coord)) _func)(coord);
}

GLAPI void APIENTRY glFogCoordfEXT(GLfloat coord)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[742];
   ((void (APIENTRY *)(GLfloat coord)) _func)(coord);
}

GLAPI void APIENTRY glFogCoordfv(const GLfloat *coord)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[743];
   ((void (APIENTRY *)(const GLfloat *coord)) _func)(coord);
}

GLAPI void APIENTRY glFogCoordfvEXT(const GLfloat *coord)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[744];
   ((void (APIENTRY *)(const GLfloat *coord)) _func)(coord);
}

GLAPI void APIENTRY glFogCoordhNV(GLhalf fog)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[745];
   ((void (APIENTRY *)(GLhalf fog)) _func)(fog);
}

GLAPI void APIENTRY glFogCoordhvNV(const GLhalf *fog)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[746];
   ((void (APIENTRY *)(const GLhalf *fog)) _func)(fog);
}

GLAPI void APIENTRY glFogFuncSGIS(GLsizei n, const GLfloat *points)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[747];
   ((void (APIENTRY *)(GLsizei n, const GLfloat *points)) _func)(n, points);
}

GLAPI void APIENTRY glFogf(GLenum pname, GLfloat param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[748];
   ((void (APIENTRY *)(GLenum pname, GLfloat param)) _func)(pname, param);
}

GLAPI void APIENTRY glFogfv(GLenum pname, const GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[749];
   ((void (APIENTRY *)(GLenum pname, const GLfloat *params)) _func)(pname, params);
}

GLAPI void APIENTRY glFogi(GLenum pname, GLint param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[750];
   ((void (APIENTRY *)(GLenum pname, GLint param)) _func)(pname, param);
}

GLAPI void APIENTRY glFogiv(GLenum pname, const GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[751];
   ((void (APIENTRY *)(GLenum pname, const GLint *params)) _func)(pname, params);
}

GLAPI void APIENTRY glFogx(GLenum pname, GLfixed param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[752];
   ((void (APIENTRY *)(GLenum pname, GLfixed param)) _func)(pname, param);
}

GLAPI void APIENTRY glFogxOES(GLenum pname, GLfixed param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[753];
   ((void (APIENTRY *)(GLenum pname, GLfixed param)) _func)(pname, param);
}

GLAPI void APIENTRY glFogxv(GLenum pname, const GLfixed *param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[754];
   ((void (APIENTRY *)(GLenum pname, const GLfixed *param)) _func)(pname, param);
}

GLAPI void APIENTRY glFogxvOES(GLenum pname, const GLfixed *param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[755];
   ((void (APIENTRY *)(GLenum pname, const GLfixed *param)) _func)(pname, param);
}

GLAPI void APIENTRY glFragmentColorMaterialSGIX(GLenum face, GLenum mode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[756];
   ((void (APIENTRY *)(GLenum face, GLenum mode)) _func)(face, mode);
}

GLAPI void APIENTRY glFragmentCoverageColorNV(GLuint color)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[757];
   ((void (APIENTRY *)(GLuint color)) _func)(color);
}

GLAPI void APIENTRY glFragmentLightModelfSGIX(GLenum pname, GLfloat param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[758];
   ((void (APIENTRY *)(GLenum pname, GLfloat param)) _func)(pname, param);
}

GLAPI void APIENTRY glFragmentLightModelfvSGIX(GLenum pname, const GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[759];
   ((void (APIENTRY *)(GLenum pname, const GLfloat *params)) _func)(pname, params);
}

GLAPI void APIENTRY glFragmentLightModeliSGIX(GLenum pname, GLint param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[760];
   ((void (APIENTRY *)(GLenum pname, GLint param)) _func)(pname, param);
}

GLAPI void APIENTRY glFragmentLightModelivSGIX(GLenum pname, const GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[761];
   ((void (APIENTRY *)(GLenum pname, const GLint *params)) _func)(pname, params);
}

GLAPI void APIENTRY glFragmentLightfSGIX(GLenum light, GLenum pname, GLfloat param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[762];
   ((void (APIENTRY *)(GLenum light, GLenum pname, GLfloat param)) _func)(light, pname, param);
}

GLAPI void APIENTRY glFragmentLightfvSGIX(GLenum light, GLenum pname, const GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[763];
   ((void (APIENTRY *)(GLenum light, GLenum pname, const GLfloat *params)) _func)(light, pname, params);
}

GLAPI void APIENTRY glFragmentLightiSGIX(GLenum light, GLenum pname, GLint param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[764];
   ((void (APIENTRY *)(GLenum light, GLenum pname, GLint param)) _func)(light, pname, param);
}

GLAPI void APIENTRY glFragmentLightivSGIX(GLenum light, GLenum pname, const GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[765];
   ((void (APIENTRY *)(GLenum light, GLenum pname, const GLint *params)) _func)(light, pname, params);
}

GLAPI void APIENTRY glFragmentMaterialfSGIX(GLenum face, GLenum pname, GLfloat param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[766];
   ((void (APIENTRY *)(GLenum face, GLenum pname, GLfloat param)) _func)(face, pname, param);
}

GLAPI void APIENTRY glFragmentMaterialfvSGIX(GLenum face, GLenum pname, const GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[767];
   ((void (APIENTRY *)(GLenum face, GLenum pname, const GLfloat *params)) _func)(face, pname, params);
}

GLAPI void APIENTRY glFragmentMaterialiSGIX(GLenum face, GLenum pname, GLint param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[768];
   ((void (APIENTRY *)(GLenum face, GLenum pname, GLint param)) _func)(face, pname, param);
}

GLAPI void APIENTRY glFragmentMaterialivSGIX(GLenum face, GLenum pname, const GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[769];
   ((void (APIENTRY *)(GLenum face, GLenum pname, const GLint *params)) _func)(face, pname, params);
}

GLAPI void APIENTRY glFrameTerminatorGREMEDY(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[770];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glFrameZoomSGIX(GLint factor)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[771];
   ((void (APIENTRY *)(GLint factor)) _func)(factor);
}

GLAPI void APIENTRY glFramebufferDrawBufferEXT(GLuint framebuffer, GLenum mode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[772];
   ((void (APIENTRY *)(GLuint framebuffer, GLenum mode)) _func)(framebuffer, mode);
}

GLAPI void APIENTRY glFramebufferDrawBuffersEXT(GLuint framebuffer, GLsizei n, const GLenum *bufs)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[773];
   ((void (APIENTRY *)(GLuint framebuffer, GLsizei n, const GLenum *bufs)) _func)(framebuffer, n, bufs);
}

GLAPI void APIENTRY glFramebufferFetchBarrierEXT(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[774];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glFramebufferFetchBarrierQCOM(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[775];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glFramebufferFoveationConfigQCOM(GLuint framebuffer, GLuint numLayers, GLuint focalPointsPerLayer, GLuint requestedFeatures, GLuint *providedFeatures)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[776];
   ((void (APIENTRY *)(GLuint framebuffer, GLuint numLayers, GLuint focalPointsPerLayer, GLuint requestedFeatures, GLuint *providedFeatures)) _func)(framebuffer, numLayers, focalPointsPerLayer, requestedFeatures, providedFeatures);
}

GLAPI void APIENTRY glFramebufferFoveationParametersQCOM(GLuint framebuffer, GLuint layer, GLuint focalPoint, GLfloat focalX, GLfloat focalY, GLfloat gainX, GLfloat gainY, GLfloat foveaArea)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[777];
   ((void (APIENTRY *)(GLuint framebuffer, GLuint layer, GLuint focalPoint, GLfloat focalX, GLfloat focalY, GLfloat gainX, GLfloat gainY, GLfloat foveaArea)) _func)(framebuffer, layer, focalPoint, focalX, focalY, gainX, gainY, foveaArea);
}

GLAPI void APIENTRY glFramebufferParameteri(GLenum target, GLenum pname, GLint param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[778];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLint param)) _func)(target, pname, param);
}

GLAPI void APIENTRY glFramebufferParameteriMESA(GLenum target, GLenum pname, GLint param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[779];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLint param)) _func)(target, pname, param);
}

GLAPI void APIENTRY glFramebufferPixelLocalStorageSizeEXT(GLuint target, GLsizei size)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[780];
   ((void (APIENTRY *)(GLuint target, GLsizei size)) _func)(target, size);
}

GLAPI void APIENTRY glFramebufferReadBufferEXT(GLuint framebuffer, GLenum mode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[781];
   ((void (APIENTRY *)(GLuint framebuffer, GLenum mode)) _func)(framebuffer, mode);
}

GLAPI void APIENTRY glFramebufferRenderbuffer(GLenum target, GLenum attachment, GLenum renderbuffertarget, GLuint renderbuffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[782];
   ((void (APIENTRY *)(GLenum target, GLenum attachment, GLenum renderbuffertarget, GLuint renderbuffer)) _func)(target, attachment, renderbuffertarget, renderbuffer);
}

GLAPI void APIENTRY glFramebufferRenderbufferEXT(GLenum target, GLenum attachment, GLenum renderbuffertarget, GLuint renderbuffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[783];
   ((void (APIENTRY *)(GLenum target, GLenum attachment, GLenum renderbuffertarget, GLuint renderbuffer)) _func)(target, attachment, renderbuffertarget, renderbuffer);
}

GLAPI void APIENTRY glFramebufferRenderbufferOES(GLenum target, GLenum attachment, GLenum renderbuffertarget, GLuint renderbuffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[784];
   ((void (APIENTRY *)(GLenum target, GLenum attachment, GLenum renderbuffertarget, GLuint renderbuffer)) _func)(target, attachment, renderbuffertarget, renderbuffer);
}

GLAPI void APIENTRY glFramebufferSampleLocationsfvARB(GLenum target, GLuint start, GLsizei count, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[785];
   ((void (APIENTRY *)(GLenum target, GLuint start, GLsizei count, const GLfloat *v)) _func)(target, start, count, v);
}

GLAPI void APIENTRY glFramebufferSampleLocationsfvNV(GLenum target, GLuint start, GLsizei count, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[786];
   ((void (APIENTRY *)(GLenum target, GLuint start, GLsizei count, const GLfloat *v)) _func)(target, start, count, v);
}

GLAPI void APIENTRY glFramebufferSamplePositionsfvAMD(GLenum target, GLuint numsamples, GLuint pixelindex, const GLfloat *values)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[787];
   ((void (APIENTRY *)(GLenum target, GLuint numsamples, GLuint pixelindex, const GLfloat *values)) _func)(target, numsamples, pixelindex, values);
}

GLAPI void APIENTRY glFramebufferTexture(GLenum target, GLenum attachment, GLuint texture, GLint level)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[789];
   ((void (APIENTRY *)(GLenum target, GLenum attachment, GLuint texture, GLint level)) _func)(target, attachment, texture, level);
}

GLAPI void APIENTRY glFramebufferTexture1D(GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[790];
   ((void (APIENTRY *)(GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level)) _func)(target, attachment, textarget, texture, level);
}

GLAPI void APIENTRY glFramebufferTexture1DEXT(GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[791];
   ((void (APIENTRY *)(GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level)) _func)(target, attachment, textarget, texture, level);
}

GLAPI void APIENTRY glFramebufferTexture2D(GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[792];
   ((void (APIENTRY *)(GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level)) _func)(target, attachment, textarget, texture, level);
}

GLAPI void APIENTRY glFramebufferTexture2DDownsampleIMG(GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level, GLint xscale, GLint yscale)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[793];
   ((void (APIENTRY *)(GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level, GLint xscale, GLint yscale)) _func)(target, attachment, textarget, texture, level, xscale, yscale);
}

GLAPI void APIENTRY glFramebufferTexture2DEXT(GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[794];
   ((void (APIENTRY *)(GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level)) _func)(target, attachment, textarget, texture, level);
}

GLAPI void APIENTRY glFramebufferTexture2DMultisampleEXT(GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level, GLsizei samples)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[795];
   ((void (APIENTRY *)(GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level, GLsizei samples)) _func)(target, attachment, textarget, texture, level, samples);
}

GLAPI void APIENTRY glFramebufferTexture2DMultisampleIMG(GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level, GLsizei samples)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[796];
   ((void (APIENTRY *)(GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level, GLsizei samples)) _func)(target, attachment, textarget, texture, level, samples);
}

GLAPI void APIENTRY glFramebufferTexture2DOES(GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[797];
   ((void (APIENTRY *)(GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level)) _func)(target, attachment, textarget, texture, level);
}

GLAPI void APIENTRY glFramebufferTexture3D(GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level, GLint zoffset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[798];
   ((void (APIENTRY *)(GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level, GLint zoffset)) _func)(target, attachment, textarget, texture, level, zoffset);
}

GLAPI void APIENTRY glFramebufferTexture3DEXT(GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level, GLint zoffset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[799];
   ((void (APIENTRY *)(GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level, GLint zoffset)) _func)(target, attachment, textarget, texture, level, zoffset);
}

GLAPI void APIENTRY glFramebufferTexture3DOES(GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level, GLint zoffset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[800];
   ((void (APIENTRY *)(GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level, GLint zoffset)) _func)(target, attachment, textarget, texture, level, zoffset);
}

GLAPI void APIENTRY glFramebufferTextureARB(GLenum target, GLenum attachment, GLuint texture, GLint level)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[801];
   ((void (APIENTRY *)(GLenum target, GLenum attachment, GLuint texture, GLint level)) _func)(target, attachment, texture, level);
}

GLAPI void APIENTRY glFramebufferTextureEXT(GLenum target, GLenum attachment, GLuint texture, GLint level)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[802];
   ((void (APIENTRY *)(GLenum target, GLenum attachment, GLuint texture, GLint level)) _func)(target, attachment, texture, level);
}

GLAPI void APIENTRY glFramebufferTextureFaceARB(GLenum target, GLenum attachment, GLuint texture, GLint level, GLenum face)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[803];
   ((void (APIENTRY *)(GLenum target, GLenum attachment, GLuint texture, GLint level, GLenum face)) _func)(target, attachment, texture, level, face);
}

GLAPI void APIENTRY glFramebufferTextureFaceEXT(GLenum target, GLenum attachment, GLuint texture, GLint level, GLenum face)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[804];
   ((void (APIENTRY *)(GLenum target, GLenum attachment, GLuint texture, GLint level, GLenum face)) _func)(target, attachment, texture, level, face);
}

GLAPI void APIENTRY glFramebufferTextureLayer(GLenum target, GLenum attachment, GLuint texture, GLint level, GLint layer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[805];
   ((void (APIENTRY *)(GLenum target, GLenum attachment, GLuint texture, GLint level, GLint layer)) _func)(target, attachment, texture, level, layer);
}

GLAPI void APIENTRY glFramebufferTextureLayerARB(GLenum target, GLenum attachment, GLuint texture, GLint level, GLint layer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[806];
   ((void (APIENTRY *)(GLenum target, GLenum attachment, GLuint texture, GLint level, GLint layer)) _func)(target, attachment, texture, level, layer);
}

GLAPI void APIENTRY glFramebufferTextureLayerDownsampleIMG(GLenum target, GLenum attachment, GLuint texture, GLint level, GLint layer, GLint xscale, GLint yscale)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[807];
   ((void (APIENTRY *)(GLenum target, GLenum attachment, GLuint texture, GLint level, GLint layer, GLint xscale, GLint yscale)) _func)(target, attachment, texture, level, layer, xscale, yscale);
}

GLAPI void APIENTRY glFramebufferTextureLayerEXT(GLenum target, GLenum attachment, GLuint texture, GLint level, GLint layer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[808];
   ((void (APIENTRY *)(GLenum target, GLenum attachment, GLuint texture, GLint level, GLint layer)) _func)(target, attachment, texture, level, layer);
}

GLAPI void APIENTRY glFramebufferTextureLayerNV(GLenum target, GLenum attachment, GLuint texture, GLint level, GLint layer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[809];
   ((void (APIENTRY *)(GLenum target, GLenum attachment, GLuint texture, GLint level, GLint layer)) _func)(target, attachment, texture, level, layer);
}

GLAPI void APIENTRY glFramebufferTextureMultisampleMultiviewOVR(GLenum target, GLenum attachment, GLuint texture, GLint level, GLsizei samples, GLint baseViewIndex, GLsizei numViews)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[810];
   ((void (APIENTRY *)(GLenum target, GLenum attachment, GLuint texture, GLint level, GLsizei samples, GLint baseViewIndex, GLsizei numViews)) _func)(target, attachment, texture, level, samples, baseViewIndex, numViews);
}

GLAPI void APIENTRY glFramebufferTextureMultiviewOVR(GLenum target, GLenum attachment, GLuint texture, GLint level, GLint baseViewIndex, GLsizei numViews)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[811];
   ((void (APIENTRY *)(GLenum target, GLenum attachment, GLuint texture, GLint level, GLint baseViewIndex, GLsizei numViews)) _func)(target, attachment, texture, level, baseViewIndex, numViews);
}

GLAPI void APIENTRY glFramebufferTextureOES(GLenum target, GLenum attachment, GLuint texture, GLint level)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[812];
   ((void (APIENTRY *)(GLenum target, GLenum attachment, GLuint texture, GLint level)) _func)(target, attachment, texture, level);
}

GLAPI void APIENTRY glFreeObjectBufferATI(GLuint buffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[813];
   ((void (APIENTRY *)(GLuint buffer)) _func)(buffer);
}

GLAPI void APIENTRY glFrontFace(GLenum mode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[814];
   ((void (APIENTRY *)(GLenum mode)) _func)(mode);
}

GLAPI void APIENTRY glFrustum(GLdouble left, GLdouble right, GLdouble bottom, GLdouble top, GLdouble zNear, GLdouble zFar)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[815];
   ((void (APIENTRY *)(GLdouble left, GLdouble right, GLdouble bottom, GLdouble top, GLdouble zNear, GLdouble zFar)) _func)(left, right, bottom, top, zNear, zFar);
}

GLAPI void APIENTRY glFrustumf(GLfloat l, GLfloat r, GLfloat b, GLfloat t, GLfloat n, GLfloat f)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[816];
   ((void (APIENTRY *)(GLfloat l, GLfloat r, GLfloat b, GLfloat t, GLfloat n, GLfloat f)) _func)(l, r, b, t, n, f);
}

GLAPI void APIENTRY glFrustumfOES(GLfloat l, GLfloat r, GLfloat b, GLfloat t, GLfloat n, GLfloat f)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[817];
   ((void (APIENTRY *)(GLfloat l, GLfloat r, GLfloat b, GLfloat t, GLfloat n, GLfloat f)) _func)(l, r, b, t, n, f);
}

GLAPI void APIENTRY glFrustumx(GLfixed l, GLfixed r, GLfixed b, GLfixed t, GLfixed n, GLfixed f)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[818];
   ((void (APIENTRY *)(GLfixed l, GLfixed r, GLfixed b, GLfixed t, GLfixed n, GLfixed f)) _func)(l, r, b, t, n, f);
}

GLAPI void APIENTRY glFrustumxOES(GLfixed l, GLfixed r, GLfixed b, GLfixed t, GLfixed n, GLfixed f)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[819];
   ((void (APIENTRY *)(GLfixed l, GLfixed r, GLfixed b, GLfixed t, GLfixed n, GLfixed f)) _func)(l, r, b, t, n, f);
}

GLAPI GLuint APIENTRY glGenAsyncMarkersSGIX(GLsizei range)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[820];
   return ((GLuint (APIENTRY *)(GLsizei range)) _func)(range);
}

GLAPI void APIENTRY glGenBuffers(GLsizei n, GLuint *buffers)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[821];
   ((void (APIENTRY *)(GLsizei n, GLuint *buffers)) _func)(n, buffers);
}

GLAPI void APIENTRY glGenBuffersARB(GLsizei n, GLuint *buffers)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[822];
   ((void (APIENTRY *)(GLsizei n, GLuint *buffers)) _func)(n, buffers);
}

GLAPI void APIENTRY glGenFencesAPPLE(GLsizei n, GLuint *fences)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[823];
   ((void (APIENTRY *)(GLsizei n, GLuint *fences)) _func)(n, fences);
}

GLAPI void APIENTRY glGenFencesNV(GLsizei n, GLuint *fences)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[824];
   ((void (APIENTRY *)(GLsizei n, GLuint *fences)) _func)(n, fences);
}

GLAPI GLuint APIENTRY glGenFragmentShadersATI(GLuint range)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[825];
   return ((GLuint (APIENTRY *)(GLuint range)) _func)(range);
}

GLAPI void APIENTRY glGenFramebuffers(GLsizei n, GLuint *framebuffers)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[826];
   ((void (APIENTRY *)(GLsizei n, GLuint *framebuffers)) _func)(n, framebuffers);
}

GLAPI void APIENTRY glGenFramebuffersEXT(GLsizei n, GLuint *framebuffers)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[827];
   ((void (APIENTRY *)(GLsizei n, GLuint *framebuffers)) _func)(n, framebuffers);
}

GLAPI void APIENTRY glGenFramebuffersOES(GLsizei n, GLuint *framebuffers)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[828];
   ((void (APIENTRY *)(GLsizei n, GLuint *framebuffers)) _func)(n, framebuffers);
}

GLAPI GLuint APIENTRY glGenLists(GLsizei range)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[829];
   return ((GLuint (APIENTRY *)(GLsizei range)) _func)(range);
}

GLAPI void APIENTRY glGenNamesAMD(GLenum identifier, GLuint num, GLuint *names)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[830];
   ((void (APIENTRY *)(GLenum identifier, GLuint num, GLuint *names)) _func)(identifier, num, names);
}

GLAPI void APIENTRY glGenOcclusionQueriesNV(GLsizei n, GLuint *ids)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[831];
   ((void (APIENTRY *)(GLsizei n, GLuint *ids)) _func)(n, ids);
}

GLAPI GLuint APIENTRY glGenPathsNV(GLsizei range)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[832];
   return ((GLuint (APIENTRY *)(GLsizei range)) _func)(range);
}

GLAPI void APIENTRY glGenPerfMonitorsAMD(GLsizei n, GLuint *monitors)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[833];
   ((void (APIENTRY *)(GLsizei n, GLuint *monitors)) _func)(n, monitors);
}

GLAPI void APIENTRY glGenProgramPipelines(GLsizei n, GLuint *pipelines)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[834];
   ((void (APIENTRY *)(GLsizei n, GLuint *pipelines)) _func)(n, pipelines);
}

GLAPI void APIENTRY glGenProgramPipelinesEXT(GLsizei n, GLuint *pipelines)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[835];
   ((void (APIENTRY *)(GLsizei n, GLuint *pipelines)) _func)(n, pipelines);
}

GLAPI void APIENTRY glGenProgramsARB(GLsizei n, GLuint *programs)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[836];
   ((void (APIENTRY *)(GLsizei n, GLuint *programs)) _func)(n, programs);
}

GLAPI void APIENTRY glGenProgramsNV(GLsizei n, GLuint *programs)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[837];
   ((void (APIENTRY *)(GLsizei n, GLuint *programs)) _func)(n, programs);
}

GLAPI void APIENTRY glGenQueries(GLsizei n, GLuint *ids)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[838];
   ((void (APIENTRY *)(GLsizei n, GLuint *ids)) _func)(n, ids);
}

GLAPI void APIENTRY glGenQueriesARB(GLsizei n, GLuint *ids)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[839];
   ((void (APIENTRY *)(GLsizei n, GLuint *ids)) _func)(n, ids);
}

GLAPI void APIENTRY glGenQueriesEXT(GLsizei n, GLuint *ids)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[840];
   ((void (APIENTRY *)(GLsizei n, GLuint *ids)) _func)(n, ids);
}

GLAPI void APIENTRY glGenQueryResourceTagNV(GLsizei n, GLint *tagIds)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[841];
   ((void (APIENTRY *)(GLsizei n, GLint *tagIds)) _func)(n, tagIds);
}

GLAPI void APIENTRY glGenRenderbuffers(GLsizei n, GLuint *renderbuffers)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[842];
   ((void (APIENTRY *)(GLsizei n, GLuint *renderbuffers)) _func)(n, renderbuffers);
}

GLAPI void APIENTRY glGenRenderbuffersEXT(GLsizei n, GLuint *renderbuffers)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[843];
   ((void (APIENTRY *)(GLsizei n, GLuint *renderbuffers)) _func)(n, renderbuffers);
}

GLAPI void APIENTRY glGenRenderbuffersOES(GLsizei n, GLuint *renderbuffers)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[844];
   ((void (APIENTRY *)(GLsizei n, GLuint *renderbuffers)) _func)(n, renderbuffers);
}

GLAPI void APIENTRY glGenSamplers(GLsizei count, GLuint *samplers)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[845];
   ((void (APIENTRY *)(GLsizei count, GLuint *samplers)) _func)(count, samplers);
}

GLAPI void APIENTRY glGenSemaphoresEXT(GLsizei n, GLuint *semaphores)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[846];
   ((void (APIENTRY *)(GLsizei n, GLuint *semaphores)) _func)(n, semaphores);
}

GLAPI GLuint APIENTRY glGenSymbolsEXT(GLenum datatype, GLenum storagetype, GLenum range, GLuint components)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[847];
   return ((GLuint (APIENTRY *)(GLenum datatype, GLenum storagetype, GLenum range, GLuint components)) _func)(datatype, storagetype, range, components);
}

GLAPI void APIENTRY glGenTextures(GLsizei n, GLuint *textures)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[848];
   ((void (APIENTRY *)(GLsizei n, GLuint *textures)) _func)(n, textures);
}

GLAPI void APIENTRY glGenTexturesEXT(GLsizei n, GLuint *textures)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[849];
   ((void (APIENTRY *)(GLsizei n, GLuint *textures)) _func)(n, textures);
}

GLAPI void APIENTRY glGenTransformFeedbacks(GLsizei n, GLuint *ids)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[850];
   ((void (APIENTRY *)(GLsizei n, GLuint *ids)) _func)(n, ids);
}

GLAPI void APIENTRY glGenTransformFeedbacksEXT(GLsizei n, GLuint *ids)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[851];
   ((void (APIENTRY *)(GLsizei n, GLuint *ids)) _func)(n, ids);
}

GLAPI void APIENTRY glGenTransformFeedbacksNV(GLsizei n, GLuint *ids)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[852];
   ((void (APIENTRY *)(GLsizei n, GLuint *ids)) _func)(n, ids);
}

GLAPI void APIENTRY glGenVertexArrays(GLsizei n, GLuint *arrays)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[853];
   ((void (APIENTRY *)(GLsizei n, GLuint *arrays)) _func)(n, arrays);
}

GLAPI void APIENTRY glGenVertexArraysAPPLE(GLsizei n, GLuint *arrays)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[854];
   ((void (APIENTRY *)(GLsizei n, GLuint *arrays)) _func)(n, arrays);
}

GLAPI void APIENTRY glGenVertexArraysOES(GLsizei n, GLuint *arrays)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[855];
   ((void (APIENTRY *)(GLsizei n, GLuint *arrays)) _func)(n, arrays);
}

GLAPI GLuint APIENTRY glGenVertexShadersEXT(GLuint range)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[856];
   return ((GLuint (APIENTRY *)(GLuint range)) _func)(range);
}

GLAPI void APIENTRY glGenerateMipmap(GLenum target)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[857];
   ((void (APIENTRY *)(GLenum target)) _func)(target);
}

GLAPI void APIENTRY glGenerateMipmapEXT(GLenum target)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[858];
   ((void (APIENTRY *)(GLenum target)) _func)(target);
}

GLAPI void APIENTRY glGenerateMipmapOES(GLenum target)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[859];
   ((void (APIENTRY *)(GLenum target)) _func)(target);
}

GLAPI void APIENTRY glGenerateMultiTexMipmapEXT(GLenum texunit, GLenum target)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[860];
   ((void (APIENTRY *)(GLenum texunit, GLenum target)) _func)(texunit, target);
}

GLAPI void APIENTRY glGenerateTextureMipmap(GLuint texture)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[861];
   ((void (APIENTRY *)(GLuint texture)) _func)(texture);
}

GLAPI void APIENTRY glGenerateTextureMipmapEXT(GLuint texture, GLenum target)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[862];
   ((void (APIENTRY *)(GLuint texture, GLenum target)) _func)(texture, target);
}

GLAPI void APIENTRY glGetActiveAtomicCounterBufferiv(GLuint program, GLuint bufferIndex, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[863];
   ((void (APIENTRY *)(GLuint program, GLuint bufferIndex, GLenum pname, GLint *params)) _func)(program, bufferIndex, pname, params);
}

GLAPI void APIENTRY glGetActiveAttrib(GLuint program, GLuint index, GLsizei bufSize, GLsizei *length, GLint *size, GLenum *type, GLchar *name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[864];
   ((void (APIENTRY *)(GLuint program, GLuint index, GLsizei bufSize, GLsizei *length, GLint *size, GLenum *type, GLchar *name)) _func)(program, index, bufSize, length, size, type, name);
}

GLAPI void APIENTRY glGetActiveAttribARB(GLhandleARB programObj, GLuint index, GLsizei maxLength, GLsizei *length, GLint *size, GLenum *type, GLcharARB *name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[865];
   ((void (APIENTRY *)(GLhandleARB programObj, GLuint index, GLsizei maxLength, GLsizei *length, GLint *size, GLenum *type, GLcharARB *name)) _func)(programObj, index, maxLength, length, size, type, name);
}

GLAPI void APIENTRY glGetActiveSubroutineName(GLuint program, GLenum shadertype, GLuint index, GLsizei bufSize, GLsizei *length, GLchar *name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[866];
   ((void (APIENTRY *)(GLuint program, GLenum shadertype, GLuint index, GLsizei bufSize, GLsizei *length, GLchar *name)) _func)(program, shadertype, index, bufSize, length, name);
}

GLAPI void APIENTRY glGetActiveSubroutineUniformName(GLuint program, GLenum shadertype, GLuint index, GLsizei bufSize, GLsizei *length, GLchar *name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[867];
   ((void (APIENTRY *)(GLuint program, GLenum shadertype, GLuint index, GLsizei bufSize, GLsizei *length, GLchar *name)) _func)(program, shadertype, index, bufSize, length, name);
}

GLAPI void APIENTRY glGetActiveSubroutineUniformiv(GLuint program, GLenum shadertype, GLuint index, GLenum pname, GLint *values)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[868];
   ((void (APIENTRY *)(GLuint program, GLenum shadertype, GLuint index, GLenum pname, GLint *values)) _func)(program, shadertype, index, pname, values);
}

GLAPI void APIENTRY glGetActiveUniform(GLuint program, GLuint index, GLsizei bufSize, GLsizei *length, GLint *size, GLenum *type, GLchar *name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[869];
   ((void (APIENTRY *)(GLuint program, GLuint index, GLsizei bufSize, GLsizei *length, GLint *size, GLenum *type, GLchar *name)) _func)(program, index, bufSize, length, size, type, name);
}

GLAPI void APIENTRY glGetActiveUniformARB(GLhandleARB programObj, GLuint index, GLsizei maxLength, GLsizei *length, GLint *size, GLenum *type, GLcharARB *name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[870];
   ((void (APIENTRY *)(GLhandleARB programObj, GLuint index, GLsizei maxLength, GLsizei *length, GLint *size, GLenum *type, GLcharARB *name)) _func)(programObj, index, maxLength, length, size, type, name);
}

GLAPI void APIENTRY glGetActiveUniformBlockName(GLuint program, GLuint uniformBlockIndex, GLsizei bufSize, GLsizei *length, GLchar *uniformBlockName)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[871];
   ((void (APIENTRY *)(GLuint program, GLuint uniformBlockIndex, GLsizei bufSize, GLsizei *length, GLchar *uniformBlockName)) _func)(program, uniformBlockIndex, bufSize, length, uniformBlockName);
}

GLAPI void APIENTRY glGetActiveUniformBlockiv(GLuint program, GLuint uniformBlockIndex, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[872];
   ((void (APIENTRY *)(GLuint program, GLuint uniformBlockIndex, GLenum pname, GLint *params)) _func)(program, uniformBlockIndex, pname, params);
}

GLAPI void APIENTRY glGetActiveUniformName(GLuint program, GLuint uniformIndex, GLsizei bufSize, GLsizei *length, GLchar *uniformName)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[873];
   ((void (APIENTRY *)(GLuint program, GLuint uniformIndex, GLsizei bufSize, GLsizei *length, GLchar *uniformName)) _func)(program, uniformIndex, bufSize, length, uniformName);
}

GLAPI void APIENTRY glGetActiveUniformsiv(GLuint program, GLsizei uniformCount, const GLuint *uniformIndices, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[874];
   ((void (APIENTRY *)(GLuint program, GLsizei uniformCount, const GLuint *uniformIndices, GLenum pname, GLint *params)) _func)(program, uniformCount, uniformIndices, pname, params);
}

GLAPI void APIENTRY glGetActiveVaryingNV(GLuint program, GLuint index, GLsizei bufSize, GLsizei *length, GLsizei *size, GLenum *type, GLchar *name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[875];
   ((void (APIENTRY *)(GLuint program, GLuint index, GLsizei bufSize, GLsizei *length, GLsizei *size, GLenum *type, GLchar *name)) _func)(program, index, bufSize, length, size, type, name);
}

GLAPI void APIENTRY glGetArrayObjectfvATI(GLenum array, GLenum pname, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[876];
   ((void (APIENTRY *)(GLenum array, GLenum pname, GLfloat *params)) _func)(array, pname, params);
}

GLAPI void APIENTRY glGetArrayObjectivATI(GLenum array, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[877];
   ((void (APIENTRY *)(GLenum array, GLenum pname, GLint *params)) _func)(array, pname, params);
}

GLAPI void APIENTRY glGetAttachedObjectsARB(GLhandleARB containerObj, GLsizei maxCount, GLsizei *count, GLhandleARB *obj)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[878];
   ((void (APIENTRY *)(GLhandleARB containerObj, GLsizei maxCount, GLsizei *count, GLhandleARB *obj)) _func)(containerObj, maxCount, count, obj);
}

GLAPI void APIENTRY glGetAttachedShaders(GLuint program, GLsizei maxCount, GLsizei *count, GLuint *shaders)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[879];
   ((void (APIENTRY *)(GLuint program, GLsizei maxCount, GLsizei *count, GLuint *shaders)) _func)(program, maxCount, count, shaders);
}

GLAPI GLint APIENTRY glGetAttribLocation(GLuint program, const GLchar *name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[880];
   return ((GLint (APIENTRY *)(GLuint program, const GLchar *name)) _func)(program, name);
}

GLAPI GLint APIENTRY glGetAttribLocationARB(GLhandleARB programObj, const GLcharARB *name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[881];
   return ((GLint (APIENTRY *)(GLhandleARB programObj, const GLcharARB *name)) _func)(programObj, name);
}

GLAPI void APIENTRY glGetBooleanIndexedvEXT(GLenum target, GLuint index, GLboolean *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[882];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLboolean *data)) _func)(target, index, data);
}

GLAPI void APIENTRY glGetBooleani_v(GLenum target, GLuint index, GLboolean *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[883];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLboolean *data)) _func)(target, index, data);
}

GLAPI void APIENTRY glGetBooleanv(GLenum pname, GLboolean *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[884];
   ((void (APIENTRY *)(GLenum pname, GLboolean *data)) _func)(pname, data);
}

GLAPI void APIENTRY glGetBufferParameteri64v(GLenum target, GLenum pname, GLint64 *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[885];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLint64 *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetBufferParameteriv(GLenum target, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[886];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLint *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetBufferParameterivARB(GLenum target, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[887];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLint *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetBufferParameterui64vNV(GLenum target, GLenum pname, GLuint64 *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[888];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLuint64 *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetBufferPointerv(GLenum target, GLenum pname, void **params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[889];
   ((void (APIENTRY *)(GLenum target, GLenum pname, void **params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetBufferPointervARB(GLenum target, GLenum pname, void **params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[890];
   ((void (APIENTRY *)(GLenum target, GLenum pname, void **params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetBufferPointervOES(GLenum target, GLenum pname, void **params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[891];
   ((void (APIENTRY *)(GLenum target, GLenum pname, void **params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetBufferSubData(GLenum target, GLintptr offset, GLsizeiptr size, void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[892];
   ((void (APIENTRY *)(GLenum target, GLintptr offset, GLsizeiptr size, void *data)) _func)(target, offset, size, data);
}

GLAPI void APIENTRY glGetBufferSubDataARB(GLenum target, GLintptr offset, GLsizeiptr size, void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[893];
   ((void (APIENTRY *)(GLenum target, GLintptr offset, GLsizeiptr size, void *data)) _func)(target, offset, size, data);
}

GLAPI void APIENTRY glGetClipPlane(GLenum plane, GLdouble *equation)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[894];
   ((void (APIENTRY *)(GLenum plane, GLdouble *equation)) _func)(plane, equation);
}

GLAPI void APIENTRY glGetClipPlanef(GLenum plane, GLfloat *equation)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[895];
   ((void (APIENTRY *)(GLenum plane, GLfloat *equation)) _func)(plane, equation);
}

GLAPI void APIENTRY glGetClipPlanefOES(GLenum plane, GLfloat *equation)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[896];
   ((void (APIENTRY *)(GLenum plane, GLfloat *equation)) _func)(plane, equation);
}

GLAPI void APIENTRY glGetClipPlanex(GLenum plane, GLfixed *equation)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[897];
   ((void (APIENTRY *)(GLenum plane, GLfixed *equation)) _func)(plane, equation);
}

GLAPI void APIENTRY glGetClipPlanexOES(GLenum plane, GLfixed *equation)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[898];
   ((void (APIENTRY *)(GLenum plane, GLfixed *equation)) _func)(plane, equation);
}

GLAPI void APIENTRY glGetColorTable(GLenum target, GLenum format, GLenum type, void *table)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[899];
   ((void (APIENTRY *)(GLenum target, GLenum format, GLenum type, void *table)) _func)(target, format, type, table);
}

GLAPI void APIENTRY glGetColorTableEXT(GLenum target, GLenum format, GLenum type, void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[900];
   ((void (APIENTRY *)(GLenum target, GLenum format, GLenum type, void *data)) _func)(target, format, type, data);
}

GLAPI void APIENTRY glGetColorTableParameterfv(GLenum target, GLenum pname, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[901];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLfloat *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetColorTableParameterfvEXT(GLenum target, GLenum pname, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[902];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLfloat *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetColorTableParameterfvSGI(GLenum target, GLenum pname, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[903];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLfloat *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetColorTableParameteriv(GLenum target, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[904];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLint *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetColorTableParameterivEXT(GLenum target, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[905];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLint *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetColorTableParameterivSGI(GLenum target, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[906];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLint *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetColorTableSGI(GLenum target, GLenum format, GLenum type, void *table)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[907];
   ((void (APIENTRY *)(GLenum target, GLenum format, GLenum type, void *table)) _func)(target, format, type, table);
}

GLAPI void APIENTRY glGetCombinerInputParameterfvNV(GLenum stage, GLenum portion, GLenum variable, GLenum pname, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[908];
   ((void (APIENTRY *)(GLenum stage, GLenum portion, GLenum variable, GLenum pname, GLfloat *params)) _func)(stage, portion, variable, pname, params);
}

GLAPI void APIENTRY glGetCombinerInputParameterivNV(GLenum stage, GLenum portion, GLenum variable, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[909];
   ((void (APIENTRY *)(GLenum stage, GLenum portion, GLenum variable, GLenum pname, GLint *params)) _func)(stage, portion, variable, pname, params);
}

GLAPI void APIENTRY glGetCombinerOutputParameterfvNV(GLenum stage, GLenum portion, GLenum pname, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[910];
   ((void (APIENTRY *)(GLenum stage, GLenum portion, GLenum pname, GLfloat *params)) _func)(stage, portion, pname, params);
}

GLAPI void APIENTRY glGetCombinerOutputParameterivNV(GLenum stage, GLenum portion, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[911];
   ((void (APIENTRY *)(GLenum stage, GLenum portion, GLenum pname, GLint *params)) _func)(stage, portion, pname, params);
}

GLAPI void APIENTRY glGetCombinerStageParameterfvNV(GLenum stage, GLenum pname, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[912];
   ((void (APIENTRY *)(GLenum stage, GLenum pname, GLfloat *params)) _func)(stage, pname, params);
}

GLAPI GLuint APIENTRY glGetCommandHeaderNV(GLenum tokenID, GLuint size)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[913];
   return ((GLuint (APIENTRY *)(GLenum tokenID, GLuint size)) _func)(tokenID, size);
}

GLAPI void APIENTRY glGetCompressedMultiTexImageEXT(GLenum texunit, GLenum target, GLint lod, void *img)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[914];
   ((void (APIENTRY *)(GLenum texunit, GLenum target, GLint lod, void *img)) _func)(texunit, target, lod, img);
}

GLAPI void APIENTRY glGetCompressedTexImage(GLenum target, GLint level, void *img)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[915];
   ((void (APIENTRY *)(GLenum target, GLint level, void *img)) _func)(target, level, img);
}

GLAPI void APIENTRY glGetCompressedTexImageARB(GLenum target, GLint level, void *img)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[916];
   ((void (APIENTRY *)(GLenum target, GLint level, void *img)) _func)(target, level, img);
}

GLAPI void APIENTRY glGetCompressedTexImageNV(GLenum target, GLint lod, void *img)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[917];
   ((void (APIENTRY *)(GLenum target, GLint lod, void *img)) _func)(target, lod, img);
}

GLAPI void APIENTRY glGetCompressedTextureImage(GLuint texture, GLint level, GLsizei bufSize, void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[918];
   ((void (APIENTRY *)(GLuint texture, GLint level, GLsizei bufSize, void *pixels)) _func)(texture, level, bufSize, pixels);
}

GLAPI void APIENTRY glGetCompressedTextureImageEXT(GLuint texture, GLenum target, GLint lod, void *img)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[919];
   ((void (APIENTRY *)(GLuint texture, GLenum target, GLint lod, void *img)) _func)(texture, target, lod, img);
}

GLAPI void APIENTRY glGetCompressedTextureSubImage(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLsizei bufSize, void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[920];
   ((void (APIENTRY *)(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLsizei bufSize, void *pixels)) _func)(texture, level, xoffset, yoffset, zoffset, width, height, depth, bufSize, pixels);
}

GLAPI void APIENTRY glGetConvolutionFilter(GLenum target, GLenum format, GLenum type, void *image)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[921];
   ((void (APIENTRY *)(GLenum target, GLenum format, GLenum type, void *image)) _func)(target, format, type, image);
}

GLAPI void APIENTRY glGetConvolutionFilterEXT(GLenum target, GLenum format, GLenum type, void *image)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[922];
   ((void (APIENTRY *)(GLenum target, GLenum format, GLenum type, void *image)) _func)(target, format, type, image);
}

GLAPI void APIENTRY glGetConvolutionParameterfv(GLenum target, GLenum pname, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[923];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLfloat *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetConvolutionParameterfvEXT(GLenum target, GLenum pname, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[924];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLfloat *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetConvolutionParameteriv(GLenum target, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[925];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLint *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetConvolutionParameterivEXT(GLenum target, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[926];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLint *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetConvolutionParameterxvOES(GLenum target, GLenum pname, GLfixed *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[927];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLfixed *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetCoverageModulationTableNV(GLsizei bufSize, GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[928];
   ((void (APIENTRY *)(GLsizei bufSize, GLfloat *v)) _func)(bufSize, v);
}

GLAPI GLuint APIENTRY glGetDebugMessageLog(GLuint count, GLsizei bufSize, GLenum *sources, GLenum *types, GLuint *ids, GLenum *severities, GLsizei *lengths, GLchar *messageLog)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[929];
   return ((GLuint (APIENTRY *)(GLuint count, GLsizei bufSize, GLenum *sources, GLenum *types, GLuint *ids, GLenum *severities, GLsizei *lengths, GLchar *messageLog)) _func)(count, bufSize, sources, types, ids, severities, lengths, messageLog);
}

GLAPI GLuint APIENTRY glGetDebugMessageLogAMD(GLuint count, GLsizei bufSize, GLenum *categories, GLenum *severities, GLuint *ids, GLsizei *lengths, GLchar *message)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[930];
   return ((GLuint (APIENTRY *)(GLuint count, GLsizei bufSize, GLenum *categories, GLenum *severities, GLuint *ids, GLsizei *lengths, GLchar *message)) _func)(count, bufSize, categories, severities, ids, lengths, message);
}

GLAPI GLuint APIENTRY glGetDebugMessageLogARB(GLuint count, GLsizei bufSize, GLenum *sources, GLenum *types, GLuint *ids, GLenum *severities, GLsizei *lengths, GLchar *messageLog)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[931];
   return ((GLuint (APIENTRY *)(GLuint count, GLsizei bufSize, GLenum *sources, GLenum *types, GLuint *ids, GLenum *severities, GLsizei *lengths, GLchar *messageLog)) _func)(count, bufSize, sources, types, ids, severities, lengths, messageLog);
}

GLAPI GLuint APIENTRY glGetDebugMessageLogKHR(GLuint count, GLsizei bufSize, GLenum *sources, GLenum *types, GLuint *ids, GLenum *severities, GLsizei *lengths, GLchar *messageLog)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[932];
   return ((GLuint (APIENTRY *)(GLuint count, GLsizei bufSize, GLenum *sources, GLenum *types, GLuint *ids, GLenum *severities, GLsizei *lengths, GLchar *messageLog)) _func)(count, bufSize, sources, types, ids, severities, lengths, messageLog);
}

GLAPI GLuint APIENTRY glGetDebugMessageLogOES(GLuint count, GLsizei bufsize, GLenum *sources, GLenum *types, GLuint *ids, GLenum *severities, GLsizei *lengths, GLchar *messageLog)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[933];
   return ((GLuint (APIENTRY *)(GLuint count, GLsizei bufsize, GLenum *sources, GLenum *types, GLuint *ids, GLenum *severities, GLsizei *lengths, GLchar *messageLog)) _func)(count, bufsize, sources, types, ids, severities, lengths, messageLog);
}

GLAPI void APIENTRY glGetDetailTexFuncSGIS(GLenum target, GLfloat *points)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[934];
   ((void (APIENTRY *)(GLenum target, GLfloat *points)) _func)(target, points);
}

GLAPI void APIENTRY glGetDoubleIndexedvEXT(GLenum target, GLuint index, GLdouble *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[935];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLdouble *data)) _func)(target, index, data);
}

GLAPI void APIENTRY glGetDoublei_v(GLenum target, GLuint index, GLdouble *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[936];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLdouble *data)) _func)(target, index, data);
}

GLAPI void APIENTRY glGetDoublei_vEXT(GLenum pname, GLuint index, GLdouble *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[937];
   ((void (APIENTRY *)(GLenum pname, GLuint index, GLdouble *params)) _func)(pname, index, params);
}

GLAPI void APIENTRY glGetDoublev(GLenum pname, GLdouble *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[938];
   ((void (APIENTRY *)(GLenum pname, GLdouble *data)) _func)(pname, data);
}

GLAPI void APIENTRY glGetDriverControlStringQCOM(GLuint driverControl, GLsizei bufSize, GLsizei *length, GLchar *driverControlString)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[939];
   ((void (APIENTRY *)(GLuint driverControl, GLsizei bufSize, GLsizei *length, GLchar *driverControlString)) _func)(driverControl, bufSize, length, driverControlString);
}

GLAPI void APIENTRY glGetDriverControlsQCOM(GLint *num, GLsizei size, GLuint *driverControls)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[940];
   ((void (APIENTRY *)(GLint *num, GLsizei size, GLuint *driverControls)) _func)(num, size, driverControls);
}

GLAPI GLenum APIENTRY glGetError(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[941];
   return ((GLenum (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glGetFenceivNV(GLuint fence, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[942];
   ((void (APIENTRY *)(GLuint fence, GLenum pname, GLint *params)) _func)(fence, pname, params);
}

GLAPI void APIENTRY glGetFinalCombinerInputParameterfvNV(GLenum variable, GLenum pname, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[943];
   ((void (APIENTRY *)(GLenum variable, GLenum pname, GLfloat *params)) _func)(variable, pname, params);
}

GLAPI void APIENTRY glGetFinalCombinerInputParameterivNV(GLenum variable, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[944];
   ((void (APIENTRY *)(GLenum variable, GLenum pname, GLint *params)) _func)(variable, pname, params);
}

GLAPI void APIENTRY glGetFirstPerfQueryIdINTEL(GLuint *queryId)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[945];
   ((void (APIENTRY *)(GLuint *queryId)) _func)(queryId);
}

GLAPI void APIENTRY glGetFixedv(GLenum pname, GLfixed *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[946];
   ((void (APIENTRY *)(GLenum pname, GLfixed *params)) _func)(pname, params);
}

GLAPI void APIENTRY glGetFixedvOES(GLenum pname, GLfixed *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[947];
   ((void (APIENTRY *)(GLenum pname, GLfixed *params)) _func)(pname, params);
}

GLAPI void APIENTRY glGetFloatIndexedvEXT(GLenum target, GLuint index, GLfloat *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[948];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLfloat *data)) _func)(target, index, data);
}

GLAPI void APIENTRY glGetFloati_v(GLenum target, GLuint index, GLfloat *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[949];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLfloat *data)) _func)(target, index, data);
}

GLAPI void APIENTRY glGetFloati_vEXT(GLenum pname, GLuint index, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[950];
   ((void (APIENTRY *)(GLenum pname, GLuint index, GLfloat *params)) _func)(pname, index, params);
}

GLAPI void APIENTRY glGetFloati_vNV(GLenum target, GLuint index, GLfloat *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[951];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLfloat *data)) _func)(target, index, data);
}

GLAPI void APIENTRY glGetFloati_vOES(GLenum target, GLuint index, GLfloat *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[952];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLfloat *data)) _func)(target, index, data);
}

GLAPI void APIENTRY glGetFloatv(GLenum pname, GLfloat *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[953];
   ((void (APIENTRY *)(GLenum pname, GLfloat *data)) _func)(pname, data);
}

GLAPI void APIENTRY glGetFogFuncSGIS(GLfloat *points)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[954];
   ((void (APIENTRY *)(GLfloat *points)) _func)(points);
}

GLAPI GLint APIENTRY glGetFragDataIndex(GLuint program, const GLchar *name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[955];
   return ((GLint (APIENTRY *)(GLuint program, const GLchar *name)) _func)(program, name);
}

GLAPI GLint APIENTRY glGetFragDataIndexEXT(GLuint program, const GLchar *name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[956];
   return ((GLint (APIENTRY *)(GLuint program, const GLchar *name)) _func)(program, name);
}

GLAPI GLint APIENTRY glGetFragDataLocation(GLuint program, const GLchar *name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[957];
   return ((GLint (APIENTRY *)(GLuint program, const GLchar *name)) _func)(program, name);
}

GLAPI GLint APIENTRY glGetFragDataLocationEXT(GLuint program, const GLchar *name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[958];
   return ((GLint (APIENTRY *)(GLuint program, const GLchar *name)) _func)(program, name);
}

GLAPI void APIENTRY glGetFragmentLightfvSGIX(GLenum light, GLenum pname, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[959];
   ((void (APIENTRY *)(GLenum light, GLenum pname, GLfloat *params)) _func)(light, pname, params);
}

GLAPI void APIENTRY glGetFragmentLightivSGIX(GLenum light, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[960];
   ((void (APIENTRY *)(GLenum light, GLenum pname, GLint *params)) _func)(light, pname, params);
}

GLAPI void APIENTRY glGetFragmentMaterialfvSGIX(GLenum face, GLenum pname, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[961];
   ((void (APIENTRY *)(GLenum face, GLenum pname, GLfloat *params)) _func)(face, pname, params);
}

GLAPI void APIENTRY glGetFragmentMaterialivSGIX(GLenum face, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[962];
   ((void (APIENTRY *)(GLenum face, GLenum pname, GLint *params)) _func)(face, pname, params);
}

GLAPI void APIENTRY glGetFramebufferAttachmentParameteriv(GLenum target, GLenum attachment, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[964];
   ((void (APIENTRY *)(GLenum target, GLenum attachment, GLenum pname, GLint *params)) _func)(target, attachment, pname, params);
}

GLAPI void APIENTRY glGetFramebufferAttachmentParameterivEXT(GLenum target, GLenum attachment, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[965];
   ((void (APIENTRY *)(GLenum target, GLenum attachment, GLenum pname, GLint *params)) _func)(target, attachment, pname, params);
}

GLAPI void APIENTRY glGetFramebufferAttachmentParameterivOES(GLenum target, GLenum attachment, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[966];
   ((void (APIENTRY *)(GLenum target, GLenum attachment, GLenum pname, GLint *params)) _func)(target, attachment, pname, params);
}

GLAPI void APIENTRY glGetFramebufferParameterfvAMD(GLenum target, GLenum pname, GLuint numsamples, GLuint pixelindex, GLsizei size, GLfloat *values)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[967];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLuint numsamples, GLuint pixelindex, GLsizei size, GLfloat *values)) _func)(target, pname, numsamples, pixelindex, size, values);
}

GLAPI void APIENTRY glGetFramebufferParameteriv(GLenum target, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[968];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLint *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetFramebufferParameterivEXT(GLuint framebuffer, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[969];
   ((void (APIENTRY *)(GLuint framebuffer, GLenum pname, GLint *params)) _func)(framebuffer, pname, params);
}

GLAPI void APIENTRY glGetFramebufferParameterivMESA(GLenum target, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[970];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLint *params)) _func)(target, pname, params);
}

GLAPI GLsizei APIENTRY glGetFramebufferPixelLocalStorageSizeEXT(GLuint target)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[971];
   return ((GLsizei (APIENTRY *)(GLuint target)) _func)(target);
}

GLAPI GLenum APIENTRY glGetGraphicsResetStatus(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[972];
   return ((GLenum (APIENTRY *)(void)) _func)();
}

GLAPI GLenum APIENTRY glGetGraphicsResetStatusARB(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[973];
   return ((GLenum (APIENTRY *)(void)) _func)();
}

GLAPI GLenum APIENTRY glGetGraphicsResetStatusEXT(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[974];
   return ((GLenum (APIENTRY *)(void)) _func)();
}

GLAPI GLenum APIENTRY glGetGraphicsResetStatusKHR(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[975];
   return ((GLenum (APIENTRY *)(void)) _func)();
}

GLAPI GLhandleARB APIENTRY glGetHandleARB(GLenum pname)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[976];
   return ((GLhandleARB (APIENTRY *)(GLenum pname)) _func)(pname);
}

GLAPI void APIENTRY glGetHistogram(GLenum target, GLboolean reset, GLenum format, GLenum type, void *values)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[977];
   ((void (APIENTRY *)(GLenum target, GLboolean reset, GLenum format, GLenum type, void *values)) _func)(target, reset, format, type, values);
}

GLAPI void APIENTRY glGetHistogramEXT(GLenum target, GLboolean reset, GLenum format, GLenum type, void *values)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[978];
   ((void (APIENTRY *)(GLenum target, GLboolean reset, GLenum format, GLenum type, void *values)) _func)(target, reset, format, type, values);
}

GLAPI void APIENTRY glGetHistogramParameterfv(GLenum target, GLenum pname, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[979];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLfloat *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetHistogramParameterfvEXT(GLenum target, GLenum pname, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[980];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLfloat *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetHistogramParameteriv(GLenum target, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[981];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLint *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetHistogramParameterivEXT(GLenum target, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[982];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLint *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetHistogramParameterxvOES(GLenum target, GLenum pname, GLfixed *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[983];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLfixed *params)) _func)(target, pname, params);
}

GLAPI GLuint64 APIENTRY glGetImageHandleARB(GLuint texture, GLint level, GLboolean layered, GLint layer, GLenum format)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[984];
   return ((GLuint64 (APIENTRY *)(GLuint texture, GLint level, GLboolean layered, GLint layer, GLenum format)) _func)(texture, level, layered, layer, format);
}

GLAPI GLuint64 APIENTRY glGetImageHandleNV(GLuint texture, GLint level, GLboolean layered, GLint layer, GLenum format)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[985];
   return ((GLuint64 (APIENTRY *)(GLuint texture, GLint level, GLboolean layered, GLint layer, GLenum format)) _func)(texture, level, layered, layer, format);
}

GLAPI void APIENTRY glGetImageTransformParameterfvHP(GLenum target, GLenum pname, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[986];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLfloat *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetImageTransformParameterivHP(GLenum target, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[987];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLint *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetInfoLogARB(GLhandleARB obj, GLsizei maxLength, GLsizei *length, GLcharARB *infoLog)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[988];
   ((void (APIENTRY *)(GLhandleARB obj, GLsizei maxLength, GLsizei *length, GLcharARB *infoLog)) _func)(obj, maxLength, length, infoLog);
}

GLAPI GLint APIENTRY glGetInstrumentsSGIX(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[989];
   return ((GLint (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glGetInteger64i_v(GLenum target, GLuint index, GLint64 *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[990];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLint64 *data)) _func)(target, index, data);
}

GLAPI void APIENTRY glGetInteger64v(GLenum pname, GLint64 *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[991];
   ((void (APIENTRY *)(GLenum pname, GLint64 *data)) _func)(pname, data);
}

GLAPI void APIENTRY glGetInteger64vAPPLE(GLenum pname, GLint64 *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[992];
   ((void (APIENTRY *)(GLenum pname, GLint64 *params)) _func)(pname, params);
}

GLAPI void APIENTRY glGetIntegerIndexedvEXT(GLenum target, GLuint index, GLint *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[994];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLint *data)) _func)(target, index, data);
}

GLAPI void APIENTRY glGetIntegeri_v(GLenum target, GLuint index, GLint *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[995];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLint *data)) _func)(target, index, data);
}

GLAPI void APIENTRY glGetIntegeri_vEXT(GLenum target, GLuint index, GLint *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[996];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLint *data)) _func)(target, index, data);
}

GLAPI void APIENTRY glGetIntegerui64i_vNV(GLenum value, GLuint index, GLuint64 *result)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[997];
   ((void (APIENTRY *)(GLenum value, GLuint index, GLuint64 *result)) _func)(value, index, result);
}

GLAPI void APIENTRY glGetIntegerui64vNV(GLenum value, GLuint64 *result)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[998];
   ((void (APIENTRY *)(GLenum value, GLuint64 *result)) _func)(value, result);
}

GLAPI void APIENTRY glGetIntegerv(GLenum pname, GLint *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[999];
   ((void (APIENTRY *)(GLenum pname, GLint *data)) _func)(pname, data);
}

GLAPI void APIENTRY glGetInternalformatSampleivNV(GLenum target, GLenum internalformat, GLsizei samples, GLenum pname, GLsizei count, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1000];
   ((void (APIENTRY *)(GLenum target, GLenum internalformat, GLsizei samples, GLenum pname, GLsizei count, GLint *params)) _func)(target, internalformat, samples, pname, count, params);
}

GLAPI void APIENTRY glGetInternalformati64v(GLenum target, GLenum internalformat, GLenum pname, GLsizei count, GLint64 *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1001];
   ((void (APIENTRY *)(GLenum target, GLenum internalformat, GLenum pname, GLsizei count, GLint64 *params)) _func)(target, internalformat, pname, count, params);
}

GLAPI void APIENTRY glGetInternalformativ(GLenum target, GLenum internalformat, GLenum pname, GLsizei count, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1002];
   ((void (APIENTRY *)(GLenum target, GLenum internalformat, GLenum pname, GLsizei count, GLint *params)) _func)(target, internalformat, pname, count, params);
}

GLAPI void APIENTRY glGetInvariantBooleanvEXT(GLuint id, GLenum value, GLboolean *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1003];
   ((void (APIENTRY *)(GLuint id, GLenum value, GLboolean *data)) _func)(id, value, data);
}

GLAPI void APIENTRY glGetInvariantFloatvEXT(GLuint id, GLenum value, GLfloat *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1004];
   ((void (APIENTRY *)(GLuint id, GLenum value, GLfloat *data)) _func)(id, value, data);
}

GLAPI void APIENTRY glGetInvariantIntegervEXT(GLuint id, GLenum value, GLint *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1005];
   ((void (APIENTRY *)(GLuint id, GLenum value, GLint *data)) _func)(id, value, data);
}

GLAPI void APIENTRY glGetLightfv(GLenum light, GLenum pname, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1006];
   ((void (APIENTRY *)(GLenum light, GLenum pname, GLfloat *params)) _func)(light, pname, params);
}

GLAPI void APIENTRY glGetLightiv(GLenum light, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1007];
   ((void (APIENTRY *)(GLenum light, GLenum pname, GLint *params)) _func)(light, pname, params);
}

GLAPI void APIENTRY glGetLightxOES(GLenum light, GLenum pname, GLfixed *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1008];
   ((void (APIENTRY *)(GLenum light, GLenum pname, GLfixed *params)) _func)(light, pname, params);
}

GLAPI void APIENTRY glGetLightxv(GLenum light, GLenum pname, GLfixed *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1009];
   ((void (APIENTRY *)(GLenum light, GLenum pname, GLfixed *params)) _func)(light, pname, params);
}

GLAPI void APIENTRY glGetLightxvOES(GLenum light, GLenum pname, GLfixed *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1010];
   ((void (APIENTRY *)(GLenum light, GLenum pname, GLfixed *params)) _func)(light, pname, params);
}

GLAPI void APIENTRY glGetListParameterfvSGIX(GLuint list, GLenum pname, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1011];
   ((void (APIENTRY *)(GLuint list, GLenum pname, GLfloat *params)) _func)(list, pname, params);
}

GLAPI void APIENTRY glGetListParameterivSGIX(GLuint list, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1012];
   ((void (APIENTRY *)(GLuint list, GLenum pname, GLint *params)) _func)(list, pname, params);
}

GLAPI void APIENTRY glGetLocalConstantBooleanvEXT(GLuint id, GLenum value, GLboolean *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1013];
   ((void (APIENTRY *)(GLuint id, GLenum value, GLboolean *data)) _func)(id, value, data);
}

GLAPI void APIENTRY glGetLocalConstantFloatvEXT(GLuint id, GLenum value, GLfloat *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1014];
   ((void (APIENTRY *)(GLuint id, GLenum value, GLfloat *data)) _func)(id, value, data);
}

GLAPI void APIENTRY glGetLocalConstantIntegervEXT(GLuint id, GLenum value, GLint *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1015];
   ((void (APIENTRY *)(GLuint id, GLenum value, GLint *data)) _func)(id, value, data);
}

GLAPI void APIENTRY glGetMapAttribParameterfvNV(GLenum target, GLuint index, GLenum pname, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1016];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLenum pname, GLfloat *params)) _func)(target, index, pname, params);
}

GLAPI void APIENTRY glGetMapAttribParameterivNV(GLenum target, GLuint index, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1017];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLenum pname, GLint *params)) _func)(target, index, pname, params);
}

GLAPI void APIENTRY glGetMapControlPointsNV(GLenum target, GLuint index, GLenum type, GLsizei ustride, GLsizei vstride, GLboolean packed, void *points)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1018];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLenum type, GLsizei ustride, GLsizei vstride, GLboolean packed, void *points)) _func)(target, index, type, ustride, vstride, packed, points);
}

GLAPI void APIENTRY glGetMapParameterfvNV(GLenum target, GLenum pname, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1019];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLfloat *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetMapParameterivNV(GLenum target, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1020];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLint *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetMapdv(GLenum target, GLenum query, GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1021];
   ((void (APIENTRY *)(GLenum target, GLenum query, GLdouble *v)) _func)(target, query, v);
}

GLAPI void APIENTRY glGetMapfv(GLenum target, GLenum query, GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1022];
   ((void (APIENTRY *)(GLenum target, GLenum query, GLfloat *v)) _func)(target, query, v);
}

GLAPI void APIENTRY glGetMapiv(GLenum target, GLenum query, GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1023];
   ((void (APIENTRY *)(GLenum target, GLenum query, GLint *v)) _func)(target, query, v);
}

GLAPI void APIENTRY glGetMapxvOES(GLenum target, GLenum query, GLfixed *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1024];
   ((void (APIENTRY *)(GLenum target, GLenum query, GLfixed *v)) _func)(target, query, v);
}

GLAPI void APIENTRY glGetMaterialfv(GLenum face, GLenum pname, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1025];
   ((void (APIENTRY *)(GLenum face, GLenum pname, GLfloat *params)) _func)(face, pname, params);
}

GLAPI void APIENTRY glGetMaterialiv(GLenum face, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1026];
   ((void (APIENTRY *)(GLenum face, GLenum pname, GLint *params)) _func)(face, pname, params);
}

GLAPI void APIENTRY glGetMaterialxOES(GLenum face, GLenum pname, GLfixed param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1027];
   ((void (APIENTRY *)(GLenum face, GLenum pname, GLfixed param)) _func)(face, pname, param);
}

GLAPI void APIENTRY glGetMaterialxv(GLenum face, GLenum pname, GLfixed *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1028];
   ((void (APIENTRY *)(GLenum face, GLenum pname, GLfixed *params)) _func)(face, pname, params);
}

GLAPI void APIENTRY glGetMaterialxvOES(GLenum face, GLenum pname, GLfixed *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1029];
   ((void (APIENTRY *)(GLenum face, GLenum pname, GLfixed *params)) _func)(face, pname, params);
}

GLAPI void APIENTRY glGetMemoryObjectDetachedResourcesuivNV(GLuint memory, GLenum pname, GLint first, GLsizei count, GLuint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1030];
   ((void (APIENTRY *)(GLuint memory, GLenum pname, GLint first, GLsizei count, GLuint *params)) _func)(memory, pname, first, count, params);
}

GLAPI void APIENTRY glGetMemoryObjectParameterivEXT(GLuint memoryObject, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1031];
   ((void (APIENTRY *)(GLuint memoryObject, GLenum pname, GLint *params)) _func)(memoryObject, pname, params);
}

GLAPI void APIENTRY glGetMinmax(GLenum target, GLboolean reset, GLenum format, GLenum type, void *values)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1032];
   ((void (APIENTRY *)(GLenum target, GLboolean reset, GLenum format, GLenum type, void *values)) _func)(target, reset, format, type, values);
}

GLAPI void APIENTRY glGetMinmaxEXT(GLenum target, GLboolean reset, GLenum format, GLenum type, void *values)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1033];
   ((void (APIENTRY *)(GLenum target, GLboolean reset, GLenum format, GLenum type, void *values)) _func)(target, reset, format, type, values);
}

GLAPI void APIENTRY glGetMinmaxParameterfv(GLenum target, GLenum pname, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1034];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLfloat *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetMinmaxParameterfvEXT(GLenum target, GLenum pname, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1035];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLfloat *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetMinmaxParameteriv(GLenum target, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1036];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLint *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetMinmaxParameterivEXT(GLenum target, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1037];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLint *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetMultiTexEnvfvEXT(GLenum texunit, GLenum target, GLenum pname, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1038];
   ((void (APIENTRY *)(GLenum texunit, GLenum target, GLenum pname, GLfloat *params)) _func)(texunit, target, pname, params);
}

GLAPI void APIENTRY glGetMultiTexEnvivEXT(GLenum texunit, GLenum target, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1039];
   ((void (APIENTRY *)(GLenum texunit, GLenum target, GLenum pname, GLint *params)) _func)(texunit, target, pname, params);
}

GLAPI void APIENTRY glGetMultiTexGendvEXT(GLenum texunit, GLenum coord, GLenum pname, GLdouble *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1040];
   ((void (APIENTRY *)(GLenum texunit, GLenum coord, GLenum pname, GLdouble *params)) _func)(texunit, coord, pname, params);
}

GLAPI void APIENTRY glGetMultiTexGenfvEXT(GLenum texunit, GLenum coord, GLenum pname, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1041];
   ((void (APIENTRY *)(GLenum texunit, GLenum coord, GLenum pname, GLfloat *params)) _func)(texunit, coord, pname, params);
}

GLAPI void APIENTRY glGetMultiTexGenivEXT(GLenum texunit, GLenum coord, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1042];
   ((void (APIENTRY *)(GLenum texunit, GLenum coord, GLenum pname, GLint *params)) _func)(texunit, coord, pname, params);
}

GLAPI void APIENTRY glGetMultiTexImageEXT(GLenum texunit, GLenum target, GLint level, GLenum format, GLenum type, void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1043];
   ((void (APIENTRY *)(GLenum texunit, GLenum target, GLint level, GLenum format, GLenum type, void *pixels)) _func)(texunit, target, level, format, type, pixels);
}

GLAPI void APIENTRY glGetMultiTexLevelParameterfvEXT(GLenum texunit, GLenum target, GLint level, GLenum pname, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1044];
   ((void (APIENTRY *)(GLenum texunit, GLenum target, GLint level, GLenum pname, GLfloat *params)) _func)(texunit, target, level, pname, params);
}

GLAPI void APIENTRY glGetMultiTexLevelParameterivEXT(GLenum texunit, GLenum target, GLint level, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1045];
   ((void (APIENTRY *)(GLenum texunit, GLenum target, GLint level, GLenum pname, GLint *params)) _func)(texunit, target, level, pname, params);
}

GLAPI void APIENTRY glGetMultiTexParameterIivEXT(GLenum texunit, GLenum target, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1046];
   ((void (APIENTRY *)(GLenum texunit, GLenum target, GLenum pname, GLint *params)) _func)(texunit, target, pname, params);
}

GLAPI void APIENTRY glGetMultiTexParameterIuivEXT(GLenum texunit, GLenum target, GLenum pname, GLuint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1047];
   ((void (APIENTRY *)(GLenum texunit, GLenum target, GLenum pname, GLuint *params)) _func)(texunit, target, pname, params);
}

GLAPI void APIENTRY glGetMultiTexParameterfvEXT(GLenum texunit, GLenum target, GLenum pname, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1048];
   ((void (APIENTRY *)(GLenum texunit, GLenum target, GLenum pname, GLfloat *params)) _func)(texunit, target, pname, params);
}

GLAPI void APIENTRY glGetMultiTexParameterivEXT(GLenum texunit, GLenum target, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1049];
   ((void (APIENTRY *)(GLenum texunit, GLenum target, GLenum pname, GLint *params)) _func)(texunit, target, pname, params);
}

GLAPI void APIENTRY glGetMultisamplefv(GLenum pname, GLuint index, GLfloat *val)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1050];
   ((void (APIENTRY *)(GLenum pname, GLuint index, GLfloat *val)) _func)(pname, index, val);
}

GLAPI void APIENTRY glGetMultisamplefvNV(GLenum pname, GLuint index, GLfloat *val)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1051];
   ((void (APIENTRY *)(GLenum pname, GLuint index, GLfloat *val)) _func)(pname, index, val);
}

GLAPI void APIENTRY glGetNamedBufferParameteri64v(GLuint buffer, GLenum pname, GLint64 *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1052];
   ((void (APIENTRY *)(GLuint buffer, GLenum pname, GLint64 *params)) _func)(buffer, pname, params);
}

GLAPI void APIENTRY glGetNamedBufferParameteri64vEXT(GLuint buffer, GLenum pname, GLint64 *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1053];
   ((void (APIENTRY *)(GLuint buffer, GLenum pname, GLint64 *params)) _func)(buffer, pname, params);
}

GLAPI void APIENTRY glGetNamedBufferParameteriv(GLuint buffer, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1054];
   ((void (APIENTRY *)(GLuint buffer, GLenum pname, GLint *params)) _func)(buffer, pname, params);
}

GLAPI void APIENTRY glGetNamedBufferParameterivEXT(GLuint buffer, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1055];
   ((void (APIENTRY *)(GLuint buffer, GLenum pname, GLint *params)) _func)(buffer, pname, params);
}

GLAPI void APIENTRY glGetNamedBufferParameterui64vNV(GLuint buffer, GLenum pname, GLuint64 *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1056];
   ((void (APIENTRY *)(GLuint buffer, GLenum pname, GLuint64 *params)) _func)(buffer, pname, params);
}

GLAPI void APIENTRY glGetNamedBufferPointerv(GLuint buffer, GLenum pname, void **params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1057];
   ((void (APIENTRY *)(GLuint buffer, GLenum pname, void **params)) _func)(buffer, pname, params);
}

GLAPI void APIENTRY glGetNamedBufferPointervEXT(GLuint buffer, GLenum pname, void **params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1058];
   ((void (APIENTRY *)(GLuint buffer, GLenum pname, void **params)) _func)(buffer, pname, params);
}

GLAPI void APIENTRY glGetNamedBufferSubData(GLuint buffer, GLintptr offset, GLsizeiptr size, void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1059];
   ((void (APIENTRY *)(GLuint buffer, GLintptr offset, GLsizeiptr size, void *data)) _func)(buffer, offset, size, data);
}

GLAPI void APIENTRY glGetNamedBufferSubDataEXT(GLuint buffer, GLintptr offset, GLsizeiptr size, void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1060];
   ((void (APIENTRY *)(GLuint buffer, GLintptr offset, GLsizeiptr size, void *data)) _func)(buffer, offset, size, data);
}

GLAPI void APIENTRY glGetNamedFramebufferAttachmentParameteriv(GLuint framebuffer, GLenum attachment, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1061];
   ((void (APIENTRY *)(GLuint framebuffer, GLenum attachment, GLenum pname, GLint *params)) _func)(framebuffer, attachment, pname, params);
}

GLAPI void APIENTRY glGetNamedFramebufferAttachmentParameterivEXT(GLuint framebuffer, GLenum attachment, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1062];
   ((void (APIENTRY *)(GLuint framebuffer, GLenum attachment, GLenum pname, GLint *params)) _func)(framebuffer, attachment, pname, params);
}

GLAPI void APIENTRY glGetNamedFramebufferParameterfvAMD(GLuint framebuffer, GLenum pname, GLuint numsamples, GLuint pixelindex, GLsizei size, GLfloat *values)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1063];
   ((void (APIENTRY *)(GLuint framebuffer, GLenum pname, GLuint numsamples, GLuint pixelindex, GLsizei size, GLfloat *values)) _func)(framebuffer, pname, numsamples, pixelindex, size, values);
}

GLAPI void APIENTRY glGetNamedFramebufferParameteriv(GLuint framebuffer, GLenum pname, GLint *param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1064];
   ((void (APIENTRY *)(GLuint framebuffer, GLenum pname, GLint *param)) _func)(framebuffer, pname, param);
}

GLAPI void APIENTRY glGetNamedFramebufferParameterivEXT(GLuint framebuffer, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1065];
   ((void (APIENTRY *)(GLuint framebuffer, GLenum pname, GLint *params)) _func)(framebuffer, pname, params);
}

GLAPI void APIENTRY glGetNamedProgramLocalParameterIivEXT(GLuint program, GLenum target, GLuint index, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1066];
   ((void (APIENTRY *)(GLuint program, GLenum target, GLuint index, GLint *params)) _func)(program, target, index, params);
}

GLAPI void APIENTRY glGetNamedProgramLocalParameterIuivEXT(GLuint program, GLenum target, GLuint index, GLuint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1067];
   ((void (APIENTRY *)(GLuint program, GLenum target, GLuint index, GLuint *params)) _func)(program, target, index, params);
}

GLAPI void APIENTRY glGetNamedProgramLocalParameterdvEXT(GLuint program, GLenum target, GLuint index, GLdouble *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1068];
   ((void (APIENTRY *)(GLuint program, GLenum target, GLuint index, GLdouble *params)) _func)(program, target, index, params);
}

GLAPI void APIENTRY glGetNamedProgramLocalParameterfvEXT(GLuint program, GLenum target, GLuint index, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1069];
   ((void (APIENTRY *)(GLuint program, GLenum target, GLuint index, GLfloat *params)) _func)(program, target, index, params);
}

GLAPI void APIENTRY glGetNamedProgramStringEXT(GLuint program, GLenum target, GLenum pname, void *string)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1070];
   ((void (APIENTRY *)(GLuint program, GLenum target, GLenum pname, void *string)) _func)(program, target, pname, string);
}

GLAPI void APIENTRY glGetNamedProgramivEXT(GLuint program, GLenum target, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1071];
   ((void (APIENTRY *)(GLuint program, GLenum target, GLenum pname, GLint *params)) _func)(program, target, pname, params);
}

GLAPI void APIENTRY glGetNamedRenderbufferParameteriv(GLuint renderbuffer, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1072];
   ((void (APIENTRY *)(GLuint renderbuffer, GLenum pname, GLint *params)) _func)(renderbuffer, pname, params);
}

GLAPI void APIENTRY glGetNamedRenderbufferParameterivEXT(GLuint renderbuffer, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1073];
   ((void (APIENTRY *)(GLuint renderbuffer, GLenum pname, GLint *params)) _func)(renderbuffer, pname, params);
}

GLAPI void APIENTRY glGetNamedStringARB(GLint namelen, const GLchar *name, GLsizei bufSize, GLint *stringlen, GLchar *string)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1074];
   ((void (APIENTRY *)(GLint namelen, const GLchar *name, GLsizei bufSize, GLint *stringlen, GLchar *string)) _func)(namelen, name, bufSize, stringlen, string);
}

GLAPI void APIENTRY glGetNamedStringivARB(GLint namelen, const GLchar *name, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1075];
   ((void (APIENTRY *)(GLint namelen, const GLchar *name, GLenum pname, GLint *params)) _func)(namelen, name, pname, params);
}

GLAPI void APIENTRY glGetNextPerfQueryIdINTEL(GLuint queryId, GLuint *nextQueryId)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1076];
   ((void (APIENTRY *)(GLuint queryId, GLuint *nextQueryId)) _func)(queryId, nextQueryId);
}

GLAPI void APIENTRY glGetObjectBufferfvATI(GLuint buffer, GLenum pname, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1077];
   ((void (APIENTRY *)(GLuint buffer, GLenum pname, GLfloat *params)) _func)(buffer, pname, params);
}

GLAPI void APIENTRY glGetObjectBufferivATI(GLuint buffer, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1078];
   ((void (APIENTRY *)(GLuint buffer, GLenum pname, GLint *params)) _func)(buffer, pname, params);
}

GLAPI void APIENTRY glGetObjectLabel(GLenum identifier, GLuint name, GLsizei bufSize, GLsizei *length, GLchar *label)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1079];
   ((void (APIENTRY *)(GLenum identifier, GLuint name, GLsizei bufSize, GLsizei *length, GLchar *label)) _func)(identifier, name, bufSize, length, label);
}

GLAPI void APIENTRY glGetObjectLabelEXT(GLenum type, GLuint object, GLsizei bufSize, GLsizei *length, GLchar *label)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1080];
   ((void (APIENTRY *)(GLenum type, GLuint object, GLsizei bufSize, GLsizei *length, GLchar *label)) _func)(type, object, bufSize, length, label);
}

GLAPI void APIENTRY glGetObjectLabelKHR(GLenum identifier, GLuint name, GLsizei bufSize, GLsizei *length, GLchar *label)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1081];
   ((void (APIENTRY *)(GLenum identifier, GLuint name, GLsizei bufSize, GLsizei *length, GLchar *label)) _func)(identifier, name, bufSize, length, label);
}

GLAPI void APIENTRY glGetObjectLabelOES(GLenum identifier, GLuint name, GLsizei bufSize, GLsizei *length, GLchar *label)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1082];
   ((void (APIENTRY *)(GLenum identifier, GLuint name, GLsizei bufSize, GLsizei *length, GLchar *label)) _func)(identifier, name, bufSize, length, label);
}

GLAPI void APIENTRY glGetObjectParameterfvARB(GLhandleARB obj, GLenum pname, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1083];
   ((void (APIENTRY *)(GLhandleARB obj, GLenum pname, GLfloat *params)) _func)(obj, pname, params);
}

GLAPI void APIENTRY glGetObjectParameterivAPPLE(GLenum objectType, GLuint name, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1084];
   ((void (APIENTRY *)(GLenum objectType, GLuint name, GLenum pname, GLint *params)) _func)(objectType, name, pname, params);
}

GLAPI void APIENTRY glGetObjectParameterivARB(GLhandleARB obj, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1085];
   ((void (APIENTRY *)(GLhandleARB obj, GLenum pname, GLint *params)) _func)(obj, pname, params);
}

GLAPI void APIENTRY glGetObjectPtrLabel(const void *ptr, GLsizei bufSize, GLsizei *length, GLchar *label)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1086];
   ((void (APIENTRY *)(const void *ptr, GLsizei bufSize, GLsizei *length, GLchar *label)) _func)(ptr, bufSize, length, label);
}

GLAPI void APIENTRY glGetObjectPtrLabelKHR(const void *ptr, GLsizei bufSize, GLsizei *length, GLchar *label)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1087];
   ((void (APIENTRY *)(const void *ptr, GLsizei bufSize, GLsizei *length, GLchar *label)) _func)(ptr, bufSize, length, label);
}

GLAPI void APIENTRY glGetObjectPtrLabelOES(void *ptr, GLsizei bufSize, GLsizei *length, GLchar *label)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1088];
   ((void (APIENTRY *)(void *ptr, GLsizei bufSize, GLsizei *length, GLchar *label)) _func)(ptr, bufSize, length, label);
}

GLAPI void APIENTRY glGetOcclusionQueryivNV(GLuint id, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1089];
   ((void (APIENTRY *)(GLuint id, GLenum pname, GLint *params)) _func)(id, pname, params);
}

GLAPI void APIENTRY glGetOcclusionQueryuivNV(GLuint id, GLenum pname, GLuint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1090];
   ((void (APIENTRY *)(GLuint id, GLenum pname, GLuint *params)) _func)(id, pname, params);
}

GLAPI void APIENTRY glGetPathColorGenfvNV(GLenum color, GLenum pname, GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1091];
   ((void (APIENTRY *)(GLenum color, GLenum pname, GLfloat *value)) _func)(color, pname, value);
}

GLAPI void APIENTRY glGetPathColorGenivNV(GLenum color, GLenum pname, GLint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1092];
   ((void (APIENTRY *)(GLenum color, GLenum pname, GLint *value)) _func)(color, pname, value);
}

GLAPI void APIENTRY glGetPathCommandsNV(GLuint path, GLubyte *commands)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1093];
   ((void (APIENTRY *)(GLuint path, GLubyte *commands)) _func)(path, commands);
}

GLAPI void APIENTRY glGetPathCoordsNV(GLuint path, GLfloat *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1094];
   ((void (APIENTRY *)(GLuint path, GLfloat *coords)) _func)(path, coords);
}

GLAPI void APIENTRY glGetPathDashArrayNV(GLuint path, GLfloat *dashArray)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1095];
   ((void (APIENTRY *)(GLuint path, GLfloat *dashArray)) _func)(path, dashArray);
}

GLAPI GLfloat APIENTRY glGetPathLengthNV(GLuint path, GLsizei startSegment, GLsizei numSegments)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1096];
   return ((GLfloat (APIENTRY *)(GLuint path, GLsizei startSegment, GLsizei numSegments)) _func)(path, startSegment, numSegments);
}

GLAPI void APIENTRY glGetPathMetricRangeNV(GLbitfield metricQueryMask, GLuint firstPathName, GLsizei numPaths, GLsizei stride, GLfloat *metrics)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1097];
   ((void (APIENTRY *)(GLbitfield metricQueryMask, GLuint firstPathName, GLsizei numPaths, GLsizei stride, GLfloat *metrics)) _func)(metricQueryMask, firstPathName, numPaths, stride, metrics);
}

GLAPI void APIENTRY glGetPathMetricsNV(GLbitfield metricQueryMask, GLsizei numPaths, GLenum pathNameType, const void *paths, GLuint pathBase, GLsizei stride, GLfloat *metrics)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1098];
   ((void (APIENTRY *)(GLbitfield metricQueryMask, GLsizei numPaths, GLenum pathNameType, const void *paths, GLuint pathBase, GLsizei stride, GLfloat *metrics)) _func)(metricQueryMask, numPaths, pathNameType, paths, pathBase, stride, metrics);
}

GLAPI void APIENTRY glGetPathParameterfvNV(GLuint path, GLenum pname, GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1099];
   ((void (APIENTRY *)(GLuint path, GLenum pname, GLfloat *value)) _func)(path, pname, value);
}

GLAPI void APIENTRY glGetPathParameterivNV(GLuint path, GLenum pname, GLint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1100];
   ((void (APIENTRY *)(GLuint path, GLenum pname, GLint *value)) _func)(path, pname, value);
}

GLAPI void APIENTRY glGetPathSpacingNV(GLenum pathListMode, GLsizei numPaths, GLenum pathNameType, const void *paths, GLuint pathBase, GLfloat advanceScale, GLfloat kerningScale, GLenum transformType, GLfloat *returnedSpacing)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1101];
   ((void (APIENTRY *)(GLenum pathListMode, GLsizei numPaths, GLenum pathNameType, const void *paths, GLuint pathBase, GLfloat advanceScale, GLfloat kerningScale, GLenum transformType, GLfloat *returnedSpacing)) _func)(pathListMode, numPaths, pathNameType, paths, pathBase, advanceScale, kerningScale, transformType, returnedSpacing);
}

GLAPI void APIENTRY glGetPathTexGenfvNV(GLenum texCoordSet, GLenum pname, GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1102];
   ((void (APIENTRY *)(GLenum texCoordSet, GLenum pname, GLfloat *value)) _func)(texCoordSet, pname, value);
}

GLAPI void APIENTRY glGetPathTexGenivNV(GLenum texCoordSet, GLenum pname, GLint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1103];
   ((void (APIENTRY *)(GLenum texCoordSet, GLenum pname, GLint *value)) _func)(texCoordSet, pname, value);
}

GLAPI void APIENTRY glGetPerfCounterInfoINTEL(GLuint queryId, GLuint counterId, GLuint counterNameLength, GLchar *counterName, GLuint counterDescLength, GLchar *counterDesc, GLuint *counterOffset, GLuint *counterDataSize, GLuint *counterTypeEnum, GLuint *counterDataTypeEnum, GLuint64 *rawCounterMaxValue)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1104];
   ((void (APIENTRY *)(GLuint queryId, GLuint counterId, GLuint counterNameLength, GLchar *counterName, GLuint counterDescLength, GLchar *counterDesc, GLuint *counterOffset, GLuint *counterDataSize, GLuint *counterTypeEnum, GLuint *counterDataTypeEnum, GLuint64 *rawCounterMaxValue)) _func)(queryId, counterId, counterNameLength, counterName, counterDescLength, counterDesc, counterOffset, counterDataSize, counterTypeEnum, counterDataTypeEnum, rawCounterMaxValue);
}

GLAPI void APIENTRY glGetPerfMonitorCounterDataAMD(GLuint monitor, GLenum pname, GLsizei dataSize, GLuint *data, GLint *bytesWritten)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1105];
   ((void (APIENTRY *)(GLuint monitor, GLenum pname, GLsizei dataSize, GLuint *data, GLint *bytesWritten)) _func)(monitor, pname, dataSize, data, bytesWritten);
}

GLAPI void APIENTRY glGetPerfMonitorCounterInfoAMD(GLuint group, GLuint counter, GLenum pname, void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1106];
   ((void (APIENTRY *)(GLuint group, GLuint counter, GLenum pname, void *data)) _func)(group, counter, pname, data);
}

GLAPI void APIENTRY glGetPerfMonitorCounterStringAMD(GLuint group, GLuint counter, GLsizei bufSize, GLsizei *length, GLchar *counterString)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1107];
   ((void (APIENTRY *)(GLuint group, GLuint counter, GLsizei bufSize, GLsizei *length, GLchar *counterString)) _func)(group, counter, bufSize, length, counterString);
}

GLAPI void APIENTRY glGetPerfMonitorCountersAMD(GLuint group, GLint *numCounters, GLint *maxActiveCounters, GLsizei counterSize, GLuint *counters)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1108];
   ((void (APIENTRY *)(GLuint group, GLint *numCounters, GLint *maxActiveCounters, GLsizei counterSize, GLuint *counters)) _func)(group, numCounters, maxActiveCounters, counterSize, counters);
}

GLAPI void APIENTRY glGetPerfMonitorGroupStringAMD(GLuint group, GLsizei bufSize, GLsizei *length, GLchar *groupString)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1109];
   ((void (APIENTRY *)(GLuint group, GLsizei bufSize, GLsizei *length, GLchar *groupString)) _func)(group, bufSize, length, groupString);
}

GLAPI void APIENTRY glGetPerfMonitorGroupsAMD(GLint *numGroups, GLsizei groupsSize, GLuint *groups)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1110];
   ((void (APIENTRY *)(GLint *numGroups, GLsizei groupsSize, GLuint *groups)) _func)(numGroups, groupsSize, groups);
}

GLAPI void APIENTRY glGetPerfQueryDataINTEL(GLuint queryHandle, GLuint flags, GLsizei dataSize, void *data, GLuint *bytesWritten)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1111];
   ((void (APIENTRY *)(GLuint queryHandle, GLuint flags, GLsizei dataSize, void *data, GLuint *bytesWritten)) _func)(queryHandle, flags, dataSize, data, bytesWritten);
}

GLAPI void APIENTRY glGetPerfQueryIdByNameINTEL(GLchar *queryName, GLuint *queryId)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1112];
   ((void (APIENTRY *)(GLchar *queryName, GLuint *queryId)) _func)(queryName, queryId);
}

GLAPI void APIENTRY glGetPerfQueryInfoINTEL(GLuint queryId, GLuint queryNameLength, GLchar *queryName, GLuint *dataSize, GLuint *noCounters, GLuint *noInstances, GLuint *capsMask)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1113];
   ((void (APIENTRY *)(GLuint queryId, GLuint queryNameLength, GLchar *queryName, GLuint *dataSize, GLuint *noCounters, GLuint *noInstances, GLuint *capsMask)) _func)(queryId, queryNameLength, queryName, dataSize, noCounters, noInstances, capsMask);
}

GLAPI void APIENTRY glGetPixelMapfv(GLenum map, GLfloat *values)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1114];
   ((void (APIENTRY *)(GLenum map, GLfloat *values)) _func)(map, values);
}

GLAPI void APIENTRY glGetPixelMapuiv(GLenum map, GLuint *values)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1115];
   ((void (APIENTRY *)(GLenum map, GLuint *values)) _func)(map, values);
}

GLAPI void APIENTRY glGetPixelMapusv(GLenum map, GLushort *values)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1116];
   ((void (APIENTRY *)(GLenum map, GLushort *values)) _func)(map, values);
}

GLAPI void APIENTRY glGetPixelMapxv(GLenum map, GLint size, GLfixed *values)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1117];
   ((void (APIENTRY *)(GLenum map, GLint size, GLfixed *values)) _func)(map, size, values);
}

GLAPI void APIENTRY glGetPixelTexGenParameterfvSGIS(GLenum pname, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1118];
   ((void (APIENTRY *)(GLenum pname, GLfloat *params)) _func)(pname, params);
}

GLAPI void APIENTRY glGetPixelTexGenParameterivSGIS(GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1119];
   ((void (APIENTRY *)(GLenum pname, GLint *params)) _func)(pname, params);
}

GLAPI void APIENTRY glGetPixelTransformParameterfvEXT(GLenum target, GLenum pname, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1120];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLfloat *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetPixelTransformParameterivEXT(GLenum target, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1121];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLint *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetPointerIndexedvEXT(GLenum target, GLuint index, void **data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1122];
   ((void (APIENTRY *)(GLenum target, GLuint index, void **data)) _func)(target, index, data);
}

GLAPI void APIENTRY glGetPointeri_vEXT(GLenum pname, GLuint index, void **params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1123];
   ((void (APIENTRY *)(GLenum pname, GLuint index, void **params)) _func)(pname, index, params);
}

GLAPI void APIENTRY glGetPointerv(GLenum pname, void **params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1124];
   ((void (APIENTRY *)(GLenum pname, void **params)) _func)(pname, params);
}

GLAPI void APIENTRY glGetPointervEXT(GLenum pname, void **params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1125];
   ((void (APIENTRY *)(GLenum pname, void **params)) _func)(pname, params);
}

GLAPI void APIENTRY glGetPointervKHR(GLenum pname, void **params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1126];
   ((void (APIENTRY *)(GLenum pname, void **params)) _func)(pname, params);
}

GLAPI void APIENTRY glGetPointervOES(GLenum pname, void **params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1127];
   ((void (APIENTRY *)(GLenum pname, void **params)) _func)(pname, params);
}

GLAPI void APIENTRY glGetPolygonStipple(GLubyte *mask)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1128];
   ((void (APIENTRY *)(GLubyte *mask)) _func)(mask);
}

GLAPI void APIENTRY glGetProgramBinary(GLuint program, GLsizei bufSize, GLsizei *length, GLenum *binaryFormat, void *binary)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1129];
   ((void (APIENTRY *)(GLuint program, GLsizei bufSize, GLsizei *length, GLenum *binaryFormat, void *binary)) _func)(program, bufSize, length, binaryFormat, binary);
}

GLAPI void APIENTRY glGetProgramBinaryOES(GLuint program, GLsizei bufSize, GLsizei *length, GLenum *binaryFormat, void *binary)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1130];
   ((void (APIENTRY *)(GLuint program, GLsizei bufSize, GLsizei *length, GLenum *binaryFormat, void *binary)) _func)(program, bufSize, length, binaryFormat, binary);
}

GLAPI void APIENTRY glGetProgramEnvParameterIivNV(GLenum target, GLuint index, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1131];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLint *params)) _func)(target, index, params);
}

GLAPI void APIENTRY glGetProgramEnvParameterIuivNV(GLenum target, GLuint index, GLuint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1132];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLuint *params)) _func)(target, index, params);
}

GLAPI void APIENTRY glGetProgramEnvParameterdvARB(GLenum target, GLuint index, GLdouble *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1133];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLdouble *params)) _func)(target, index, params);
}

GLAPI void APIENTRY glGetProgramEnvParameterfvARB(GLenum target, GLuint index, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1134];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLfloat *params)) _func)(target, index, params);
}

GLAPI void APIENTRY glGetProgramInfoLog(GLuint program, GLsizei bufSize, GLsizei *length, GLchar *infoLog)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1135];
   ((void (APIENTRY *)(GLuint program, GLsizei bufSize, GLsizei *length, GLchar *infoLog)) _func)(program, bufSize, length, infoLog);
}

GLAPI void APIENTRY glGetProgramInterfaceiv(GLuint program, GLenum programInterface, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1136];
   ((void (APIENTRY *)(GLuint program, GLenum programInterface, GLenum pname, GLint *params)) _func)(program, programInterface, pname, params);
}

GLAPI void APIENTRY glGetProgramLocalParameterIivNV(GLenum target, GLuint index, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1137];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLint *params)) _func)(target, index, params);
}

GLAPI void APIENTRY glGetProgramLocalParameterIuivNV(GLenum target, GLuint index, GLuint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1138];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLuint *params)) _func)(target, index, params);
}

GLAPI void APIENTRY glGetProgramLocalParameterdvARB(GLenum target, GLuint index, GLdouble *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1139];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLdouble *params)) _func)(target, index, params);
}

GLAPI void APIENTRY glGetProgramLocalParameterfvARB(GLenum target, GLuint index, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1140];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLfloat *params)) _func)(target, index, params);
}

GLAPI void APIENTRY glGetProgramNamedParameterdvNV(GLuint id, GLsizei len, const GLubyte *name, GLdouble *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1141];
   ((void (APIENTRY *)(GLuint id, GLsizei len, const GLubyte *name, GLdouble *params)) _func)(id, len, name, params);
}

GLAPI void APIENTRY glGetProgramNamedParameterfvNV(GLuint id, GLsizei len, const GLubyte *name, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1142];
   ((void (APIENTRY *)(GLuint id, GLsizei len, const GLubyte *name, GLfloat *params)) _func)(id, len, name, params);
}

GLAPI void APIENTRY glGetProgramParameterdvNV(GLenum target, GLuint index, GLenum pname, GLdouble *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1143];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLenum pname, GLdouble *params)) _func)(target, index, pname, params);
}

GLAPI void APIENTRY glGetProgramParameterfvNV(GLenum target, GLuint index, GLenum pname, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1144];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLenum pname, GLfloat *params)) _func)(target, index, pname, params);
}

GLAPI void APIENTRY glGetProgramPipelineInfoLog(GLuint pipeline, GLsizei bufSize, GLsizei *length, GLchar *infoLog)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1145];
   ((void (APIENTRY *)(GLuint pipeline, GLsizei bufSize, GLsizei *length, GLchar *infoLog)) _func)(pipeline, bufSize, length, infoLog);
}

GLAPI void APIENTRY glGetProgramPipelineInfoLogEXT(GLuint pipeline, GLsizei bufSize, GLsizei *length, GLchar *infoLog)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1146];
   ((void (APIENTRY *)(GLuint pipeline, GLsizei bufSize, GLsizei *length, GLchar *infoLog)) _func)(pipeline, bufSize, length, infoLog);
}

GLAPI void APIENTRY glGetProgramPipelineiv(GLuint pipeline, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1147];
   ((void (APIENTRY *)(GLuint pipeline, GLenum pname, GLint *params)) _func)(pipeline, pname, params);
}

GLAPI void APIENTRY glGetProgramPipelineivEXT(GLuint pipeline, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1148];
   ((void (APIENTRY *)(GLuint pipeline, GLenum pname, GLint *params)) _func)(pipeline, pname, params);
}

GLAPI GLuint APIENTRY glGetProgramResourceIndex(GLuint program, GLenum programInterface, const GLchar *name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1149];
   return ((GLuint (APIENTRY *)(GLuint program, GLenum programInterface, const GLchar *name)) _func)(program, programInterface, name);
}

GLAPI GLint APIENTRY glGetProgramResourceLocation(GLuint program, GLenum programInterface, const GLchar *name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1150];
   return ((GLint (APIENTRY *)(GLuint program, GLenum programInterface, const GLchar *name)) _func)(program, programInterface, name);
}

GLAPI GLint APIENTRY glGetProgramResourceLocationIndex(GLuint program, GLenum programInterface, const GLchar *name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1151];
   return ((GLint (APIENTRY *)(GLuint program, GLenum programInterface, const GLchar *name)) _func)(program, programInterface, name);
}

GLAPI GLint APIENTRY glGetProgramResourceLocationIndexEXT(GLuint program, GLenum programInterface, const GLchar *name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1152];
   return ((GLint (APIENTRY *)(GLuint program, GLenum programInterface, const GLchar *name)) _func)(program, programInterface, name);
}

GLAPI void APIENTRY glGetProgramResourceName(GLuint program, GLenum programInterface, GLuint index, GLsizei bufSize, GLsizei *length, GLchar *name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1153];
   ((void (APIENTRY *)(GLuint program, GLenum programInterface, GLuint index, GLsizei bufSize, GLsizei *length, GLchar *name)) _func)(program, programInterface, index, bufSize, length, name);
}

GLAPI void APIENTRY glGetProgramResourcefvNV(GLuint program, GLenum programInterface, GLuint index, GLsizei propCount, const GLenum *props, GLsizei count, GLsizei *length, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1154];
   ((void (APIENTRY *)(GLuint program, GLenum programInterface, GLuint index, GLsizei propCount, const GLenum *props, GLsizei count, GLsizei *length, GLfloat *params)) _func)(program, programInterface, index, propCount, props, count, length, params);
}

GLAPI void APIENTRY glGetProgramResourceiv(GLuint program, GLenum programInterface, GLuint index, GLsizei propCount, const GLenum *props, GLsizei count, GLsizei *length, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1155];
   ((void (APIENTRY *)(GLuint program, GLenum programInterface, GLuint index, GLsizei propCount, const GLenum *props, GLsizei count, GLsizei *length, GLint *params)) _func)(program, programInterface, index, propCount, props, count, length, params);
}

GLAPI void APIENTRY glGetProgramStageiv(GLuint program, GLenum shadertype, GLenum pname, GLint *values)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1156];
   ((void (APIENTRY *)(GLuint program, GLenum shadertype, GLenum pname, GLint *values)) _func)(program, shadertype, pname, values);
}

GLAPI void APIENTRY glGetProgramStringARB(GLenum target, GLenum pname, void *string)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1157];
   ((void (APIENTRY *)(GLenum target, GLenum pname, void *string)) _func)(target, pname, string);
}

GLAPI void APIENTRY glGetProgramStringNV(GLuint id, GLenum pname, GLubyte *program)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1158];
   ((void (APIENTRY *)(GLuint id, GLenum pname, GLubyte *program)) _func)(id, pname, program);
}

GLAPI void APIENTRY glGetProgramSubroutineParameteruivNV(GLenum target, GLuint index, GLuint *param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1159];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLuint *param)) _func)(target, index, param);
}

GLAPI void APIENTRY glGetProgramiv(GLuint program, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1160];
   ((void (APIENTRY *)(GLuint program, GLenum pname, GLint *params)) _func)(program, pname, params);
}

GLAPI void APIENTRY glGetProgramivARB(GLenum target, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1161];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLint *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetProgramivNV(GLuint id, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1162];
   ((void (APIENTRY *)(GLuint id, GLenum pname, GLint *params)) _func)(id, pname, params);
}

GLAPI void APIENTRY glGetQueryBufferObjecti64v(GLuint id, GLuint buffer, GLenum pname, GLintptr offset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1163];
   ((void (APIENTRY *)(GLuint id, GLuint buffer, GLenum pname, GLintptr offset)) _func)(id, buffer, pname, offset);
}

GLAPI void APIENTRY glGetQueryBufferObjectiv(GLuint id, GLuint buffer, GLenum pname, GLintptr offset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1164];
   ((void (APIENTRY *)(GLuint id, GLuint buffer, GLenum pname, GLintptr offset)) _func)(id, buffer, pname, offset);
}

GLAPI void APIENTRY glGetQueryBufferObjectui64v(GLuint id, GLuint buffer, GLenum pname, GLintptr offset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1165];
   ((void (APIENTRY *)(GLuint id, GLuint buffer, GLenum pname, GLintptr offset)) _func)(id, buffer, pname, offset);
}

GLAPI void APIENTRY glGetQueryBufferObjectuiv(GLuint id, GLuint buffer, GLenum pname, GLintptr offset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1166];
   ((void (APIENTRY *)(GLuint id, GLuint buffer, GLenum pname, GLintptr offset)) _func)(id, buffer, pname, offset);
}

GLAPI void APIENTRY glGetQueryIndexediv(GLenum target, GLuint index, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1167];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLenum pname, GLint *params)) _func)(target, index, pname, params);
}

GLAPI void APIENTRY glGetQueryObjecti64v(GLuint id, GLenum pname, GLint64 *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1168];
   ((void (APIENTRY *)(GLuint id, GLenum pname, GLint64 *params)) _func)(id, pname, params);
}

GLAPI void APIENTRY glGetQueryObjecti64vEXT(GLuint id, GLenum pname, GLint64 *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1169];
   ((void (APIENTRY *)(GLuint id, GLenum pname, GLint64 *params)) _func)(id, pname, params);
}

GLAPI void APIENTRY glGetQueryObjectiv(GLuint id, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1170];
   ((void (APIENTRY *)(GLuint id, GLenum pname, GLint *params)) _func)(id, pname, params);
}

GLAPI void APIENTRY glGetQueryObjectivARB(GLuint id, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1171];
   ((void (APIENTRY *)(GLuint id, GLenum pname, GLint *params)) _func)(id, pname, params);
}

GLAPI void APIENTRY glGetQueryObjectivEXT(GLuint id, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1172];
   ((void (APIENTRY *)(GLuint id, GLenum pname, GLint *params)) _func)(id, pname, params);
}

GLAPI void APIENTRY glGetQueryObjectui64v(GLuint id, GLenum pname, GLuint64 *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1173];
   ((void (APIENTRY *)(GLuint id, GLenum pname, GLuint64 *params)) _func)(id, pname, params);
}

GLAPI void APIENTRY glGetQueryObjectui64vEXT(GLuint id, GLenum pname, GLuint64 *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1174];
   ((void (APIENTRY *)(GLuint id, GLenum pname, GLuint64 *params)) _func)(id, pname, params);
}

GLAPI void APIENTRY glGetQueryObjectui64vNV(GLuint id, GLenum pname, GLuint64 *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1175];
   ((void (APIENTRY *)(GLuint id, GLenum pname, GLuint64 *params)) _func)(id, pname, params);
}

GLAPI void APIENTRY glGetQueryObjectuiv(GLuint id, GLenum pname, GLuint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1176];
   ((void (APIENTRY *)(GLuint id, GLenum pname, GLuint *params)) _func)(id, pname, params);
}

GLAPI void APIENTRY glGetQueryObjectuivARB(GLuint id, GLenum pname, GLuint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1177];
   ((void (APIENTRY *)(GLuint id, GLenum pname, GLuint *params)) _func)(id, pname, params);
}

GLAPI void APIENTRY glGetQueryObjectuivEXT(GLuint id, GLenum pname, GLuint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1178];
   ((void (APIENTRY *)(GLuint id, GLenum pname, GLuint *params)) _func)(id, pname, params);
}

GLAPI void APIENTRY glGetQueryiv(GLenum target, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1179];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLint *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetQueryivARB(GLenum target, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1180];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLint *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetQueryivEXT(GLenum target, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1181];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLint *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetRenderbufferParameteriv(GLenum target, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1182];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLint *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetRenderbufferParameterivEXT(GLenum target, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1183];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLint *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetRenderbufferParameterivOES(GLenum target, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1184];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLint *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetSamplerParameterIiv(GLuint sampler, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1185];
   ((void (APIENTRY *)(GLuint sampler, GLenum pname, GLint *params)) _func)(sampler, pname, params);
}

GLAPI void APIENTRY glGetSamplerParameterIivEXT(GLuint sampler, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1186];
   ((void (APIENTRY *)(GLuint sampler, GLenum pname, GLint *params)) _func)(sampler, pname, params);
}

GLAPI void APIENTRY glGetSamplerParameterIivOES(GLuint sampler, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1187];
   ((void (APIENTRY *)(GLuint sampler, GLenum pname, GLint *params)) _func)(sampler, pname, params);
}

GLAPI void APIENTRY glGetSamplerParameterIuiv(GLuint sampler, GLenum pname, GLuint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1188];
   ((void (APIENTRY *)(GLuint sampler, GLenum pname, GLuint *params)) _func)(sampler, pname, params);
}

GLAPI void APIENTRY glGetSamplerParameterIuivEXT(GLuint sampler, GLenum pname, GLuint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1189];
   ((void (APIENTRY *)(GLuint sampler, GLenum pname, GLuint *params)) _func)(sampler, pname, params);
}

GLAPI void APIENTRY glGetSamplerParameterIuivOES(GLuint sampler, GLenum pname, GLuint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1190];
   ((void (APIENTRY *)(GLuint sampler, GLenum pname, GLuint *params)) _func)(sampler, pname, params);
}

GLAPI void APIENTRY glGetSamplerParameterfv(GLuint sampler, GLenum pname, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1191];
   ((void (APIENTRY *)(GLuint sampler, GLenum pname, GLfloat *params)) _func)(sampler, pname, params);
}

GLAPI void APIENTRY glGetSamplerParameteriv(GLuint sampler, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1192];
   ((void (APIENTRY *)(GLuint sampler, GLenum pname, GLint *params)) _func)(sampler, pname, params);
}

GLAPI void APIENTRY glGetSemaphoreParameterui64vEXT(GLuint semaphore, GLenum pname, GLuint64 *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1194];
   ((void (APIENTRY *)(GLuint semaphore, GLenum pname, GLuint64 *params)) _func)(semaphore, pname, params);
}

GLAPI void APIENTRY glGetSeparableFilter(GLenum target, GLenum format, GLenum type, void *row, void *column, void *span)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1195];
   ((void (APIENTRY *)(GLenum target, GLenum format, GLenum type, void *row, void *column, void *span)) _func)(target, format, type, row, column, span);
}

GLAPI void APIENTRY glGetSeparableFilterEXT(GLenum target, GLenum format, GLenum type, void *row, void *column, void *span)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1196];
   ((void (APIENTRY *)(GLenum target, GLenum format, GLenum type, void *row, void *column, void *span)) _func)(target, format, type, row, column, span);
}

GLAPI void APIENTRY glGetShaderInfoLog(GLuint shader, GLsizei bufSize, GLsizei *length, GLchar *infoLog)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1197];
   ((void (APIENTRY *)(GLuint shader, GLsizei bufSize, GLsizei *length, GLchar *infoLog)) _func)(shader, bufSize, length, infoLog);
}

GLAPI void APIENTRY glGetShaderPrecisionFormat(GLenum shadertype, GLenum precisiontype, GLint *range, GLint *precision)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1198];
   ((void (APIENTRY *)(GLenum shadertype, GLenum precisiontype, GLint *range, GLint *precision)) _func)(shadertype, precisiontype, range, precision);
}

GLAPI void APIENTRY glGetShaderSource(GLuint shader, GLsizei bufSize, GLsizei *length, GLchar *source)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1199];
   ((void (APIENTRY *)(GLuint shader, GLsizei bufSize, GLsizei *length, GLchar *source)) _func)(shader, bufSize, length, source);
}

GLAPI void APIENTRY glGetShaderSourceARB(GLhandleARB obj, GLsizei maxLength, GLsizei *length, GLcharARB *source)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1200];
   ((void (APIENTRY *)(GLhandleARB obj, GLsizei maxLength, GLsizei *length, GLcharARB *source)) _func)(obj, maxLength, length, source);
}

GLAPI void APIENTRY glGetShaderiv(GLuint shader, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1201];
   ((void (APIENTRY *)(GLuint shader, GLenum pname, GLint *params)) _func)(shader, pname, params);
}

GLAPI void APIENTRY glGetShadingRateImagePaletteNV(GLuint viewport, GLuint entry, GLenum *rate)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1202];
   ((void (APIENTRY *)(GLuint viewport, GLuint entry, GLenum *rate)) _func)(viewport, entry, rate);
}

GLAPI void APIENTRY glGetShadingRateSampleLocationivNV(GLenum rate, GLuint samples, GLuint index, GLint *location)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1203];
   ((void (APIENTRY *)(GLenum rate, GLuint samples, GLuint index, GLint *location)) _func)(rate, samples, index, location);
}

GLAPI void APIENTRY glGetSharpenTexFuncSGIS(GLenum target, GLfloat *points)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1204];
   ((void (APIENTRY *)(GLenum target, GLfloat *points)) _func)(target, points);
}

GLAPI GLushort APIENTRY glGetStageIndexNV(GLenum shadertype)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1205];
   return ((GLushort (APIENTRY *)(GLenum shadertype)) _func)(shadertype);
}

GLAPI const GLubyte * APIENTRY glGetString(GLenum name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1206];
   return ((const GLubyte * (APIENTRY *)(GLenum name)) _func)(name);
}

GLAPI const GLubyte * APIENTRY glGetStringi(GLenum name, GLuint index)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1207];
   return ((const GLubyte * (APIENTRY *)(GLenum name, GLuint index)) _func)(name, index);
}

GLAPI GLuint APIENTRY glGetSubroutineIndex(GLuint program, GLenum shadertype, const GLchar *name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1208];
   return ((GLuint (APIENTRY *)(GLuint program, GLenum shadertype, const GLchar *name)) _func)(program, shadertype, name);
}

GLAPI GLint APIENTRY glGetSubroutineUniformLocation(GLuint program, GLenum shadertype, const GLchar *name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1209];
   return ((GLint (APIENTRY *)(GLuint program, GLenum shadertype, const GLchar *name)) _func)(program, shadertype, name);
}

GLAPI void APIENTRY glGetSynciv(GLsync sync, GLenum pname, GLsizei count, GLsizei *length, GLint *values)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1210];
   ((void (APIENTRY *)(GLsync sync, GLenum pname, GLsizei count, GLsizei *length, GLint *values)) _func)(sync, pname, count, length, values);
}

GLAPI void APIENTRY glGetSyncivAPPLE(GLsync sync, GLenum pname, GLsizei count, GLsizei *length, GLint *values)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1211];
   ((void (APIENTRY *)(GLsync sync, GLenum pname, GLsizei count, GLsizei *length, GLint *values)) _func)(sync, pname, count, length, values);
}

GLAPI void APIENTRY glGetSyncv64NVX(GLsync sync, GLenum pname, GLuint64 *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1212];
   ((void (APIENTRY *)(GLsync sync, GLenum pname, GLuint64 *value)) _func)(sync, pname, value);
}

GLAPI void APIENTRY glGetTexBumpParameterfvATI(GLenum pname, GLfloat *param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1213];
   ((void (APIENTRY *)(GLenum pname, GLfloat *param)) _func)(pname, param);
}

GLAPI void APIENTRY glGetTexBumpParameterivATI(GLenum pname, GLint *param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1214];
   ((void (APIENTRY *)(GLenum pname, GLint *param)) _func)(pname, param);
}

GLAPI void APIENTRY glGetTexEnvfv(GLenum target, GLenum pname, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1215];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLfloat *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetTexEnviv(GLenum target, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1216];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLint *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetTexEnvxv(GLenum target, GLenum pname, GLfixed *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1217];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLfixed *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetTexEnvxvOES(GLenum target, GLenum pname, GLfixed *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1218];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLfixed *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetTexFilterFuncSGIS(GLenum target, GLenum filter, GLfloat *weights)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1219];
   ((void (APIENTRY *)(GLenum target, GLenum filter, GLfloat *weights)) _func)(target, filter, weights);
}

GLAPI void APIENTRY glGetTexGendv(GLenum coord, GLenum pname, GLdouble *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1220];
   ((void (APIENTRY *)(GLenum coord, GLenum pname, GLdouble *params)) _func)(coord, pname, params);
}

GLAPI void APIENTRY glGetTexGenfv(GLenum coord, GLenum pname, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1221];
   ((void (APIENTRY *)(GLenum coord, GLenum pname, GLfloat *params)) _func)(coord, pname, params);
}

GLAPI void APIENTRY glGetTexGenfvOES(GLenum coord, GLenum pname, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1222];
   ((void (APIENTRY *)(GLenum coord, GLenum pname, GLfloat *params)) _func)(coord, pname, params);
}

GLAPI void APIENTRY glGetTexGeniv(GLenum coord, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1223];
   ((void (APIENTRY *)(GLenum coord, GLenum pname, GLint *params)) _func)(coord, pname, params);
}

GLAPI void APIENTRY glGetTexGenivOES(GLenum coord, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1224];
   ((void (APIENTRY *)(GLenum coord, GLenum pname, GLint *params)) _func)(coord, pname, params);
}

GLAPI void APIENTRY glGetTexGenxvOES(GLenum coord, GLenum pname, GLfixed *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1225];
   ((void (APIENTRY *)(GLenum coord, GLenum pname, GLfixed *params)) _func)(coord, pname, params);
}

GLAPI void APIENTRY glGetTexImage(GLenum target, GLint level, GLenum format, GLenum type, void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1226];
   ((void (APIENTRY *)(GLenum target, GLint level, GLenum format, GLenum type, void *pixels)) _func)(target, level, format, type, pixels);
}

GLAPI void APIENTRY glGetTexImageNV(GLenum target, GLint level, GLenum format, GLenum type, void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1227];
   ((void (APIENTRY *)(GLenum target, GLint level, GLenum format, GLenum type, void *pixels)) _func)(target, level, format, type, pixels);
}

GLAPI void APIENTRY glGetTexLevelParameterfv(GLenum target, GLint level, GLenum pname, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1228];
   ((void (APIENTRY *)(GLenum target, GLint level, GLenum pname, GLfloat *params)) _func)(target, level, pname, params);
}

GLAPI void APIENTRY glGetTexLevelParameterfvNV(GLenum target, GLint level, GLenum pname, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1229];
   ((void (APIENTRY *)(GLenum target, GLint level, GLenum pname, GLfloat *params)) _func)(target, level, pname, params);
}

GLAPI void APIENTRY glGetTexLevelParameteriv(GLenum target, GLint level, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1230];
   ((void (APIENTRY *)(GLenum target, GLint level, GLenum pname, GLint *params)) _func)(target, level, pname, params);
}

GLAPI void APIENTRY glGetTexLevelParameterivNV(GLenum target, GLint level, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1231];
   ((void (APIENTRY *)(GLenum target, GLint level, GLenum pname, GLint *params)) _func)(target, level, pname, params);
}

GLAPI void APIENTRY glGetTexLevelParameterxvOES(GLenum target, GLint level, GLenum pname, GLfixed *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1232];
   ((void (APIENTRY *)(GLenum target, GLint level, GLenum pname, GLfixed *params)) _func)(target, level, pname, params);
}

GLAPI void APIENTRY glGetTexParameterIiv(GLenum target, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1233];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLint *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetTexParameterIivEXT(GLenum target, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1234];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLint *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetTexParameterIivOES(GLenum target, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1235];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLint *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetTexParameterIuiv(GLenum target, GLenum pname, GLuint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1236];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLuint *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetTexParameterIuivEXT(GLenum target, GLenum pname, GLuint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1237];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLuint *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetTexParameterIuivOES(GLenum target, GLenum pname, GLuint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1238];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLuint *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetTexParameterPointervAPPLE(GLenum target, GLenum pname, void **params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1239];
   ((void (APIENTRY *)(GLenum target, GLenum pname, void **params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetTexParameterfv(GLenum target, GLenum pname, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1240];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLfloat *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetTexParameteriv(GLenum target, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1241];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLint *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetTexParameterxv(GLenum target, GLenum pname, GLfixed *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1242];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLfixed *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glGetTexParameterxvOES(GLenum target, GLenum pname, GLfixed *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1243];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLfixed *params)) _func)(target, pname, params);
}

GLAPI GLuint64 APIENTRY glGetTextureHandleARB(GLuint texture)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1244];
   return ((GLuint64 (APIENTRY *)(GLuint texture)) _func)(texture);
}

GLAPI GLuint64 APIENTRY glGetTextureHandleIMG(GLuint texture)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1245];
   return ((GLuint64 (APIENTRY *)(GLuint texture)) _func)(texture);
}

GLAPI GLuint64 APIENTRY glGetTextureHandleNV(GLuint texture)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1246];
   return ((GLuint64 (APIENTRY *)(GLuint texture)) _func)(texture);
}

GLAPI void APIENTRY glGetTextureImage(GLuint texture, GLint level, GLenum format, GLenum type, GLsizei bufSize, void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1247];
   ((void (APIENTRY *)(GLuint texture, GLint level, GLenum format, GLenum type, GLsizei bufSize, void *pixels)) _func)(texture, level, format, type, bufSize, pixels);
}

GLAPI void APIENTRY glGetTextureImageEXT(GLuint texture, GLenum target, GLint level, GLenum format, GLenum type, void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1248];
   ((void (APIENTRY *)(GLuint texture, GLenum target, GLint level, GLenum format, GLenum type, void *pixels)) _func)(texture, target, level, format, type, pixels);
}

GLAPI void APIENTRY glGetTextureLevelParameterfv(GLuint texture, GLint level, GLenum pname, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1249];
   ((void (APIENTRY *)(GLuint texture, GLint level, GLenum pname, GLfloat *params)) _func)(texture, level, pname, params);
}

GLAPI void APIENTRY glGetTextureLevelParameterfvEXT(GLuint texture, GLenum target, GLint level, GLenum pname, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1250];
   ((void (APIENTRY *)(GLuint texture, GLenum target, GLint level, GLenum pname, GLfloat *params)) _func)(texture, target, level, pname, params);
}

GLAPI void APIENTRY glGetTextureLevelParameteriv(GLuint texture, GLint level, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1251];
   ((void (APIENTRY *)(GLuint texture, GLint level, GLenum pname, GLint *params)) _func)(texture, level, pname, params);
}

GLAPI void APIENTRY glGetTextureLevelParameterivEXT(GLuint texture, GLenum target, GLint level, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1252];
   ((void (APIENTRY *)(GLuint texture, GLenum target, GLint level, GLenum pname, GLint *params)) _func)(texture, target, level, pname, params);
}

GLAPI void APIENTRY glGetTextureParameterIiv(GLuint texture, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1253];
   ((void (APIENTRY *)(GLuint texture, GLenum pname, GLint *params)) _func)(texture, pname, params);
}

GLAPI void APIENTRY glGetTextureParameterIivEXT(GLuint texture, GLenum target, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1254];
   ((void (APIENTRY *)(GLuint texture, GLenum target, GLenum pname, GLint *params)) _func)(texture, target, pname, params);
}

GLAPI void APIENTRY glGetTextureParameterIuiv(GLuint texture, GLenum pname, GLuint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1255];
   ((void (APIENTRY *)(GLuint texture, GLenum pname, GLuint *params)) _func)(texture, pname, params);
}

GLAPI void APIENTRY glGetTextureParameterIuivEXT(GLuint texture, GLenum target, GLenum pname, GLuint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1256];
   ((void (APIENTRY *)(GLuint texture, GLenum target, GLenum pname, GLuint *params)) _func)(texture, target, pname, params);
}

GLAPI void APIENTRY glGetTextureParameterfv(GLuint texture, GLenum pname, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1257];
   ((void (APIENTRY *)(GLuint texture, GLenum pname, GLfloat *params)) _func)(texture, pname, params);
}

GLAPI void APIENTRY glGetTextureParameterfvEXT(GLuint texture, GLenum target, GLenum pname, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1258];
   ((void (APIENTRY *)(GLuint texture, GLenum target, GLenum pname, GLfloat *params)) _func)(texture, target, pname, params);
}

GLAPI void APIENTRY glGetTextureParameteriv(GLuint texture, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1259];
   ((void (APIENTRY *)(GLuint texture, GLenum pname, GLint *params)) _func)(texture, pname, params);
}

GLAPI void APIENTRY glGetTextureParameterivEXT(GLuint texture, GLenum target, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1260];
   ((void (APIENTRY *)(GLuint texture, GLenum target, GLenum pname, GLint *params)) _func)(texture, target, pname, params);
}

GLAPI GLuint64 APIENTRY glGetTextureSamplerHandleARB(GLuint texture, GLuint sampler)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1261];
   return ((GLuint64 (APIENTRY *)(GLuint texture, GLuint sampler)) _func)(texture, sampler);
}

GLAPI GLuint64 APIENTRY glGetTextureSamplerHandleIMG(GLuint texture, GLuint sampler)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1262];
   return ((GLuint64 (APIENTRY *)(GLuint texture, GLuint sampler)) _func)(texture, sampler);
}

GLAPI GLuint64 APIENTRY glGetTextureSamplerHandleNV(GLuint texture, GLuint sampler)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1263];
   return ((GLuint64 (APIENTRY *)(GLuint texture, GLuint sampler)) _func)(texture, sampler);
}

GLAPI void APIENTRY glGetTextureSubImage(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, GLsizei bufSize, void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1264];
   ((void (APIENTRY *)(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, GLsizei bufSize, void *pixels)) _func)(texture, level, xoffset, yoffset, zoffset, width, height, depth, format, type, bufSize, pixels);
}

GLAPI void APIENTRY glGetTrackMatrixivNV(GLenum target, GLuint address, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1265];
   ((void (APIENTRY *)(GLenum target, GLuint address, GLenum pname, GLint *params)) _func)(target, address, pname, params);
}

GLAPI void APIENTRY glGetTransformFeedbackVarying(GLuint program, GLuint index, GLsizei bufSize, GLsizei *length, GLsizei *size, GLenum *type, GLchar *name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1266];
   ((void (APIENTRY *)(GLuint program, GLuint index, GLsizei bufSize, GLsizei *length, GLsizei *size, GLenum *type, GLchar *name)) _func)(program, index, bufSize, length, size, type, name);
}

GLAPI void APIENTRY glGetTransformFeedbackVaryingEXT(GLuint program, GLuint index, GLsizei bufSize, GLsizei *length, GLsizei *size, GLenum *type, GLchar *name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1267];
   ((void (APIENTRY *)(GLuint program, GLuint index, GLsizei bufSize, GLsizei *length, GLsizei *size, GLenum *type, GLchar *name)) _func)(program, index, bufSize, length, size, type, name);
}

GLAPI void APIENTRY glGetTransformFeedbackVaryingNV(GLuint program, GLuint index, GLint *location)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1268];
   ((void (APIENTRY *)(GLuint program, GLuint index, GLint *location)) _func)(program, index, location);
}

GLAPI void APIENTRY glGetTransformFeedbacki64_v(GLuint xfb, GLenum pname, GLuint index, GLint64 *param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1269];
   ((void (APIENTRY *)(GLuint xfb, GLenum pname, GLuint index, GLint64 *param)) _func)(xfb, pname, index, param);
}

GLAPI void APIENTRY glGetTransformFeedbacki_v(GLuint xfb, GLenum pname, GLuint index, GLint *param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1270];
   ((void (APIENTRY *)(GLuint xfb, GLenum pname, GLuint index, GLint *param)) _func)(xfb, pname, index, param);
}

GLAPI void APIENTRY glGetTransformFeedbackiv(GLuint xfb, GLenum pname, GLint *param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1271];
   ((void (APIENTRY *)(GLuint xfb, GLenum pname, GLint *param)) _func)(xfb, pname, param);
}

GLAPI void APIENTRY glGetTranslatedShaderSourceANGLE(GLuint shader, GLsizei bufSize, GLsizei *length, GLchar *source)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1272];
   ((void (APIENTRY *)(GLuint shader, GLsizei bufSize, GLsizei *length, GLchar *source)) _func)(shader, bufSize, length, source);
}

GLAPI GLuint APIENTRY glGetUniformBlockIndex(GLuint program, const GLchar *uniformBlockName)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1273];
   return ((GLuint (APIENTRY *)(GLuint program, const GLchar *uniformBlockName)) _func)(program, uniformBlockName);
}

GLAPI GLint APIENTRY glGetUniformBufferSizeEXT(GLuint program, GLint location)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1274];
   return ((GLint (APIENTRY *)(GLuint program, GLint location)) _func)(program, location);
}

GLAPI void APIENTRY glGetUniformIndices(GLuint program, GLsizei uniformCount, const GLchar *const *uniformNames, GLuint *uniformIndices)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1275];
   ((void (APIENTRY *)(GLuint program, GLsizei uniformCount, const GLchar *const *uniformNames, GLuint *uniformIndices)) _func)(program, uniformCount, uniformNames, uniformIndices);
}

GLAPI GLint APIENTRY glGetUniformLocation(GLuint program, const GLchar *name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1276];
   return ((GLint (APIENTRY *)(GLuint program, const GLchar *name)) _func)(program, name);
}

GLAPI GLint APIENTRY glGetUniformLocationARB(GLhandleARB programObj, const GLcharARB *name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1277];
   return ((GLint (APIENTRY *)(GLhandleARB programObj, const GLcharARB *name)) _func)(programObj, name);
}

GLAPI GLintptr APIENTRY glGetUniformOffsetEXT(GLuint program, GLint location)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1278];
   return ((GLintptr (APIENTRY *)(GLuint program, GLint location)) _func)(program, location);
}

GLAPI void APIENTRY glGetUniformSubroutineuiv(GLenum shadertype, GLint location, GLuint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1279];
   ((void (APIENTRY *)(GLenum shadertype, GLint location, GLuint *params)) _func)(shadertype, location, params);
}

GLAPI void APIENTRY glGetUniformdv(GLuint program, GLint location, GLdouble *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1280];
   ((void (APIENTRY *)(GLuint program, GLint location, GLdouble *params)) _func)(program, location, params);
}

GLAPI void APIENTRY glGetUniformfv(GLuint program, GLint location, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1281];
   ((void (APIENTRY *)(GLuint program, GLint location, GLfloat *params)) _func)(program, location, params);
}

GLAPI void APIENTRY glGetUniformfvARB(GLhandleARB programObj, GLint location, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1282];
   ((void (APIENTRY *)(GLhandleARB programObj, GLint location, GLfloat *params)) _func)(programObj, location, params);
}

GLAPI void APIENTRY glGetUniformi64vARB(GLuint program, GLint location, GLint64 *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1283];
   ((void (APIENTRY *)(GLuint program, GLint location, GLint64 *params)) _func)(program, location, params);
}

GLAPI void APIENTRY glGetUniformi64vNV(GLuint program, GLint location, GLint64 *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1284];
   ((void (APIENTRY *)(GLuint program, GLint location, GLint64 *params)) _func)(program, location, params);
}

GLAPI void APIENTRY glGetUniformiv(GLuint program, GLint location, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1285];
   ((void (APIENTRY *)(GLuint program, GLint location, GLint *params)) _func)(program, location, params);
}

GLAPI void APIENTRY glGetUniformivARB(GLhandleARB programObj, GLint location, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1286];
   ((void (APIENTRY *)(GLhandleARB programObj, GLint location, GLint *params)) _func)(programObj, location, params);
}

GLAPI void APIENTRY glGetUniformui64vARB(GLuint program, GLint location, GLuint64 *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1287];
   ((void (APIENTRY *)(GLuint program, GLint location, GLuint64 *params)) _func)(program, location, params);
}

GLAPI void APIENTRY glGetUniformui64vNV(GLuint program, GLint location, GLuint64 *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1288];
   ((void (APIENTRY *)(GLuint program, GLint location, GLuint64 *params)) _func)(program, location, params);
}

GLAPI void APIENTRY glGetUniformuiv(GLuint program, GLint location, GLuint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1289];
   ((void (APIENTRY *)(GLuint program, GLint location, GLuint *params)) _func)(program, location, params);
}

GLAPI void APIENTRY glGetUniformuivEXT(GLuint program, GLint location, GLuint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1290];
   ((void (APIENTRY *)(GLuint program, GLint location, GLuint *params)) _func)(program, location, params);
}

GLAPI void APIENTRY glGetUnsignedBytei_vEXT(GLenum target, GLuint index, GLubyte *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1291];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLubyte *data)) _func)(target, index, data);
}

GLAPI void APIENTRY glGetUnsignedBytevEXT(GLenum pname, GLubyte *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1292];
   ((void (APIENTRY *)(GLenum pname, GLubyte *data)) _func)(pname, data);
}

GLAPI void APIENTRY glGetVariantArrayObjectfvATI(GLuint id, GLenum pname, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1293];
   ((void (APIENTRY *)(GLuint id, GLenum pname, GLfloat *params)) _func)(id, pname, params);
}

GLAPI void APIENTRY glGetVariantArrayObjectivATI(GLuint id, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1294];
   ((void (APIENTRY *)(GLuint id, GLenum pname, GLint *params)) _func)(id, pname, params);
}

GLAPI void APIENTRY glGetVariantBooleanvEXT(GLuint id, GLenum value, GLboolean *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1295];
   ((void (APIENTRY *)(GLuint id, GLenum value, GLboolean *data)) _func)(id, value, data);
}

GLAPI void APIENTRY glGetVariantFloatvEXT(GLuint id, GLenum value, GLfloat *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1296];
   ((void (APIENTRY *)(GLuint id, GLenum value, GLfloat *data)) _func)(id, value, data);
}

GLAPI void APIENTRY glGetVariantIntegervEXT(GLuint id, GLenum value, GLint *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1297];
   ((void (APIENTRY *)(GLuint id, GLenum value, GLint *data)) _func)(id, value, data);
}

GLAPI void APIENTRY glGetVariantPointervEXT(GLuint id, GLenum value, void **data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1298];
   ((void (APIENTRY *)(GLuint id, GLenum value, void **data)) _func)(id, value, data);
}

GLAPI GLint APIENTRY glGetVaryingLocationNV(GLuint program, const GLchar *name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1299];
   return ((GLint (APIENTRY *)(GLuint program, const GLchar *name)) _func)(program, name);
}

GLAPI void APIENTRY glGetVertexArrayIndexed64iv(GLuint vaobj, GLuint index, GLenum pname, GLint64 *param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1300];
   ((void (APIENTRY *)(GLuint vaobj, GLuint index, GLenum pname, GLint64 *param)) _func)(vaobj, index, pname, param);
}

GLAPI void APIENTRY glGetVertexArrayIndexediv(GLuint vaobj, GLuint index, GLenum pname, GLint *param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1301];
   ((void (APIENTRY *)(GLuint vaobj, GLuint index, GLenum pname, GLint *param)) _func)(vaobj, index, pname, param);
}

GLAPI void APIENTRY glGetVertexArrayIntegeri_vEXT(GLuint vaobj, GLuint index, GLenum pname, GLint *param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1302];
   ((void (APIENTRY *)(GLuint vaobj, GLuint index, GLenum pname, GLint *param)) _func)(vaobj, index, pname, param);
}

GLAPI void APIENTRY glGetVertexArrayIntegervEXT(GLuint vaobj, GLenum pname, GLint *param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1303];
   ((void (APIENTRY *)(GLuint vaobj, GLenum pname, GLint *param)) _func)(vaobj, pname, param);
}

GLAPI void APIENTRY glGetVertexArrayPointeri_vEXT(GLuint vaobj, GLuint index, GLenum pname, void **param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1304];
   ((void (APIENTRY *)(GLuint vaobj, GLuint index, GLenum pname, void **param)) _func)(vaobj, index, pname, param);
}

GLAPI void APIENTRY glGetVertexArrayPointervEXT(GLuint vaobj, GLenum pname, void **param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1305];
   ((void (APIENTRY *)(GLuint vaobj, GLenum pname, void **param)) _func)(vaobj, pname, param);
}

GLAPI void APIENTRY glGetVertexArrayiv(GLuint vaobj, GLenum pname, GLint *param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1306];
   ((void (APIENTRY *)(GLuint vaobj, GLenum pname, GLint *param)) _func)(vaobj, pname, param);
}

GLAPI void APIENTRY glGetVertexAttribArrayObjectfvATI(GLuint index, GLenum pname, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1307];
   ((void (APIENTRY *)(GLuint index, GLenum pname, GLfloat *params)) _func)(index, pname, params);
}

GLAPI void APIENTRY glGetVertexAttribArrayObjectivATI(GLuint index, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1308];
   ((void (APIENTRY *)(GLuint index, GLenum pname, GLint *params)) _func)(index, pname, params);
}

GLAPI void APIENTRY glGetVertexAttribIiv(GLuint index, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1309];
   ((void (APIENTRY *)(GLuint index, GLenum pname, GLint *params)) _func)(index, pname, params);
}

GLAPI void APIENTRY glGetVertexAttribIivEXT(GLuint index, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1310];
   ((void (APIENTRY *)(GLuint index, GLenum pname, GLint *params)) _func)(index, pname, params);
}

GLAPI void APIENTRY glGetVertexAttribIuiv(GLuint index, GLenum pname, GLuint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1311];
   ((void (APIENTRY *)(GLuint index, GLenum pname, GLuint *params)) _func)(index, pname, params);
}

GLAPI void APIENTRY glGetVertexAttribIuivEXT(GLuint index, GLenum pname, GLuint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1312];
   ((void (APIENTRY *)(GLuint index, GLenum pname, GLuint *params)) _func)(index, pname, params);
}

GLAPI void APIENTRY glGetVertexAttribLdv(GLuint index, GLenum pname, GLdouble *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1313];
   ((void (APIENTRY *)(GLuint index, GLenum pname, GLdouble *params)) _func)(index, pname, params);
}

GLAPI void APIENTRY glGetVertexAttribLdvEXT(GLuint index, GLenum pname, GLdouble *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1314];
   ((void (APIENTRY *)(GLuint index, GLenum pname, GLdouble *params)) _func)(index, pname, params);
}

GLAPI void APIENTRY glGetVertexAttribLi64vNV(GLuint index, GLenum pname, GLint64 *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1315];
   ((void (APIENTRY *)(GLuint index, GLenum pname, GLint64 *params)) _func)(index, pname, params);
}

GLAPI void APIENTRY glGetVertexAttribLui64vARB(GLuint index, GLenum pname, GLuint64 *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1316];
   ((void (APIENTRY *)(GLuint index, GLenum pname, GLuint64 *params)) _func)(index, pname, params);
}

GLAPI void APIENTRY glGetVertexAttribLui64vNV(GLuint index, GLenum pname, GLuint64 *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1317];
   ((void (APIENTRY *)(GLuint index, GLenum pname, GLuint64 *params)) _func)(index, pname, params);
}

GLAPI void APIENTRY glGetVertexAttribPointerv(GLuint index, GLenum pname, void **pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1318];
   ((void (APIENTRY *)(GLuint index, GLenum pname, void **pointer)) _func)(index, pname, pointer);
}

GLAPI void APIENTRY glGetVertexAttribPointervARB(GLuint index, GLenum pname, void **pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1319];
   ((void (APIENTRY *)(GLuint index, GLenum pname, void **pointer)) _func)(index, pname, pointer);
}

GLAPI void APIENTRY glGetVertexAttribPointervNV(GLuint index, GLenum pname, void **pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1320];
   ((void (APIENTRY *)(GLuint index, GLenum pname, void **pointer)) _func)(index, pname, pointer);
}

GLAPI void APIENTRY glGetVertexAttribdv(GLuint index, GLenum pname, GLdouble *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1321];
   ((void (APIENTRY *)(GLuint index, GLenum pname, GLdouble *params)) _func)(index, pname, params);
}

GLAPI void APIENTRY glGetVertexAttribdvARB(GLuint index, GLenum pname, GLdouble *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1322];
   ((void (APIENTRY *)(GLuint index, GLenum pname, GLdouble *params)) _func)(index, pname, params);
}

GLAPI void APIENTRY glGetVertexAttribdvNV(GLuint index, GLenum pname, GLdouble *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1323];
   ((void (APIENTRY *)(GLuint index, GLenum pname, GLdouble *params)) _func)(index, pname, params);
}

GLAPI void APIENTRY glGetVertexAttribfv(GLuint index, GLenum pname, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1324];
   ((void (APIENTRY *)(GLuint index, GLenum pname, GLfloat *params)) _func)(index, pname, params);
}

GLAPI void APIENTRY glGetVertexAttribfvARB(GLuint index, GLenum pname, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1325];
   ((void (APIENTRY *)(GLuint index, GLenum pname, GLfloat *params)) _func)(index, pname, params);
}

GLAPI void APIENTRY glGetVertexAttribfvNV(GLuint index, GLenum pname, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1326];
   ((void (APIENTRY *)(GLuint index, GLenum pname, GLfloat *params)) _func)(index, pname, params);
}

GLAPI void APIENTRY glGetVertexAttribiv(GLuint index, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1327];
   ((void (APIENTRY *)(GLuint index, GLenum pname, GLint *params)) _func)(index, pname, params);
}

GLAPI void APIENTRY glGetVertexAttribivARB(GLuint index, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1328];
   ((void (APIENTRY *)(GLuint index, GLenum pname, GLint *params)) _func)(index, pname, params);
}

GLAPI void APIENTRY glGetVertexAttribivNV(GLuint index, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1329];
   ((void (APIENTRY *)(GLuint index, GLenum pname, GLint *params)) _func)(index, pname, params);
}

GLAPI void APIENTRY glGetVideoCaptureANCStreamivNVX(GLuint video_capture_slot, GLuint stream, GLenum pname, GLenum frame_region, GLenum anc_region, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1330];
   ((void (APIENTRY *)(GLuint video_capture_slot, GLuint stream, GLenum pname, GLenum frame_region, GLenum anc_region, GLint *params)) _func)(video_capture_slot, stream, pname, frame_region, anc_region, params);
}

GLAPI void APIENTRY glGetVideoCaptureStreamdvNV(GLuint video_capture_slot, GLuint stream, GLenum pname, GLdouble *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1331];
   ((void (APIENTRY *)(GLuint video_capture_slot, GLuint stream, GLenum pname, GLdouble *params)) _func)(video_capture_slot, stream, pname, params);
}

GLAPI void APIENTRY glGetVideoCaptureStreamfvNV(GLuint video_capture_slot, GLuint stream, GLenum pname, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1332];
   ((void (APIENTRY *)(GLuint video_capture_slot, GLuint stream, GLenum pname, GLfloat *params)) _func)(video_capture_slot, stream, pname, params);
}

GLAPI void APIENTRY glGetVideoCaptureStreamivNV(GLuint video_capture_slot, GLuint stream, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1333];
   ((void (APIENTRY *)(GLuint video_capture_slot, GLuint stream, GLenum pname, GLint *params)) _func)(video_capture_slot, stream, pname, params);
}

GLAPI void APIENTRY glGetVideoCaptureivNV(GLuint video_capture_slot, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1334];
   ((void (APIENTRY *)(GLuint video_capture_slot, GLenum pname, GLint *params)) _func)(video_capture_slot, pname, params);
}

GLAPI void APIENTRY glGetVideoi64vNV(GLuint video_slot, GLenum pname, GLint64 *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1335];
   ((void (APIENTRY *)(GLuint video_slot, GLenum pname, GLint64 *params)) _func)(video_slot, pname, params);
}

GLAPI void APIENTRY glGetVideoivNV(GLuint video_slot, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1336];
   ((void (APIENTRY *)(GLuint video_slot, GLenum pname, GLint *params)) _func)(video_slot, pname, params);
}

GLAPI void APIENTRY glGetVideoui64vNV(GLuint video_slot, GLenum pname, GLuint64 *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1337];
   ((void (APIENTRY *)(GLuint video_slot, GLenum pname, GLuint64 *params)) _func)(video_slot, pname, params);
}

GLAPI void APIENTRY glGetVideouivNV(GLuint video_slot, GLenum pname, GLuint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1338];
   ((void (APIENTRY *)(GLuint video_slot, GLenum pname, GLuint *params)) _func)(video_slot, pname, params);
}

GLAPI GLVULKANPROCNV APIENTRY glGetVkProcAddrNV(const GLchar *name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1339];
   return ((GLVULKANPROCNV (APIENTRY *)(const GLchar *name)) _func)(name);
}

GLAPI void APIENTRY glGetnColorTable(GLenum target, GLenum format, GLenum type, GLsizei bufSize, void *table)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1340];
   ((void (APIENTRY *)(GLenum target, GLenum format, GLenum type, GLsizei bufSize, void *table)) _func)(target, format, type, bufSize, table);
}

GLAPI void APIENTRY glGetnColorTableARB(GLenum target, GLenum format, GLenum type, GLsizei bufSize, void *table)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1341];
   ((void (APIENTRY *)(GLenum target, GLenum format, GLenum type, GLsizei bufSize, void *table)) _func)(target, format, type, bufSize, table);
}

GLAPI void APIENTRY glGetnCompressedTexImage(GLenum target, GLint lod, GLsizei bufSize, void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1342];
   ((void (APIENTRY *)(GLenum target, GLint lod, GLsizei bufSize, void *pixels)) _func)(target, lod, bufSize, pixels);
}

GLAPI void APIENTRY glGetnCompressedTexImageARB(GLenum target, GLint lod, GLsizei bufSize, void *img)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1343];
   ((void (APIENTRY *)(GLenum target, GLint lod, GLsizei bufSize, void *img)) _func)(target, lod, bufSize, img);
}

GLAPI void APIENTRY glGetnConvolutionFilter(GLenum target, GLenum format, GLenum type, GLsizei bufSize, void *image)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1344];
   ((void (APIENTRY *)(GLenum target, GLenum format, GLenum type, GLsizei bufSize, void *image)) _func)(target, format, type, bufSize, image);
}

GLAPI void APIENTRY glGetnConvolutionFilterARB(GLenum target, GLenum format, GLenum type, GLsizei bufSize, void *image)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1345];
   ((void (APIENTRY *)(GLenum target, GLenum format, GLenum type, GLsizei bufSize, void *image)) _func)(target, format, type, bufSize, image);
}

GLAPI void APIENTRY glGetnHistogram(GLenum target, GLboolean reset, GLenum format, GLenum type, GLsizei bufSize, void *values)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1346];
   ((void (APIENTRY *)(GLenum target, GLboolean reset, GLenum format, GLenum type, GLsizei bufSize, void *values)) _func)(target, reset, format, type, bufSize, values);
}

GLAPI void APIENTRY glGetnHistogramARB(GLenum target, GLboolean reset, GLenum format, GLenum type, GLsizei bufSize, void *values)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1347];
   ((void (APIENTRY *)(GLenum target, GLboolean reset, GLenum format, GLenum type, GLsizei bufSize, void *values)) _func)(target, reset, format, type, bufSize, values);
}

GLAPI void APIENTRY glGetnMapdv(GLenum target, GLenum query, GLsizei bufSize, GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1348];
   ((void (APIENTRY *)(GLenum target, GLenum query, GLsizei bufSize, GLdouble *v)) _func)(target, query, bufSize, v);
}

GLAPI void APIENTRY glGetnMapdvARB(GLenum target, GLenum query, GLsizei bufSize, GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1349];
   ((void (APIENTRY *)(GLenum target, GLenum query, GLsizei bufSize, GLdouble *v)) _func)(target, query, bufSize, v);
}

GLAPI void APIENTRY glGetnMapfv(GLenum target, GLenum query, GLsizei bufSize, GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1350];
   ((void (APIENTRY *)(GLenum target, GLenum query, GLsizei bufSize, GLfloat *v)) _func)(target, query, bufSize, v);
}

GLAPI void APIENTRY glGetnMapfvARB(GLenum target, GLenum query, GLsizei bufSize, GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1351];
   ((void (APIENTRY *)(GLenum target, GLenum query, GLsizei bufSize, GLfloat *v)) _func)(target, query, bufSize, v);
}

GLAPI void APIENTRY glGetnMapiv(GLenum target, GLenum query, GLsizei bufSize, GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1352];
   ((void (APIENTRY *)(GLenum target, GLenum query, GLsizei bufSize, GLint *v)) _func)(target, query, bufSize, v);
}

GLAPI void APIENTRY glGetnMapivARB(GLenum target, GLenum query, GLsizei bufSize, GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1353];
   ((void (APIENTRY *)(GLenum target, GLenum query, GLsizei bufSize, GLint *v)) _func)(target, query, bufSize, v);
}

GLAPI void APIENTRY glGetnMinmax(GLenum target, GLboolean reset, GLenum format, GLenum type, GLsizei bufSize, void *values)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1354];
   ((void (APIENTRY *)(GLenum target, GLboolean reset, GLenum format, GLenum type, GLsizei bufSize, void *values)) _func)(target, reset, format, type, bufSize, values);
}

GLAPI void APIENTRY glGetnMinmaxARB(GLenum target, GLboolean reset, GLenum format, GLenum type, GLsizei bufSize, void *values)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1355];
   ((void (APIENTRY *)(GLenum target, GLboolean reset, GLenum format, GLenum type, GLsizei bufSize, void *values)) _func)(target, reset, format, type, bufSize, values);
}

GLAPI void APIENTRY glGetnPixelMapfv(GLenum map, GLsizei bufSize, GLfloat *values)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1356];
   ((void (APIENTRY *)(GLenum map, GLsizei bufSize, GLfloat *values)) _func)(map, bufSize, values);
}

GLAPI void APIENTRY glGetnPixelMapfvARB(GLenum map, GLsizei bufSize, GLfloat *values)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1357];
   ((void (APIENTRY *)(GLenum map, GLsizei bufSize, GLfloat *values)) _func)(map, bufSize, values);
}

GLAPI void APIENTRY glGetnPixelMapuiv(GLenum map, GLsizei bufSize, GLuint *values)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1358];
   ((void (APIENTRY *)(GLenum map, GLsizei bufSize, GLuint *values)) _func)(map, bufSize, values);
}

GLAPI void APIENTRY glGetnPixelMapuivARB(GLenum map, GLsizei bufSize, GLuint *values)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1359];
   ((void (APIENTRY *)(GLenum map, GLsizei bufSize, GLuint *values)) _func)(map, bufSize, values);
}

GLAPI void APIENTRY glGetnPixelMapusv(GLenum map, GLsizei bufSize, GLushort *values)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1360];
   ((void (APIENTRY *)(GLenum map, GLsizei bufSize, GLushort *values)) _func)(map, bufSize, values);
}

GLAPI void APIENTRY glGetnPixelMapusvARB(GLenum map, GLsizei bufSize, GLushort *values)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1361];
   ((void (APIENTRY *)(GLenum map, GLsizei bufSize, GLushort *values)) _func)(map, bufSize, values);
}

GLAPI void APIENTRY glGetnPolygonStipple(GLsizei bufSize, GLubyte *pattern)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1362];
   ((void (APIENTRY *)(GLsizei bufSize, GLubyte *pattern)) _func)(bufSize, pattern);
}

GLAPI void APIENTRY glGetnPolygonStippleARB(GLsizei bufSize, GLubyte *pattern)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1363];
   ((void (APIENTRY *)(GLsizei bufSize, GLubyte *pattern)) _func)(bufSize, pattern);
}

GLAPI void APIENTRY glGetnSeparableFilter(GLenum target, GLenum format, GLenum type, GLsizei rowBufSize, void *row, GLsizei columnBufSize, void *column, void *span)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1364];
   ((void (APIENTRY *)(GLenum target, GLenum format, GLenum type, GLsizei rowBufSize, void *row, GLsizei columnBufSize, void *column, void *span)) _func)(target, format, type, rowBufSize, row, columnBufSize, column, span);
}

GLAPI void APIENTRY glGetnSeparableFilterARB(GLenum target, GLenum format, GLenum type, GLsizei rowBufSize, void *row, GLsizei columnBufSize, void *column, void *span)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1365];
   ((void (APIENTRY *)(GLenum target, GLenum format, GLenum type, GLsizei rowBufSize, void *row, GLsizei columnBufSize, void *column, void *span)) _func)(target, format, type, rowBufSize, row, columnBufSize, column, span);
}

GLAPI void APIENTRY glGetnTexImage(GLenum target, GLint level, GLenum format, GLenum type, GLsizei bufSize, void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1366];
   ((void (APIENTRY *)(GLenum target, GLint level, GLenum format, GLenum type, GLsizei bufSize, void *pixels)) _func)(target, level, format, type, bufSize, pixels);
}

GLAPI void APIENTRY glGetnTexImageARB(GLenum target, GLint level, GLenum format, GLenum type, GLsizei bufSize, void *img)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1367];
   ((void (APIENTRY *)(GLenum target, GLint level, GLenum format, GLenum type, GLsizei bufSize, void *img)) _func)(target, level, format, type, bufSize, img);
}

GLAPI void APIENTRY glGetnUniformdv(GLuint program, GLint location, GLsizei bufSize, GLdouble *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1368];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei bufSize, GLdouble *params)) _func)(program, location, bufSize, params);
}

GLAPI void APIENTRY glGetnUniformdvARB(GLuint program, GLint location, GLsizei bufSize, GLdouble *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1369];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei bufSize, GLdouble *params)) _func)(program, location, bufSize, params);
}

GLAPI void APIENTRY glGetnUniformfv(GLuint program, GLint location, GLsizei bufSize, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1370];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei bufSize, GLfloat *params)) _func)(program, location, bufSize, params);
}

GLAPI void APIENTRY glGetnUniformfvARB(GLuint program, GLint location, GLsizei bufSize, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1371];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei bufSize, GLfloat *params)) _func)(program, location, bufSize, params);
}

GLAPI void APIENTRY glGetnUniformfvEXT(GLuint program, GLint location, GLsizei bufSize, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1372];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei bufSize, GLfloat *params)) _func)(program, location, bufSize, params);
}

GLAPI void APIENTRY glGetnUniformfvKHR(GLuint program, GLint location, GLsizei bufSize, GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1373];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei bufSize, GLfloat *params)) _func)(program, location, bufSize, params);
}

GLAPI void APIENTRY glGetnUniformi64vARB(GLuint program, GLint location, GLsizei bufSize, GLint64 *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1374];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei bufSize, GLint64 *params)) _func)(program, location, bufSize, params);
}

GLAPI void APIENTRY glGetnUniformiv(GLuint program, GLint location, GLsizei bufSize, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1375];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei bufSize, GLint *params)) _func)(program, location, bufSize, params);
}

GLAPI void APIENTRY glGetnUniformivARB(GLuint program, GLint location, GLsizei bufSize, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1376];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei bufSize, GLint *params)) _func)(program, location, bufSize, params);
}

GLAPI void APIENTRY glGetnUniformivEXT(GLuint program, GLint location, GLsizei bufSize, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1377];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei bufSize, GLint *params)) _func)(program, location, bufSize, params);
}

GLAPI void APIENTRY glGetnUniformivKHR(GLuint program, GLint location, GLsizei bufSize, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1378];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei bufSize, GLint *params)) _func)(program, location, bufSize, params);
}

GLAPI void APIENTRY glGetnUniformui64vARB(GLuint program, GLint location, GLsizei bufSize, GLuint64 *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1379];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei bufSize, GLuint64 *params)) _func)(program, location, bufSize, params);
}

GLAPI void APIENTRY glGetnUniformuiv(GLuint program, GLint location, GLsizei bufSize, GLuint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1380];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei bufSize, GLuint *params)) _func)(program, location, bufSize, params);
}

GLAPI void APIENTRY glGetnUniformuivARB(GLuint program, GLint location, GLsizei bufSize, GLuint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1381];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei bufSize, GLuint *params)) _func)(program, location, bufSize, params);
}

GLAPI void APIENTRY glGetnUniformuivKHR(GLuint program, GLint location, GLsizei bufSize, GLuint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1382];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei bufSize, GLuint *params)) _func)(program, location, bufSize, params);
}

GLAPI void APIENTRY glGlobalAlphaFactorbSUN(GLbyte factor)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1383];
   ((void (APIENTRY *)(GLbyte factor)) _func)(factor);
}

GLAPI void APIENTRY glGlobalAlphaFactordSUN(GLdouble factor)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1384];
   ((void (APIENTRY *)(GLdouble factor)) _func)(factor);
}

GLAPI void APIENTRY glGlobalAlphaFactorfSUN(GLfloat factor)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1385];
   ((void (APIENTRY *)(GLfloat factor)) _func)(factor);
}

GLAPI void APIENTRY glGlobalAlphaFactoriSUN(GLint factor)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1386];
   ((void (APIENTRY *)(GLint factor)) _func)(factor);
}

GLAPI void APIENTRY glGlobalAlphaFactorsSUN(GLshort factor)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1387];
   ((void (APIENTRY *)(GLshort factor)) _func)(factor);
}

GLAPI void APIENTRY glGlobalAlphaFactorubSUN(GLubyte factor)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1388];
   ((void (APIENTRY *)(GLubyte factor)) _func)(factor);
}

GLAPI void APIENTRY glGlobalAlphaFactoruiSUN(GLuint factor)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1389];
   ((void (APIENTRY *)(GLuint factor)) _func)(factor);
}

GLAPI void APIENTRY glGlobalAlphaFactorusSUN(GLushort factor)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1390];
   ((void (APIENTRY *)(GLushort factor)) _func)(factor);
}

GLAPI void APIENTRY glGpuSyncAcquireNVX(GLintptr sync)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1391];
   ((void (APIENTRY *)(GLintptr sync)) _func)(sync);
}

GLAPI GLintptr APIENTRY glGpuSyncCreateNVX(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1392];
   return ((GLintptr (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glGpuSyncDestroyNVX(GLintptr sync)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1393];
   ((void (APIENTRY *)(GLintptr sync)) _func)(sync);
}

GLAPI void APIENTRY glGpuSyncReleaseNVX(GLintptr sync)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1394];
   ((void (APIENTRY *)(GLintptr sync)) _func)(sync);
}

GLAPI void APIENTRY glHint(GLenum target, GLenum mode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1395];
   ((void (APIENTRY *)(GLenum target, GLenum mode)) _func)(target, mode);
}

GLAPI void APIENTRY glHintPGI(GLenum target, GLint mode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1396];
   ((void (APIENTRY *)(GLenum target, GLint mode)) _func)(target, mode);
}

GLAPI void APIENTRY glHistogram(GLenum target, GLsizei width, GLenum internalformat, GLboolean sink)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1397];
   ((void (APIENTRY *)(GLenum target, GLsizei width, GLenum internalformat, GLboolean sink)) _func)(target, width, internalformat, sink);
}

GLAPI void APIENTRY glHistogramEXT(GLenum target, GLsizei width, GLenum internalformat, GLboolean sink)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1398];
   ((void (APIENTRY *)(GLenum target, GLsizei width, GLenum internalformat, GLboolean sink)) _func)(target, width, internalformat, sink);
}

GLAPI void APIENTRY glIglooInterfaceSGIX(GLenum pname, const void *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1399];
   ((void (APIENTRY *)(GLenum pname, const void *params)) _func)(pname, params);
}

GLAPI void APIENTRY glImageTransformParameterfHP(GLenum target, GLenum pname, GLfloat param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1400];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLfloat param)) _func)(target, pname, param);
}

GLAPI void APIENTRY glImageTransformParameterfvHP(GLenum target, GLenum pname, const GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1401];
   ((void (APIENTRY *)(GLenum target, GLenum pname, const GLfloat *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glImageTransformParameteriHP(GLenum target, GLenum pname, GLint param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1402];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLint param)) _func)(target, pname, param);
}

GLAPI void APIENTRY glImageTransformParameterivHP(GLenum target, GLenum pname, const GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1403];
   ((void (APIENTRY *)(GLenum target, GLenum pname, const GLint *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glImportMemoryFdEXT(GLuint memory, GLuint64 size, GLenum handleType, GLint fd)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1404];
   ((void (APIENTRY *)(GLuint memory, GLuint64 size, GLenum handleType, GLint fd)) _func)(memory, size, handleType, fd);
}

GLAPI void APIENTRY glImportMemoryWin32HandleEXT(GLuint memory, GLuint64 size, GLenum handleType, void *handle)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1405];
   ((void (APIENTRY *)(GLuint memory, GLuint64 size, GLenum handleType, void *handle)) _func)(memory, size, handleType, handle);
}

GLAPI void APIENTRY glImportMemoryWin32NameEXT(GLuint memory, GLuint64 size, GLenum handleType, const void *name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1406];
   ((void (APIENTRY *)(GLuint memory, GLuint64 size, GLenum handleType, const void *name)) _func)(memory, size, handleType, name);
}

GLAPI void APIENTRY glImportSemaphoreFdEXT(GLuint semaphore, GLenum handleType, GLint fd)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1407];
   ((void (APIENTRY *)(GLuint semaphore, GLenum handleType, GLint fd)) _func)(semaphore, handleType, fd);
}

GLAPI void APIENTRY glImportSemaphoreWin32HandleEXT(GLuint semaphore, GLenum handleType, void *handle)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1408];
   ((void (APIENTRY *)(GLuint semaphore, GLenum handleType, void *handle)) _func)(semaphore, handleType, handle);
}

GLAPI void APIENTRY glImportSemaphoreWin32NameEXT(GLuint semaphore, GLenum handleType, const void *name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1409];
   ((void (APIENTRY *)(GLuint semaphore, GLenum handleType, const void *name)) _func)(semaphore, handleType, name);
}

GLAPI GLsync APIENTRY glImportSyncEXT(GLenum external_sync_type, GLintptr external_sync, GLbitfield flags)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1410];
   return ((GLsync (APIENTRY *)(GLenum external_sync_type, GLintptr external_sync, GLbitfield flags)) _func)(external_sync_type, external_sync, flags);
}

GLAPI void APIENTRY glIndexFormatNV(GLenum type, GLsizei stride)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1411];
   ((void (APIENTRY *)(GLenum type, GLsizei stride)) _func)(type, stride);
}

GLAPI void APIENTRY glIndexFuncEXT(GLenum func, GLclampf ref)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1412];
   ((void (APIENTRY *)(GLenum func, GLclampf ref)) _func)(func, ref);
}

GLAPI void APIENTRY glIndexMask(GLuint mask)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1413];
   ((void (APIENTRY *)(GLuint mask)) _func)(mask);
}

GLAPI void APIENTRY glIndexMaterialEXT(GLenum face, GLenum mode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1414];
   ((void (APIENTRY *)(GLenum face, GLenum mode)) _func)(face, mode);
}

GLAPI void APIENTRY glIndexPointer(GLenum type, GLsizei stride, const void *pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1415];
   ((void (APIENTRY *)(GLenum type, GLsizei stride, const void *pointer)) _func)(type, stride, pointer);
}

GLAPI void APIENTRY glIndexPointerEXT(GLenum type, GLsizei stride, GLsizei count, const void *pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1416];
   ((void (APIENTRY *)(GLenum type, GLsizei stride, GLsizei count, const void *pointer)) _func)(type, stride, count, pointer);
}

GLAPI void APIENTRY glIndexPointerListIBM(GLenum type, GLint stride, const void **pointer, GLint ptrstride)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1417];
   ((void (APIENTRY *)(GLenum type, GLint stride, const void **pointer, GLint ptrstride)) _func)(type, stride, pointer, ptrstride);
}

GLAPI void APIENTRY glIndexd(GLdouble c)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1418];
   ((void (APIENTRY *)(GLdouble c)) _func)(c);
}

GLAPI void APIENTRY glIndexdv(const GLdouble *c)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1419];
   ((void (APIENTRY *)(const GLdouble *c)) _func)(c);
}

GLAPI void APIENTRY glIndexf(GLfloat c)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1420];
   ((void (APIENTRY *)(GLfloat c)) _func)(c);
}

GLAPI void APIENTRY glIndexfv(const GLfloat *c)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1421];
   ((void (APIENTRY *)(const GLfloat *c)) _func)(c);
}

GLAPI void APIENTRY glIndexi(GLint c)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1422];
   ((void (APIENTRY *)(GLint c)) _func)(c);
}

GLAPI void APIENTRY glIndexiv(const GLint *c)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1423];
   ((void (APIENTRY *)(const GLint *c)) _func)(c);
}

GLAPI void APIENTRY glIndexs(GLshort c)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1424];
   ((void (APIENTRY *)(GLshort c)) _func)(c);
}

GLAPI void APIENTRY glIndexsv(const GLshort *c)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1425];
   ((void (APIENTRY *)(const GLshort *c)) _func)(c);
}

GLAPI void APIENTRY glIndexub(GLubyte c)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1426];
   ((void (APIENTRY *)(GLubyte c)) _func)(c);
}

GLAPI void APIENTRY glIndexubv(const GLubyte *c)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1427];
   ((void (APIENTRY *)(const GLubyte *c)) _func)(c);
}

GLAPI void APIENTRY glIndexxOES(GLfixed component)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1428];
   ((void (APIENTRY *)(GLfixed component)) _func)(component);
}

GLAPI void APIENTRY glIndexxvOES(const GLfixed *component)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1429];
   ((void (APIENTRY *)(const GLfixed *component)) _func)(component);
}

GLAPI void APIENTRY glInitNames(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1430];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glInsertComponentEXT(GLuint res, GLuint src, GLuint num)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1431];
   ((void (APIENTRY *)(GLuint res, GLuint src, GLuint num)) _func)(res, src, num);
}

GLAPI void APIENTRY glInsertEventMarkerEXT(GLsizei length, const GLchar *marker)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1432];
   ((void (APIENTRY *)(GLsizei length, const GLchar *marker)) _func)(length, marker);
}

GLAPI void APIENTRY glInstrumentsBufferSGIX(GLsizei size, GLint *buffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1433];
   ((void (APIENTRY *)(GLsizei size, GLint *buffer)) _func)(size, buffer);
}

GLAPI void APIENTRY glInterleavedArrays(GLenum format, GLsizei stride, const void *pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1434];
   ((void (APIENTRY *)(GLenum format, GLsizei stride, const void *pointer)) _func)(format, stride, pointer);
}

GLAPI void APIENTRY glInterpolatePathsNV(GLuint resultPath, GLuint pathA, GLuint pathB, GLfloat weight)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1435];
   ((void (APIENTRY *)(GLuint resultPath, GLuint pathA, GLuint pathB, GLfloat weight)) _func)(resultPath, pathA, pathB, weight);
}

GLAPI void APIENTRY glInvalidateBufferData(GLuint buffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1436];
   ((void (APIENTRY *)(GLuint buffer)) _func)(buffer);
}

GLAPI void APIENTRY glInvalidateBufferSubData(GLuint buffer, GLintptr offset, GLsizeiptr length)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1437];
   ((void (APIENTRY *)(GLuint buffer, GLintptr offset, GLsizeiptr length)) _func)(buffer, offset, length);
}

GLAPI void APIENTRY glInvalidateFramebuffer(GLenum target, GLsizei numAttachments, const GLenum *attachments)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1438];
   ((void (APIENTRY *)(GLenum target, GLsizei numAttachments, const GLenum *attachments)) _func)(target, numAttachments, attachments);
}

GLAPI void APIENTRY glInvalidateNamedFramebufferData(GLuint framebuffer, GLsizei numAttachments, const GLenum *attachments)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1439];
   ((void (APIENTRY *)(GLuint framebuffer, GLsizei numAttachments, const GLenum *attachments)) _func)(framebuffer, numAttachments, attachments);
}

GLAPI void APIENTRY glInvalidateNamedFramebufferSubData(GLuint framebuffer, GLsizei numAttachments, const GLenum *attachments, GLint x, GLint y, GLsizei width, GLsizei height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1440];
   ((void (APIENTRY *)(GLuint framebuffer, GLsizei numAttachments, const GLenum *attachments, GLint x, GLint y, GLsizei width, GLsizei height)) _func)(framebuffer, numAttachments, attachments, x, y, width, height);
}

GLAPI void APIENTRY glInvalidateSubFramebuffer(GLenum target, GLsizei numAttachments, const GLenum *attachments, GLint x, GLint y, GLsizei width, GLsizei height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1441];
   ((void (APIENTRY *)(GLenum target, GLsizei numAttachments, const GLenum *attachments, GLint x, GLint y, GLsizei width, GLsizei height)) _func)(target, numAttachments, attachments, x, y, width, height);
}

GLAPI void APIENTRY glInvalidateTexImage(GLuint texture, GLint level)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1442];
   ((void (APIENTRY *)(GLuint texture, GLint level)) _func)(texture, level);
}

GLAPI void APIENTRY glInvalidateTexSubImage(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1443];
   ((void (APIENTRY *)(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth)) _func)(texture, level, xoffset, yoffset, zoffset, width, height, depth);
}

GLAPI GLboolean APIENTRY glIsAsyncMarkerSGIX(GLuint marker)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1444];
   return ((GLboolean (APIENTRY *)(GLuint marker)) _func)(marker);
}

GLAPI GLboolean APIENTRY glIsBuffer(GLuint buffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1445];
   return ((GLboolean (APIENTRY *)(GLuint buffer)) _func)(buffer);
}

GLAPI GLboolean APIENTRY glIsBufferARB(GLuint buffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1446];
   return ((GLboolean (APIENTRY *)(GLuint buffer)) _func)(buffer);
}

GLAPI GLboolean APIENTRY glIsBufferResidentNV(GLenum target)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1447];
   return ((GLboolean (APIENTRY *)(GLenum target)) _func)(target);
}

GLAPI GLboolean APIENTRY glIsCommandListNV(GLuint list)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1448];
   return ((GLboolean (APIENTRY *)(GLuint list)) _func)(list);
}

GLAPI GLboolean APIENTRY glIsEnabled(GLenum cap)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1449];
   return ((GLboolean (APIENTRY *)(GLenum cap)) _func)(cap);
}

GLAPI GLboolean APIENTRY glIsEnabledIndexedEXT(GLenum target, GLuint index)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1450];
   return ((GLboolean (APIENTRY *)(GLenum target, GLuint index)) _func)(target, index);
}

GLAPI GLboolean APIENTRY glIsEnabledi(GLenum target, GLuint index)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1451];
   return ((GLboolean (APIENTRY *)(GLenum target, GLuint index)) _func)(target, index);
}

GLAPI GLboolean APIENTRY glIsEnablediEXT(GLenum target, GLuint index)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1452];
   return ((GLboolean (APIENTRY *)(GLenum target, GLuint index)) _func)(target, index);
}

GLAPI GLboolean APIENTRY glIsEnablediNV(GLenum target, GLuint index)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1453];
   return ((GLboolean (APIENTRY *)(GLenum target, GLuint index)) _func)(target, index);
}

GLAPI GLboolean APIENTRY glIsEnablediOES(GLenum target, GLuint index)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1454];
   return ((GLboolean (APIENTRY *)(GLenum target, GLuint index)) _func)(target, index);
}

GLAPI GLboolean APIENTRY glIsFenceAPPLE(GLuint fence)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1455];
   return ((GLboolean (APIENTRY *)(GLuint fence)) _func)(fence);
}

GLAPI GLboolean APIENTRY glIsFenceNV(GLuint fence)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1456];
   return ((GLboolean (APIENTRY *)(GLuint fence)) _func)(fence);
}

GLAPI GLboolean APIENTRY glIsFramebuffer(GLuint framebuffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1457];
   return ((GLboolean (APIENTRY *)(GLuint framebuffer)) _func)(framebuffer);
}

GLAPI GLboolean APIENTRY glIsFramebufferEXT(GLuint framebuffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1458];
   return ((GLboolean (APIENTRY *)(GLuint framebuffer)) _func)(framebuffer);
}

GLAPI GLboolean APIENTRY glIsFramebufferOES(GLuint framebuffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1459];
   return ((GLboolean (APIENTRY *)(GLuint framebuffer)) _func)(framebuffer);
}

GLAPI GLboolean APIENTRY glIsImageHandleResidentARB(GLuint64 handle)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1460];
   return ((GLboolean (APIENTRY *)(GLuint64 handle)) _func)(handle);
}

GLAPI GLboolean APIENTRY glIsImageHandleResidentNV(GLuint64 handle)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1461];
   return ((GLboolean (APIENTRY *)(GLuint64 handle)) _func)(handle);
}

GLAPI GLboolean APIENTRY glIsList(GLuint list)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1462];
   return ((GLboolean (APIENTRY *)(GLuint list)) _func)(list);
}

GLAPI GLboolean APIENTRY glIsMemoryObjectEXT(GLuint memoryObject)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1463];
   return ((GLboolean (APIENTRY *)(GLuint memoryObject)) _func)(memoryObject);
}

GLAPI GLboolean APIENTRY glIsNameAMD(GLenum identifier, GLuint name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1464];
   return ((GLboolean (APIENTRY *)(GLenum identifier, GLuint name)) _func)(identifier, name);
}

GLAPI GLboolean APIENTRY glIsNamedBufferResidentNV(GLuint buffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1465];
   return ((GLboolean (APIENTRY *)(GLuint buffer)) _func)(buffer);
}

GLAPI GLboolean APIENTRY glIsNamedStringARB(GLint namelen, const GLchar *name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1466];
   return ((GLboolean (APIENTRY *)(GLint namelen, const GLchar *name)) _func)(namelen, name);
}

GLAPI GLboolean APIENTRY glIsObjectBufferATI(GLuint buffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1467];
   return ((GLboolean (APIENTRY *)(GLuint buffer)) _func)(buffer);
}

GLAPI GLboolean APIENTRY glIsOcclusionQueryNV(GLuint id)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1468];
   return ((GLboolean (APIENTRY *)(GLuint id)) _func)(id);
}

GLAPI GLboolean APIENTRY glIsPathNV(GLuint path)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1469];
   return ((GLboolean (APIENTRY *)(GLuint path)) _func)(path);
}

GLAPI GLboolean APIENTRY glIsPointInFillPathNV(GLuint path, GLuint mask, GLfloat x, GLfloat y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1470];
   return ((GLboolean (APIENTRY *)(GLuint path, GLuint mask, GLfloat x, GLfloat y)) _func)(path, mask, x, y);
}

GLAPI GLboolean APIENTRY glIsPointInStrokePathNV(GLuint path, GLfloat x, GLfloat y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1471];
   return ((GLboolean (APIENTRY *)(GLuint path, GLfloat x, GLfloat y)) _func)(path, x, y);
}

GLAPI GLboolean APIENTRY glIsProgram(GLuint program)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1472];
   return ((GLboolean (APIENTRY *)(GLuint program)) _func)(program);
}

GLAPI GLboolean APIENTRY glIsProgramARB(GLuint program)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1473];
   return ((GLboolean (APIENTRY *)(GLuint program)) _func)(program);
}

GLAPI GLboolean APIENTRY glIsProgramNV(GLuint id)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1474];
   return ((GLboolean (APIENTRY *)(GLuint id)) _func)(id);
}

GLAPI GLboolean APIENTRY glIsProgramPipeline(GLuint pipeline)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1475];
   return ((GLboolean (APIENTRY *)(GLuint pipeline)) _func)(pipeline);
}

GLAPI GLboolean APIENTRY glIsProgramPipelineEXT(GLuint pipeline)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1476];
   return ((GLboolean (APIENTRY *)(GLuint pipeline)) _func)(pipeline);
}

GLAPI GLboolean APIENTRY glIsQuery(GLuint id)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1477];
   return ((GLboolean (APIENTRY *)(GLuint id)) _func)(id);
}

GLAPI GLboolean APIENTRY glIsQueryARB(GLuint id)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1478];
   return ((GLboolean (APIENTRY *)(GLuint id)) _func)(id);
}

GLAPI GLboolean APIENTRY glIsQueryEXT(GLuint id)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1479];
   return ((GLboolean (APIENTRY *)(GLuint id)) _func)(id);
}

GLAPI GLboolean APIENTRY glIsRenderbuffer(GLuint renderbuffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1480];
   return ((GLboolean (APIENTRY *)(GLuint renderbuffer)) _func)(renderbuffer);
}

GLAPI GLboolean APIENTRY glIsRenderbufferEXT(GLuint renderbuffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1481];
   return ((GLboolean (APIENTRY *)(GLuint renderbuffer)) _func)(renderbuffer);
}

GLAPI GLboolean APIENTRY glIsRenderbufferOES(GLuint renderbuffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1482];
   return ((GLboolean (APIENTRY *)(GLuint renderbuffer)) _func)(renderbuffer);
}

GLAPI GLboolean APIENTRY glIsSampler(GLuint sampler)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1483];
   return ((GLboolean (APIENTRY *)(GLuint sampler)) _func)(sampler);
}

GLAPI GLboolean APIENTRY glIsSemaphoreEXT(GLuint semaphore)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1484];
   return ((GLboolean (APIENTRY *)(GLuint semaphore)) _func)(semaphore);
}

GLAPI GLboolean APIENTRY glIsShader(GLuint shader)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1485];
   return ((GLboolean (APIENTRY *)(GLuint shader)) _func)(shader);
}

GLAPI GLboolean APIENTRY glIsStateNV(GLuint state)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1486];
   return ((GLboolean (APIENTRY *)(GLuint state)) _func)(state);
}

GLAPI GLboolean APIENTRY glIsSync(GLsync sync)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1487];
   return ((GLboolean (APIENTRY *)(GLsync sync)) _func)(sync);
}

GLAPI GLboolean APIENTRY glIsSyncAPPLE(GLsync sync)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1488];
   return ((GLboolean (APIENTRY *)(GLsync sync)) _func)(sync);
}

GLAPI GLboolean APIENTRY glIsTexture(GLuint texture)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1489];
   return ((GLboolean (APIENTRY *)(GLuint texture)) _func)(texture);
}

GLAPI GLboolean APIENTRY glIsTextureEXT(GLuint texture)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1490];
   return ((GLboolean (APIENTRY *)(GLuint texture)) _func)(texture);
}

GLAPI GLboolean APIENTRY glIsTextureHandleResidentARB(GLuint64 handle)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1491];
   return ((GLboolean (APIENTRY *)(GLuint64 handle)) _func)(handle);
}

GLAPI GLboolean APIENTRY glIsTextureHandleResidentNV(GLuint64 handle)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1492];
   return ((GLboolean (APIENTRY *)(GLuint64 handle)) _func)(handle);
}

GLAPI GLboolean APIENTRY glIsTransformFeedback(GLuint id)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1493];
   return ((GLboolean (APIENTRY *)(GLuint id)) _func)(id);
}

GLAPI GLboolean APIENTRY glIsTransformFeedbackEXT(GLuint id)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1494];
   return ((GLboolean (APIENTRY *)(GLuint id)) _func)(id);
}

GLAPI GLboolean APIENTRY glIsTransformFeedbackNV(GLuint id)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1495];
   return ((GLboolean (APIENTRY *)(GLuint id)) _func)(id);
}

GLAPI GLboolean APIENTRY glIsVariantEnabledEXT(GLuint id, GLenum cap)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1496];
   return ((GLboolean (APIENTRY *)(GLuint id, GLenum cap)) _func)(id, cap);
}

GLAPI GLboolean APIENTRY glIsVertexArray(GLuint array)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1497];
   return ((GLboolean (APIENTRY *)(GLuint array)) _func)(array);
}

GLAPI GLboolean APIENTRY glIsVertexArrayAPPLE(GLuint array)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1498];
   return ((GLboolean (APIENTRY *)(GLuint array)) _func)(array);
}

GLAPI GLboolean APIENTRY glIsVertexArrayOES(GLuint array)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1499];
   return ((GLboolean (APIENTRY *)(GLuint array)) _func)(array);
}

GLAPI GLboolean APIENTRY glIsVertexAttribEnabledAPPLE(GLuint index, GLenum pname)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1500];
   return ((GLboolean (APIENTRY *)(GLuint index, GLenum pname)) _func)(index, pname);
}

GLAPI void APIENTRY glLGPUCopyImageSubDataNVX(GLuint sourceGpu, GLbitfield destinationGpuMask, GLuint srcName, GLenum srcTarget, GLint srcLevel, GLint srcX, GLint srxY, GLint srcZ, GLuint dstName, GLenum dstTarget, GLint dstLevel, GLint dstX, GLint dstY, GLint dstZ, GLsizei width, GLsizei height, GLsizei depth)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1501];
   ((void (APIENTRY *)(GLuint sourceGpu, GLbitfield destinationGpuMask, GLuint srcName, GLenum srcTarget, GLint srcLevel, GLint srcX, GLint srxY, GLint srcZ, GLuint dstName, GLenum dstTarget, GLint dstLevel, GLint dstX, GLint dstY, GLint dstZ, GLsizei width, GLsizei height, GLsizei depth)) _func)(sourceGpu, destinationGpuMask, srcName, srcTarget, srcLevel, srcX, srxY, srcZ, dstName, dstTarget, dstLevel, dstX, dstY, dstZ, width, height, depth);
}

GLAPI void APIENTRY glLGPUInterlockNVX(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1502];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glLGPUNamedBufferSubDataNVX(GLbitfield gpuMask, GLuint buffer, GLintptr offset, GLsizeiptr size, const void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1503];
   ((void (APIENTRY *)(GLbitfield gpuMask, GLuint buffer, GLintptr offset, GLsizeiptr size, const void *data)) _func)(gpuMask, buffer, offset, size, data);
}

GLAPI void APIENTRY glLabelObjectEXT(GLenum type, GLuint object, GLsizei length, const GLchar *label)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1504];
   ((void (APIENTRY *)(GLenum type, GLuint object, GLsizei length, const GLchar *label)) _func)(type, object, length, label);
}

GLAPI void APIENTRY glLightEnviSGIX(GLenum pname, GLint param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1505];
   ((void (APIENTRY *)(GLenum pname, GLint param)) _func)(pname, param);
}

GLAPI void APIENTRY glLightModelf(GLenum pname, GLfloat param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1506];
   ((void (APIENTRY *)(GLenum pname, GLfloat param)) _func)(pname, param);
}

GLAPI void APIENTRY glLightModelfv(GLenum pname, const GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1507];
   ((void (APIENTRY *)(GLenum pname, const GLfloat *params)) _func)(pname, params);
}

GLAPI void APIENTRY glLightModeli(GLenum pname, GLint param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1508];
   ((void (APIENTRY *)(GLenum pname, GLint param)) _func)(pname, param);
}

GLAPI void APIENTRY glLightModeliv(GLenum pname, const GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1509];
   ((void (APIENTRY *)(GLenum pname, const GLint *params)) _func)(pname, params);
}

GLAPI void APIENTRY glLightModelx(GLenum pname, GLfixed param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1510];
   ((void (APIENTRY *)(GLenum pname, GLfixed param)) _func)(pname, param);
}

GLAPI void APIENTRY glLightModelxOES(GLenum pname, GLfixed param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1511];
   ((void (APIENTRY *)(GLenum pname, GLfixed param)) _func)(pname, param);
}

GLAPI void APIENTRY glLightModelxv(GLenum pname, const GLfixed *param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1512];
   ((void (APIENTRY *)(GLenum pname, const GLfixed *param)) _func)(pname, param);
}

GLAPI void APIENTRY glLightModelxvOES(GLenum pname, const GLfixed *param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1513];
   ((void (APIENTRY *)(GLenum pname, const GLfixed *param)) _func)(pname, param);
}

GLAPI void APIENTRY glLightf(GLenum light, GLenum pname, GLfloat param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1514];
   ((void (APIENTRY *)(GLenum light, GLenum pname, GLfloat param)) _func)(light, pname, param);
}

GLAPI void APIENTRY glLightfv(GLenum light, GLenum pname, const GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1515];
   ((void (APIENTRY *)(GLenum light, GLenum pname, const GLfloat *params)) _func)(light, pname, params);
}

GLAPI void APIENTRY glLighti(GLenum light, GLenum pname, GLint param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1516];
   ((void (APIENTRY *)(GLenum light, GLenum pname, GLint param)) _func)(light, pname, param);
}

GLAPI void APIENTRY glLightiv(GLenum light, GLenum pname, const GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1517];
   ((void (APIENTRY *)(GLenum light, GLenum pname, const GLint *params)) _func)(light, pname, params);
}

GLAPI void APIENTRY glLightx(GLenum light, GLenum pname, GLfixed param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1518];
   ((void (APIENTRY *)(GLenum light, GLenum pname, GLfixed param)) _func)(light, pname, param);
}

GLAPI void APIENTRY glLightxOES(GLenum light, GLenum pname, GLfixed param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1519];
   ((void (APIENTRY *)(GLenum light, GLenum pname, GLfixed param)) _func)(light, pname, param);
}

GLAPI void APIENTRY glLightxv(GLenum light, GLenum pname, const GLfixed *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1520];
   ((void (APIENTRY *)(GLenum light, GLenum pname, const GLfixed *params)) _func)(light, pname, params);
}

GLAPI void APIENTRY glLightxvOES(GLenum light, GLenum pname, const GLfixed *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1521];
   ((void (APIENTRY *)(GLenum light, GLenum pname, const GLfixed *params)) _func)(light, pname, params);
}

GLAPI void APIENTRY glLineStipple(GLint factor, GLushort pattern)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1522];
   ((void (APIENTRY *)(GLint factor, GLushort pattern)) _func)(factor, pattern);
}

GLAPI void APIENTRY glLineWidth(GLfloat width)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1523];
   ((void (APIENTRY *)(GLfloat width)) _func)(width);
}

GLAPI void APIENTRY glLineWidthx(GLfixed width)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1524];
   ((void (APIENTRY *)(GLfixed width)) _func)(width);
}

GLAPI void APIENTRY glLineWidthxOES(GLfixed width)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1525];
   ((void (APIENTRY *)(GLfixed width)) _func)(width);
}

GLAPI void APIENTRY glLinkProgram(GLuint program)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1526];
   ((void (APIENTRY *)(GLuint program)) _func)(program);
}

GLAPI void APIENTRY glLinkProgramARB(GLhandleARB programObj)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1527];
   ((void (APIENTRY *)(GLhandleARB programObj)) _func)(programObj);
}

GLAPI void APIENTRY glListBase(GLuint base)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1528];
   ((void (APIENTRY *)(GLuint base)) _func)(base);
}

GLAPI void APIENTRY glListDrawCommandsStatesClientNV(GLuint list, GLuint segment, const void **indirects, const GLsizei *sizes, const GLuint *states, const GLuint *fbos, GLuint count)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1529];
   ((void (APIENTRY *)(GLuint list, GLuint segment, const void **indirects, const GLsizei *sizes, const GLuint *states, const GLuint *fbos, GLuint count)) _func)(list, segment, indirects, sizes, states, fbos, count);
}

GLAPI void APIENTRY glListParameterfSGIX(GLuint list, GLenum pname, GLfloat param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1530];
   ((void (APIENTRY *)(GLuint list, GLenum pname, GLfloat param)) _func)(list, pname, param);
}

GLAPI void APIENTRY glListParameterfvSGIX(GLuint list, GLenum pname, const GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1531];
   ((void (APIENTRY *)(GLuint list, GLenum pname, const GLfloat *params)) _func)(list, pname, params);
}

GLAPI void APIENTRY glListParameteriSGIX(GLuint list, GLenum pname, GLint param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1532];
   ((void (APIENTRY *)(GLuint list, GLenum pname, GLint param)) _func)(list, pname, param);
}

GLAPI void APIENTRY glListParameterivSGIX(GLuint list, GLenum pname, const GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1533];
   ((void (APIENTRY *)(GLuint list, GLenum pname, const GLint *params)) _func)(list, pname, params);
}

GLAPI void APIENTRY glLoadIdentity(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1534];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glLoadIdentityDeformationMapSGIX(GLbitfield mask)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1535];
   ((void (APIENTRY *)(GLbitfield mask)) _func)(mask);
}

GLAPI void APIENTRY glLoadMatrixd(const GLdouble *m)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1536];
   ((void (APIENTRY *)(const GLdouble *m)) _func)(m);
}

GLAPI void APIENTRY glLoadMatrixf(const GLfloat *m)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1537];
   ((void (APIENTRY *)(const GLfloat *m)) _func)(m);
}

GLAPI void APIENTRY glLoadMatrixx(const GLfixed *m)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1538];
   ((void (APIENTRY *)(const GLfixed *m)) _func)(m);
}

GLAPI void APIENTRY glLoadMatrixxOES(const GLfixed *m)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1539];
   ((void (APIENTRY *)(const GLfixed *m)) _func)(m);
}

GLAPI void APIENTRY glLoadName(GLuint name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1540];
   ((void (APIENTRY *)(GLuint name)) _func)(name);
}

GLAPI void APIENTRY glLoadPaletteFromModelViewMatrixOES(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1541];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glLoadProgramNV(GLenum target, GLuint id, GLsizei len, const GLubyte *program)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1542];
   ((void (APIENTRY *)(GLenum target, GLuint id, GLsizei len, const GLubyte *program)) _func)(target, id, len, program);
}

GLAPI void APIENTRY glLoadTransformEXT(GLenum transform)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1543];
   ((void (APIENTRY *)(GLenum transform)) _func)(transform);
}

GLAPI void APIENTRY glLoadTransposeMatrixd(const GLdouble *m)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1544];
   ((void (APIENTRY *)(const GLdouble *m)) _func)(m);
}

GLAPI void APIENTRY glLoadTransposeMatrixdARB(const GLdouble *m)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1545];
   ((void (APIENTRY *)(const GLdouble *m)) _func)(m);
}

GLAPI void APIENTRY glLoadTransposeMatrixf(const GLfloat *m)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1546];
   ((void (APIENTRY *)(const GLfloat *m)) _func)(m);
}

GLAPI void APIENTRY glLoadTransposeMatrixfARB(const GLfloat *m)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1547];
   ((void (APIENTRY *)(const GLfloat *m)) _func)(m);
}

GLAPI void APIENTRY glLoadTransposeMatrixxOES(const GLfixed *m)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1548];
   ((void (APIENTRY *)(const GLfixed *m)) _func)(m);
}

GLAPI void APIENTRY glLockArraysEXT(GLint first, GLsizei count)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1549];
   ((void (APIENTRY *)(GLint first, GLsizei count)) _func)(first, count);
}

GLAPI void APIENTRY glLogicOp(GLenum opcode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1550];
   ((void (APIENTRY *)(GLenum opcode)) _func)(opcode);
}

GLAPI void APIENTRY glMakeBufferNonResidentNV(GLenum target)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1551];
   ((void (APIENTRY *)(GLenum target)) _func)(target);
}

GLAPI void APIENTRY glMakeBufferResidentNV(GLenum target, GLenum access)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1552];
   ((void (APIENTRY *)(GLenum target, GLenum access)) _func)(target, access);
}

GLAPI void APIENTRY glMakeImageHandleNonResidentARB(GLuint64 handle)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1553];
   ((void (APIENTRY *)(GLuint64 handle)) _func)(handle);
}

GLAPI void APIENTRY glMakeImageHandleNonResidentNV(GLuint64 handle)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1554];
   ((void (APIENTRY *)(GLuint64 handle)) _func)(handle);
}

GLAPI void APIENTRY glMakeImageHandleResidentARB(GLuint64 handle, GLenum access)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1555];
   ((void (APIENTRY *)(GLuint64 handle, GLenum access)) _func)(handle, access);
}

GLAPI void APIENTRY glMakeImageHandleResidentNV(GLuint64 handle, GLenum access)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1556];
   ((void (APIENTRY *)(GLuint64 handle, GLenum access)) _func)(handle, access);
}

GLAPI void APIENTRY glMakeNamedBufferNonResidentNV(GLuint buffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1557];
   ((void (APIENTRY *)(GLuint buffer)) _func)(buffer);
}

GLAPI void APIENTRY glMakeNamedBufferResidentNV(GLuint buffer, GLenum access)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1558];
   ((void (APIENTRY *)(GLuint buffer, GLenum access)) _func)(buffer, access);
}

GLAPI void APIENTRY glMakeTextureHandleNonResidentARB(GLuint64 handle)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1559];
   ((void (APIENTRY *)(GLuint64 handle)) _func)(handle);
}

GLAPI void APIENTRY glMakeTextureHandleNonResidentNV(GLuint64 handle)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1560];
   ((void (APIENTRY *)(GLuint64 handle)) _func)(handle);
}

GLAPI void APIENTRY glMakeTextureHandleResidentARB(GLuint64 handle)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1561];
   ((void (APIENTRY *)(GLuint64 handle)) _func)(handle);
}

GLAPI void APIENTRY glMakeTextureHandleResidentNV(GLuint64 handle)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1562];
   ((void (APIENTRY *)(GLuint64 handle)) _func)(handle);
}

GLAPI void APIENTRY glMap1d(GLenum target, GLdouble u1, GLdouble u2, GLint stride, GLint order, const GLdouble *points)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1563];
   ((void (APIENTRY *)(GLenum target, GLdouble u1, GLdouble u2, GLint stride, GLint order, const GLdouble *points)) _func)(target, u1, u2, stride, order, points);
}

GLAPI void APIENTRY glMap1f(GLenum target, GLfloat u1, GLfloat u2, GLint stride, GLint order, const GLfloat *points)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1564];
   ((void (APIENTRY *)(GLenum target, GLfloat u1, GLfloat u2, GLint stride, GLint order, const GLfloat *points)) _func)(target, u1, u2, stride, order, points);
}

GLAPI void APIENTRY glMap1xOES(GLenum target, GLfixed u1, GLfixed u2, GLint stride, GLint order, GLfixed points)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1565];
   ((void (APIENTRY *)(GLenum target, GLfixed u1, GLfixed u2, GLint stride, GLint order, GLfixed points)) _func)(target, u1, u2, stride, order, points);
}

GLAPI void APIENTRY glMap2d(GLenum target, GLdouble u1, GLdouble u2, GLint ustride, GLint uorder, GLdouble v1, GLdouble v2, GLint vstride, GLint vorder, const GLdouble *points)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1566];
   ((void (APIENTRY *)(GLenum target, GLdouble u1, GLdouble u2, GLint ustride, GLint uorder, GLdouble v1, GLdouble v2, GLint vstride, GLint vorder, const GLdouble *points)) _func)(target, u1, u2, ustride, uorder, v1, v2, vstride, vorder, points);
}

GLAPI void APIENTRY glMap2f(GLenum target, GLfloat u1, GLfloat u2, GLint ustride, GLint uorder, GLfloat v1, GLfloat v2, GLint vstride, GLint vorder, const GLfloat *points)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1567];
   ((void (APIENTRY *)(GLenum target, GLfloat u1, GLfloat u2, GLint ustride, GLint uorder, GLfloat v1, GLfloat v2, GLint vstride, GLint vorder, const GLfloat *points)) _func)(target, u1, u2, ustride, uorder, v1, v2, vstride, vorder, points);
}

GLAPI void APIENTRY glMap2xOES(GLenum target, GLfixed u1, GLfixed u2, GLint ustride, GLint uorder, GLfixed v1, GLfixed v2, GLint vstride, GLint vorder, GLfixed points)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1568];
   ((void (APIENTRY *)(GLenum target, GLfixed u1, GLfixed u2, GLint ustride, GLint uorder, GLfixed v1, GLfixed v2, GLint vstride, GLint vorder, GLfixed points)) _func)(target, u1, u2, ustride, uorder, v1, v2, vstride, vorder, points);
}

GLAPI void * APIENTRY glMapBuffer(GLenum target, GLenum access)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1569];
   return ((void * (APIENTRY *)(GLenum target, GLenum access)) _func)(target, access);
}

GLAPI void * APIENTRY glMapBufferARB(GLenum target, GLenum access)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1570];
   return ((void * (APIENTRY *)(GLenum target, GLenum access)) _func)(target, access);
}

GLAPI void * APIENTRY glMapBufferOES(GLenum target, GLenum access)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1571];
   return ((void * (APIENTRY *)(GLenum target, GLenum access)) _func)(target, access);
}

GLAPI void * APIENTRY glMapBufferRange(GLenum target, GLintptr offset, GLsizeiptr length, GLbitfield access)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1572];
   return ((void * (APIENTRY *)(GLenum target, GLintptr offset, GLsizeiptr length, GLbitfield access)) _func)(target, offset, length, access);
}

GLAPI void * APIENTRY glMapBufferRangeEXT(GLenum target, GLintptr offset, GLsizeiptr length, GLbitfield access)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1573];
   return ((void * (APIENTRY *)(GLenum target, GLintptr offset, GLsizeiptr length, GLbitfield access)) _func)(target, offset, length, access);
}

GLAPI void APIENTRY glMapControlPointsNV(GLenum target, GLuint index, GLenum type, GLsizei ustride, GLsizei vstride, GLint uorder, GLint vorder, GLboolean packed, const void *points)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1574];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLenum type, GLsizei ustride, GLsizei vstride, GLint uorder, GLint vorder, GLboolean packed, const void *points)) _func)(target, index, type, ustride, vstride, uorder, vorder, packed, points);
}

GLAPI void APIENTRY glMapGrid1d(GLint un, GLdouble u1, GLdouble u2)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1575];
   ((void (APIENTRY *)(GLint un, GLdouble u1, GLdouble u2)) _func)(un, u1, u2);
}

GLAPI void APIENTRY glMapGrid1f(GLint un, GLfloat u1, GLfloat u2)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1576];
   ((void (APIENTRY *)(GLint un, GLfloat u1, GLfloat u2)) _func)(un, u1, u2);
}

GLAPI void APIENTRY glMapGrid1xOES(GLint n, GLfixed u1, GLfixed u2)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1577];
   ((void (APIENTRY *)(GLint n, GLfixed u1, GLfixed u2)) _func)(n, u1, u2);
}

GLAPI void APIENTRY glMapGrid2d(GLint un, GLdouble u1, GLdouble u2, GLint vn, GLdouble v1, GLdouble v2)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1578];
   ((void (APIENTRY *)(GLint un, GLdouble u1, GLdouble u2, GLint vn, GLdouble v1, GLdouble v2)) _func)(un, u1, u2, vn, v1, v2);
}

GLAPI void APIENTRY glMapGrid2f(GLint un, GLfloat u1, GLfloat u2, GLint vn, GLfloat v1, GLfloat v2)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1579];
   ((void (APIENTRY *)(GLint un, GLfloat u1, GLfloat u2, GLint vn, GLfloat v1, GLfloat v2)) _func)(un, u1, u2, vn, v1, v2);
}

GLAPI void APIENTRY glMapGrid2xOES(GLint n, GLfixed u1, GLfixed u2, GLfixed v1, GLfixed v2)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1580];
   ((void (APIENTRY *)(GLint n, GLfixed u1, GLfixed u2, GLfixed v1, GLfixed v2)) _func)(n, u1, u2, v1, v2);
}

GLAPI void * APIENTRY glMapNamedBuffer(GLuint buffer, GLenum access)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1581];
   return ((void * (APIENTRY *)(GLuint buffer, GLenum access)) _func)(buffer, access);
}

GLAPI void * APIENTRY glMapNamedBufferEXT(GLuint buffer, GLenum access)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1582];
   return ((void * (APIENTRY *)(GLuint buffer, GLenum access)) _func)(buffer, access);
}

GLAPI void * APIENTRY glMapNamedBufferRange(GLuint buffer, GLintptr offset, GLsizeiptr length, GLbitfield access)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1583];
   return ((void * (APIENTRY *)(GLuint buffer, GLintptr offset, GLsizeiptr length, GLbitfield access)) _func)(buffer, offset, length, access);
}

GLAPI void * APIENTRY glMapNamedBufferRangeEXT(GLuint buffer, GLintptr offset, GLsizeiptr length, GLbitfield access)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1584];
   return ((void * (APIENTRY *)(GLuint buffer, GLintptr offset, GLsizeiptr length, GLbitfield access)) _func)(buffer, offset, length, access);
}

GLAPI void * APIENTRY glMapObjectBufferATI(GLuint buffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1585];
   return ((void * (APIENTRY *)(GLuint buffer)) _func)(buffer);
}

GLAPI void APIENTRY glMapParameterfvNV(GLenum target, GLenum pname, const GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1586];
   ((void (APIENTRY *)(GLenum target, GLenum pname, const GLfloat *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glMapParameterivNV(GLenum target, GLenum pname, const GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1587];
   ((void (APIENTRY *)(GLenum target, GLenum pname, const GLint *params)) _func)(target, pname, params);
}

GLAPI void * APIENTRY glMapTexture2DINTEL(GLuint texture, GLint level, GLbitfield access, GLint *stride, GLenum *layout)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1588];
   return ((void * (APIENTRY *)(GLuint texture, GLint level, GLbitfield access, GLint *stride, GLenum *layout)) _func)(texture, level, access, stride, layout);
}

GLAPI void APIENTRY glMapVertexAttrib1dAPPLE(GLuint index, GLuint size, GLdouble u1, GLdouble u2, GLint stride, GLint order, const GLdouble *points)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1589];
   ((void (APIENTRY *)(GLuint index, GLuint size, GLdouble u1, GLdouble u2, GLint stride, GLint order, const GLdouble *points)) _func)(index, size, u1, u2, stride, order, points);
}

GLAPI void APIENTRY glMapVertexAttrib1fAPPLE(GLuint index, GLuint size, GLfloat u1, GLfloat u2, GLint stride, GLint order, const GLfloat *points)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1590];
   ((void (APIENTRY *)(GLuint index, GLuint size, GLfloat u1, GLfloat u2, GLint stride, GLint order, const GLfloat *points)) _func)(index, size, u1, u2, stride, order, points);
}

GLAPI void APIENTRY glMapVertexAttrib2dAPPLE(GLuint index, GLuint size, GLdouble u1, GLdouble u2, GLint ustride, GLint uorder, GLdouble v1, GLdouble v2, GLint vstride, GLint vorder, const GLdouble *points)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1591];
   ((void (APIENTRY *)(GLuint index, GLuint size, GLdouble u1, GLdouble u2, GLint ustride, GLint uorder, GLdouble v1, GLdouble v2, GLint vstride, GLint vorder, const GLdouble *points)) _func)(index, size, u1, u2, ustride, uorder, v1, v2, vstride, vorder, points);
}

GLAPI void APIENTRY glMapVertexAttrib2fAPPLE(GLuint index, GLuint size, GLfloat u1, GLfloat u2, GLint ustride, GLint uorder, GLfloat v1, GLfloat v2, GLint vstride, GLint vorder, const GLfloat *points)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1592];
   ((void (APIENTRY *)(GLuint index, GLuint size, GLfloat u1, GLfloat u2, GLint ustride, GLint uorder, GLfloat v1, GLfloat v2, GLint vstride, GLint vorder, const GLfloat *points)) _func)(index, size, u1, u2, ustride, uorder, v1, v2, vstride, vorder, points);
}

GLAPI void APIENTRY glMaterialf(GLenum face, GLenum pname, GLfloat param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1593];
   ((void (APIENTRY *)(GLenum face, GLenum pname, GLfloat param)) _func)(face, pname, param);
}

GLAPI void APIENTRY glMaterialfv(GLenum face, GLenum pname, const GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1594];
   ((void (APIENTRY *)(GLenum face, GLenum pname, const GLfloat *params)) _func)(face, pname, params);
}

GLAPI void APIENTRY glMateriali(GLenum face, GLenum pname, GLint param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1595];
   ((void (APIENTRY *)(GLenum face, GLenum pname, GLint param)) _func)(face, pname, param);
}

GLAPI void APIENTRY glMaterialiv(GLenum face, GLenum pname, const GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1596];
   ((void (APIENTRY *)(GLenum face, GLenum pname, const GLint *params)) _func)(face, pname, params);
}

GLAPI void APIENTRY glMaterialx(GLenum face, GLenum pname, GLfixed param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1597];
   ((void (APIENTRY *)(GLenum face, GLenum pname, GLfixed param)) _func)(face, pname, param);
}

GLAPI void APIENTRY glMaterialxOES(GLenum face, GLenum pname, GLfixed param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1598];
   ((void (APIENTRY *)(GLenum face, GLenum pname, GLfixed param)) _func)(face, pname, param);
}

GLAPI void APIENTRY glMaterialxv(GLenum face, GLenum pname, const GLfixed *param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1599];
   ((void (APIENTRY *)(GLenum face, GLenum pname, const GLfixed *param)) _func)(face, pname, param);
}

GLAPI void APIENTRY glMaterialxvOES(GLenum face, GLenum pname, const GLfixed *param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1600];
   ((void (APIENTRY *)(GLenum face, GLenum pname, const GLfixed *param)) _func)(face, pname, param);
}

GLAPI void APIENTRY glMatrixFrustumEXT(GLenum mode, GLdouble left, GLdouble right, GLdouble bottom, GLdouble top, GLdouble zNear, GLdouble zFar)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1601];
   ((void (APIENTRY *)(GLenum mode, GLdouble left, GLdouble right, GLdouble bottom, GLdouble top, GLdouble zNear, GLdouble zFar)) _func)(mode, left, right, bottom, top, zNear, zFar);
}

GLAPI void APIENTRY glMatrixIndexPointerARB(GLint size, GLenum type, GLsizei stride, const void *pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1602];
   ((void (APIENTRY *)(GLint size, GLenum type, GLsizei stride, const void *pointer)) _func)(size, type, stride, pointer);
}

GLAPI void APIENTRY glMatrixIndexPointerOES(GLint size, GLenum type, GLsizei stride, const void *pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1603];
   ((void (APIENTRY *)(GLint size, GLenum type, GLsizei stride, const void *pointer)) _func)(size, type, stride, pointer);
}

GLAPI void APIENTRY glMatrixIndexubvARB(GLint size, const GLubyte *indices)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1604];
   ((void (APIENTRY *)(GLint size, const GLubyte *indices)) _func)(size, indices);
}

GLAPI void APIENTRY glMatrixIndexuivARB(GLint size, const GLuint *indices)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1605];
   ((void (APIENTRY *)(GLint size, const GLuint *indices)) _func)(size, indices);
}

GLAPI void APIENTRY glMatrixIndexusvARB(GLint size, const GLushort *indices)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1606];
   ((void (APIENTRY *)(GLint size, const GLushort *indices)) _func)(size, indices);
}

GLAPI void APIENTRY glMatrixLoad3x2fNV(GLenum matrixMode, const GLfloat *m)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1607];
   ((void (APIENTRY *)(GLenum matrixMode, const GLfloat *m)) _func)(matrixMode, m);
}

GLAPI void APIENTRY glMatrixLoad3x3fNV(GLenum matrixMode, const GLfloat *m)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1608];
   ((void (APIENTRY *)(GLenum matrixMode, const GLfloat *m)) _func)(matrixMode, m);
}

GLAPI void APIENTRY glMatrixLoadIdentityEXT(GLenum mode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1609];
   ((void (APIENTRY *)(GLenum mode)) _func)(mode);
}

GLAPI void APIENTRY glMatrixLoadTranspose3x3fNV(GLenum matrixMode, const GLfloat *m)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1610];
   ((void (APIENTRY *)(GLenum matrixMode, const GLfloat *m)) _func)(matrixMode, m);
}

GLAPI void APIENTRY glMatrixLoadTransposedEXT(GLenum mode, const GLdouble *m)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1611];
   ((void (APIENTRY *)(GLenum mode, const GLdouble *m)) _func)(mode, m);
}

GLAPI void APIENTRY glMatrixLoadTransposefEXT(GLenum mode, const GLfloat *m)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1612];
   ((void (APIENTRY *)(GLenum mode, const GLfloat *m)) _func)(mode, m);
}

GLAPI void APIENTRY glMatrixLoaddEXT(GLenum mode, const GLdouble *m)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1613];
   ((void (APIENTRY *)(GLenum mode, const GLdouble *m)) _func)(mode, m);
}

GLAPI void APIENTRY glMatrixLoadfEXT(GLenum mode, const GLfloat *m)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1614];
   ((void (APIENTRY *)(GLenum mode, const GLfloat *m)) _func)(mode, m);
}

GLAPI void APIENTRY glMatrixMode(GLenum mode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1615];
   ((void (APIENTRY *)(GLenum mode)) _func)(mode);
}

GLAPI void APIENTRY glMatrixMult3x2fNV(GLenum matrixMode, const GLfloat *m)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1616];
   ((void (APIENTRY *)(GLenum matrixMode, const GLfloat *m)) _func)(matrixMode, m);
}

GLAPI void APIENTRY glMatrixMult3x3fNV(GLenum matrixMode, const GLfloat *m)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1617];
   ((void (APIENTRY *)(GLenum matrixMode, const GLfloat *m)) _func)(matrixMode, m);
}

GLAPI void APIENTRY glMatrixMultTranspose3x3fNV(GLenum matrixMode, const GLfloat *m)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1618];
   ((void (APIENTRY *)(GLenum matrixMode, const GLfloat *m)) _func)(matrixMode, m);
}

GLAPI void APIENTRY glMatrixMultTransposedEXT(GLenum mode, const GLdouble *m)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1619];
   ((void (APIENTRY *)(GLenum mode, const GLdouble *m)) _func)(mode, m);
}

GLAPI void APIENTRY glMatrixMultTransposefEXT(GLenum mode, const GLfloat *m)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1620];
   ((void (APIENTRY *)(GLenum mode, const GLfloat *m)) _func)(mode, m);
}

GLAPI void APIENTRY glMatrixMultdEXT(GLenum mode, const GLdouble *m)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1621];
   ((void (APIENTRY *)(GLenum mode, const GLdouble *m)) _func)(mode, m);
}

GLAPI void APIENTRY glMatrixMultfEXT(GLenum mode, const GLfloat *m)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1622];
   ((void (APIENTRY *)(GLenum mode, const GLfloat *m)) _func)(mode, m);
}

GLAPI void APIENTRY glMatrixOrthoEXT(GLenum mode, GLdouble left, GLdouble right, GLdouble bottom, GLdouble top, GLdouble zNear, GLdouble zFar)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1623];
   ((void (APIENTRY *)(GLenum mode, GLdouble left, GLdouble right, GLdouble bottom, GLdouble top, GLdouble zNear, GLdouble zFar)) _func)(mode, left, right, bottom, top, zNear, zFar);
}

GLAPI void APIENTRY glMatrixPopEXT(GLenum mode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1624];
   ((void (APIENTRY *)(GLenum mode)) _func)(mode);
}

GLAPI void APIENTRY glMatrixPushEXT(GLenum mode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1625];
   ((void (APIENTRY *)(GLenum mode)) _func)(mode);
}

GLAPI void APIENTRY glMatrixRotatedEXT(GLenum mode, GLdouble angle, GLdouble x, GLdouble y, GLdouble z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1626];
   ((void (APIENTRY *)(GLenum mode, GLdouble angle, GLdouble x, GLdouble y, GLdouble z)) _func)(mode, angle, x, y, z);
}

GLAPI void APIENTRY glMatrixRotatefEXT(GLenum mode, GLfloat angle, GLfloat x, GLfloat y, GLfloat z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1627];
   ((void (APIENTRY *)(GLenum mode, GLfloat angle, GLfloat x, GLfloat y, GLfloat z)) _func)(mode, angle, x, y, z);
}

GLAPI void APIENTRY glMatrixScaledEXT(GLenum mode, GLdouble x, GLdouble y, GLdouble z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1628];
   ((void (APIENTRY *)(GLenum mode, GLdouble x, GLdouble y, GLdouble z)) _func)(mode, x, y, z);
}

GLAPI void APIENTRY glMatrixScalefEXT(GLenum mode, GLfloat x, GLfloat y, GLfloat z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1629];
   ((void (APIENTRY *)(GLenum mode, GLfloat x, GLfloat y, GLfloat z)) _func)(mode, x, y, z);
}

GLAPI void APIENTRY glMatrixTranslatedEXT(GLenum mode, GLdouble x, GLdouble y, GLdouble z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1630];
   ((void (APIENTRY *)(GLenum mode, GLdouble x, GLdouble y, GLdouble z)) _func)(mode, x, y, z);
}

GLAPI void APIENTRY glMatrixTranslatefEXT(GLenum mode, GLfloat x, GLfloat y, GLfloat z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1631];
   ((void (APIENTRY *)(GLenum mode, GLfloat x, GLfloat y, GLfloat z)) _func)(mode, x, y, z);
}

GLAPI void APIENTRY glMaxShaderCompilerThreadsARB(GLuint count)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1632];
   ((void (APIENTRY *)(GLuint count)) _func)(count);
}

GLAPI void APIENTRY glMaxShaderCompilerThreadsKHR(GLuint count)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1633];
   ((void (APIENTRY *)(GLuint count)) _func)(count);
}

GLAPI void APIENTRY glMemoryBarrier(GLbitfield barriers)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1634];
   ((void (APIENTRY *)(GLbitfield barriers)) _func)(barriers);
}

GLAPI void APIENTRY glMemoryBarrierByRegion(GLbitfield barriers)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1635];
   ((void (APIENTRY *)(GLbitfield barriers)) _func)(barriers);
}

GLAPI void APIENTRY glMemoryBarrierEXT(GLbitfield barriers)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1636];
   ((void (APIENTRY *)(GLbitfield barriers)) _func)(barriers);
}

GLAPI void APIENTRY glMemoryObjectParameterivEXT(GLuint memoryObject, GLenum pname, const GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1637];
   ((void (APIENTRY *)(GLuint memoryObject, GLenum pname, const GLint *params)) _func)(memoryObject, pname, params);
}

GLAPI void APIENTRY glMinSampleShading(GLfloat value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1638];
   ((void (APIENTRY *)(GLfloat value)) _func)(value);
}

GLAPI void APIENTRY glMinSampleShadingARB(GLfloat value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1639];
   ((void (APIENTRY *)(GLfloat value)) _func)(value);
}

GLAPI void APIENTRY glMinSampleShadingOES(GLfloat value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1640];
   ((void (APIENTRY *)(GLfloat value)) _func)(value);
}

GLAPI void APIENTRY glMinmax(GLenum target, GLenum internalformat, GLboolean sink)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1641];
   ((void (APIENTRY *)(GLenum target, GLenum internalformat, GLboolean sink)) _func)(target, internalformat, sink);
}

GLAPI void APIENTRY glMinmaxEXT(GLenum target, GLenum internalformat, GLboolean sink)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1642];
   ((void (APIENTRY *)(GLenum target, GLenum internalformat, GLboolean sink)) _func)(target, internalformat, sink);
}

GLAPI void APIENTRY glMultMatrixd(const GLdouble *m)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1643];
   ((void (APIENTRY *)(const GLdouble *m)) _func)(m);
}

GLAPI void APIENTRY glMultMatrixf(const GLfloat *m)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1644];
   ((void (APIENTRY *)(const GLfloat *m)) _func)(m);
}

GLAPI void APIENTRY glMultMatrixx(const GLfixed *m)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1645];
   ((void (APIENTRY *)(const GLfixed *m)) _func)(m);
}

GLAPI void APIENTRY glMultMatrixxOES(const GLfixed *m)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1646];
   ((void (APIENTRY *)(const GLfixed *m)) _func)(m);
}

GLAPI void APIENTRY glMultTransformEXT(GLenum transform)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1647];
   ((void (APIENTRY *)(GLenum transform)) _func)(transform);
}

GLAPI void APIENTRY glMultTransposeMatrixd(const GLdouble *m)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1648];
   ((void (APIENTRY *)(const GLdouble *m)) _func)(m);
}

GLAPI void APIENTRY glMultTransposeMatrixdARB(const GLdouble *m)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1649];
   ((void (APIENTRY *)(const GLdouble *m)) _func)(m);
}

GLAPI void APIENTRY glMultTransposeMatrixf(const GLfloat *m)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1650];
   ((void (APIENTRY *)(const GLfloat *m)) _func)(m);
}

GLAPI void APIENTRY glMultTransposeMatrixfARB(const GLfloat *m)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1651];
   ((void (APIENTRY *)(const GLfloat *m)) _func)(m);
}

GLAPI void APIENTRY glMultTransposeMatrixxOES(const GLfixed *m)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1652];
   ((void (APIENTRY *)(const GLfixed *m)) _func)(m);
}

GLAPI void APIENTRY glMultiDrawArrays(GLenum mode, const GLint *first, const GLsizei *count, GLsizei drawcount)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1653];
   ((void (APIENTRY *)(GLenum mode, const GLint *first, const GLsizei *count, GLsizei drawcount)) _func)(mode, first, count, drawcount);
}

GLAPI void APIENTRY glMultiDrawArraysEXT(GLenum mode, const GLint *first, const GLsizei *count, GLsizei primcount)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1654];
   ((void (APIENTRY *)(GLenum mode, const GLint *first, const GLsizei *count, GLsizei primcount)) _func)(mode, first, count, primcount);
}

GLAPI void APIENTRY glMultiDrawArraysIndirect(GLenum mode, const void *indirect, GLsizei drawcount, GLsizei stride)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1655];
   ((void (APIENTRY *)(GLenum mode, const void *indirect, GLsizei drawcount, GLsizei stride)) _func)(mode, indirect, drawcount, stride);
}

GLAPI void APIENTRY glMultiDrawArraysIndirectAMD(GLenum mode, const void *indirect, GLsizei primcount, GLsizei stride)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1656];
   ((void (APIENTRY *)(GLenum mode, const void *indirect, GLsizei primcount, GLsizei stride)) _func)(mode, indirect, primcount, stride);
}

GLAPI void APIENTRY glMultiDrawArraysIndirectBindlessCountNV(GLenum mode, const void *indirect, GLsizei drawCount, GLsizei maxDrawCount, GLsizei stride, GLint vertexBufferCount)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1657];
   ((void (APIENTRY *)(GLenum mode, const void *indirect, GLsizei drawCount, GLsizei maxDrawCount, GLsizei stride, GLint vertexBufferCount)) _func)(mode, indirect, drawCount, maxDrawCount, stride, vertexBufferCount);
}

GLAPI void APIENTRY glMultiDrawArraysIndirectBindlessNV(GLenum mode, const void *indirect, GLsizei drawCount, GLsizei stride, GLint vertexBufferCount)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1658];
   ((void (APIENTRY *)(GLenum mode, const void *indirect, GLsizei drawCount, GLsizei stride, GLint vertexBufferCount)) _func)(mode, indirect, drawCount, stride, vertexBufferCount);
}

GLAPI void APIENTRY glMultiDrawArraysIndirectCount(GLenum mode, const void *indirect, GLintptr drawcount, GLsizei maxdrawcount, GLsizei stride)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1659];
   ((void (APIENTRY *)(GLenum mode, const void *indirect, GLintptr drawcount, GLsizei maxdrawcount, GLsizei stride)) _func)(mode, indirect, drawcount, maxdrawcount, stride);
}

GLAPI void APIENTRY glMultiDrawArraysIndirectCountARB(GLenum mode, const void *indirect, GLintptr drawcount, GLsizei maxdrawcount, GLsizei stride)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1660];
   ((void (APIENTRY *)(GLenum mode, const void *indirect, GLintptr drawcount, GLsizei maxdrawcount, GLsizei stride)) _func)(mode, indirect, drawcount, maxdrawcount, stride);
}

GLAPI void APIENTRY glMultiDrawArraysIndirectEXT(GLenum mode, const void *indirect, GLsizei drawcount, GLsizei stride)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1661];
   ((void (APIENTRY *)(GLenum mode, const void *indirect, GLsizei drawcount, GLsizei stride)) _func)(mode, indirect, drawcount, stride);
}

GLAPI void APIENTRY glMultiDrawElementArrayAPPLE(GLenum mode, const GLint *first, const GLsizei *count, GLsizei primcount)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1662];
   ((void (APIENTRY *)(GLenum mode, const GLint *first, const GLsizei *count, GLsizei primcount)) _func)(mode, first, count, primcount);
}

GLAPI void APIENTRY glMultiDrawElements(GLenum mode, const GLsizei *count, GLenum type, const void *const *indices, GLsizei drawcount)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1663];
   ((void (APIENTRY *)(GLenum mode, const GLsizei *count, GLenum type, const void *const *indices, GLsizei drawcount)) _func)(mode, count, type, indices, drawcount);
}

GLAPI void APIENTRY glMultiDrawElementsBaseVertex(GLenum mode, const GLsizei *count, GLenum type, const void *const *indices, GLsizei drawcount, const GLint *basevertex)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1664];
   ((void (APIENTRY *)(GLenum mode, const GLsizei *count, GLenum type, const void *const *indices, GLsizei drawcount, const GLint *basevertex)) _func)(mode, count, type, indices, drawcount, basevertex);
}

GLAPI void APIENTRY glMultiDrawElementsBaseVertexEXT(GLenum mode, const GLsizei *count, GLenum type, const void *const *indices, GLsizei drawcount, const GLint *basevertex)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1665];
   ((void (APIENTRY *)(GLenum mode, const GLsizei *count, GLenum type, const void *const *indices, GLsizei drawcount, const GLint *basevertex)) _func)(mode, count, type, indices, drawcount, basevertex);
}

GLAPI void APIENTRY glMultiDrawElementsEXT(GLenum mode, const GLsizei *count, GLenum type, const void *const *indices, GLsizei primcount)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1666];
   ((void (APIENTRY *)(GLenum mode, const GLsizei *count, GLenum type, const void *const *indices, GLsizei primcount)) _func)(mode, count, type, indices, primcount);
}

GLAPI void APIENTRY glMultiDrawElementsIndirect(GLenum mode, GLenum type, const void *indirect, GLsizei drawcount, GLsizei stride)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1667];
   ((void (APIENTRY *)(GLenum mode, GLenum type, const void *indirect, GLsizei drawcount, GLsizei stride)) _func)(mode, type, indirect, drawcount, stride);
}

GLAPI void APIENTRY glMultiDrawElementsIndirectAMD(GLenum mode, GLenum type, const void *indirect, GLsizei primcount, GLsizei stride)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1668];
   ((void (APIENTRY *)(GLenum mode, GLenum type, const void *indirect, GLsizei primcount, GLsizei stride)) _func)(mode, type, indirect, primcount, stride);
}

GLAPI void APIENTRY glMultiDrawElementsIndirectBindlessCountNV(GLenum mode, GLenum type, const void *indirect, GLsizei drawCount, GLsizei maxDrawCount, GLsizei stride, GLint vertexBufferCount)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1669];
   ((void (APIENTRY *)(GLenum mode, GLenum type, const void *indirect, GLsizei drawCount, GLsizei maxDrawCount, GLsizei stride, GLint vertexBufferCount)) _func)(mode, type, indirect, drawCount, maxDrawCount, stride, vertexBufferCount);
}

GLAPI void APIENTRY glMultiDrawElementsIndirectBindlessNV(GLenum mode, GLenum type, const void *indirect, GLsizei drawCount, GLsizei stride, GLint vertexBufferCount)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1670];
   ((void (APIENTRY *)(GLenum mode, GLenum type, const void *indirect, GLsizei drawCount, GLsizei stride, GLint vertexBufferCount)) _func)(mode, type, indirect, drawCount, stride, vertexBufferCount);
}

GLAPI void APIENTRY glMultiDrawElementsIndirectCount(GLenum mode, GLenum type, const void *indirect, GLintptr drawcount, GLsizei maxdrawcount, GLsizei stride)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1671];
   ((void (APIENTRY *)(GLenum mode, GLenum type, const void *indirect, GLintptr drawcount, GLsizei maxdrawcount, GLsizei stride)) _func)(mode, type, indirect, drawcount, maxdrawcount, stride);
}

GLAPI void APIENTRY glMultiDrawElementsIndirectCountARB(GLenum mode, GLenum type, const void *indirect, GLintptr drawcount, GLsizei maxdrawcount, GLsizei stride)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1672];
   ((void (APIENTRY *)(GLenum mode, GLenum type, const void *indirect, GLintptr drawcount, GLsizei maxdrawcount, GLsizei stride)) _func)(mode, type, indirect, drawcount, maxdrawcount, stride);
}

GLAPI void APIENTRY glMultiDrawElementsIndirectEXT(GLenum mode, GLenum type, const void *indirect, GLsizei drawcount, GLsizei stride)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1673];
   ((void (APIENTRY *)(GLenum mode, GLenum type, const void *indirect, GLsizei drawcount, GLsizei stride)) _func)(mode, type, indirect, drawcount, stride);
}

GLAPI void APIENTRY glMultiDrawMeshTasksIndirectCountNV(GLintptr indirect, GLintptr drawcount, GLsizei maxdrawcount, GLsizei stride)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1674];
   ((void (APIENTRY *)(GLintptr indirect, GLintptr drawcount, GLsizei maxdrawcount, GLsizei stride)) _func)(indirect, drawcount, maxdrawcount, stride);
}

GLAPI void APIENTRY glMultiDrawMeshTasksIndirectNV(GLintptr indirect, GLsizei drawcount, GLsizei stride)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1675];
   ((void (APIENTRY *)(GLintptr indirect, GLsizei drawcount, GLsizei stride)) _func)(indirect, drawcount, stride);
}

GLAPI void APIENTRY glMultiDrawRangeElementArrayAPPLE(GLenum mode, GLuint start, GLuint end, const GLint *first, const GLsizei *count, GLsizei primcount)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1676];
   ((void (APIENTRY *)(GLenum mode, GLuint start, GLuint end, const GLint *first, const GLsizei *count, GLsizei primcount)) _func)(mode, start, end, first, count, primcount);
}

GLAPI void APIENTRY glMultiModeDrawArraysIBM(const GLenum *mode, const GLint *first, const GLsizei *count, GLsizei primcount, GLint modestride)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1677];
   ((void (APIENTRY *)(const GLenum *mode, const GLint *first, const GLsizei *count, GLsizei primcount, GLint modestride)) _func)(mode, first, count, primcount, modestride);
}

GLAPI void APIENTRY glMultiModeDrawElementsIBM(const GLenum *mode, const GLsizei *count, GLenum type, const void *const *indices, GLsizei primcount, GLint modestride)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1678];
   ((void (APIENTRY *)(const GLenum *mode, const GLsizei *count, GLenum type, const void *const *indices, GLsizei primcount, GLint modestride)) _func)(mode, count, type, indices, primcount, modestride);
}

GLAPI void APIENTRY glMultiTexBufferEXT(GLenum texunit, GLenum target, GLenum internalformat, GLuint buffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1679];
   ((void (APIENTRY *)(GLenum texunit, GLenum target, GLenum internalformat, GLuint buffer)) _func)(texunit, target, internalformat, buffer);
}

GLAPI void APIENTRY glMultiTexCoord1bOES(GLenum texture, GLbyte s)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1680];
   ((void (APIENTRY *)(GLenum texture, GLbyte s)) _func)(texture, s);
}

GLAPI void APIENTRY glMultiTexCoord1bvOES(GLenum texture, const GLbyte *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1681];
   ((void (APIENTRY *)(GLenum texture, const GLbyte *coords)) _func)(texture, coords);
}

GLAPI void APIENTRY glMultiTexCoord1d(GLenum target, GLdouble s)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1682];
   ((void (APIENTRY *)(GLenum target, GLdouble s)) _func)(target, s);
}

GLAPI void APIENTRY glMultiTexCoord1dARB(GLenum target, GLdouble s)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1683];
   ((void (APIENTRY *)(GLenum target, GLdouble s)) _func)(target, s);
}

GLAPI void APIENTRY glMultiTexCoord1dv(GLenum target, const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1684];
   ((void (APIENTRY *)(GLenum target, const GLdouble *v)) _func)(target, v);
}

GLAPI void APIENTRY glMultiTexCoord1dvARB(GLenum target, const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1685];
   ((void (APIENTRY *)(GLenum target, const GLdouble *v)) _func)(target, v);
}

GLAPI void APIENTRY glMultiTexCoord1f(GLenum target, GLfloat s)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1686];
   ((void (APIENTRY *)(GLenum target, GLfloat s)) _func)(target, s);
}

GLAPI void APIENTRY glMultiTexCoord1fARB(GLenum target, GLfloat s)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1687];
   ((void (APIENTRY *)(GLenum target, GLfloat s)) _func)(target, s);
}

GLAPI void APIENTRY glMultiTexCoord1fv(GLenum target, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1688];
   ((void (APIENTRY *)(GLenum target, const GLfloat *v)) _func)(target, v);
}

GLAPI void APIENTRY glMultiTexCoord1fvARB(GLenum target, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1689];
   ((void (APIENTRY *)(GLenum target, const GLfloat *v)) _func)(target, v);
}

GLAPI void APIENTRY glMultiTexCoord1hNV(GLenum target, GLhalf s)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1690];
   ((void (APIENTRY *)(GLenum target, GLhalf s)) _func)(target, s);
}

GLAPI void APIENTRY glMultiTexCoord1hvNV(GLenum target, const GLhalf *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1691];
   ((void (APIENTRY *)(GLenum target, const GLhalf *v)) _func)(target, v);
}

GLAPI void APIENTRY glMultiTexCoord1i(GLenum target, GLint s)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1692];
   ((void (APIENTRY *)(GLenum target, GLint s)) _func)(target, s);
}

GLAPI void APIENTRY glMultiTexCoord1iARB(GLenum target, GLint s)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1693];
   ((void (APIENTRY *)(GLenum target, GLint s)) _func)(target, s);
}

GLAPI void APIENTRY glMultiTexCoord1iv(GLenum target, const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1694];
   ((void (APIENTRY *)(GLenum target, const GLint *v)) _func)(target, v);
}

GLAPI void APIENTRY glMultiTexCoord1ivARB(GLenum target, const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1695];
   ((void (APIENTRY *)(GLenum target, const GLint *v)) _func)(target, v);
}

GLAPI void APIENTRY glMultiTexCoord1s(GLenum target, GLshort s)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1696];
   ((void (APIENTRY *)(GLenum target, GLshort s)) _func)(target, s);
}

GLAPI void APIENTRY glMultiTexCoord1sARB(GLenum target, GLshort s)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1697];
   ((void (APIENTRY *)(GLenum target, GLshort s)) _func)(target, s);
}

GLAPI void APIENTRY glMultiTexCoord1sv(GLenum target, const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1698];
   ((void (APIENTRY *)(GLenum target, const GLshort *v)) _func)(target, v);
}

GLAPI void APIENTRY glMultiTexCoord1svARB(GLenum target, const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1699];
   ((void (APIENTRY *)(GLenum target, const GLshort *v)) _func)(target, v);
}

GLAPI void APIENTRY glMultiTexCoord1x(GLenum target, GLfixed s)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1700];
   ((void (APIENTRY *)(GLenum target, GLfixed s)) _func)(target, s);
}

GLAPI void APIENTRY glMultiTexCoord1xOES(GLenum texture, GLfixed s)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1701];
   ((void (APIENTRY *)(GLenum texture, GLfixed s)) _func)(texture, s);
}

GLAPI void APIENTRY glMultiTexCoord1xv(GLenum target, const GLfixed *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1702];
   ((void (APIENTRY *)(GLenum target, const GLfixed *v)) _func)(target, v);
}

GLAPI void APIENTRY glMultiTexCoord1xvOES(GLenum texture, const GLfixed *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1703];
   ((void (APIENTRY *)(GLenum texture, const GLfixed *coords)) _func)(texture, coords);
}

GLAPI void APIENTRY glMultiTexCoord2bOES(GLenum texture, GLbyte s, GLbyte t)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1704];
   ((void (APIENTRY *)(GLenum texture, GLbyte s, GLbyte t)) _func)(texture, s, t);
}

GLAPI void APIENTRY glMultiTexCoord2bvOES(GLenum texture, const GLbyte *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1705];
   ((void (APIENTRY *)(GLenum texture, const GLbyte *coords)) _func)(texture, coords);
}

GLAPI void APIENTRY glMultiTexCoord2d(GLenum target, GLdouble s, GLdouble t)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1706];
   ((void (APIENTRY *)(GLenum target, GLdouble s, GLdouble t)) _func)(target, s, t);
}

GLAPI void APIENTRY glMultiTexCoord2dARB(GLenum target, GLdouble s, GLdouble t)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1707];
   ((void (APIENTRY *)(GLenum target, GLdouble s, GLdouble t)) _func)(target, s, t);
}

GLAPI void APIENTRY glMultiTexCoord2dv(GLenum target, const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1708];
   ((void (APIENTRY *)(GLenum target, const GLdouble *v)) _func)(target, v);
}

GLAPI void APIENTRY glMultiTexCoord2dvARB(GLenum target, const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1709];
   ((void (APIENTRY *)(GLenum target, const GLdouble *v)) _func)(target, v);
}

GLAPI void APIENTRY glMultiTexCoord2f(GLenum target, GLfloat s, GLfloat t)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1710];
   ((void (APIENTRY *)(GLenum target, GLfloat s, GLfloat t)) _func)(target, s, t);
}

GLAPI void APIENTRY glMultiTexCoord2fARB(GLenum target, GLfloat s, GLfloat t)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1711];
   ((void (APIENTRY *)(GLenum target, GLfloat s, GLfloat t)) _func)(target, s, t);
}

GLAPI void APIENTRY glMultiTexCoord2fv(GLenum target, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1712];
   ((void (APIENTRY *)(GLenum target, const GLfloat *v)) _func)(target, v);
}

GLAPI void APIENTRY glMultiTexCoord2fvARB(GLenum target, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1713];
   ((void (APIENTRY *)(GLenum target, const GLfloat *v)) _func)(target, v);
}

GLAPI void APIENTRY glMultiTexCoord2hNV(GLenum target, GLhalf s, GLhalf t)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1714];
   ((void (APIENTRY *)(GLenum target, GLhalf s, GLhalf t)) _func)(target, s, t);
}

GLAPI void APIENTRY glMultiTexCoord2hvNV(GLenum target, const GLhalf *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1715];
   ((void (APIENTRY *)(GLenum target, const GLhalf *v)) _func)(target, v);
}

GLAPI void APIENTRY glMultiTexCoord2i(GLenum target, GLint s, GLint t)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1716];
   ((void (APIENTRY *)(GLenum target, GLint s, GLint t)) _func)(target, s, t);
}

GLAPI void APIENTRY glMultiTexCoord2iARB(GLenum target, GLint s, GLint t)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1717];
   ((void (APIENTRY *)(GLenum target, GLint s, GLint t)) _func)(target, s, t);
}

GLAPI void APIENTRY glMultiTexCoord2iv(GLenum target, const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1718];
   ((void (APIENTRY *)(GLenum target, const GLint *v)) _func)(target, v);
}

GLAPI void APIENTRY glMultiTexCoord2ivARB(GLenum target, const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1719];
   ((void (APIENTRY *)(GLenum target, const GLint *v)) _func)(target, v);
}

GLAPI void APIENTRY glMultiTexCoord2s(GLenum target, GLshort s, GLshort t)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1720];
   ((void (APIENTRY *)(GLenum target, GLshort s, GLshort t)) _func)(target, s, t);
}

GLAPI void APIENTRY glMultiTexCoord2sARB(GLenum target, GLshort s, GLshort t)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1721];
   ((void (APIENTRY *)(GLenum target, GLshort s, GLshort t)) _func)(target, s, t);
}

GLAPI void APIENTRY glMultiTexCoord2sv(GLenum target, const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1722];
   ((void (APIENTRY *)(GLenum target, const GLshort *v)) _func)(target, v);
}

GLAPI void APIENTRY glMultiTexCoord2svARB(GLenum target, const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1723];
   ((void (APIENTRY *)(GLenum target, const GLshort *v)) _func)(target, v);
}

GLAPI void APIENTRY glMultiTexCoord2x(GLenum target, GLfixed s, GLfixed t)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1724];
   ((void (APIENTRY *)(GLenum target, GLfixed s, GLfixed t)) _func)(target, s, t);
}

GLAPI void APIENTRY glMultiTexCoord2xOES(GLenum texture, GLfixed s, GLfixed t)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1725];
   ((void (APIENTRY *)(GLenum texture, GLfixed s, GLfixed t)) _func)(texture, s, t);
}

GLAPI void APIENTRY glMultiTexCoord2xv(GLenum target, const GLfixed *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1726];
   ((void (APIENTRY *)(GLenum target, const GLfixed *v)) _func)(target, v);
}

GLAPI void APIENTRY glMultiTexCoord2xvOES(GLenum texture, const GLfixed *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1727];
   ((void (APIENTRY *)(GLenum texture, const GLfixed *coords)) _func)(texture, coords);
}

GLAPI void APIENTRY glMultiTexCoord3bOES(GLenum texture, GLbyte s, GLbyte t, GLbyte r)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1728];
   ((void (APIENTRY *)(GLenum texture, GLbyte s, GLbyte t, GLbyte r)) _func)(texture, s, t, r);
}

GLAPI void APIENTRY glMultiTexCoord3bvOES(GLenum texture, const GLbyte *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1729];
   ((void (APIENTRY *)(GLenum texture, const GLbyte *coords)) _func)(texture, coords);
}

GLAPI void APIENTRY glMultiTexCoord3d(GLenum target, GLdouble s, GLdouble t, GLdouble r)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1730];
   ((void (APIENTRY *)(GLenum target, GLdouble s, GLdouble t, GLdouble r)) _func)(target, s, t, r);
}

GLAPI void APIENTRY glMultiTexCoord3dARB(GLenum target, GLdouble s, GLdouble t, GLdouble r)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1731];
   ((void (APIENTRY *)(GLenum target, GLdouble s, GLdouble t, GLdouble r)) _func)(target, s, t, r);
}

GLAPI void APIENTRY glMultiTexCoord3dv(GLenum target, const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1732];
   ((void (APIENTRY *)(GLenum target, const GLdouble *v)) _func)(target, v);
}

GLAPI void APIENTRY glMultiTexCoord3dvARB(GLenum target, const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1733];
   ((void (APIENTRY *)(GLenum target, const GLdouble *v)) _func)(target, v);
}

GLAPI void APIENTRY glMultiTexCoord3f(GLenum target, GLfloat s, GLfloat t, GLfloat r)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1734];
   ((void (APIENTRY *)(GLenum target, GLfloat s, GLfloat t, GLfloat r)) _func)(target, s, t, r);
}

GLAPI void APIENTRY glMultiTexCoord3fARB(GLenum target, GLfloat s, GLfloat t, GLfloat r)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1735];
   ((void (APIENTRY *)(GLenum target, GLfloat s, GLfloat t, GLfloat r)) _func)(target, s, t, r);
}

GLAPI void APIENTRY glMultiTexCoord3fv(GLenum target, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1736];
   ((void (APIENTRY *)(GLenum target, const GLfloat *v)) _func)(target, v);
}

GLAPI void APIENTRY glMultiTexCoord3fvARB(GLenum target, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1737];
   ((void (APIENTRY *)(GLenum target, const GLfloat *v)) _func)(target, v);
}

GLAPI void APIENTRY glMultiTexCoord3hNV(GLenum target, GLhalf s, GLhalf t, GLhalf r)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1738];
   ((void (APIENTRY *)(GLenum target, GLhalf s, GLhalf t, GLhalf r)) _func)(target, s, t, r);
}

GLAPI void APIENTRY glMultiTexCoord3hvNV(GLenum target, const GLhalf *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1739];
   ((void (APIENTRY *)(GLenum target, const GLhalf *v)) _func)(target, v);
}

GLAPI void APIENTRY glMultiTexCoord3i(GLenum target, GLint s, GLint t, GLint r)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1740];
   ((void (APIENTRY *)(GLenum target, GLint s, GLint t, GLint r)) _func)(target, s, t, r);
}

GLAPI void APIENTRY glMultiTexCoord3iARB(GLenum target, GLint s, GLint t, GLint r)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1741];
   ((void (APIENTRY *)(GLenum target, GLint s, GLint t, GLint r)) _func)(target, s, t, r);
}

GLAPI void APIENTRY glMultiTexCoord3iv(GLenum target, const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1742];
   ((void (APIENTRY *)(GLenum target, const GLint *v)) _func)(target, v);
}

GLAPI void APIENTRY glMultiTexCoord3ivARB(GLenum target, const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1743];
   ((void (APIENTRY *)(GLenum target, const GLint *v)) _func)(target, v);
}

GLAPI void APIENTRY glMultiTexCoord3s(GLenum target, GLshort s, GLshort t, GLshort r)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1744];
   ((void (APIENTRY *)(GLenum target, GLshort s, GLshort t, GLshort r)) _func)(target, s, t, r);
}

GLAPI void APIENTRY glMultiTexCoord3sARB(GLenum target, GLshort s, GLshort t, GLshort r)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1745];
   ((void (APIENTRY *)(GLenum target, GLshort s, GLshort t, GLshort r)) _func)(target, s, t, r);
}

GLAPI void APIENTRY glMultiTexCoord3sv(GLenum target, const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1746];
   ((void (APIENTRY *)(GLenum target, const GLshort *v)) _func)(target, v);
}

GLAPI void APIENTRY glMultiTexCoord3svARB(GLenum target, const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1747];
   ((void (APIENTRY *)(GLenum target, const GLshort *v)) _func)(target, v);
}

GLAPI void APIENTRY glMultiTexCoord3x(GLenum target, GLfixed s, GLfixed t, GLfixed r)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1748];
   ((void (APIENTRY *)(GLenum target, GLfixed s, GLfixed t, GLfixed r)) _func)(target, s, t, r);
}

GLAPI void APIENTRY glMultiTexCoord3xOES(GLenum texture, GLfixed s, GLfixed t, GLfixed r)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1749];
   ((void (APIENTRY *)(GLenum texture, GLfixed s, GLfixed t, GLfixed r)) _func)(texture, s, t, r);
}

GLAPI void APIENTRY glMultiTexCoord3xv(GLenum target, const GLfixed *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1750];
   ((void (APIENTRY *)(GLenum target, const GLfixed *v)) _func)(target, v);
}

GLAPI void APIENTRY glMultiTexCoord3xvOES(GLenum texture, const GLfixed *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1751];
   ((void (APIENTRY *)(GLenum texture, const GLfixed *coords)) _func)(texture, coords);
}

GLAPI void APIENTRY glMultiTexCoord4bOES(GLenum texture, GLbyte s, GLbyte t, GLbyte r, GLbyte q)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1752];
   ((void (APIENTRY *)(GLenum texture, GLbyte s, GLbyte t, GLbyte r, GLbyte q)) _func)(texture, s, t, r, q);
}

GLAPI void APIENTRY glMultiTexCoord4bvOES(GLenum texture, const GLbyte *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1753];
   ((void (APIENTRY *)(GLenum texture, const GLbyte *coords)) _func)(texture, coords);
}

GLAPI void APIENTRY glMultiTexCoord4d(GLenum target, GLdouble s, GLdouble t, GLdouble r, GLdouble q)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1754];
   ((void (APIENTRY *)(GLenum target, GLdouble s, GLdouble t, GLdouble r, GLdouble q)) _func)(target, s, t, r, q);
}

GLAPI void APIENTRY glMultiTexCoord4dARB(GLenum target, GLdouble s, GLdouble t, GLdouble r, GLdouble q)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1755];
   ((void (APIENTRY *)(GLenum target, GLdouble s, GLdouble t, GLdouble r, GLdouble q)) _func)(target, s, t, r, q);
}

GLAPI void APIENTRY glMultiTexCoord4dv(GLenum target, const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1756];
   ((void (APIENTRY *)(GLenum target, const GLdouble *v)) _func)(target, v);
}

GLAPI void APIENTRY glMultiTexCoord4dvARB(GLenum target, const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1757];
   ((void (APIENTRY *)(GLenum target, const GLdouble *v)) _func)(target, v);
}

GLAPI void APIENTRY glMultiTexCoord4f(GLenum target, GLfloat s, GLfloat t, GLfloat r, GLfloat q)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1758];
   ((void (APIENTRY *)(GLenum target, GLfloat s, GLfloat t, GLfloat r, GLfloat q)) _func)(target, s, t, r, q);
}

GLAPI void APIENTRY glMultiTexCoord4fARB(GLenum target, GLfloat s, GLfloat t, GLfloat r, GLfloat q)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1759];
   ((void (APIENTRY *)(GLenum target, GLfloat s, GLfloat t, GLfloat r, GLfloat q)) _func)(target, s, t, r, q);
}

GLAPI void APIENTRY glMultiTexCoord4fv(GLenum target, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1760];
   ((void (APIENTRY *)(GLenum target, const GLfloat *v)) _func)(target, v);
}

GLAPI void APIENTRY glMultiTexCoord4fvARB(GLenum target, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1761];
   ((void (APIENTRY *)(GLenum target, const GLfloat *v)) _func)(target, v);
}

GLAPI void APIENTRY glMultiTexCoord4hNV(GLenum target, GLhalf s, GLhalf t, GLhalf r, GLhalf q)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1762];
   ((void (APIENTRY *)(GLenum target, GLhalf s, GLhalf t, GLhalf r, GLhalf q)) _func)(target, s, t, r, q);
}

GLAPI void APIENTRY glMultiTexCoord4hvNV(GLenum target, const GLhalf *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1763];
   ((void (APIENTRY *)(GLenum target, const GLhalf *v)) _func)(target, v);
}

GLAPI void APIENTRY glMultiTexCoord4i(GLenum target, GLint s, GLint t, GLint r, GLint q)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1764];
   ((void (APIENTRY *)(GLenum target, GLint s, GLint t, GLint r, GLint q)) _func)(target, s, t, r, q);
}

GLAPI void APIENTRY glMultiTexCoord4iARB(GLenum target, GLint s, GLint t, GLint r, GLint q)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1765];
   ((void (APIENTRY *)(GLenum target, GLint s, GLint t, GLint r, GLint q)) _func)(target, s, t, r, q);
}

GLAPI void APIENTRY glMultiTexCoord4iv(GLenum target, const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1766];
   ((void (APIENTRY *)(GLenum target, const GLint *v)) _func)(target, v);
}

GLAPI void APIENTRY glMultiTexCoord4ivARB(GLenum target, const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1767];
   ((void (APIENTRY *)(GLenum target, const GLint *v)) _func)(target, v);
}

GLAPI void APIENTRY glMultiTexCoord4s(GLenum target, GLshort s, GLshort t, GLshort r, GLshort q)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1768];
   ((void (APIENTRY *)(GLenum target, GLshort s, GLshort t, GLshort r, GLshort q)) _func)(target, s, t, r, q);
}

GLAPI void APIENTRY glMultiTexCoord4sARB(GLenum target, GLshort s, GLshort t, GLshort r, GLshort q)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1769];
   ((void (APIENTRY *)(GLenum target, GLshort s, GLshort t, GLshort r, GLshort q)) _func)(target, s, t, r, q);
}

GLAPI void APIENTRY glMultiTexCoord4sv(GLenum target, const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1770];
   ((void (APIENTRY *)(GLenum target, const GLshort *v)) _func)(target, v);
}

GLAPI void APIENTRY glMultiTexCoord4svARB(GLenum target, const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1771];
   ((void (APIENTRY *)(GLenum target, const GLshort *v)) _func)(target, v);
}

GLAPI void APIENTRY glMultiTexCoord4x(GLenum texture, GLfixed s, GLfixed t, GLfixed r, GLfixed q)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1772];
   ((void (APIENTRY *)(GLenum texture, GLfixed s, GLfixed t, GLfixed r, GLfixed q)) _func)(texture, s, t, r, q);
}

GLAPI void APIENTRY glMultiTexCoord4xOES(GLenum texture, GLfixed s, GLfixed t, GLfixed r, GLfixed q)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1773];
   ((void (APIENTRY *)(GLenum texture, GLfixed s, GLfixed t, GLfixed r, GLfixed q)) _func)(texture, s, t, r, q);
}

GLAPI void APIENTRY glMultiTexCoord4xv(GLenum target, const GLfixed *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1774];
   ((void (APIENTRY *)(GLenum target, const GLfixed *v)) _func)(target, v);
}

GLAPI void APIENTRY glMultiTexCoord4xvOES(GLenum texture, const GLfixed *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1775];
   ((void (APIENTRY *)(GLenum texture, const GLfixed *coords)) _func)(texture, coords);
}

GLAPI void APIENTRY glMultiTexCoordP1ui(GLenum texture, GLenum type, GLuint coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1776];
   ((void (APIENTRY *)(GLenum texture, GLenum type, GLuint coords)) _func)(texture, type, coords);
}

GLAPI void APIENTRY glMultiTexCoordP1uiv(GLenum texture, GLenum type, const GLuint *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1777];
   ((void (APIENTRY *)(GLenum texture, GLenum type, const GLuint *coords)) _func)(texture, type, coords);
}

GLAPI void APIENTRY glMultiTexCoordP2ui(GLenum texture, GLenum type, GLuint coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1778];
   ((void (APIENTRY *)(GLenum texture, GLenum type, GLuint coords)) _func)(texture, type, coords);
}

GLAPI void APIENTRY glMultiTexCoordP2uiv(GLenum texture, GLenum type, const GLuint *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1779];
   ((void (APIENTRY *)(GLenum texture, GLenum type, const GLuint *coords)) _func)(texture, type, coords);
}

GLAPI void APIENTRY glMultiTexCoordP3ui(GLenum texture, GLenum type, GLuint coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1780];
   ((void (APIENTRY *)(GLenum texture, GLenum type, GLuint coords)) _func)(texture, type, coords);
}

GLAPI void APIENTRY glMultiTexCoordP3uiv(GLenum texture, GLenum type, const GLuint *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1781];
   ((void (APIENTRY *)(GLenum texture, GLenum type, const GLuint *coords)) _func)(texture, type, coords);
}

GLAPI void APIENTRY glMultiTexCoordP4ui(GLenum texture, GLenum type, GLuint coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1782];
   ((void (APIENTRY *)(GLenum texture, GLenum type, GLuint coords)) _func)(texture, type, coords);
}

GLAPI void APIENTRY glMultiTexCoordP4uiv(GLenum texture, GLenum type, const GLuint *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1783];
   ((void (APIENTRY *)(GLenum texture, GLenum type, const GLuint *coords)) _func)(texture, type, coords);
}

GLAPI void APIENTRY glMultiTexCoordPointerEXT(GLenum texunit, GLint size, GLenum type, GLsizei stride, const void *pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1784];
   ((void (APIENTRY *)(GLenum texunit, GLint size, GLenum type, GLsizei stride, const void *pointer)) _func)(texunit, size, type, stride, pointer);
}

GLAPI void APIENTRY glMultiTexEnvfEXT(GLenum texunit, GLenum target, GLenum pname, GLfloat param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1785];
   ((void (APIENTRY *)(GLenum texunit, GLenum target, GLenum pname, GLfloat param)) _func)(texunit, target, pname, param);
}

GLAPI void APIENTRY glMultiTexEnvfvEXT(GLenum texunit, GLenum target, GLenum pname, const GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1786];
   ((void (APIENTRY *)(GLenum texunit, GLenum target, GLenum pname, const GLfloat *params)) _func)(texunit, target, pname, params);
}

GLAPI void APIENTRY glMultiTexEnviEXT(GLenum texunit, GLenum target, GLenum pname, GLint param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1787];
   ((void (APIENTRY *)(GLenum texunit, GLenum target, GLenum pname, GLint param)) _func)(texunit, target, pname, param);
}

GLAPI void APIENTRY glMultiTexEnvivEXT(GLenum texunit, GLenum target, GLenum pname, const GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1788];
   ((void (APIENTRY *)(GLenum texunit, GLenum target, GLenum pname, const GLint *params)) _func)(texunit, target, pname, params);
}

GLAPI void APIENTRY glMultiTexGendEXT(GLenum texunit, GLenum coord, GLenum pname, GLdouble param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1789];
   ((void (APIENTRY *)(GLenum texunit, GLenum coord, GLenum pname, GLdouble param)) _func)(texunit, coord, pname, param);
}

GLAPI void APIENTRY glMultiTexGendvEXT(GLenum texunit, GLenum coord, GLenum pname, const GLdouble *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1790];
   ((void (APIENTRY *)(GLenum texunit, GLenum coord, GLenum pname, const GLdouble *params)) _func)(texunit, coord, pname, params);
}

GLAPI void APIENTRY glMultiTexGenfEXT(GLenum texunit, GLenum coord, GLenum pname, GLfloat param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1791];
   ((void (APIENTRY *)(GLenum texunit, GLenum coord, GLenum pname, GLfloat param)) _func)(texunit, coord, pname, param);
}

GLAPI void APIENTRY glMultiTexGenfvEXT(GLenum texunit, GLenum coord, GLenum pname, const GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1792];
   ((void (APIENTRY *)(GLenum texunit, GLenum coord, GLenum pname, const GLfloat *params)) _func)(texunit, coord, pname, params);
}

GLAPI void APIENTRY glMultiTexGeniEXT(GLenum texunit, GLenum coord, GLenum pname, GLint param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1793];
   ((void (APIENTRY *)(GLenum texunit, GLenum coord, GLenum pname, GLint param)) _func)(texunit, coord, pname, param);
}

GLAPI void APIENTRY glMultiTexGenivEXT(GLenum texunit, GLenum coord, GLenum pname, const GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1794];
   ((void (APIENTRY *)(GLenum texunit, GLenum coord, GLenum pname, const GLint *params)) _func)(texunit, coord, pname, params);
}

GLAPI void APIENTRY glMultiTexImage1DEXT(GLenum texunit, GLenum target, GLint level, GLint internalformat, GLsizei width, GLint border, GLenum format, GLenum type, const void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1795];
   ((void (APIENTRY *)(GLenum texunit, GLenum target, GLint level, GLint internalformat, GLsizei width, GLint border, GLenum format, GLenum type, const void *pixels)) _func)(texunit, target, level, internalformat, width, border, format, type, pixels);
}

GLAPI void APIENTRY glMultiTexImage2DEXT(GLenum texunit, GLenum target, GLint level, GLint internalformat, GLsizei width, GLsizei height, GLint border, GLenum format, GLenum type, const void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1796];
   ((void (APIENTRY *)(GLenum texunit, GLenum target, GLint level, GLint internalformat, GLsizei width, GLsizei height, GLint border, GLenum format, GLenum type, const void *pixels)) _func)(texunit, target, level, internalformat, width, height, border, format, type, pixels);
}

GLAPI void APIENTRY glMultiTexImage3DEXT(GLenum texunit, GLenum target, GLint level, GLint internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLenum format, GLenum type, const void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1797];
   ((void (APIENTRY *)(GLenum texunit, GLenum target, GLint level, GLint internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLenum format, GLenum type, const void *pixels)) _func)(texunit, target, level, internalformat, width, height, depth, border, format, type, pixels);
}

GLAPI void APIENTRY glMultiTexParameterIivEXT(GLenum texunit, GLenum target, GLenum pname, const GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1798];
   ((void (APIENTRY *)(GLenum texunit, GLenum target, GLenum pname, const GLint *params)) _func)(texunit, target, pname, params);
}

GLAPI void APIENTRY glMultiTexParameterIuivEXT(GLenum texunit, GLenum target, GLenum pname, const GLuint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1799];
   ((void (APIENTRY *)(GLenum texunit, GLenum target, GLenum pname, const GLuint *params)) _func)(texunit, target, pname, params);
}

GLAPI void APIENTRY glMultiTexParameterfEXT(GLenum texunit, GLenum target, GLenum pname, GLfloat param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1800];
   ((void (APIENTRY *)(GLenum texunit, GLenum target, GLenum pname, GLfloat param)) _func)(texunit, target, pname, param);
}

GLAPI void APIENTRY glMultiTexParameterfvEXT(GLenum texunit, GLenum target, GLenum pname, const GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1801];
   ((void (APIENTRY *)(GLenum texunit, GLenum target, GLenum pname, const GLfloat *params)) _func)(texunit, target, pname, params);
}

GLAPI void APIENTRY glMultiTexParameteriEXT(GLenum texunit, GLenum target, GLenum pname, GLint param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1802];
   ((void (APIENTRY *)(GLenum texunit, GLenum target, GLenum pname, GLint param)) _func)(texunit, target, pname, param);
}

GLAPI void APIENTRY glMultiTexParameterivEXT(GLenum texunit, GLenum target, GLenum pname, const GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1803];
   ((void (APIENTRY *)(GLenum texunit, GLenum target, GLenum pname, const GLint *params)) _func)(texunit, target, pname, params);
}

GLAPI void APIENTRY glMultiTexRenderbufferEXT(GLenum texunit, GLenum target, GLuint renderbuffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1804];
   ((void (APIENTRY *)(GLenum texunit, GLenum target, GLuint renderbuffer)) _func)(texunit, target, renderbuffer);
}

GLAPI void APIENTRY glMultiTexSubImage1DEXT(GLenum texunit, GLenum target, GLint level, GLint xoffset, GLsizei width, GLenum format, GLenum type, const void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1805];
   ((void (APIENTRY *)(GLenum texunit, GLenum target, GLint level, GLint xoffset, GLsizei width, GLenum format, GLenum type, const void *pixels)) _func)(texunit, target, level, xoffset, width, format, type, pixels);
}

GLAPI void APIENTRY glMultiTexSubImage2DEXT(GLenum texunit, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLenum type, const void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1806];
   ((void (APIENTRY *)(GLenum texunit, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLenum type, const void *pixels)) _func)(texunit, target, level, xoffset, yoffset, width, height, format, type, pixels);
}

GLAPI void APIENTRY glMultiTexSubImage3DEXT(GLenum texunit, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1807];
   ((void (APIENTRY *)(GLenum texunit, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void *pixels)) _func)(texunit, target, level, xoffset, yoffset, zoffset, width, height, depth, format, type, pixels);
}

GLAPI void APIENTRY glMulticastBarrierNV(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1808];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glMulticastBlitFramebufferNV(GLuint srcGpu, GLuint dstGpu, GLint srcX0, GLint srcY0, GLint srcX1, GLint srcY1, GLint dstX0, GLint dstY0, GLint dstX1, GLint dstY1, GLbitfield mask, GLenum filter)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1809];
   ((void (APIENTRY *)(GLuint srcGpu, GLuint dstGpu, GLint srcX0, GLint srcY0, GLint srcX1, GLint srcY1, GLint dstX0, GLint dstY0, GLint dstX1, GLint dstY1, GLbitfield mask, GLenum filter)) _func)(srcGpu, dstGpu, srcX0, srcY0, srcX1, srcY1, dstX0, dstY0, dstX1, dstY1, mask, filter);
}

GLAPI void APIENTRY glMulticastBufferSubDataNV(GLbitfield gpuMask, GLuint buffer, GLintptr offset, GLsizeiptr size, const void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1810];
   ((void (APIENTRY *)(GLbitfield gpuMask, GLuint buffer, GLintptr offset, GLsizeiptr size, const void *data)) _func)(gpuMask, buffer, offset, size, data);
}

GLAPI void APIENTRY glMulticastCopyBufferSubDataNV(GLuint readGpu, GLbitfield writeGpuMask, GLuint readBuffer, GLuint writeBuffer, GLintptr readOffset, GLintptr writeOffset, GLsizeiptr size)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1811];
   ((void (APIENTRY *)(GLuint readGpu, GLbitfield writeGpuMask, GLuint readBuffer, GLuint writeBuffer, GLintptr readOffset, GLintptr writeOffset, GLsizeiptr size)) _func)(readGpu, writeGpuMask, readBuffer, writeBuffer, readOffset, writeOffset, size);
}

GLAPI void APIENTRY glMulticastCopyImageSubDataNV(GLuint srcGpu, GLbitfield dstGpuMask, GLuint srcName, GLenum srcTarget, GLint srcLevel, GLint srcX, GLint srcY, GLint srcZ, GLuint dstName, GLenum dstTarget, GLint dstLevel, GLint dstX, GLint dstY, GLint dstZ, GLsizei srcWidth, GLsizei srcHeight, GLsizei srcDepth)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1812];
   ((void (APIENTRY *)(GLuint srcGpu, GLbitfield dstGpuMask, GLuint srcName, GLenum srcTarget, GLint srcLevel, GLint srcX, GLint srcY, GLint srcZ, GLuint dstName, GLenum dstTarget, GLint dstLevel, GLint dstX, GLint dstY, GLint dstZ, GLsizei srcWidth, GLsizei srcHeight, GLsizei srcDepth)) _func)(srcGpu, dstGpuMask, srcName, srcTarget, srcLevel, srcX, srcY, srcZ, dstName, dstTarget, dstLevel, dstX, dstY, dstZ, srcWidth, srcHeight, srcDepth);
}

GLAPI void APIENTRY glMulticastFramebufferSampleLocationsfvNV(GLuint gpu, GLuint framebuffer, GLuint start, GLsizei count, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1813];
   ((void (APIENTRY *)(GLuint gpu, GLuint framebuffer, GLuint start, GLsizei count, const GLfloat *v)) _func)(gpu, framebuffer, start, count, v);
}

GLAPI void APIENTRY glMulticastGetQueryObjecti64vNV(GLuint gpu, GLuint id, GLenum pname, GLint64 *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1814];
   ((void (APIENTRY *)(GLuint gpu, GLuint id, GLenum pname, GLint64 *params)) _func)(gpu, id, pname, params);
}

GLAPI void APIENTRY glMulticastGetQueryObjectivNV(GLuint gpu, GLuint id, GLenum pname, GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1815];
   ((void (APIENTRY *)(GLuint gpu, GLuint id, GLenum pname, GLint *params)) _func)(gpu, id, pname, params);
}

GLAPI void APIENTRY glMulticastGetQueryObjectui64vNV(GLuint gpu, GLuint id, GLenum pname, GLuint64 *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1816];
   ((void (APIENTRY *)(GLuint gpu, GLuint id, GLenum pname, GLuint64 *params)) _func)(gpu, id, pname, params);
}

GLAPI void APIENTRY glMulticastGetQueryObjectuivNV(GLuint gpu, GLuint id, GLenum pname, GLuint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1817];
   ((void (APIENTRY *)(GLuint gpu, GLuint id, GLenum pname, GLuint *params)) _func)(gpu, id, pname, params);
}

GLAPI void APIENTRY glMulticastScissorArrayvNVX(GLuint gpu, GLuint first, GLsizei count, const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1818];
   ((void (APIENTRY *)(GLuint gpu, GLuint first, GLsizei count, const GLint *v)) _func)(gpu, first, count, v);
}

GLAPI void APIENTRY glMulticastViewportArrayvNVX(GLuint gpu, GLuint first, GLsizei count, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1819];
   ((void (APIENTRY *)(GLuint gpu, GLuint first, GLsizei count, const GLfloat *v)) _func)(gpu, first, count, v);
}

GLAPI void APIENTRY glMulticastViewportPositionWScaleNVX(GLuint gpu, GLuint index, GLfloat xcoeff, GLfloat ycoeff)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1820];
   ((void (APIENTRY *)(GLuint gpu, GLuint index, GLfloat xcoeff, GLfloat ycoeff)) _func)(gpu, index, xcoeff, ycoeff);
}

GLAPI void APIENTRY glMulticastWaitSyncNV(GLuint signalGpu, GLbitfield waitGpuMask)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1821];
   ((void (APIENTRY *)(GLuint signalGpu, GLbitfield waitGpuMask)) _func)(signalGpu, waitGpuMask);
}

GLAPI void APIENTRY glNVENCInterOpFunctionNVX(void *dataPtr)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1822];
   ((void (APIENTRY *)(void *dataPtr)) _func)(dataPtr);
}

GLAPI void APIENTRY glNamedBufferAttachMemoryNV(GLuint buffer, GLuint memory, GLuint64 offset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1823];
   ((void (APIENTRY *)(GLuint buffer, GLuint memory, GLuint64 offset)) _func)(buffer, memory, offset);
}

GLAPI void APIENTRY glNamedBufferData(GLuint buffer, GLsizeiptr size, const void *data, GLenum usage)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1824];
   ((void (APIENTRY *)(GLuint buffer, GLsizeiptr size, const void *data, GLenum usage)) _func)(buffer, size, data, usage);
}

GLAPI void APIENTRY glNamedBufferDataEXT(GLuint buffer, GLsizeiptr size, const void *data, GLenum usage)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1825];
   ((void (APIENTRY *)(GLuint buffer, GLsizeiptr size, const void *data, GLenum usage)) _func)(buffer, size, data, usage);
}

GLAPI void APIENTRY glNamedBufferPageCommitmentARB(GLuint buffer, GLintptr offset, GLsizeiptr size, GLboolean commit)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1826];
   ((void (APIENTRY *)(GLuint buffer, GLintptr offset, GLsizeiptr size, GLboolean commit)) _func)(buffer, offset, size, commit);
}

GLAPI void APIENTRY glNamedBufferPageCommitmentEXT(GLuint buffer, GLintptr offset, GLsizeiptr size, GLboolean commit)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1827];
   ((void (APIENTRY *)(GLuint buffer, GLintptr offset, GLsizeiptr size, GLboolean commit)) _func)(buffer, offset, size, commit);
}

GLAPI void APIENTRY glNamedBufferStorage(GLuint buffer, GLsizeiptr size, const void *data, GLbitfield flags)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1829];
   ((void (APIENTRY *)(GLuint buffer, GLsizeiptr size, const void *data, GLbitfield flags)) _func)(buffer, size, data, flags);
}

GLAPI void APIENTRY glNamedBufferStorageEXT(GLuint buffer, GLsizeiptr size, const void *data, GLbitfield flags)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1830];
   ((void (APIENTRY *)(GLuint buffer, GLsizeiptr size, const void *data, GLbitfield flags)) _func)(buffer, size, data, flags);
}

GLAPI void APIENTRY glNamedBufferStorageExternalEXT(GLuint buffer, GLintptr offset, GLsizeiptr size, GLeglClientBufferEXT clientBuffer, GLbitfield flags)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1831];
   ((void (APIENTRY *)(GLuint buffer, GLintptr offset, GLsizeiptr size, GLeglClientBufferEXT clientBuffer, GLbitfield flags)) _func)(buffer, offset, size, clientBuffer, flags);
}

GLAPI void APIENTRY glNamedBufferStorageMemEXT(GLuint buffer, GLsizeiptr size, GLuint memory, GLuint64 offset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1832];
   ((void (APIENTRY *)(GLuint buffer, GLsizeiptr size, GLuint memory, GLuint64 offset)) _func)(buffer, size, memory, offset);
}

GLAPI void APIENTRY glNamedBufferSubData(GLuint buffer, GLintptr offset, GLsizeiptr size, const void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1833];
   ((void (APIENTRY *)(GLuint buffer, GLintptr offset, GLsizeiptr size, const void *data)) _func)(buffer, offset, size, data);
}

GLAPI void APIENTRY glNamedBufferSubDataEXT(GLuint buffer, GLintptr offset, GLsizeiptr size, const void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1834];
   ((void (APIENTRY *)(GLuint buffer, GLintptr offset, GLsizeiptr size, const void *data)) _func)(buffer, offset, size, data);
}

GLAPI void APIENTRY glNamedCopyBufferSubDataEXT(GLuint readBuffer, GLuint writeBuffer, GLintptr readOffset, GLintptr writeOffset, GLsizeiptr size)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1835];
   ((void (APIENTRY *)(GLuint readBuffer, GLuint writeBuffer, GLintptr readOffset, GLintptr writeOffset, GLsizeiptr size)) _func)(readBuffer, writeBuffer, readOffset, writeOffset, size);
}

GLAPI void APIENTRY glNamedFramebufferDrawBuffer(GLuint framebuffer, GLenum buf)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1836];
   ((void (APIENTRY *)(GLuint framebuffer, GLenum buf)) _func)(framebuffer, buf);
}

GLAPI void APIENTRY glNamedFramebufferDrawBuffers(GLuint framebuffer, GLsizei n, const GLenum *bufs)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1837];
   ((void (APIENTRY *)(GLuint framebuffer, GLsizei n, const GLenum *bufs)) _func)(framebuffer, n, bufs);
}

GLAPI void APIENTRY glNamedFramebufferParameteri(GLuint framebuffer, GLenum pname, GLint param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1838];
   ((void (APIENTRY *)(GLuint framebuffer, GLenum pname, GLint param)) _func)(framebuffer, pname, param);
}

GLAPI void APIENTRY glNamedFramebufferParameteriEXT(GLuint framebuffer, GLenum pname, GLint param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1839];
   ((void (APIENTRY *)(GLuint framebuffer, GLenum pname, GLint param)) _func)(framebuffer, pname, param);
}

GLAPI void APIENTRY glNamedFramebufferReadBuffer(GLuint framebuffer, GLenum src)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1840];
   ((void (APIENTRY *)(GLuint framebuffer, GLenum src)) _func)(framebuffer, src);
}

GLAPI void APIENTRY glNamedFramebufferRenderbuffer(GLuint framebuffer, GLenum attachment, GLenum renderbuffertarget, GLuint renderbuffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1841];
   ((void (APIENTRY *)(GLuint framebuffer, GLenum attachment, GLenum renderbuffertarget, GLuint renderbuffer)) _func)(framebuffer, attachment, renderbuffertarget, renderbuffer);
}

GLAPI void APIENTRY glNamedFramebufferRenderbufferEXT(GLuint framebuffer, GLenum attachment, GLenum renderbuffertarget, GLuint renderbuffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1842];
   ((void (APIENTRY *)(GLuint framebuffer, GLenum attachment, GLenum renderbuffertarget, GLuint renderbuffer)) _func)(framebuffer, attachment, renderbuffertarget, renderbuffer);
}

GLAPI void APIENTRY glNamedFramebufferSampleLocationsfvARB(GLuint framebuffer, GLuint start, GLsizei count, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1843];
   ((void (APIENTRY *)(GLuint framebuffer, GLuint start, GLsizei count, const GLfloat *v)) _func)(framebuffer, start, count, v);
}

GLAPI void APIENTRY glNamedFramebufferSampleLocationsfvNV(GLuint framebuffer, GLuint start, GLsizei count, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1844];
   ((void (APIENTRY *)(GLuint framebuffer, GLuint start, GLsizei count, const GLfloat *v)) _func)(framebuffer, start, count, v);
}

GLAPI void APIENTRY glNamedFramebufferSamplePositionsfvAMD(GLuint framebuffer, GLuint numsamples, GLuint pixelindex, const GLfloat *values)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1845];
   ((void (APIENTRY *)(GLuint framebuffer, GLuint numsamples, GLuint pixelindex, const GLfloat *values)) _func)(framebuffer, numsamples, pixelindex, values);
}

GLAPI void APIENTRY glNamedFramebufferTexture(GLuint framebuffer, GLenum attachment, GLuint texture, GLint level)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1846];
   ((void (APIENTRY *)(GLuint framebuffer, GLenum attachment, GLuint texture, GLint level)) _func)(framebuffer, attachment, texture, level);
}

GLAPI void APIENTRY glNamedFramebufferTexture1DEXT(GLuint framebuffer, GLenum attachment, GLenum textarget, GLuint texture, GLint level)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1847];
   ((void (APIENTRY *)(GLuint framebuffer, GLenum attachment, GLenum textarget, GLuint texture, GLint level)) _func)(framebuffer, attachment, textarget, texture, level);
}

GLAPI void APIENTRY glNamedFramebufferTexture2DEXT(GLuint framebuffer, GLenum attachment, GLenum textarget, GLuint texture, GLint level)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1848];
   ((void (APIENTRY *)(GLuint framebuffer, GLenum attachment, GLenum textarget, GLuint texture, GLint level)) _func)(framebuffer, attachment, textarget, texture, level);
}

GLAPI void APIENTRY glNamedFramebufferTexture3DEXT(GLuint framebuffer, GLenum attachment, GLenum textarget, GLuint texture, GLint level, GLint zoffset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1849];
   ((void (APIENTRY *)(GLuint framebuffer, GLenum attachment, GLenum textarget, GLuint texture, GLint level, GLint zoffset)) _func)(framebuffer, attachment, textarget, texture, level, zoffset);
}

GLAPI void APIENTRY glNamedFramebufferTextureEXT(GLuint framebuffer, GLenum attachment, GLuint texture, GLint level)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1850];
   ((void (APIENTRY *)(GLuint framebuffer, GLenum attachment, GLuint texture, GLint level)) _func)(framebuffer, attachment, texture, level);
}

GLAPI void APIENTRY glNamedFramebufferTextureFaceEXT(GLuint framebuffer, GLenum attachment, GLuint texture, GLint level, GLenum face)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1851];
   ((void (APIENTRY *)(GLuint framebuffer, GLenum attachment, GLuint texture, GLint level, GLenum face)) _func)(framebuffer, attachment, texture, level, face);
}

GLAPI void APIENTRY glNamedFramebufferTextureLayer(GLuint framebuffer, GLenum attachment, GLuint texture, GLint level, GLint layer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1852];
   ((void (APIENTRY *)(GLuint framebuffer, GLenum attachment, GLuint texture, GLint level, GLint layer)) _func)(framebuffer, attachment, texture, level, layer);
}

GLAPI void APIENTRY glNamedFramebufferTextureLayerEXT(GLuint framebuffer, GLenum attachment, GLuint texture, GLint level, GLint layer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1853];
   ((void (APIENTRY *)(GLuint framebuffer, GLenum attachment, GLuint texture, GLint level, GLint layer)) _func)(framebuffer, attachment, texture, level, layer);
}

GLAPI void APIENTRY glNamedProgramLocalParameter4dEXT(GLuint program, GLenum target, GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1854];
   ((void (APIENTRY *)(GLuint program, GLenum target, GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w)) _func)(program, target, index, x, y, z, w);
}

GLAPI void APIENTRY glNamedProgramLocalParameter4dvEXT(GLuint program, GLenum target, GLuint index, const GLdouble *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1855];
   ((void (APIENTRY *)(GLuint program, GLenum target, GLuint index, const GLdouble *params)) _func)(program, target, index, params);
}

GLAPI void APIENTRY glNamedProgramLocalParameter4fEXT(GLuint program, GLenum target, GLuint index, GLfloat x, GLfloat y, GLfloat z, GLfloat w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1856];
   ((void (APIENTRY *)(GLuint program, GLenum target, GLuint index, GLfloat x, GLfloat y, GLfloat z, GLfloat w)) _func)(program, target, index, x, y, z, w);
}

GLAPI void APIENTRY glNamedProgramLocalParameter4fvEXT(GLuint program, GLenum target, GLuint index, const GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1857];
   ((void (APIENTRY *)(GLuint program, GLenum target, GLuint index, const GLfloat *params)) _func)(program, target, index, params);
}

GLAPI void APIENTRY glNamedProgramLocalParameterI4iEXT(GLuint program, GLenum target, GLuint index, GLint x, GLint y, GLint z, GLint w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1858];
   ((void (APIENTRY *)(GLuint program, GLenum target, GLuint index, GLint x, GLint y, GLint z, GLint w)) _func)(program, target, index, x, y, z, w);
}

GLAPI void APIENTRY glNamedProgramLocalParameterI4ivEXT(GLuint program, GLenum target, GLuint index, const GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1859];
   ((void (APIENTRY *)(GLuint program, GLenum target, GLuint index, const GLint *params)) _func)(program, target, index, params);
}

GLAPI void APIENTRY glNamedProgramLocalParameterI4uiEXT(GLuint program, GLenum target, GLuint index, GLuint x, GLuint y, GLuint z, GLuint w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1860];
   ((void (APIENTRY *)(GLuint program, GLenum target, GLuint index, GLuint x, GLuint y, GLuint z, GLuint w)) _func)(program, target, index, x, y, z, w);
}

GLAPI void APIENTRY glNamedProgramLocalParameterI4uivEXT(GLuint program, GLenum target, GLuint index, const GLuint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1861];
   ((void (APIENTRY *)(GLuint program, GLenum target, GLuint index, const GLuint *params)) _func)(program, target, index, params);
}

GLAPI void APIENTRY glNamedProgramLocalParameters4fvEXT(GLuint program, GLenum target, GLuint index, GLsizei count, const GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1862];
   ((void (APIENTRY *)(GLuint program, GLenum target, GLuint index, GLsizei count, const GLfloat *params)) _func)(program, target, index, count, params);
}

GLAPI void APIENTRY glNamedProgramLocalParametersI4ivEXT(GLuint program, GLenum target, GLuint index, GLsizei count, const GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1863];
   ((void (APIENTRY *)(GLuint program, GLenum target, GLuint index, GLsizei count, const GLint *params)) _func)(program, target, index, count, params);
}

GLAPI void APIENTRY glNamedProgramLocalParametersI4uivEXT(GLuint program, GLenum target, GLuint index, GLsizei count, const GLuint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1864];
   ((void (APIENTRY *)(GLuint program, GLenum target, GLuint index, GLsizei count, const GLuint *params)) _func)(program, target, index, count, params);
}

GLAPI void APIENTRY glNamedProgramStringEXT(GLuint program, GLenum target, GLenum format, GLsizei len, const void *string)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1865];
   ((void (APIENTRY *)(GLuint program, GLenum target, GLenum format, GLsizei len, const void *string)) _func)(program, target, format, len, string);
}

GLAPI void APIENTRY glNamedRenderbufferStorage(GLuint renderbuffer, GLenum internalformat, GLsizei width, GLsizei height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1866];
   ((void (APIENTRY *)(GLuint renderbuffer, GLenum internalformat, GLsizei width, GLsizei height)) _func)(renderbuffer, internalformat, width, height);
}

GLAPI void APIENTRY glNamedRenderbufferStorageEXT(GLuint renderbuffer, GLenum internalformat, GLsizei width, GLsizei height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1867];
   ((void (APIENTRY *)(GLuint renderbuffer, GLenum internalformat, GLsizei width, GLsizei height)) _func)(renderbuffer, internalformat, width, height);
}

GLAPI void APIENTRY glNamedRenderbufferStorageMultisample(GLuint renderbuffer, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1868];
   ((void (APIENTRY *)(GLuint renderbuffer, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height)) _func)(renderbuffer, samples, internalformat, width, height);
}

GLAPI void APIENTRY glNamedRenderbufferStorageMultisampleAdvancedAMD(GLuint renderbuffer, GLsizei samples, GLsizei storageSamples, GLenum internalformat, GLsizei width, GLsizei height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1869];
   ((void (APIENTRY *)(GLuint renderbuffer, GLsizei samples, GLsizei storageSamples, GLenum internalformat, GLsizei width, GLsizei height)) _func)(renderbuffer, samples, storageSamples, internalformat, width, height);
}

GLAPI void APIENTRY glNamedRenderbufferStorageMultisampleCoverageEXT(GLuint renderbuffer, GLsizei coverageSamples, GLsizei colorSamples, GLenum internalformat, GLsizei width, GLsizei height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1870];
   ((void (APIENTRY *)(GLuint renderbuffer, GLsizei coverageSamples, GLsizei colorSamples, GLenum internalformat, GLsizei width, GLsizei height)) _func)(renderbuffer, coverageSamples, colorSamples, internalformat, width, height);
}

GLAPI void APIENTRY glNamedRenderbufferStorageMultisampleEXT(GLuint renderbuffer, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1871];
   ((void (APIENTRY *)(GLuint renderbuffer, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height)) _func)(renderbuffer, samples, internalformat, width, height);
}

GLAPI void APIENTRY glNamedStringARB(GLenum type, GLint namelen, const GLchar *name, GLint stringlen, const GLchar *string)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1872];
   ((void (APIENTRY *)(GLenum type, GLint namelen, const GLchar *name, GLint stringlen, const GLchar *string)) _func)(type, namelen, name, stringlen, string);
}

GLAPI void APIENTRY glNewList(GLuint list, GLenum mode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1873];
   ((void (APIENTRY *)(GLuint list, GLenum mode)) _func)(list, mode);
}

GLAPI GLuint APIENTRY glNewObjectBufferATI(GLsizei size, const void *pointer, GLenum usage)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1874];
   return ((GLuint (APIENTRY *)(GLsizei size, const void *pointer, GLenum usage)) _func)(size, pointer, usage);
}

GLAPI void APIENTRY glNormal3b(GLbyte nx, GLbyte ny, GLbyte nz)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1875];
   ((void (APIENTRY *)(GLbyte nx, GLbyte ny, GLbyte nz)) _func)(nx, ny, nz);
}

GLAPI void APIENTRY glNormal3bv(const GLbyte *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1876];
   ((void (APIENTRY *)(const GLbyte *v)) _func)(v);
}

GLAPI void APIENTRY glNormal3d(GLdouble nx, GLdouble ny, GLdouble nz)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1877];
   ((void (APIENTRY *)(GLdouble nx, GLdouble ny, GLdouble nz)) _func)(nx, ny, nz);
}

GLAPI void APIENTRY glNormal3dv(const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1878];
   ((void (APIENTRY *)(const GLdouble *v)) _func)(v);
}

GLAPI void APIENTRY glNormal3f(GLfloat nx, GLfloat ny, GLfloat nz)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1879];
   ((void (APIENTRY *)(GLfloat nx, GLfloat ny, GLfloat nz)) _func)(nx, ny, nz);
}

GLAPI void APIENTRY glNormal3fVertex3fSUN(GLfloat nx, GLfloat ny, GLfloat nz, GLfloat x, GLfloat y, GLfloat z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1880];
   ((void (APIENTRY *)(GLfloat nx, GLfloat ny, GLfloat nz, GLfloat x, GLfloat y, GLfloat z)) _func)(nx, ny, nz, x, y, z);
}

GLAPI void APIENTRY glNormal3fVertex3fvSUN(const GLfloat *n, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1881];
   ((void (APIENTRY *)(const GLfloat *n, const GLfloat *v)) _func)(n, v);
}

GLAPI void APIENTRY glNormal3fv(const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1882];
   ((void (APIENTRY *)(const GLfloat *v)) _func)(v);
}

GLAPI void APIENTRY glNormal3hNV(GLhalf nx, GLhalf ny, GLhalf nz)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1883];
   ((void (APIENTRY *)(GLhalf nx, GLhalf ny, GLhalf nz)) _func)(nx, ny, nz);
}

GLAPI void APIENTRY glNormal3hvNV(const GLhalf *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1884];
   ((void (APIENTRY *)(const GLhalf *v)) _func)(v);
}

GLAPI void APIENTRY glNormal3i(GLint nx, GLint ny, GLint nz)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1885];
   ((void (APIENTRY *)(GLint nx, GLint ny, GLint nz)) _func)(nx, ny, nz);
}

GLAPI void APIENTRY glNormal3iv(const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1886];
   ((void (APIENTRY *)(const GLint *v)) _func)(v);
}

GLAPI void APIENTRY glNormal3s(GLshort nx, GLshort ny, GLshort nz)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1887];
   ((void (APIENTRY *)(GLshort nx, GLshort ny, GLshort nz)) _func)(nx, ny, nz);
}

GLAPI void APIENTRY glNormal3sv(const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1888];
   ((void (APIENTRY *)(const GLshort *v)) _func)(v);
}

GLAPI void APIENTRY glNormal3x(GLfixed nx, GLfixed ny, GLfixed nz)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1889];
   ((void (APIENTRY *)(GLfixed nx, GLfixed ny, GLfixed nz)) _func)(nx, ny, nz);
}

GLAPI void APIENTRY glNormal3xOES(GLfixed nx, GLfixed ny, GLfixed nz)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1890];
   ((void (APIENTRY *)(GLfixed nx, GLfixed ny, GLfixed nz)) _func)(nx, ny, nz);
}

GLAPI void APIENTRY glNormal3xvOES(const GLfixed *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1891];
   ((void (APIENTRY *)(const GLfixed *coords)) _func)(coords);
}

GLAPI void APIENTRY glNormalFormatNV(GLenum type, GLsizei stride)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1892];
   ((void (APIENTRY *)(GLenum type, GLsizei stride)) _func)(type, stride);
}

GLAPI void APIENTRY glNormalP3ui(GLenum type, GLuint coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1893];
   ((void (APIENTRY *)(GLenum type, GLuint coords)) _func)(type, coords);
}

GLAPI void APIENTRY glNormalP3uiv(GLenum type, const GLuint *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1894];
   ((void (APIENTRY *)(GLenum type, const GLuint *coords)) _func)(type, coords);
}

GLAPI void APIENTRY glNormalPointer(GLenum type, GLsizei stride, const void *pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1895];
   ((void (APIENTRY *)(GLenum type, GLsizei stride, const void *pointer)) _func)(type, stride, pointer);
}

GLAPI void APIENTRY glNormalPointerEXT(GLenum type, GLsizei stride, GLsizei count, const void *pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1896];
   ((void (APIENTRY *)(GLenum type, GLsizei stride, GLsizei count, const void *pointer)) _func)(type, stride, count, pointer);
}

GLAPI void APIENTRY glNormalPointerListIBM(GLenum type, GLint stride, const void **pointer, GLint ptrstride)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1897];
   ((void (APIENTRY *)(GLenum type, GLint stride, const void **pointer, GLint ptrstride)) _func)(type, stride, pointer, ptrstride);
}

GLAPI void APIENTRY glNormalPointervINTEL(GLenum type, const void **pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1898];
   ((void (APIENTRY *)(GLenum type, const void **pointer)) _func)(type, pointer);
}

GLAPI void APIENTRY glNormalStream3bATI(GLenum stream, GLbyte nx, GLbyte ny, GLbyte nz)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1899];
   ((void (APIENTRY *)(GLenum stream, GLbyte nx, GLbyte ny, GLbyte nz)) _func)(stream, nx, ny, nz);
}

GLAPI void APIENTRY glNormalStream3bvATI(GLenum stream, const GLbyte *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1900];
   ((void (APIENTRY *)(GLenum stream, const GLbyte *coords)) _func)(stream, coords);
}

GLAPI void APIENTRY glNormalStream3dATI(GLenum stream, GLdouble nx, GLdouble ny, GLdouble nz)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1901];
   ((void (APIENTRY *)(GLenum stream, GLdouble nx, GLdouble ny, GLdouble nz)) _func)(stream, nx, ny, nz);
}

GLAPI void APIENTRY glNormalStream3dvATI(GLenum stream, const GLdouble *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1902];
   ((void (APIENTRY *)(GLenum stream, const GLdouble *coords)) _func)(stream, coords);
}

GLAPI void APIENTRY glNormalStream3fATI(GLenum stream, GLfloat nx, GLfloat ny, GLfloat nz)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1903];
   ((void (APIENTRY *)(GLenum stream, GLfloat nx, GLfloat ny, GLfloat nz)) _func)(stream, nx, ny, nz);
}

GLAPI void APIENTRY glNormalStream3fvATI(GLenum stream, const GLfloat *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1904];
   ((void (APIENTRY *)(GLenum stream, const GLfloat *coords)) _func)(stream, coords);
}

GLAPI void APIENTRY glNormalStream3iATI(GLenum stream, GLint nx, GLint ny, GLint nz)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1905];
   ((void (APIENTRY *)(GLenum stream, GLint nx, GLint ny, GLint nz)) _func)(stream, nx, ny, nz);
}

GLAPI void APIENTRY glNormalStream3ivATI(GLenum stream, const GLint *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1906];
   ((void (APIENTRY *)(GLenum stream, const GLint *coords)) _func)(stream, coords);
}

GLAPI void APIENTRY glNormalStream3sATI(GLenum stream, GLshort nx, GLshort ny, GLshort nz)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1907];
   ((void (APIENTRY *)(GLenum stream, GLshort nx, GLshort ny, GLshort nz)) _func)(stream, nx, ny, nz);
}

GLAPI void APIENTRY glNormalStream3svATI(GLenum stream, const GLshort *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1908];
   ((void (APIENTRY *)(GLenum stream, const GLshort *coords)) _func)(stream, coords);
}

GLAPI void APIENTRY glObjectLabel(GLenum identifier, GLuint name, GLsizei length, const GLchar *label)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1909];
   ((void (APIENTRY *)(GLenum identifier, GLuint name, GLsizei length, const GLchar *label)) _func)(identifier, name, length, label);
}

GLAPI void APIENTRY glObjectLabelKHR(GLenum identifier, GLuint name, GLsizei length, const GLchar *label)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1910];
   ((void (APIENTRY *)(GLenum identifier, GLuint name, GLsizei length, const GLchar *label)) _func)(identifier, name, length, label);
}

GLAPI void APIENTRY glObjectLabelOES(GLenum identifier, GLuint name, GLsizei length, const GLchar *label)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1911];
   ((void (APIENTRY *)(GLenum identifier, GLuint name, GLsizei length, const GLchar *label)) _func)(identifier, name, length, label);
}

GLAPI void APIENTRY glObjectPtrLabel(const void *ptr, GLsizei length, const GLchar *label)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1912];
   ((void (APIENTRY *)(const void *ptr, GLsizei length, const GLchar *label)) _func)(ptr, length, label);
}

GLAPI void APIENTRY glObjectPtrLabelKHR(const void *ptr, GLsizei length, const GLchar *label)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1913];
   ((void (APIENTRY *)(const void *ptr, GLsizei length, const GLchar *label)) _func)(ptr, length, label);
}

GLAPI void APIENTRY glObjectPtrLabelOES(void *ptr, GLsizei length, const GLchar *label)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1914];
   ((void (APIENTRY *)(void *ptr, GLsizei length, const GLchar *label)) _func)(ptr, length, label);
}

GLAPI GLenum APIENTRY glObjectPurgeableAPPLE(GLenum objectType, GLuint name, GLenum option)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1915];
   return ((GLenum (APIENTRY *)(GLenum objectType, GLuint name, GLenum option)) _func)(objectType, name, option);
}

GLAPI GLenum APIENTRY glObjectUnpurgeableAPPLE(GLenum objectType, GLuint name, GLenum option)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1916];
   return ((GLenum (APIENTRY *)(GLenum objectType, GLuint name, GLenum option)) _func)(objectType, name, option);
}

GLAPI void APIENTRY glOrtho(GLdouble left, GLdouble right, GLdouble bottom, GLdouble top, GLdouble zNear, GLdouble zFar)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1917];
   ((void (APIENTRY *)(GLdouble left, GLdouble right, GLdouble bottom, GLdouble top, GLdouble zNear, GLdouble zFar)) _func)(left, right, bottom, top, zNear, zFar);
}

GLAPI void APIENTRY glOrthof(GLfloat l, GLfloat r, GLfloat b, GLfloat t, GLfloat n, GLfloat f)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1918];
   ((void (APIENTRY *)(GLfloat l, GLfloat r, GLfloat b, GLfloat t, GLfloat n, GLfloat f)) _func)(l, r, b, t, n, f);
}

GLAPI void APIENTRY glOrthofOES(GLfloat l, GLfloat r, GLfloat b, GLfloat t, GLfloat n, GLfloat f)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1919];
   ((void (APIENTRY *)(GLfloat l, GLfloat r, GLfloat b, GLfloat t, GLfloat n, GLfloat f)) _func)(l, r, b, t, n, f);
}

GLAPI void APIENTRY glOrthox(GLfixed l, GLfixed r, GLfixed b, GLfixed t, GLfixed n, GLfixed f)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1920];
   ((void (APIENTRY *)(GLfixed l, GLfixed r, GLfixed b, GLfixed t, GLfixed n, GLfixed f)) _func)(l, r, b, t, n, f);
}

GLAPI void APIENTRY glOrthoxOES(GLfixed l, GLfixed r, GLfixed b, GLfixed t, GLfixed n, GLfixed f)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1921];
   ((void (APIENTRY *)(GLfixed l, GLfixed r, GLfixed b, GLfixed t, GLfixed n, GLfixed f)) _func)(l, r, b, t, n, f);
}

GLAPI void APIENTRY glPNTrianglesfATI(GLenum pname, GLfloat param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1922];
   ((void (APIENTRY *)(GLenum pname, GLfloat param)) _func)(pname, param);
}

GLAPI void APIENTRY glPNTrianglesiATI(GLenum pname, GLint param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1923];
   ((void (APIENTRY *)(GLenum pname, GLint param)) _func)(pname, param);
}

GLAPI void APIENTRY glPassTexCoordATI(GLuint dst, GLuint coord, GLenum swizzle)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1924];
   ((void (APIENTRY *)(GLuint dst, GLuint coord, GLenum swizzle)) _func)(dst, coord, swizzle);
}

GLAPI void APIENTRY glPassThrough(GLfloat token)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1925];
   ((void (APIENTRY *)(GLfloat token)) _func)(token);
}

GLAPI void APIENTRY glPassThroughxOES(GLfixed token)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1926];
   ((void (APIENTRY *)(GLfixed token)) _func)(token);
}

GLAPI void APIENTRY glPatchParameterfv(GLenum pname, const GLfloat *values)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1927];
   ((void (APIENTRY *)(GLenum pname, const GLfloat *values)) _func)(pname, values);
}

GLAPI void APIENTRY glPatchParameterfvEXT(GLenum pname, const GLfloat *values)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1928];
   ((void (APIENTRY *)(GLenum pname, const GLfloat *values)) _func)(pname, values);
}

GLAPI void APIENTRY glPatchParameterfvNV(GLenum pname, const GLfloat *values)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1929];
   ((void (APIENTRY *)(GLenum pname, const GLfloat *values)) _func)(pname, values);
}

GLAPI void APIENTRY glPatchParameteri(GLenum pname, GLint value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1930];
   ((void (APIENTRY *)(GLenum pname, GLint value)) _func)(pname, value);
}

GLAPI void APIENTRY glPatchParameteriEXT(GLenum pname, GLint value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1931];
   ((void (APIENTRY *)(GLenum pname, GLint value)) _func)(pname, value);
}

GLAPI void APIENTRY glPatchParameteriNV(GLenum pname, GLint value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1932];
   ((void (APIENTRY *)(GLenum pname, GLint value)) _func)(pname, value);
}

GLAPI void APIENTRY glPatchParameteriOES(GLenum pname, GLint value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1933];
   ((void (APIENTRY *)(GLenum pname, GLint value)) _func)(pname, value);
}

GLAPI void APIENTRY glPathColorGenNV(GLenum color, GLenum genMode, GLenum colorFormat, const GLfloat *coeffs)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1934];
   ((void (APIENTRY *)(GLenum color, GLenum genMode, GLenum colorFormat, const GLfloat *coeffs)) _func)(color, genMode, colorFormat, coeffs);
}

GLAPI void APIENTRY glPathCommandsNV(GLuint path, GLsizei numCommands, const GLubyte *commands, GLsizei numCoords, GLenum coordType, const void *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1935];
   ((void (APIENTRY *)(GLuint path, GLsizei numCommands, const GLubyte *commands, GLsizei numCoords, GLenum coordType, const void *coords)) _func)(path, numCommands, commands, numCoords, coordType, coords);
}

GLAPI void APIENTRY glPathCoordsNV(GLuint path, GLsizei numCoords, GLenum coordType, const void *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1936];
   ((void (APIENTRY *)(GLuint path, GLsizei numCoords, GLenum coordType, const void *coords)) _func)(path, numCoords, coordType, coords);
}

GLAPI void APIENTRY glPathCoverDepthFuncNV(GLenum func)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1937];
   ((void (APIENTRY *)(GLenum func)) _func)(func);
}

GLAPI void APIENTRY glPathDashArrayNV(GLuint path, GLsizei dashCount, const GLfloat *dashArray)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1938];
   ((void (APIENTRY *)(GLuint path, GLsizei dashCount, const GLfloat *dashArray)) _func)(path, dashCount, dashArray);
}

GLAPI void APIENTRY glPathFogGenNV(GLenum genMode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1939];
   ((void (APIENTRY *)(GLenum genMode)) _func)(genMode);
}

GLAPI GLenum APIENTRY glPathGlyphIndexArrayNV(GLuint firstPathName, GLenum fontTarget, const void *fontName, GLbitfield fontStyle, GLuint firstGlyphIndex, GLsizei numGlyphs, GLuint pathParameterTemplate, GLfloat emScale)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1940];
   return ((GLenum (APIENTRY *)(GLuint firstPathName, GLenum fontTarget, const void *fontName, GLbitfield fontStyle, GLuint firstGlyphIndex, GLsizei numGlyphs, GLuint pathParameterTemplate, GLfloat emScale)) _func)(firstPathName, fontTarget, fontName, fontStyle, firstGlyphIndex, numGlyphs, pathParameterTemplate, emScale);
}

GLAPI GLenum APIENTRY glPathGlyphIndexRangeNV(GLenum fontTarget, const void *fontName, GLbitfield fontStyle, GLuint pathParameterTemplate, GLfloat emScale, GLuint *baseAndCount)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1941];
   return ((GLenum (APIENTRY *)(GLenum fontTarget, const void *fontName, GLbitfield fontStyle, GLuint pathParameterTemplate, GLfloat emScale, GLuint *baseAndCount)) _func)(fontTarget, fontName, fontStyle, pathParameterTemplate, emScale, baseAndCount);
}

GLAPI void APIENTRY glPathGlyphRangeNV(GLuint firstPathName, GLenum fontTarget, const void *fontName, GLbitfield fontStyle, GLuint firstGlyph, GLsizei numGlyphs, GLenum handleMissingGlyphs, GLuint pathParameterTemplate, GLfloat emScale)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1942];
   ((void (APIENTRY *)(GLuint firstPathName, GLenum fontTarget, const void *fontName, GLbitfield fontStyle, GLuint firstGlyph, GLsizei numGlyphs, GLenum handleMissingGlyphs, GLuint pathParameterTemplate, GLfloat emScale)) _func)(firstPathName, fontTarget, fontName, fontStyle, firstGlyph, numGlyphs, handleMissingGlyphs, pathParameterTemplate, emScale);
}

GLAPI void APIENTRY glPathGlyphsNV(GLuint firstPathName, GLenum fontTarget, const void *fontName, GLbitfield fontStyle, GLsizei numGlyphs, GLenum type, const void *charcodes, GLenum handleMissingGlyphs, GLuint pathParameterTemplate, GLfloat emScale)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1943];
   ((void (APIENTRY *)(GLuint firstPathName, GLenum fontTarget, const void *fontName, GLbitfield fontStyle, GLsizei numGlyphs, GLenum type, const void *charcodes, GLenum handleMissingGlyphs, GLuint pathParameterTemplate, GLfloat emScale)) _func)(firstPathName, fontTarget, fontName, fontStyle, numGlyphs, type, charcodes, handleMissingGlyphs, pathParameterTemplate, emScale);
}

GLAPI GLenum APIENTRY glPathMemoryGlyphIndexArrayNV(GLuint firstPathName, GLenum fontTarget, GLsizeiptr fontSize, const void *fontData, GLsizei faceIndex, GLuint firstGlyphIndex, GLsizei numGlyphs, GLuint pathParameterTemplate, GLfloat emScale)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1944];
   return ((GLenum (APIENTRY *)(GLuint firstPathName, GLenum fontTarget, GLsizeiptr fontSize, const void *fontData, GLsizei faceIndex, GLuint firstGlyphIndex, GLsizei numGlyphs, GLuint pathParameterTemplate, GLfloat emScale)) _func)(firstPathName, fontTarget, fontSize, fontData, faceIndex, firstGlyphIndex, numGlyphs, pathParameterTemplate, emScale);
}

GLAPI void APIENTRY glPathParameterfNV(GLuint path, GLenum pname, GLfloat value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1945];
   ((void (APIENTRY *)(GLuint path, GLenum pname, GLfloat value)) _func)(path, pname, value);
}

GLAPI void APIENTRY glPathParameterfvNV(GLuint path, GLenum pname, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1946];
   ((void (APIENTRY *)(GLuint path, GLenum pname, const GLfloat *value)) _func)(path, pname, value);
}

GLAPI void APIENTRY glPathParameteriNV(GLuint path, GLenum pname, GLint value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1947];
   ((void (APIENTRY *)(GLuint path, GLenum pname, GLint value)) _func)(path, pname, value);
}

GLAPI void APIENTRY glPathParameterivNV(GLuint path, GLenum pname, const GLint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1948];
   ((void (APIENTRY *)(GLuint path, GLenum pname, const GLint *value)) _func)(path, pname, value);
}

GLAPI void APIENTRY glPathStencilDepthOffsetNV(GLfloat factor, GLfloat units)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1949];
   ((void (APIENTRY *)(GLfloat factor, GLfloat units)) _func)(factor, units);
}

GLAPI void APIENTRY glPathStencilFuncNV(GLenum func, GLint ref, GLuint mask)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1950];
   ((void (APIENTRY *)(GLenum func, GLint ref, GLuint mask)) _func)(func, ref, mask);
}

GLAPI void APIENTRY glPathStringNV(GLuint path, GLenum format, GLsizei length, const void *pathString)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1951];
   ((void (APIENTRY *)(GLuint path, GLenum format, GLsizei length, const void *pathString)) _func)(path, format, length, pathString);
}

GLAPI void APIENTRY glPathSubCommandsNV(GLuint path, GLsizei commandStart, GLsizei commandsToDelete, GLsizei numCommands, const GLubyte *commands, GLsizei numCoords, GLenum coordType, const void *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1952];
   ((void (APIENTRY *)(GLuint path, GLsizei commandStart, GLsizei commandsToDelete, GLsizei numCommands, const GLubyte *commands, GLsizei numCoords, GLenum coordType, const void *coords)) _func)(path, commandStart, commandsToDelete, numCommands, commands, numCoords, coordType, coords);
}

GLAPI void APIENTRY glPathSubCoordsNV(GLuint path, GLsizei coordStart, GLsizei numCoords, GLenum coordType, const void *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1953];
   ((void (APIENTRY *)(GLuint path, GLsizei coordStart, GLsizei numCoords, GLenum coordType, const void *coords)) _func)(path, coordStart, numCoords, coordType, coords);
}

GLAPI void APIENTRY glPathTexGenNV(GLenum texCoordSet, GLenum genMode, GLint components, const GLfloat *coeffs)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1954];
   ((void (APIENTRY *)(GLenum texCoordSet, GLenum genMode, GLint components, const GLfloat *coeffs)) _func)(texCoordSet, genMode, components, coeffs);
}

GLAPI void APIENTRY glPauseTransformFeedback(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1955];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glPauseTransformFeedbackEXT(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1956];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glPauseTransformFeedbackNV(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1957];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glPixelDataRangeNV(GLenum target, GLsizei length, const void *pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1958];
   ((void (APIENTRY *)(GLenum target, GLsizei length, const void *pointer)) _func)(target, length, pointer);
}

GLAPI void APIENTRY glPixelMapfv(GLenum map, GLsizei mapsize, const GLfloat *values)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1959];
   ((void (APIENTRY *)(GLenum map, GLsizei mapsize, const GLfloat *values)) _func)(map, mapsize, values);
}

GLAPI void APIENTRY glPixelMapuiv(GLenum map, GLsizei mapsize, const GLuint *values)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1960];
   ((void (APIENTRY *)(GLenum map, GLsizei mapsize, const GLuint *values)) _func)(map, mapsize, values);
}

GLAPI void APIENTRY glPixelMapusv(GLenum map, GLsizei mapsize, const GLushort *values)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1961];
   ((void (APIENTRY *)(GLenum map, GLsizei mapsize, const GLushort *values)) _func)(map, mapsize, values);
}

GLAPI void APIENTRY glPixelMapx(GLenum map, GLint size, const GLfixed *values)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1962];
   ((void (APIENTRY *)(GLenum map, GLint size, const GLfixed *values)) _func)(map, size, values);
}

GLAPI void APIENTRY glPixelStoref(GLenum pname, GLfloat param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1963];
   ((void (APIENTRY *)(GLenum pname, GLfloat param)) _func)(pname, param);
}

GLAPI void APIENTRY glPixelStorei(GLenum pname, GLint param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1964];
   ((void (APIENTRY *)(GLenum pname, GLint param)) _func)(pname, param);
}

GLAPI void APIENTRY glPixelStorex(GLenum pname, GLfixed param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1965];
   ((void (APIENTRY *)(GLenum pname, GLfixed param)) _func)(pname, param);
}

GLAPI void APIENTRY glPixelTexGenParameterfSGIS(GLenum pname, GLfloat param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1966];
   ((void (APIENTRY *)(GLenum pname, GLfloat param)) _func)(pname, param);
}

GLAPI void APIENTRY glPixelTexGenParameterfvSGIS(GLenum pname, const GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1967];
   ((void (APIENTRY *)(GLenum pname, const GLfloat *params)) _func)(pname, params);
}

GLAPI void APIENTRY glPixelTexGenParameteriSGIS(GLenum pname, GLint param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1968];
   ((void (APIENTRY *)(GLenum pname, GLint param)) _func)(pname, param);
}

GLAPI void APIENTRY glPixelTexGenParameterivSGIS(GLenum pname, const GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1969];
   ((void (APIENTRY *)(GLenum pname, const GLint *params)) _func)(pname, params);
}

GLAPI void APIENTRY glPixelTexGenSGIX(GLenum mode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1970];
   ((void (APIENTRY *)(GLenum mode)) _func)(mode);
}

GLAPI void APIENTRY glPixelTransferf(GLenum pname, GLfloat param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1971];
   ((void (APIENTRY *)(GLenum pname, GLfloat param)) _func)(pname, param);
}

GLAPI void APIENTRY glPixelTransferi(GLenum pname, GLint param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1972];
   ((void (APIENTRY *)(GLenum pname, GLint param)) _func)(pname, param);
}

GLAPI void APIENTRY glPixelTransferxOES(GLenum pname, GLfixed param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1973];
   ((void (APIENTRY *)(GLenum pname, GLfixed param)) _func)(pname, param);
}

GLAPI void APIENTRY glPixelTransformParameterfEXT(GLenum target, GLenum pname, GLfloat param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1974];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLfloat param)) _func)(target, pname, param);
}

GLAPI void APIENTRY glPixelTransformParameterfvEXT(GLenum target, GLenum pname, const GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1975];
   ((void (APIENTRY *)(GLenum target, GLenum pname, const GLfloat *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glPixelTransformParameteriEXT(GLenum target, GLenum pname, GLint param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1976];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLint param)) _func)(target, pname, param);
}

GLAPI void APIENTRY glPixelTransformParameterivEXT(GLenum target, GLenum pname, const GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1977];
   ((void (APIENTRY *)(GLenum target, GLenum pname, const GLint *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glPixelZoom(GLfloat xfactor, GLfloat yfactor)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1978];
   ((void (APIENTRY *)(GLfloat xfactor, GLfloat yfactor)) _func)(xfactor, yfactor);
}

GLAPI void APIENTRY glPixelZoomxOES(GLfixed xfactor, GLfixed yfactor)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1979];
   ((void (APIENTRY *)(GLfixed xfactor, GLfixed yfactor)) _func)(xfactor, yfactor);
}

GLAPI GLboolean APIENTRY glPointAlongPathNV(GLuint path, GLsizei startSegment, GLsizei numSegments, GLfloat distance, GLfloat *x, GLfloat *y, GLfloat *tangentX, GLfloat *tangentY)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1980];
   return ((GLboolean (APIENTRY *)(GLuint path, GLsizei startSegment, GLsizei numSegments, GLfloat distance, GLfloat *x, GLfloat *y, GLfloat *tangentX, GLfloat *tangentY)) _func)(path, startSegment, numSegments, distance, x, y, tangentX, tangentY);
}

GLAPI void APIENTRY glPointParameterf(GLenum pname, GLfloat param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1981];
   ((void (APIENTRY *)(GLenum pname, GLfloat param)) _func)(pname, param);
}

GLAPI void APIENTRY glPointParameterfARB(GLenum pname, GLfloat param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1982];
   ((void (APIENTRY *)(GLenum pname, GLfloat param)) _func)(pname, param);
}

GLAPI void APIENTRY glPointParameterfEXT(GLenum pname, GLfloat param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1983];
   ((void (APIENTRY *)(GLenum pname, GLfloat param)) _func)(pname, param);
}

GLAPI void APIENTRY glPointParameterfSGIS(GLenum pname, GLfloat param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1984];
   ((void (APIENTRY *)(GLenum pname, GLfloat param)) _func)(pname, param);
}

GLAPI void APIENTRY glPointParameterfv(GLenum pname, const GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1985];
   ((void (APIENTRY *)(GLenum pname, const GLfloat *params)) _func)(pname, params);
}

GLAPI void APIENTRY glPointParameterfvARB(GLenum pname, const GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1986];
   ((void (APIENTRY *)(GLenum pname, const GLfloat *params)) _func)(pname, params);
}

GLAPI void APIENTRY glPointParameterfvEXT(GLenum pname, const GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1987];
   ((void (APIENTRY *)(GLenum pname, const GLfloat *params)) _func)(pname, params);
}

GLAPI void APIENTRY glPointParameterfvSGIS(GLenum pname, const GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1988];
   ((void (APIENTRY *)(GLenum pname, const GLfloat *params)) _func)(pname, params);
}

GLAPI void APIENTRY glPointParameteri(GLenum pname, GLint param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1989];
   ((void (APIENTRY *)(GLenum pname, GLint param)) _func)(pname, param);
}

GLAPI void APIENTRY glPointParameteriNV(GLenum pname, GLint param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1990];
   ((void (APIENTRY *)(GLenum pname, GLint param)) _func)(pname, param);
}

GLAPI void APIENTRY glPointParameteriv(GLenum pname, const GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1991];
   ((void (APIENTRY *)(GLenum pname, const GLint *params)) _func)(pname, params);
}

GLAPI void APIENTRY glPointParameterivNV(GLenum pname, const GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1992];
   ((void (APIENTRY *)(GLenum pname, const GLint *params)) _func)(pname, params);
}

GLAPI void APIENTRY glPointParameterx(GLenum pname, GLfixed param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1993];
   ((void (APIENTRY *)(GLenum pname, GLfixed param)) _func)(pname, param);
}

GLAPI void APIENTRY glPointParameterxOES(GLenum pname, GLfixed param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1994];
   ((void (APIENTRY *)(GLenum pname, GLfixed param)) _func)(pname, param);
}

GLAPI void APIENTRY glPointParameterxv(GLenum pname, const GLfixed *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1995];
   ((void (APIENTRY *)(GLenum pname, const GLfixed *params)) _func)(pname, params);
}

GLAPI void APIENTRY glPointParameterxvOES(GLenum pname, const GLfixed *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1996];
   ((void (APIENTRY *)(GLenum pname, const GLfixed *params)) _func)(pname, params);
}

GLAPI void APIENTRY glPointSize(GLfloat size)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1997];
   ((void (APIENTRY *)(GLfloat size)) _func)(size);
}

GLAPI void APIENTRY glPointSizePointerOES(GLenum type, GLsizei stride, const void *pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1998];
   ((void (APIENTRY *)(GLenum type, GLsizei stride, const void *pointer)) _func)(type, stride, pointer);
}

GLAPI void APIENTRY glPointSizex(GLfixed size)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[1999];
   ((void (APIENTRY *)(GLfixed size)) _func)(size);
}

GLAPI void APIENTRY glPointSizexOES(GLfixed size)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2000];
   ((void (APIENTRY *)(GLfixed size)) _func)(size);
}

GLAPI GLint APIENTRY glPollAsyncSGIX(GLuint *markerp)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2001];
   return ((GLint (APIENTRY *)(GLuint *markerp)) _func)(markerp);
}

GLAPI GLint APIENTRY glPollInstrumentsSGIX(GLint *marker_p)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2002];
   return ((GLint (APIENTRY *)(GLint *marker_p)) _func)(marker_p);
}

GLAPI void APIENTRY glPolygonMode(GLenum face, GLenum mode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2003];
   ((void (APIENTRY *)(GLenum face, GLenum mode)) _func)(face, mode);
}

GLAPI void APIENTRY glPolygonModeNV(GLenum face, GLenum mode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2004];
   ((void (APIENTRY *)(GLenum face, GLenum mode)) _func)(face, mode);
}

GLAPI void APIENTRY glPolygonOffset(GLfloat factor, GLfloat units)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2005];
   ((void (APIENTRY *)(GLfloat factor, GLfloat units)) _func)(factor, units);
}

GLAPI void APIENTRY glPolygonOffsetClamp(GLfloat factor, GLfloat units, GLfloat clamp)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2006];
   ((void (APIENTRY *)(GLfloat factor, GLfloat units, GLfloat clamp)) _func)(factor, units, clamp);
}

GLAPI void APIENTRY glPolygonOffsetClampEXT(GLfloat factor, GLfloat units, GLfloat clamp)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2007];
   ((void (APIENTRY *)(GLfloat factor, GLfloat units, GLfloat clamp)) _func)(factor, units, clamp);
}

GLAPI void APIENTRY glPolygonOffsetEXT(GLfloat factor, GLfloat bias)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2008];
   ((void (APIENTRY *)(GLfloat factor, GLfloat bias)) _func)(factor, bias);
}

GLAPI void APIENTRY glPolygonOffsetx(GLfixed factor, GLfixed units)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2009];
   ((void (APIENTRY *)(GLfixed factor, GLfixed units)) _func)(factor, units);
}

GLAPI void APIENTRY glPolygonOffsetxOES(GLfixed factor, GLfixed units)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2010];
   ((void (APIENTRY *)(GLfixed factor, GLfixed units)) _func)(factor, units);
}

GLAPI void APIENTRY glPolygonStipple(const GLubyte *mask)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2011];
   ((void (APIENTRY *)(const GLubyte *mask)) _func)(mask);
}

GLAPI void APIENTRY glPopAttrib(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2012];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glPopClientAttrib(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2013];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glPopDebugGroup(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2014];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glPopDebugGroupKHR(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2015];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glPopDebugGroupOES(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2016];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glPopGroupMarkerEXT(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2017];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glPopMatrix(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2018];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glPopName(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2019];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glPresentFrameDualFillNV(GLuint video_slot, GLuint64 minPresentTime, GLuint beginPresentTimeId, GLuint presentDurationId, GLenum type, GLenum target0, GLuint fill0, GLenum target1, GLuint fill1, GLenum target2, GLuint fill2, GLenum target3, GLuint fill3)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2020];
   ((void (APIENTRY *)(GLuint video_slot, GLuint64 minPresentTime, GLuint beginPresentTimeId, GLuint presentDurationId, GLenum type, GLenum target0, GLuint fill0, GLenum target1, GLuint fill1, GLenum target2, GLuint fill2, GLenum target3, GLuint fill3)) _func)(video_slot, minPresentTime, beginPresentTimeId, presentDurationId, type, target0, fill0, target1, fill1, target2, fill2, target3, fill3);
}

GLAPI void APIENTRY glPresentFrameKeyedNV(GLuint video_slot, GLuint64 minPresentTime, GLuint beginPresentTimeId, GLuint presentDurationId, GLenum type, GLenum target0, GLuint fill0, GLuint key0, GLenum target1, GLuint fill1, GLuint key1)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2021];
   ((void (APIENTRY *)(GLuint video_slot, GLuint64 minPresentTime, GLuint beginPresentTimeId, GLuint presentDurationId, GLenum type, GLenum target0, GLuint fill0, GLuint key0, GLenum target1, GLuint fill1, GLuint key1)) _func)(video_slot, minPresentTime, beginPresentTimeId, presentDurationId, type, target0, fill0, key0, target1, fill1, key1);
}

GLAPI void APIENTRY glPrimitiveBoundingBox(GLfloat minX, GLfloat minY, GLfloat minZ, GLfloat minW, GLfloat maxX, GLfloat maxY, GLfloat maxZ, GLfloat maxW)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2022];
   ((void (APIENTRY *)(GLfloat minX, GLfloat minY, GLfloat minZ, GLfloat minW, GLfloat maxX, GLfloat maxY, GLfloat maxZ, GLfloat maxW)) _func)(minX, minY, minZ, minW, maxX, maxY, maxZ, maxW);
}

GLAPI void APIENTRY glPrimitiveBoundingBoxARB(GLfloat minX, GLfloat minY, GLfloat minZ, GLfloat minW, GLfloat maxX, GLfloat maxY, GLfloat maxZ, GLfloat maxW)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2023];
   ((void (APIENTRY *)(GLfloat minX, GLfloat minY, GLfloat minZ, GLfloat minW, GLfloat maxX, GLfloat maxY, GLfloat maxZ, GLfloat maxW)) _func)(minX, minY, minZ, minW, maxX, maxY, maxZ, maxW);
}

GLAPI void APIENTRY glPrimitiveBoundingBoxEXT(GLfloat minX, GLfloat minY, GLfloat minZ, GLfloat minW, GLfloat maxX, GLfloat maxY, GLfloat maxZ, GLfloat maxW)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2024];
   ((void (APIENTRY *)(GLfloat minX, GLfloat minY, GLfloat minZ, GLfloat minW, GLfloat maxX, GLfloat maxY, GLfloat maxZ, GLfloat maxW)) _func)(minX, minY, minZ, minW, maxX, maxY, maxZ, maxW);
}

GLAPI void APIENTRY glPrimitiveBoundingBoxOES(GLfloat minX, GLfloat minY, GLfloat minZ, GLfloat minW, GLfloat maxX, GLfloat maxY, GLfloat maxZ, GLfloat maxW)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2025];
   ((void (APIENTRY *)(GLfloat minX, GLfloat minY, GLfloat minZ, GLfloat minW, GLfloat maxX, GLfloat maxY, GLfloat maxZ, GLfloat maxW)) _func)(minX, minY, minZ, minW, maxX, maxY, maxZ, maxW);
}

GLAPI void APIENTRY glPrimitiveRestart(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2026];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glPrimitiveRestartIndex(GLuint index)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2027];
   ((void (APIENTRY *)(GLuint index)) _func)(index);
}

GLAPI void APIENTRY glPrimitiveRestartIndexNV(GLuint index)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2028];
   ((void (APIENTRY *)(GLuint index)) _func)(index);
}

GLAPI void APIENTRY glPrimitiveRestartNV(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2029];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glPrioritizeTextures(GLsizei n, const GLuint *textures, const GLfloat *priorities)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2030];
   ((void (APIENTRY *)(GLsizei n, const GLuint *textures, const GLfloat *priorities)) _func)(n, textures, priorities);
}

GLAPI void APIENTRY glPrioritizeTexturesEXT(GLsizei n, const GLuint *textures, const GLclampf *priorities)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2031];
   ((void (APIENTRY *)(GLsizei n, const GLuint *textures, const GLclampf *priorities)) _func)(n, textures, priorities);
}

GLAPI void APIENTRY glPrioritizeTexturesxOES(GLsizei n, const GLuint *textures, const GLfixed *priorities)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2032];
   ((void (APIENTRY *)(GLsizei n, const GLuint *textures, const GLfixed *priorities)) _func)(n, textures, priorities);
}

GLAPI void APIENTRY glProgramBinary(GLuint program, GLenum binaryFormat, const void *binary, GLsizei length)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2033];
   ((void (APIENTRY *)(GLuint program, GLenum binaryFormat, const void *binary, GLsizei length)) _func)(program, binaryFormat, binary, length);
}

GLAPI void APIENTRY glProgramBinaryOES(GLuint program, GLenum binaryFormat, const void *binary, GLint length)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2034];
   ((void (APIENTRY *)(GLuint program, GLenum binaryFormat, const void *binary, GLint length)) _func)(program, binaryFormat, binary, length);
}

GLAPI void APIENTRY glProgramBufferParametersIivNV(GLenum target, GLuint bindingIndex, GLuint wordIndex, GLsizei count, const GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2035];
   ((void (APIENTRY *)(GLenum target, GLuint bindingIndex, GLuint wordIndex, GLsizei count, const GLint *params)) _func)(target, bindingIndex, wordIndex, count, params);
}

GLAPI void APIENTRY glProgramBufferParametersIuivNV(GLenum target, GLuint bindingIndex, GLuint wordIndex, GLsizei count, const GLuint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2036];
   ((void (APIENTRY *)(GLenum target, GLuint bindingIndex, GLuint wordIndex, GLsizei count, const GLuint *params)) _func)(target, bindingIndex, wordIndex, count, params);
}

GLAPI void APIENTRY glProgramBufferParametersfvNV(GLenum target, GLuint bindingIndex, GLuint wordIndex, GLsizei count, const GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2037];
   ((void (APIENTRY *)(GLenum target, GLuint bindingIndex, GLuint wordIndex, GLsizei count, const GLfloat *params)) _func)(target, bindingIndex, wordIndex, count, params);
}

GLAPI void APIENTRY glProgramEnvParameter4dARB(GLenum target, GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2038];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w)) _func)(target, index, x, y, z, w);
}

GLAPI void APIENTRY glProgramEnvParameter4dvARB(GLenum target, GLuint index, const GLdouble *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2039];
   ((void (APIENTRY *)(GLenum target, GLuint index, const GLdouble *params)) _func)(target, index, params);
}

GLAPI void APIENTRY glProgramEnvParameter4fARB(GLenum target, GLuint index, GLfloat x, GLfloat y, GLfloat z, GLfloat w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2040];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLfloat x, GLfloat y, GLfloat z, GLfloat w)) _func)(target, index, x, y, z, w);
}

GLAPI void APIENTRY glProgramEnvParameter4fvARB(GLenum target, GLuint index, const GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2041];
   ((void (APIENTRY *)(GLenum target, GLuint index, const GLfloat *params)) _func)(target, index, params);
}

GLAPI void APIENTRY glProgramEnvParameterI4iNV(GLenum target, GLuint index, GLint x, GLint y, GLint z, GLint w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2042];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLint x, GLint y, GLint z, GLint w)) _func)(target, index, x, y, z, w);
}

GLAPI void APIENTRY glProgramEnvParameterI4ivNV(GLenum target, GLuint index, const GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2043];
   ((void (APIENTRY *)(GLenum target, GLuint index, const GLint *params)) _func)(target, index, params);
}

GLAPI void APIENTRY glProgramEnvParameterI4uiNV(GLenum target, GLuint index, GLuint x, GLuint y, GLuint z, GLuint w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2044];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLuint x, GLuint y, GLuint z, GLuint w)) _func)(target, index, x, y, z, w);
}

GLAPI void APIENTRY glProgramEnvParameterI4uivNV(GLenum target, GLuint index, const GLuint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2045];
   ((void (APIENTRY *)(GLenum target, GLuint index, const GLuint *params)) _func)(target, index, params);
}

GLAPI void APIENTRY glProgramEnvParameters4fvEXT(GLenum target, GLuint index, GLsizei count, const GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2046];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLsizei count, const GLfloat *params)) _func)(target, index, count, params);
}

GLAPI void APIENTRY glProgramEnvParametersI4ivNV(GLenum target, GLuint index, GLsizei count, const GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2047];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLsizei count, const GLint *params)) _func)(target, index, count, params);
}

GLAPI void APIENTRY glProgramEnvParametersI4uivNV(GLenum target, GLuint index, GLsizei count, const GLuint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2048];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLsizei count, const GLuint *params)) _func)(target, index, count, params);
}

GLAPI void APIENTRY glProgramLocalParameter4dARB(GLenum target, GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2049];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w)) _func)(target, index, x, y, z, w);
}

GLAPI void APIENTRY glProgramLocalParameter4dvARB(GLenum target, GLuint index, const GLdouble *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2050];
   ((void (APIENTRY *)(GLenum target, GLuint index, const GLdouble *params)) _func)(target, index, params);
}

GLAPI void APIENTRY glProgramLocalParameter4fARB(GLenum target, GLuint index, GLfloat x, GLfloat y, GLfloat z, GLfloat w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2051];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLfloat x, GLfloat y, GLfloat z, GLfloat w)) _func)(target, index, x, y, z, w);
}

GLAPI void APIENTRY glProgramLocalParameter4fvARB(GLenum target, GLuint index, const GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2052];
   ((void (APIENTRY *)(GLenum target, GLuint index, const GLfloat *params)) _func)(target, index, params);
}

GLAPI void APIENTRY glProgramLocalParameterI4iNV(GLenum target, GLuint index, GLint x, GLint y, GLint z, GLint w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2053];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLint x, GLint y, GLint z, GLint w)) _func)(target, index, x, y, z, w);
}

GLAPI void APIENTRY glProgramLocalParameterI4ivNV(GLenum target, GLuint index, const GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2054];
   ((void (APIENTRY *)(GLenum target, GLuint index, const GLint *params)) _func)(target, index, params);
}

GLAPI void APIENTRY glProgramLocalParameterI4uiNV(GLenum target, GLuint index, GLuint x, GLuint y, GLuint z, GLuint w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2055];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLuint x, GLuint y, GLuint z, GLuint w)) _func)(target, index, x, y, z, w);
}

GLAPI void APIENTRY glProgramLocalParameterI4uivNV(GLenum target, GLuint index, const GLuint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2056];
   ((void (APIENTRY *)(GLenum target, GLuint index, const GLuint *params)) _func)(target, index, params);
}

GLAPI void APIENTRY glProgramLocalParameters4fvEXT(GLenum target, GLuint index, GLsizei count, const GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2057];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLsizei count, const GLfloat *params)) _func)(target, index, count, params);
}

GLAPI void APIENTRY glProgramLocalParametersI4ivNV(GLenum target, GLuint index, GLsizei count, const GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2058];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLsizei count, const GLint *params)) _func)(target, index, count, params);
}

GLAPI void APIENTRY glProgramLocalParametersI4uivNV(GLenum target, GLuint index, GLsizei count, const GLuint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2059];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLsizei count, const GLuint *params)) _func)(target, index, count, params);
}

GLAPI void APIENTRY glProgramNamedParameter4dNV(GLuint id, GLsizei len, const GLubyte *name, GLdouble x, GLdouble y, GLdouble z, GLdouble w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2060];
   ((void (APIENTRY *)(GLuint id, GLsizei len, const GLubyte *name, GLdouble x, GLdouble y, GLdouble z, GLdouble w)) _func)(id, len, name, x, y, z, w);
}

GLAPI void APIENTRY glProgramNamedParameter4dvNV(GLuint id, GLsizei len, const GLubyte *name, const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2061];
   ((void (APIENTRY *)(GLuint id, GLsizei len, const GLubyte *name, const GLdouble *v)) _func)(id, len, name, v);
}

GLAPI void APIENTRY glProgramNamedParameter4fNV(GLuint id, GLsizei len, const GLubyte *name, GLfloat x, GLfloat y, GLfloat z, GLfloat w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2062];
   ((void (APIENTRY *)(GLuint id, GLsizei len, const GLubyte *name, GLfloat x, GLfloat y, GLfloat z, GLfloat w)) _func)(id, len, name, x, y, z, w);
}

GLAPI void APIENTRY glProgramNamedParameter4fvNV(GLuint id, GLsizei len, const GLubyte *name, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2063];
   ((void (APIENTRY *)(GLuint id, GLsizei len, const GLubyte *name, const GLfloat *v)) _func)(id, len, name, v);
}

GLAPI void APIENTRY glProgramParameter4dNV(GLenum target, GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2064];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w)) _func)(target, index, x, y, z, w);
}

GLAPI void APIENTRY glProgramParameter4dvNV(GLenum target, GLuint index, const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2065];
   ((void (APIENTRY *)(GLenum target, GLuint index, const GLdouble *v)) _func)(target, index, v);
}

GLAPI void APIENTRY glProgramParameter4fNV(GLenum target, GLuint index, GLfloat x, GLfloat y, GLfloat z, GLfloat w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2066];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLfloat x, GLfloat y, GLfloat z, GLfloat w)) _func)(target, index, x, y, z, w);
}

GLAPI void APIENTRY glProgramParameter4fvNV(GLenum target, GLuint index, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2067];
   ((void (APIENTRY *)(GLenum target, GLuint index, const GLfloat *v)) _func)(target, index, v);
}

GLAPI void APIENTRY glProgramParameteri(GLuint program, GLenum pname, GLint value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2068];
   ((void (APIENTRY *)(GLuint program, GLenum pname, GLint value)) _func)(program, pname, value);
}

GLAPI void APIENTRY glProgramParameteriARB(GLuint program, GLenum pname, GLint value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2069];
   ((void (APIENTRY *)(GLuint program, GLenum pname, GLint value)) _func)(program, pname, value);
}

GLAPI void APIENTRY glProgramParameteriEXT(GLuint program, GLenum pname, GLint value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2070];
   ((void (APIENTRY *)(GLuint program, GLenum pname, GLint value)) _func)(program, pname, value);
}

GLAPI void APIENTRY glProgramParameters4dvNV(GLenum target, GLuint index, GLsizei count, const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2071];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLsizei count, const GLdouble *v)) _func)(target, index, count, v);
}

GLAPI void APIENTRY glProgramParameters4fvNV(GLenum target, GLuint index, GLsizei count, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2072];
   ((void (APIENTRY *)(GLenum target, GLuint index, GLsizei count, const GLfloat *v)) _func)(target, index, count, v);
}

GLAPI void APIENTRY glProgramPathFragmentInputGenNV(GLuint program, GLint location, GLenum genMode, GLint components, const GLfloat *coeffs)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2073];
   ((void (APIENTRY *)(GLuint program, GLint location, GLenum genMode, GLint components, const GLfloat *coeffs)) _func)(program, location, genMode, components, coeffs);
}

GLAPI void APIENTRY glProgramStringARB(GLenum target, GLenum format, GLsizei len, const void *string)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2074];
   ((void (APIENTRY *)(GLenum target, GLenum format, GLsizei len, const void *string)) _func)(target, format, len, string);
}

GLAPI void APIENTRY glProgramSubroutineParametersuivNV(GLenum target, GLsizei count, const GLuint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2075];
   ((void (APIENTRY *)(GLenum target, GLsizei count, const GLuint *params)) _func)(target, count, params);
}

GLAPI void APIENTRY glProgramUniform1d(GLuint program, GLint location, GLdouble v0)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2076];
   ((void (APIENTRY *)(GLuint program, GLint location, GLdouble v0)) _func)(program, location, v0);
}

GLAPI void APIENTRY glProgramUniform1dEXT(GLuint program, GLint location, GLdouble x)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2077];
   ((void (APIENTRY *)(GLuint program, GLint location, GLdouble x)) _func)(program, location, x);
}

GLAPI void APIENTRY glProgramUniform1dv(GLuint program, GLint location, GLsizei count, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2078];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLdouble *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform1dvEXT(GLuint program, GLint location, GLsizei count, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2079];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLdouble *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform1f(GLuint program, GLint location, GLfloat v0)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2080];
   ((void (APIENTRY *)(GLuint program, GLint location, GLfloat v0)) _func)(program, location, v0);
}

GLAPI void APIENTRY glProgramUniform1fEXT(GLuint program, GLint location, GLfloat v0)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2081];
   ((void (APIENTRY *)(GLuint program, GLint location, GLfloat v0)) _func)(program, location, v0);
}

GLAPI void APIENTRY glProgramUniform1fv(GLuint program, GLint location, GLsizei count, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2082];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLfloat *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform1fvEXT(GLuint program, GLint location, GLsizei count, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2083];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLfloat *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform1i(GLuint program, GLint location, GLint v0)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2084];
   ((void (APIENTRY *)(GLuint program, GLint location, GLint v0)) _func)(program, location, v0);
}

GLAPI void APIENTRY glProgramUniform1i64ARB(GLuint program, GLint location, GLint64 x)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2085];
   ((void (APIENTRY *)(GLuint program, GLint location, GLint64 x)) _func)(program, location, x);
}

GLAPI void APIENTRY glProgramUniform1i64NV(GLuint program, GLint location, GLint64 x)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2086];
   ((void (APIENTRY *)(GLuint program, GLint location, GLint64 x)) _func)(program, location, x);
}

GLAPI void APIENTRY glProgramUniform1i64vARB(GLuint program, GLint location, GLsizei count, const GLint64 *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2087];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLint64 *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform1i64vNV(GLuint program, GLint location, GLsizei count, const GLint64 *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2088];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLint64 *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform1iEXT(GLuint program, GLint location, GLint v0)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2089];
   ((void (APIENTRY *)(GLuint program, GLint location, GLint v0)) _func)(program, location, v0);
}

GLAPI void APIENTRY glProgramUniform1iv(GLuint program, GLint location, GLsizei count, const GLint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2090];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLint *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform1ivEXT(GLuint program, GLint location, GLsizei count, const GLint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2091];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLint *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform1ui(GLuint program, GLint location, GLuint v0)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2092];
   ((void (APIENTRY *)(GLuint program, GLint location, GLuint v0)) _func)(program, location, v0);
}

GLAPI void APIENTRY glProgramUniform1ui64ARB(GLuint program, GLint location, GLuint64 x)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2093];
   ((void (APIENTRY *)(GLuint program, GLint location, GLuint64 x)) _func)(program, location, x);
}

GLAPI void APIENTRY glProgramUniform1ui64NV(GLuint program, GLint location, GLuint64 x)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2094];
   ((void (APIENTRY *)(GLuint program, GLint location, GLuint64 x)) _func)(program, location, x);
}

GLAPI void APIENTRY glProgramUniform1ui64vARB(GLuint program, GLint location, GLsizei count, const GLuint64 *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2095];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLuint64 *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform1ui64vNV(GLuint program, GLint location, GLsizei count, const GLuint64 *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2096];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLuint64 *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform1uiEXT(GLuint program, GLint location, GLuint v0)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2097];
   ((void (APIENTRY *)(GLuint program, GLint location, GLuint v0)) _func)(program, location, v0);
}

GLAPI void APIENTRY glProgramUniform1uiv(GLuint program, GLint location, GLsizei count, const GLuint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2098];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLuint *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform1uivEXT(GLuint program, GLint location, GLsizei count, const GLuint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2099];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLuint *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform2d(GLuint program, GLint location, GLdouble v0, GLdouble v1)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2100];
   ((void (APIENTRY *)(GLuint program, GLint location, GLdouble v0, GLdouble v1)) _func)(program, location, v0, v1);
}

GLAPI void APIENTRY glProgramUniform2dEXT(GLuint program, GLint location, GLdouble x, GLdouble y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2101];
   ((void (APIENTRY *)(GLuint program, GLint location, GLdouble x, GLdouble y)) _func)(program, location, x, y);
}

GLAPI void APIENTRY glProgramUniform2dv(GLuint program, GLint location, GLsizei count, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2102];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLdouble *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform2dvEXT(GLuint program, GLint location, GLsizei count, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2103];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLdouble *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform2f(GLuint program, GLint location, GLfloat v0, GLfloat v1)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2104];
   ((void (APIENTRY *)(GLuint program, GLint location, GLfloat v0, GLfloat v1)) _func)(program, location, v0, v1);
}

GLAPI void APIENTRY glProgramUniform2fEXT(GLuint program, GLint location, GLfloat v0, GLfloat v1)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2105];
   ((void (APIENTRY *)(GLuint program, GLint location, GLfloat v0, GLfloat v1)) _func)(program, location, v0, v1);
}

GLAPI void APIENTRY glProgramUniform2fv(GLuint program, GLint location, GLsizei count, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2106];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLfloat *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform2fvEXT(GLuint program, GLint location, GLsizei count, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2107];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLfloat *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform2i(GLuint program, GLint location, GLint v0, GLint v1)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2108];
   ((void (APIENTRY *)(GLuint program, GLint location, GLint v0, GLint v1)) _func)(program, location, v0, v1);
}

GLAPI void APIENTRY glProgramUniform2i64ARB(GLuint program, GLint location, GLint64 x, GLint64 y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2109];
   ((void (APIENTRY *)(GLuint program, GLint location, GLint64 x, GLint64 y)) _func)(program, location, x, y);
}

GLAPI void APIENTRY glProgramUniform2i64NV(GLuint program, GLint location, GLint64 x, GLint64 y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2110];
   ((void (APIENTRY *)(GLuint program, GLint location, GLint64 x, GLint64 y)) _func)(program, location, x, y);
}

GLAPI void APIENTRY glProgramUniform2i64vARB(GLuint program, GLint location, GLsizei count, const GLint64 *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2111];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLint64 *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform2i64vNV(GLuint program, GLint location, GLsizei count, const GLint64 *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2112];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLint64 *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform2iEXT(GLuint program, GLint location, GLint v0, GLint v1)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2113];
   ((void (APIENTRY *)(GLuint program, GLint location, GLint v0, GLint v1)) _func)(program, location, v0, v1);
}

GLAPI void APIENTRY glProgramUniform2iv(GLuint program, GLint location, GLsizei count, const GLint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2114];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLint *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform2ivEXT(GLuint program, GLint location, GLsizei count, const GLint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2115];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLint *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform2ui(GLuint program, GLint location, GLuint v0, GLuint v1)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2116];
   ((void (APIENTRY *)(GLuint program, GLint location, GLuint v0, GLuint v1)) _func)(program, location, v0, v1);
}

GLAPI void APIENTRY glProgramUniform2ui64ARB(GLuint program, GLint location, GLuint64 x, GLuint64 y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2117];
   ((void (APIENTRY *)(GLuint program, GLint location, GLuint64 x, GLuint64 y)) _func)(program, location, x, y);
}

GLAPI void APIENTRY glProgramUniform2ui64NV(GLuint program, GLint location, GLuint64 x, GLuint64 y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2118];
   ((void (APIENTRY *)(GLuint program, GLint location, GLuint64 x, GLuint64 y)) _func)(program, location, x, y);
}

GLAPI void APIENTRY glProgramUniform2ui64vARB(GLuint program, GLint location, GLsizei count, const GLuint64 *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2119];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLuint64 *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform2ui64vNV(GLuint program, GLint location, GLsizei count, const GLuint64 *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2120];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLuint64 *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform2uiEXT(GLuint program, GLint location, GLuint v0, GLuint v1)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2121];
   ((void (APIENTRY *)(GLuint program, GLint location, GLuint v0, GLuint v1)) _func)(program, location, v0, v1);
}

GLAPI void APIENTRY glProgramUniform2uiv(GLuint program, GLint location, GLsizei count, const GLuint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2122];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLuint *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform2uivEXT(GLuint program, GLint location, GLsizei count, const GLuint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2123];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLuint *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform3d(GLuint program, GLint location, GLdouble v0, GLdouble v1, GLdouble v2)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2124];
   ((void (APIENTRY *)(GLuint program, GLint location, GLdouble v0, GLdouble v1, GLdouble v2)) _func)(program, location, v0, v1, v2);
}

GLAPI void APIENTRY glProgramUniform3dEXT(GLuint program, GLint location, GLdouble x, GLdouble y, GLdouble z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2125];
   ((void (APIENTRY *)(GLuint program, GLint location, GLdouble x, GLdouble y, GLdouble z)) _func)(program, location, x, y, z);
}

GLAPI void APIENTRY glProgramUniform3dv(GLuint program, GLint location, GLsizei count, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2126];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLdouble *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform3dvEXT(GLuint program, GLint location, GLsizei count, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2127];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLdouble *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform3f(GLuint program, GLint location, GLfloat v0, GLfloat v1, GLfloat v2)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2128];
   ((void (APIENTRY *)(GLuint program, GLint location, GLfloat v0, GLfloat v1, GLfloat v2)) _func)(program, location, v0, v1, v2);
}

GLAPI void APIENTRY glProgramUniform3fEXT(GLuint program, GLint location, GLfloat v0, GLfloat v1, GLfloat v2)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2129];
   ((void (APIENTRY *)(GLuint program, GLint location, GLfloat v0, GLfloat v1, GLfloat v2)) _func)(program, location, v0, v1, v2);
}

GLAPI void APIENTRY glProgramUniform3fv(GLuint program, GLint location, GLsizei count, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2130];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLfloat *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform3fvEXT(GLuint program, GLint location, GLsizei count, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2131];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLfloat *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform3i(GLuint program, GLint location, GLint v0, GLint v1, GLint v2)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2132];
   ((void (APIENTRY *)(GLuint program, GLint location, GLint v0, GLint v1, GLint v2)) _func)(program, location, v0, v1, v2);
}

GLAPI void APIENTRY glProgramUniform3i64ARB(GLuint program, GLint location, GLint64 x, GLint64 y, GLint64 z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2133];
   ((void (APIENTRY *)(GLuint program, GLint location, GLint64 x, GLint64 y, GLint64 z)) _func)(program, location, x, y, z);
}

GLAPI void APIENTRY glProgramUniform3i64NV(GLuint program, GLint location, GLint64 x, GLint64 y, GLint64 z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2134];
   ((void (APIENTRY *)(GLuint program, GLint location, GLint64 x, GLint64 y, GLint64 z)) _func)(program, location, x, y, z);
}

GLAPI void APIENTRY glProgramUniform3i64vARB(GLuint program, GLint location, GLsizei count, const GLint64 *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2135];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLint64 *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform3i64vNV(GLuint program, GLint location, GLsizei count, const GLint64 *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2136];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLint64 *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform3iEXT(GLuint program, GLint location, GLint v0, GLint v1, GLint v2)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2137];
   ((void (APIENTRY *)(GLuint program, GLint location, GLint v0, GLint v1, GLint v2)) _func)(program, location, v0, v1, v2);
}

GLAPI void APIENTRY glProgramUniform3iv(GLuint program, GLint location, GLsizei count, const GLint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2138];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLint *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform3ivEXT(GLuint program, GLint location, GLsizei count, const GLint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2139];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLint *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform3ui(GLuint program, GLint location, GLuint v0, GLuint v1, GLuint v2)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2140];
   ((void (APIENTRY *)(GLuint program, GLint location, GLuint v0, GLuint v1, GLuint v2)) _func)(program, location, v0, v1, v2);
}

GLAPI void APIENTRY glProgramUniform3ui64ARB(GLuint program, GLint location, GLuint64 x, GLuint64 y, GLuint64 z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2141];
   ((void (APIENTRY *)(GLuint program, GLint location, GLuint64 x, GLuint64 y, GLuint64 z)) _func)(program, location, x, y, z);
}

GLAPI void APIENTRY glProgramUniform3ui64NV(GLuint program, GLint location, GLuint64 x, GLuint64 y, GLuint64 z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2142];
   ((void (APIENTRY *)(GLuint program, GLint location, GLuint64 x, GLuint64 y, GLuint64 z)) _func)(program, location, x, y, z);
}

GLAPI void APIENTRY glProgramUniform3ui64vARB(GLuint program, GLint location, GLsizei count, const GLuint64 *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2143];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLuint64 *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform3ui64vNV(GLuint program, GLint location, GLsizei count, const GLuint64 *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2144];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLuint64 *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform3uiEXT(GLuint program, GLint location, GLuint v0, GLuint v1, GLuint v2)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2145];
   ((void (APIENTRY *)(GLuint program, GLint location, GLuint v0, GLuint v1, GLuint v2)) _func)(program, location, v0, v1, v2);
}

GLAPI void APIENTRY glProgramUniform3uiv(GLuint program, GLint location, GLsizei count, const GLuint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2146];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLuint *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform3uivEXT(GLuint program, GLint location, GLsizei count, const GLuint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2147];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLuint *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform4d(GLuint program, GLint location, GLdouble v0, GLdouble v1, GLdouble v2, GLdouble v3)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2148];
   ((void (APIENTRY *)(GLuint program, GLint location, GLdouble v0, GLdouble v1, GLdouble v2, GLdouble v3)) _func)(program, location, v0, v1, v2, v3);
}

GLAPI void APIENTRY glProgramUniform4dEXT(GLuint program, GLint location, GLdouble x, GLdouble y, GLdouble z, GLdouble w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2149];
   ((void (APIENTRY *)(GLuint program, GLint location, GLdouble x, GLdouble y, GLdouble z, GLdouble w)) _func)(program, location, x, y, z, w);
}

GLAPI void APIENTRY glProgramUniform4dv(GLuint program, GLint location, GLsizei count, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2150];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLdouble *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform4dvEXT(GLuint program, GLint location, GLsizei count, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2151];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLdouble *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform4f(GLuint program, GLint location, GLfloat v0, GLfloat v1, GLfloat v2, GLfloat v3)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2152];
   ((void (APIENTRY *)(GLuint program, GLint location, GLfloat v0, GLfloat v1, GLfloat v2, GLfloat v3)) _func)(program, location, v0, v1, v2, v3);
}

GLAPI void APIENTRY glProgramUniform4fEXT(GLuint program, GLint location, GLfloat v0, GLfloat v1, GLfloat v2, GLfloat v3)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2153];
   ((void (APIENTRY *)(GLuint program, GLint location, GLfloat v0, GLfloat v1, GLfloat v2, GLfloat v3)) _func)(program, location, v0, v1, v2, v3);
}

GLAPI void APIENTRY glProgramUniform4fv(GLuint program, GLint location, GLsizei count, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2154];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLfloat *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform4fvEXT(GLuint program, GLint location, GLsizei count, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2155];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLfloat *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform4i(GLuint program, GLint location, GLint v0, GLint v1, GLint v2, GLint v3)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2156];
   ((void (APIENTRY *)(GLuint program, GLint location, GLint v0, GLint v1, GLint v2, GLint v3)) _func)(program, location, v0, v1, v2, v3);
}

GLAPI void APIENTRY glProgramUniform4i64ARB(GLuint program, GLint location, GLint64 x, GLint64 y, GLint64 z, GLint64 w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2157];
   ((void (APIENTRY *)(GLuint program, GLint location, GLint64 x, GLint64 y, GLint64 z, GLint64 w)) _func)(program, location, x, y, z, w);
}

GLAPI void APIENTRY glProgramUniform4i64NV(GLuint program, GLint location, GLint64 x, GLint64 y, GLint64 z, GLint64 w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2158];
   ((void (APIENTRY *)(GLuint program, GLint location, GLint64 x, GLint64 y, GLint64 z, GLint64 w)) _func)(program, location, x, y, z, w);
}

GLAPI void APIENTRY glProgramUniform4i64vARB(GLuint program, GLint location, GLsizei count, const GLint64 *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2159];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLint64 *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform4i64vNV(GLuint program, GLint location, GLsizei count, const GLint64 *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2160];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLint64 *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform4iEXT(GLuint program, GLint location, GLint v0, GLint v1, GLint v2, GLint v3)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2161];
   ((void (APIENTRY *)(GLuint program, GLint location, GLint v0, GLint v1, GLint v2, GLint v3)) _func)(program, location, v0, v1, v2, v3);
}

GLAPI void APIENTRY glProgramUniform4iv(GLuint program, GLint location, GLsizei count, const GLint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2162];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLint *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform4ivEXT(GLuint program, GLint location, GLsizei count, const GLint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2163];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLint *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform4ui(GLuint program, GLint location, GLuint v0, GLuint v1, GLuint v2, GLuint v3)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2164];
   ((void (APIENTRY *)(GLuint program, GLint location, GLuint v0, GLuint v1, GLuint v2, GLuint v3)) _func)(program, location, v0, v1, v2, v3);
}

GLAPI void APIENTRY glProgramUniform4ui64ARB(GLuint program, GLint location, GLuint64 x, GLuint64 y, GLuint64 z, GLuint64 w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2165];
   ((void (APIENTRY *)(GLuint program, GLint location, GLuint64 x, GLuint64 y, GLuint64 z, GLuint64 w)) _func)(program, location, x, y, z, w);
}

GLAPI void APIENTRY glProgramUniform4ui64NV(GLuint program, GLint location, GLuint64 x, GLuint64 y, GLuint64 z, GLuint64 w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2166];
   ((void (APIENTRY *)(GLuint program, GLint location, GLuint64 x, GLuint64 y, GLuint64 z, GLuint64 w)) _func)(program, location, x, y, z, w);
}

GLAPI void APIENTRY glProgramUniform4ui64vARB(GLuint program, GLint location, GLsizei count, const GLuint64 *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2167];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLuint64 *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform4ui64vNV(GLuint program, GLint location, GLsizei count, const GLuint64 *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2168];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLuint64 *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform4uiEXT(GLuint program, GLint location, GLuint v0, GLuint v1, GLuint v2, GLuint v3)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2169];
   ((void (APIENTRY *)(GLuint program, GLint location, GLuint v0, GLuint v1, GLuint v2, GLuint v3)) _func)(program, location, v0, v1, v2, v3);
}

GLAPI void APIENTRY glProgramUniform4uiv(GLuint program, GLint location, GLsizei count, const GLuint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2170];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLuint *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniform4uivEXT(GLuint program, GLint location, GLsizei count, const GLuint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2171];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLuint *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramUniformHandleui64ARB(GLuint program, GLint location, GLuint64 value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2172];
   ((void (APIENTRY *)(GLuint program, GLint location, GLuint64 value)) _func)(program, location, value);
}

GLAPI void APIENTRY glProgramUniformHandleui64IMG(GLuint program, GLint location, GLuint64 value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2173];
   ((void (APIENTRY *)(GLuint program, GLint location, GLuint64 value)) _func)(program, location, value);
}

GLAPI void APIENTRY glProgramUniformHandleui64NV(GLuint program, GLint location, GLuint64 value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2174];
   ((void (APIENTRY *)(GLuint program, GLint location, GLuint64 value)) _func)(program, location, value);
}

GLAPI void APIENTRY glProgramUniformHandleui64vARB(GLuint program, GLint location, GLsizei count, const GLuint64 *values)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2175];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLuint64 *values)) _func)(program, location, count, values);
}

GLAPI void APIENTRY glProgramUniformHandleui64vIMG(GLuint program, GLint location, GLsizei count, const GLuint64 *values)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2176];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLuint64 *values)) _func)(program, location, count, values);
}

GLAPI void APIENTRY glProgramUniformHandleui64vNV(GLuint program, GLint location, GLsizei count, const GLuint64 *values)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2177];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLuint64 *values)) _func)(program, location, count, values);
}

GLAPI void APIENTRY glProgramUniformMatrix2dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2178];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)) _func)(program, location, count, transpose, value);
}

GLAPI void APIENTRY glProgramUniformMatrix2dvEXT(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2179];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)) _func)(program, location, count, transpose, value);
}

GLAPI void APIENTRY glProgramUniformMatrix2fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2180];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)) _func)(program, location, count, transpose, value);
}

GLAPI void APIENTRY glProgramUniformMatrix2fvEXT(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2181];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)) _func)(program, location, count, transpose, value);
}

GLAPI void APIENTRY glProgramUniformMatrix2x3dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2182];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)) _func)(program, location, count, transpose, value);
}

GLAPI void APIENTRY glProgramUniformMatrix2x3dvEXT(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2183];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)) _func)(program, location, count, transpose, value);
}

GLAPI void APIENTRY glProgramUniformMatrix2x3fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2184];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)) _func)(program, location, count, transpose, value);
}

GLAPI void APIENTRY glProgramUniformMatrix2x3fvEXT(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2185];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)) _func)(program, location, count, transpose, value);
}

GLAPI void APIENTRY glProgramUniformMatrix2x4dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2186];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)) _func)(program, location, count, transpose, value);
}

GLAPI void APIENTRY glProgramUniformMatrix2x4dvEXT(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2187];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)) _func)(program, location, count, transpose, value);
}

GLAPI void APIENTRY glProgramUniformMatrix2x4fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2188];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)) _func)(program, location, count, transpose, value);
}

GLAPI void APIENTRY glProgramUniformMatrix2x4fvEXT(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2189];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)) _func)(program, location, count, transpose, value);
}

GLAPI void APIENTRY glProgramUniformMatrix3dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2190];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)) _func)(program, location, count, transpose, value);
}

GLAPI void APIENTRY glProgramUniformMatrix3dvEXT(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2191];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)) _func)(program, location, count, transpose, value);
}

GLAPI void APIENTRY glProgramUniformMatrix3fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2192];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)) _func)(program, location, count, transpose, value);
}

GLAPI void APIENTRY glProgramUniformMatrix3fvEXT(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2193];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)) _func)(program, location, count, transpose, value);
}

GLAPI void APIENTRY glProgramUniformMatrix3x2dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2194];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)) _func)(program, location, count, transpose, value);
}

GLAPI void APIENTRY glProgramUniformMatrix3x2dvEXT(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2195];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)) _func)(program, location, count, transpose, value);
}

GLAPI void APIENTRY glProgramUniformMatrix3x2fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2196];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)) _func)(program, location, count, transpose, value);
}

GLAPI void APIENTRY glProgramUniformMatrix3x2fvEXT(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2197];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)) _func)(program, location, count, transpose, value);
}

GLAPI void APIENTRY glProgramUniformMatrix3x4dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2198];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)) _func)(program, location, count, transpose, value);
}

GLAPI void APIENTRY glProgramUniformMatrix3x4dvEXT(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2199];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)) _func)(program, location, count, transpose, value);
}

GLAPI void APIENTRY glProgramUniformMatrix3x4fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2200];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)) _func)(program, location, count, transpose, value);
}

GLAPI void APIENTRY glProgramUniformMatrix3x4fvEXT(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2201];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)) _func)(program, location, count, transpose, value);
}

GLAPI void APIENTRY glProgramUniformMatrix4dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2202];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)) _func)(program, location, count, transpose, value);
}

GLAPI void APIENTRY glProgramUniformMatrix4dvEXT(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2203];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)) _func)(program, location, count, transpose, value);
}

GLAPI void APIENTRY glProgramUniformMatrix4fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2204];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)) _func)(program, location, count, transpose, value);
}

GLAPI void APIENTRY glProgramUniformMatrix4fvEXT(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2205];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)) _func)(program, location, count, transpose, value);
}

GLAPI void APIENTRY glProgramUniformMatrix4x2dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2206];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)) _func)(program, location, count, transpose, value);
}

GLAPI void APIENTRY glProgramUniformMatrix4x2dvEXT(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2207];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)) _func)(program, location, count, transpose, value);
}

GLAPI void APIENTRY glProgramUniformMatrix4x2fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2208];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)) _func)(program, location, count, transpose, value);
}

GLAPI void APIENTRY glProgramUniformMatrix4x2fvEXT(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2209];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)) _func)(program, location, count, transpose, value);
}

GLAPI void APIENTRY glProgramUniformMatrix4x3dv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2210];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)) _func)(program, location, count, transpose, value);
}

GLAPI void APIENTRY glProgramUniformMatrix4x3dvEXT(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2211];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)) _func)(program, location, count, transpose, value);
}

GLAPI void APIENTRY glProgramUniformMatrix4x3fv(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2212];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)) _func)(program, location, count, transpose, value);
}

GLAPI void APIENTRY glProgramUniformMatrix4x3fvEXT(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2213];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)) _func)(program, location, count, transpose, value);
}

GLAPI void APIENTRY glProgramUniformui64NV(GLuint program, GLint location, GLuint64 value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2214];
   ((void (APIENTRY *)(GLuint program, GLint location, GLuint64 value)) _func)(program, location, value);
}

GLAPI void APIENTRY glProgramUniformui64vNV(GLuint program, GLint location, GLsizei count, const GLuint64 *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2215];
   ((void (APIENTRY *)(GLuint program, GLint location, GLsizei count, const GLuint64 *value)) _func)(program, location, count, value);
}

GLAPI void APIENTRY glProgramVertexLimitNV(GLenum target, GLint limit)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2216];
   ((void (APIENTRY *)(GLenum target, GLint limit)) _func)(target, limit);
}

GLAPI void APIENTRY glProvokingVertex(GLenum mode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2217];
   ((void (APIENTRY *)(GLenum mode)) _func)(mode);
}

GLAPI void APIENTRY glProvokingVertexEXT(GLenum mode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2218];
   ((void (APIENTRY *)(GLenum mode)) _func)(mode);
}

GLAPI void APIENTRY glPushAttrib(GLbitfield mask)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2219];
   ((void (APIENTRY *)(GLbitfield mask)) _func)(mask);
}

GLAPI void APIENTRY glPushClientAttrib(GLbitfield mask)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2220];
   ((void (APIENTRY *)(GLbitfield mask)) _func)(mask);
}

GLAPI void APIENTRY glPushClientAttribDefaultEXT(GLbitfield mask)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2221];
   ((void (APIENTRY *)(GLbitfield mask)) _func)(mask);
}

GLAPI void APIENTRY glPushDebugGroup(GLenum source, GLuint id, GLsizei length, const GLchar *message)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2222];
   ((void (APIENTRY *)(GLenum source, GLuint id, GLsizei length, const GLchar *message)) _func)(source, id, length, message);
}

GLAPI void APIENTRY glPushDebugGroupKHR(GLenum source, GLuint id, GLsizei length, const GLchar *message)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2223];
   ((void (APIENTRY *)(GLenum source, GLuint id, GLsizei length, const GLchar *message)) _func)(source, id, length, message);
}

GLAPI void APIENTRY glPushDebugGroupOES(GLenum source, GLuint id, GLsizei length, const GLchar *message)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2224];
   ((void (APIENTRY *)(GLenum source, GLuint id, GLsizei length, const GLchar *message)) _func)(source, id, length, message);
}

GLAPI void APIENTRY glPushGroupMarkerEXT(GLsizei length, const GLchar *marker)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2225];
   ((void (APIENTRY *)(GLsizei length, const GLchar *marker)) _func)(length, marker);
}

GLAPI void APIENTRY glPushMatrix(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2226];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glPushName(GLuint name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2227];
   ((void (APIENTRY *)(GLuint name)) _func)(name);
}

GLAPI void APIENTRY glQueryCounter(GLuint id, GLenum target)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2228];
   ((void (APIENTRY *)(GLuint id, GLenum target)) _func)(id, target);
}

GLAPI void APIENTRY glQueryCounterEXT(GLuint id, GLenum target)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2229];
   ((void (APIENTRY *)(GLuint id, GLenum target)) _func)(id, target);
}

GLAPI void APIENTRY glQueryCounterNV(GLuint id, GLenum target)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2230];
   ((void (APIENTRY *)(GLuint id, GLenum target)) _func)(id, target);
}

GLAPI GLbitfield APIENTRY glQueryMatrixxOES(GLfixed *mantissa, GLint *exponent)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2231];
   return ((GLbitfield (APIENTRY *)(GLfixed *mantissa, GLint *exponent)) _func)(mantissa, exponent);
}

GLAPI void APIENTRY glQueryObjectParameteruiAMD(GLenum target, GLuint id, GLenum pname, GLuint param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2232];
   ((void (APIENTRY *)(GLenum target, GLuint id, GLenum pname, GLuint param)) _func)(target, id, pname, param);
}

GLAPI GLint APIENTRY glQueryResourceNV(GLenum queryType, GLint tagId, GLuint count, GLint *buffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2233];
   return ((GLint (APIENTRY *)(GLenum queryType, GLint tagId, GLuint count, GLint *buffer)) _func)(queryType, tagId, count, buffer);
}

GLAPI void APIENTRY glQueryResourceTagNV(GLint tagId, const GLchar *tagString)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2234];
   ((void (APIENTRY *)(GLint tagId, const GLchar *tagString)) _func)(tagId, tagString);
}

GLAPI void APIENTRY glRasterPos2d(GLdouble x, GLdouble y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2235];
   ((void (APIENTRY *)(GLdouble x, GLdouble y)) _func)(x, y);
}

GLAPI void APIENTRY glRasterPos2dv(const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2236];
   ((void (APIENTRY *)(const GLdouble *v)) _func)(v);
}

GLAPI void APIENTRY glRasterPos2f(GLfloat x, GLfloat y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2237];
   ((void (APIENTRY *)(GLfloat x, GLfloat y)) _func)(x, y);
}

GLAPI void APIENTRY glRasterPos2fv(const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2238];
   ((void (APIENTRY *)(const GLfloat *v)) _func)(v);
}

GLAPI void APIENTRY glRasterPos2i(GLint x, GLint y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2239];
   ((void (APIENTRY *)(GLint x, GLint y)) _func)(x, y);
}

GLAPI void APIENTRY glRasterPos2iv(const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2240];
   ((void (APIENTRY *)(const GLint *v)) _func)(v);
}

GLAPI void APIENTRY glRasterPos2s(GLshort x, GLshort y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2241];
   ((void (APIENTRY *)(GLshort x, GLshort y)) _func)(x, y);
}

GLAPI void APIENTRY glRasterPos2sv(const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2242];
   ((void (APIENTRY *)(const GLshort *v)) _func)(v);
}

GLAPI void APIENTRY glRasterPos2xOES(GLfixed x, GLfixed y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2243];
   ((void (APIENTRY *)(GLfixed x, GLfixed y)) _func)(x, y);
}

GLAPI void APIENTRY glRasterPos2xvOES(const GLfixed *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2244];
   ((void (APIENTRY *)(const GLfixed *coords)) _func)(coords);
}

GLAPI void APIENTRY glRasterPos3d(GLdouble x, GLdouble y, GLdouble z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2245];
   ((void (APIENTRY *)(GLdouble x, GLdouble y, GLdouble z)) _func)(x, y, z);
}

GLAPI void APIENTRY glRasterPos3dv(const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2246];
   ((void (APIENTRY *)(const GLdouble *v)) _func)(v);
}

GLAPI void APIENTRY glRasterPos3f(GLfloat x, GLfloat y, GLfloat z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2247];
   ((void (APIENTRY *)(GLfloat x, GLfloat y, GLfloat z)) _func)(x, y, z);
}

GLAPI void APIENTRY glRasterPos3fv(const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2248];
   ((void (APIENTRY *)(const GLfloat *v)) _func)(v);
}

GLAPI void APIENTRY glRasterPos3i(GLint x, GLint y, GLint z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2249];
   ((void (APIENTRY *)(GLint x, GLint y, GLint z)) _func)(x, y, z);
}

GLAPI void APIENTRY glRasterPos3iv(const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2250];
   ((void (APIENTRY *)(const GLint *v)) _func)(v);
}

GLAPI void APIENTRY glRasterPos3s(GLshort x, GLshort y, GLshort z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2251];
   ((void (APIENTRY *)(GLshort x, GLshort y, GLshort z)) _func)(x, y, z);
}

GLAPI void APIENTRY glRasterPos3sv(const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2252];
   ((void (APIENTRY *)(const GLshort *v)) _func)(v);
}

GLAPI void APIENTRY glRasterPos3xOES(GLfixed x, GLfixed y, GLfixed z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2253];
   ((void (APIENTRY *)(GLfixed x, GLfixed y, GLfixed z)) _func)(x, y, z);
}

GLAPI void APIENTRY glRasterPos3xvOES(const GLfixed *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2254];
   ((void (APIENTRY *)(const GLfixed *coords)) _func)(coords);
}

GLAPI void APIENTRY glRasterPos4d(GLdouble x, GLdouble y, GLdouble z, GLdouble w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2255];
   ((void (APIENTRY *)(GLdouble x, GLdouble y, GLdouble z, GLdouble w)) _func)(x, y, z, w);
}

GLAPI void APIENTRY glRasterPos4dv(const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2256];
   ((void (APIENTRY *)(const GLdouble *v)) _func)(v);
}

GLAPI void APIENTRY glRasterPos4f(GLfloat x, GLfloat y, GLfloat z, GLfloat w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2257];
   ((void (APIENTRY *)(GLfloat x, GLfloat y, GLfloat z, GLfloat w)) _func)(x, y, z, w);
}

GLAPI void APIENTRY glRasterPos4fv(const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2258];
   ((void (APIENTRY *)(const GLfloat *v)) _func)(v);
}

GLAPI void APIENTRY glRasterPos4i(GLint x, GLint y, GLint z, GLint w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2259];
   ((void (APIENTRY *)(GLint x, GLint y, GLint z, GLint w)) _func)(x, y, z, w);
}

GLAPI void APIENTRY glRasterPos4iv(const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2260];
   ((void (APIENTRY *)(const GLint *v)) _func)(v);
}

GLAPI void APIENTRY glRasterPos4s(GLshort x, GLshort y, GLshort z, GLshort w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2261];
   ((void (APIENTRY *)(GLshort x, GLshort y, GLshort z, GLshort w)) _func)(x, y, z, w);
}

GLAPI void APIENTRY glRasterPos4sv(const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2262];
   ((void (APIENTRY *)(const GLshort *v)) _func)(v);
}

GLAPI void APIENTRY glRasterPos4xOES(GLfixed x, GLfixed y, GLfixed z, GLfixed w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2263];
   ((void (APIENTRY *)(GLfixed x, GLfixed y, GLfixed z, GLfixed w)) _func)(x, y, z, w);
}

GLAPI void APIENTRY glRasterPos4xvOES(const GLfixed *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2264];
   ((void (APIENTRY *)(const GLfixed *coords)) _func)(coords);
}

GLAPI void APIENTRY glRasterSamplesEXT(GLuint samples, GLboolean fixedsamplelocations)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2265];
   ((void (APIENTRY *)(GLuint samples, GLboolean fixedsamplelocations)) _func)(samples, fixedsamplelocations);
}

GLAPI void APIENTRY glReadBuffer(GLenum src)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2266];
   ((void (APIENTRY *)(GLenum src)) _func)(src);
}

GLAPI void APIENTRY glReadBufferIndexedEXT(GLenum src, GLint index)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2267];
   ((void (APIENTRY *)(GLenum src, GLint index)) _func)(src, index);
}

GLAPI void APIENTRY glReadBufferNV(GLenum mode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2268];
   ((void (APIENTRY *)(GLenum mode)) _func)(mode);
}

GLAPI void APIENTRY glReadInstrumentsSGIX(GLint marker)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2269];
   ((void (APIENTRY *)(GLint marker)) _func)(marker);
}

GLAPI void APIENTRY glReadPixels(GLint x, GLint y, GLsizei width, GLsizei height, GLenum format, GLenum type, void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2270];
   ((void (APIENTRY *)(GLint x, GLint y, GLsizei width, GLsizei height, GLenum format, GLenum type, void *pixels)) _func)(x, y, width, height, format, type, pixels);
}

GLAPI void APIENTRY glReadnPixels(GLint x, GLint y, GLsizei width, GLsizei height, GLenum format, GLenum type, GLsizei bufSize, void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2271];
   ((void (APIENTRY *)(GLint x, GLint y, GLsizei width, GLsizei height, GLenum format, GLenum type, GLsizei bufSize, void *data)) _func)(x, y, width, height, format, type, bufSize, data);
}

GLAPI void APIENTRY glReadnPixelsARB(GLint x, GLint y, GLsizei width, GLsizei height, GLenum format, GLenum type, GLsizei bufSize, void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2272];
   ((void (APIENTRY *)(GLint x, GLint y, GLsizei width, GLsizei height, GLenum format, GLenum type, GLsizei bufSize, void *data)) _func)(x, y, width, height, format, type, bufSize, data);
}

GLAPI void APIENTRY glReadnPixelsEXT(GLint x, GLint y, GLsizei width, GLsizei height, GLenum format, GLenum type, GLsizei bufSize, void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2273];
   ((void (APIENTRY *)(GLint x, GLint y, GLsizei width, GLsizei height, GLenum format, GLenum type, GLsizei bufSize, void *data)) _func)(x, y, width, height, format, type, bufSize, data);
}

GLAPI void APIENTRY glReadnPixelsKHR(GLint x, GLint y, GLsizei width, GLsizei height, GLenum format, GLenum type, GLsizei bufSize, void *data)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2274];
   ((void (APIENTRY *)(GLint x, GLint y, GLsizei width, GLsizei height, GLenum format, GLenum type, GLsizei bufSize, void *data)) _func)(x, y, width, height, format, type, bufSize, data);
}

GLAPI void APIENTRY glRectd(GLdouble x1, GLdouble y1, GLdouble x2, GLdouble y2)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2275];
   ((void (APIENTRY *)(GLdouble x1, GLdouble y1, GLdouble x2, GLdouble y2)) _func)(x1, y1, x2, y2);
}

GLAPI void APIENTRY glRectdv(const GLdouble *v1, const GLdouble *v2)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2276];
   ((void (APIENTRY *)(const GLdouble *v1, const GLdouble *v2)) _func)(v1, v2);
}

GLAPI void APIENTRY glRectf(GLfloat x1, GLfloat y1, GLfloat x2, GLfloat y2)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2277];
   ((void (APIENTRY *)(GLfloat x1, GLfloat y1, GLfloat x2, GLfloat y2)) _func)(x1, y1, x2, y2);
}

GLAPI void APIENTRY glRectfv(const GLfloat *v1, const GLfloat *v2)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2278];
   ((void (APIENTRY *)(const GLfloat *v1, const GLfloat *v2)) _func)(v1, v2);
}

GLAPI void APIENTRY glRecti(GLint x1, GLint y1, GLint x2, GLint y2)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2279];
   ((void (APIENTRY *)(GLint x1, GLint y1, GLint x2, GLint y2)) _func)(x1, y1, x2, y2);
}

GLAPI void APIENTRY glRectiv(const GLint *v1, const GLint *v2)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2280];
   ((void (APIENTRY *)(const GLint *v1, const GLint *v2)) _func)(v1, v2);
}

GLAPI void APIENTRY glRects(GLshort x1, GLshort y1, GLshort x2, GLshort y2)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2281];
   ((void (APIENTRY *)(GLshort x1, GLshort y1, GLshort x2, GLshort y2)) _func)(x1, y1, x2, y2);
}

GLAPI void APIENTRY glRectsv(const GLshort *v1, const GLshort *v2)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2282];
   ((void (APIENTRY *)(const GLshort *v1, const GLshort *v2)) _func)(v1, v2);
}

GLAPI void APIENTRY glRectxOES(GLfixed x1, GLfixed y1, GLfixed x2, GLfixed y2)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2283];
   ((void (APIENTRY *)(GLfixed x1, GLfixed y1, GLfixed x2, GLfixed y2)) _func)(x1, y1, x2, y2);
}

GLAPI void APIENTRY glRectxvOES(const GLfixed *v1, const GLfixed *v2)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2284];
   ((void (APIENTRY *)(const GLfixed *v1, const GLfixed *v2)) _func)(v1, v2);
}

GLAPI void APIENTRY glReferencePlaneSGIX(const GLdouble *equation)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2285];
   ((void (APIENTRY *)(const GLdouble *equation)) _func)(equation);
}

GLAPI GLboolean APIENTRY glReleaseKeyedMutexWin32EXT(GLuint memory, GLuint64 key)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2286];
   return ((GLboolean (APIENTRY *)(GLuint memory, GLuint64 key)) _func)(memory, key);
}

GLAPI void APIENTRY glReleaseShaderCompiler(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2287];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glRenderGpuMaskNV(GLbitfield mask)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2288];
   ((void (APIENTRY *)(GLbitfield mask)) _func)(mask);
}

GLAPI GLint APIENTRY glRenderMode(GLenum mode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2289];
   return ((GLint (APIENTRY *)(GLenum mode)) _func)(mode);
}

GLAPI void APIENTRY glRenderbufferStorage(GLenum target, GLenum internalformat, GLsizei width, GLsizei height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2290];
   ((void (APIENTRY *)(GLenum target, GLenum internalformat, GLsizei width, GLsizei height)) _func)(target, internalformat, width, height);
}

GLAPI void APIENTRY glRenderbufferStorageEXT(GLenum target, GLenum internalformat, GLsizei width, GLsizei height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2291];
   ((void (APIENTRY *)(GLenum target, GLenum internalformat, GLsizei width, GLsizei height)) _func)(target, internalformat, width, height);
}

GLAPI void APIENTRY glRenderbufferStorageMultisample(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2292];
   ((void (APIENTRY *)(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height)) _func)(target, samples, internalformat, width, height);
}

GLAPI void APIENTRY glRenderbufferStorageMultisampleANGLE(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2293];
   ((void (APIENTRY *)(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height)) _func)(target, samples, internalformat, width, height);
}

GLAPI void APIENTRY glRenderbufferStorageMultisampleAPPLE(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2294];
   ((void (APIENTRY *)(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height)) _func)(target, samples, internalformat, width, height);
}

GLAPI void APIENTRY glRenderbufferStorageMultisampleAdvancedAMD(GLenum target, GLsizei samples, GLsizei storageSamples, GLenum internalformat, GLsizei width, GLsizei height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2295];
   ((void (APIENTRY *)(GLenum target, GLsizei samples, GLsizei storageSamples, GLenum internalformat, GLsizei width, GLsizei height)) _func)(target, samples, storageSamples, internalformat, width, height);
}

GLAPI void APIENTRY glRenderbufferStorageMultisampleCoverageNV(GLenum target, GLsizei coverageSamples, GLsizei colorSamples, GLenum internalformat, GLsizei width, GLsizei height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2296];
   ((void (APIENTRY *)(GLenum target, GLsizei coverageSamples, GLsizei colorSamples, GLenum internalformat, GLsizei width, GLsizei height)) _func)(target, coverageSamples, colorSamples, internalformat, width, height);
}

GLAPI void APIENTRY glRenderbufferStorageMultisampleEXT(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2297];
   ((void (APIENTRY *)(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height)) _func)(target, samples, internalformat, width, height);
}

GLAPI void APIENTRY glRenderbufferStorageMultisampleIMG(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2298];
   ((void (APIENTRY *)(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height)) _func)(target, samples, internalformat, width, height);
}

GLAPI void APIENTRY glRenderbufferStorageMultisampleNV(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2299];
   ((void (APIENTRY *)(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height)) _func)(target, samples, internalformat, width, height);
}

GLAPI void APIENTRY glRenderbufferStorageOES(GLenum target, GLenum internalformat, GLsizei width, GLsizei height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2300];
   ((void (APIENTRY *)(GLenum target, GLenum internalformat, GLsizei width, GLsizei height)) _func)(target, internalformat, width, height);
}

GLAPI void APIENTRY glReplacementCodePointerSUN(GLenum type, GLsizei stride, const void **pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2301];
   ((void (APIENTRY *)(GLenum type, GLsizei stride, const void **pointer)) _func)(type, stride, pointer);
}

GLAPI void APIENTRY glReplacementCodeubSUN(GLubyte code)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2302];
   ((void (APIENTRY *)(GLubyte code)) _func)(code);
}

GLAPI void APIENTRY glReplacementCodeubvSUN(const GLubyte *code)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2303];
   ((void (APIENTRY *)(const GLubyte *code)) _func)(code);
}

GLAPI void APIENTRY glReplacementCodeuiColor3fVertex3fSUN(GLuint rc, GLfloat r, GLfloat g, GLfloat b, GLfloat x, GLfloat y, GLfloat z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2304];
   ((void (APIENTRY *)(GLuint rc, GLfloat r, GLfloat g, GLfloat b, GLfloat x, GLfloat y, GLfloat z)) _func)(rc, r, g, b, x, y, z);
}

GLAPI void APIENTRY glReplacementCodeuiColor3fVertex3fvSUN(const GLuint *rc, const GLfloat *c, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2305];
   ((void (APIENTRY *)(const GLuint *rc, const GLfloat *c, const GLfloat *v)) _func)(rc, c, v);
}

GLAPI void APIENTRY glReplacementCodeuiColor4fNormal3fVertex3fSUN(GLuint rc, GLfloat r, GLfloat g, GLfloat b, GLfloat a, GLfloat nx, GLfloat ny, GLfloat nz, GLfloat x, GLfloat y, GLfloat z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2306];
   ((void (APIENTRY *)(GLuint rc, GLfloat r, GLfloat g, GLfloat b, GLfloat a, GLfloat nx, GLfloat ny, GLfloat nz, GLfloat x, GLfloat y, GLfloat z)) _func)(rc, r, g, b, a, nx, ny, nz, x, y, z);
}

GLAPI void APIENTRY glReplacementCodeuiColor4fNormal3fVertex3fvSUN(const GLuint *rc, const GLfloat *c, const GLfloat *n, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2307];
   ((void (APIENTRY *)(const GLuint *rc, const GLfloat *c, const GLfloat *n, const GLfloat *v)) _func)(rc, c, n, v);
}

GLAPI void APIENTRY glReplacementCodeuiColor4ubVertex3fSUN(GLuint rc, GLubyte r, GLubyte g, GLubyte b, GLubyte a, GLfloat x, GLfloat y, GLfloat z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2308];
   ((void (APIENTRY *)(GLuint rc, GLubyte r, GLubyte g, GLubyte b, GLubyte a, GLfloat x, GLfloat y, GLfloat z)) _func)(rc, r, g, b, a, x, y, z);
}

GLAPI void APIENTRY glReplacementCodeuiColor4ubVertex3fvSUN(const GLuint *rc, const GLubyte *c, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2309];
   ((void (APIENTRY *)(const GLuint *rc, const GLubyte *c, const GLfloat *v)) _func)(rc, c, v);
}

GLAPI void APIENTRY glReplacementCodeuiNormal3fVertex3fSUN(GLuint rc, GLfloat nx, GLfloat ny, GLfloat nz, GLfloat x, GLfloat y, GLfloat z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2310];
   ((void (APIENTRY *)(GLuint rc, GLfloat nx, GLfloat ny, GLfloat nz, GLfloat x, GLfloat y, GLfloat z)) _func)(rc, nx, ny, nz, x, y, z);
}

GLAPI void APIENTRY glReplacementCodeuiNormal3fVertex3fvSUN(const GLuint *rc, const GLfloat *n, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2311];
   ((void (APIENTRY *)(const GLuint *rc, const GLfloat *n, const GLfloat *v)) _func)(rc, n, v);
}

GLAPI void APIENTRY glReplacementCodeuiSUN(GLuint code)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2312];
   ((void (APIENTRY *)(GLuint code)) _func)(code);
}

GLAPI void APIENTRY glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fSUN(GLuint rc, GLfloat s, GLfloat t, GLfloat r, GLfloat g, GLfloat b, GLfloat a, GLfloat nx, GLfloat ny, GLfloat nz, GLfloat x, GLfloat y, GLfloat z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2313];
   ((void (APIENTRY *)(GLuint rc, GLfloat s, GLfloat t, GLfloat r, GLfloat g, GLfloat b, GLfloat a, GLfloat nx, GLfloat ny, GLfloat nz, GLfloat x, GLfloat y, GLfloat z)) _func)(rc, s, t, r, g, b, a, nx, ny, nz, x, y, z);
}

GLAPI void APIENTRY glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fvSUN(const GLuint *rc, const GLfloat *tc, const GLfloat *c, const GLfloat *n, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2314];
   ((void (APIENTRY *)(const GLuint *rc, const GLfloat *tc, const GLfloat *c, const GLfloat *n, const GLfloat *v)) _func)(rc, tc, c, n, v);
}

GLAPI void APIENTRY glReplacementCodeuiTexCoord2fNormal3fVertex3fSUN(GLuint rc, GLfloat s, GLfloat t, GLfloat nx, GLfloat ny, GLfloat nz, GLfloat x, GLfloat y, GLfloat z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2315];
   ((void (APIENTRY *)(GLuint rc, GLfloat s, GLfloat t, GLfloat nx, GLfloat ny, GLfloat nz, GLfloat x, GLfloat y, GLfloat z)) _func)(rc, s, t, nx, ny, nz, x, y, z);
}

GLAPI void APIENTRY glReplacementCodeuiTexCoord2fNormal3fVertex3fvSUN(const GLuint *rc, const GLfloat *tc, const GLfloat *n, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2316];
   ((void (APIENTRY *)(const GLuint *rc, const GLfloat *tc, const GLfloat *n, const GLfloat *v)) _func)(rc, tc, n, v);
}

GLAPI void APIENTRY glReplacementCodeuiTexCoord2fVertex3fSUN(GLuint rc, GLfloat s, GLfloat t, GLfloat x, GLfloat y, GLfloat z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2317];
   ((void (APIENTRY *)(GLuint rc, GLfloat s, GLfloat t, GLfloat x, GLfloat y, GLfloat z)) _func)(rc, s, t, x, y, z);
}

GLAPI void APIENTRY glReplacementCodeuiTexCoord2fVertex3fvSUN(const GLuint *rc, const GLfloat *tc, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2318];
   ((void (APIENTRY *)(const GLuint *rc, const GLfloat *tc, const GLfloat *v)) _func)(rc, tc, v);
}

GLAPI void APIENTRY glReplacementCodeuiVertex3fSUN(GLuint rc, GLfloat x, GLfloat y, GLfloat z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2319];
   ((void (APIENTRY *)(GLuint rc, GLfloat x, GLfloat y, GLfloat z)) _func)(rc, x, y, z);
}

GLAPI void APIENTRY glReplacementCodeuiVertex3fvSUN(const GLuint *rc, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2320];
   ((void (APIENTRY *)(const GLuint *rc, const GLfloat *v)) _func)(rc, v);
}

GLAPI void APIENTRY glReplacementCodeuivSUN(const GLuint *code)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2321];
   ((void (APIENTRY *)(const GLuint *code)) _func)(code);
}

GLAPI void APIENTRY glReplacementCodeusSUN(GLushort code)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2322];
   ((void (APIENTRY *)(GLushort code)) _func)(code);
}

GLAPI void APIENTRY glReplacementCodeusvSUN(const GLushort *code)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2323];
   ((void (APIENTRY *)(const GLushort *code)) _func)(code);
}

GLAPI void APIENTRY glRequestResidentProgramsNV(GLsizei n, const GLuint *programs)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2324];
   ((void (APIENTRY *)(GLsizei n, const GLuint *programs)) _func)(n, programs);
}

GLAPI void APIENTRY glResetHistogram(GLenum target)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2325];
   ((void (APIENTRY *)(GLenum target)) _func)(target);
}

GLAPI void APIENTRY glResetHistogramEXT(GLenum target)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2326];
   ((void (APIENTRY *)(GLenum target)) _func)(target);
}

GLAPI void APIENTRY glResetMemoryObjectParameterNV(GLuint memory, GLenum pname)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2327];
   ((void (APIENTRY *)(GLuint memory, GLenum pname)) _func)(memory, pname);
}

GLAPI void APIENTRY glResetMinmax(GLenum target)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2328];
   ((void (APIENTRY *)(GLenum target)) _func)(target);
}

GLAPI void APIENTRY glResetMinmaxEXT(GLenum target)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2329];
   ((void (APIENTRY *)(GLenum target)) _func)(target);
}

GLAPI void APIENTRY glResizeBuffersMESA(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2330];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glResolveDepthValuesNV(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2331];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glResolveMultisampleFramebufferAPPLE(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2332];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glResumeTransformFeedback(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2333];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glResumeTransformFeedbackEXT(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2334];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glResumeTransformFeedbackNV(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2335];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glRotated(GLdouble angle, GLdouble x, GLdouble y, GLdouble z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2336];
   ((void (APIENTRY *)(GLdouble angle, GLdouble x, GLdouble y, GLdouble z)) _func)(angle, x, y, z);
}

GLAPI void APIENTRY glRotatef(GLfloat angle, GLfloat x, GLfloat y, GLfloat z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2337];
   ((void (APIENTRY *)(GLfloat angle, GLfloat x, GLfloat y, GLfloat z)) _func)(angle, x, y, z);
}

GLAPI void APIENTRY glRotatex(GLfixed angle, GLfixed x, GLfixed y, GLfixed z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2338];
   ((void (APIENTRY *)(GLfixed angle, GLfixed x, GLfixed y, GLfixed z)) _func)(angle, x, y, z);
}

GLAPI void APIENTRY glRotatexOES(GLfixed angle, GLfixed x, GLfixed y, GLfixed z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2339];
   ((void (APIENTRY *)(GLfixed angle, GLfixed x, GLfixed y, GLfixed z)) _func)(angle, x, y, z);
}

GLAPI void APIENTRY glSampleCoverage(GLfloat value, GLboolean invert)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2340];
   ((void (APIENTRY *)(GLfloat value, GLboolean invert)) _func)(value, invert);
}

GLAPI void APIENTRY glSampleCoverageARB(GLfloat value, GLboolean invert)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2341];
   ((void (APIENTRY *)(GLfloat value, GLboolean invert)) _func)(value, invert);
}

GLAPI void APIENTRY glSampleCoveragex(GLclampx value, GLboolean invert)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2342];
   ((void (APIENTRY *)(GLclampx value, GLboolean invert)) _func)(value, invert);
}

GLAPI void APIENTRY glSampleCoveragexOES(GLclampx value, GLboolean invert)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2343];
   ((void (APIENTRY *)(GLclampx value, GLboolean invert)) _func)(value, invert);
}

GLAPI void APIENTRY glSampleMapATI(GLuint dst, GLuint interp, GLenum swizzle)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2344];
   ((void (APIENTRY *)(GLuint dst, GLuint interp, GLenum swizzle)) _func)(dst, interp, swizzle);
}

GLAPI void APIENTRY glSampleMaskEXT(GLclampf value, GLboolean invert)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2345];
   ((void (APIENTRY *)(GLclampf value, GLboolean invert)) _func)(value, invert);
}

GLAPI void APIENTRY glSampleMaskIndexedNV(GLuint index, GLbitfield mask)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2346];
   ((void (APIENTRY *)(GLuint index, GLbitfield mask)) _func)(index, mask);
}

GLAPI void APIENTRY glSampleMaskSGIS(GLclampf value, GLboolean invert)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2347];
   ((void (APIENTRY *)(GLclampf value, GLboolean invert)) _func)(value, invert);
}

GLAPI void APIENTRY glSampleMaski(GLuint maskNumber, GLbitfield mask)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2348];
   ((void (APIENTRY *)(GLuint maskNumber, GLbitfield mask)) _func)(maskNumber, mask);
}

GLAPI void APIENTRY glSamplePatternEXT(GLenum pattern)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2349];
   ((void (APIENTRY *)(GLenum pattern)) _func)(pattern);
}

GLAPI void APIENTRY glSamplePatternSGIS(GLenum pattern)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2350];
   ((void (APIENTRY *)(GLenum pattern)) _func)(pattern);
}

GLAPI void APIENTRY glSamplerParameterIiv(GLuint sampler, GLenum pname, const GLint *param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2351];
   ((void (APIENTRY *)(GLuint sampler, GLenum pname, const GLint *param)) _func)(sampler, pname, param);
}

GLAPI void APIENTRY glSamplerParameterIivEXT(GLuint sampler, GLenum pname, const GLint *param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2352];
   ((void (APIENTRY *)(GLuint sampler, GLenum pname, const GLint *param)) _func)(sampler, pname, param);
}

GLAPI void APIENTRY glSamplerParameterIivOES(GLuint sampler, GLenum pname, const GLint *param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2353];
   ((void (APIENTRY *)(GLuint sampler, GLenum pname, const GLint *param)) _func)(sampler, pname, param);
}

GLAPI void APIENTRY glSamplerParameterIuiv(GLuint sampler, GLenum pname, const GLuint *param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2354];
   ((void (APIENTRY *)(GLuint sampler, GLenum pname, const GLuint *param)) _func)(sampler, pname, param);
}

GLAPI void APIENTRY glSamplerParameterIuivEXT(GLuint sampler, GLenum pname, const GLuint *param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2355];
   ((void (APIENTRY *)(GLuint sampler, GLenum pname, const GLuint *param)) _func)(sampler, pname, param);
}

GLAPI void APIENTRY glSamplerParameterIuivOES(GLuint sampler, GLenum pname, const GLuint *param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2356];
   ((void (APIENTRY *)(GLuint sampler, GLenum pname, const GLuint *param)) _func)(sampler, pname, param);
}

GLAPI void APIENTRY glSamplerParameterf(GLuint sampler, GLenum pname, GLfloat param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2357];
   ((void (APIENTRY *)(GLuint sampler, GLenum pname, GLfloat param)) _func)(sampler, pname, param);
}

GLAPI void APIENTRY glSamplerParameterfv(GLuint sampler, GLenum pname, const GLfloat *param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2358];
   ((void (APIENTRY *)(GLuint sampler, GLenum pname, const GLfloat *param)) _func)(sampler, pname, param);
}

GLAPI void APIENTRY glSamplerParameteri(GLuint sampler, GLenum pname, GLint param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2359];
   ((void (APIENTRY *)(GLuint sampler, GLenum pname, GLint param)) _func)(sampler, pname, param);
}

GLAPI void APIENTRY glSamplerParameteriv(GLuint sampler, GLenum pname, const GLint *param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2360];
   ((void (APIENTRY *)(GLuint sampler, GLenum pname, const GLint *param)) _func)(sampler, pname, param);
}

GLAPI void APIENTRY glScaled(GLdouble x, GLdouble y, GLdouble z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2361];
   ((void (APIENTRY *)(GLdouble x, GLdouble y, GLdouble z)) _func)(x, y, z);
}

GLAPI void APIENTRY glScalef(GLfloat x, GLfloat y, GLfloat z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2362];
   ((void (APIENTRY *)(GLfloat x, GLfloat y, GLfloat z)) _func)(x, y, z);
}

GLAPI void APIENTRY glScalex(GLfixed x, GLfixed y, GLfixed z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2363];
   ((void (APIENTRY *)(GLfixed x, GLfixed y, GLfixed z)) _func)(x, y, z);
}

GLAPI void APIENTRY glScalexOES(GLfixed x, GLfixed y, GLfixed z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2364];
   ((void (APIENTRY *)(GLfixed x, GLfixed y, GLfixed z)) _func)(x, y, z);
}

GLAPI void APIENTRY glScissor(GLint x, GLint y, GLsizei width, GLsizei height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2365];
   ((void (APIENTRY *)(GLint x, GLint y, GLsizei width, GLsizei height)) _func)(x, y, width, height);
}

GLAPI void APIENTRY glScissorArrayv(GLuint first, GLsizei count, const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2366];
   ((void (APIENTRY *)(GLuint first, GLsizei count, const GLint *v)) _func)(first, count, v);
}

GLAPI void APIENTRY glScissorArrayvNV(GLuint first, GLsizei count, const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2367];
   ((void (APIENTRY *)(GLuint first, GLsizei count, const GLint *v)) _func)(first, count, v);
}

GLAPI void APIENTRY glScissorArrayvOES(GLuint first, GLsizei count, const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2368];
   ((void (APIENTRY *)(GLuint first, GLsizei count, const GLint *v)) _func)(first, count, v);
}

GLAPI void APIENTRY glScissorExclusiveArrayvNV(GLuint first, GLsizei count, const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2369];
   ((void (APIENTRY *)(GLuint first, GLsizei count, const GLint *v)) _func)(first, count, v);
}

GLAPI void APIENTRY glScissorExclusiveNV(GLint x, GLint y, GLsizei width, GLsizei height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2370];
   ((void (APIENTRY *)(GLint x, GLint y, GLsizei width, GLsizei height)) _func)(x, y, width, height);
}

GLAPI void APIENTRY glScissorIndexed(GLuint index, GLint left, GLint bottom, GLsizei width, GLsizei height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2371];
   ((void (APIENTRY *)(GLuint index, GLint left, GLint bottom, GLsizei width, GLsizei height)) _func)(index, left, bottom, width, height);
}

GLAPI void APIENTRY glScissorIndexedNV(GLuint index, GLint left, GLint bottom, GLsizei width, GLsizei height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2372];
   ((void (APIENTRY *)(GLuint index, GLint left, GLint bottom, GLsizei width, GLsizei height)) _func)(index, left, bottom, width, height);
}

GLAPI void APIENTRY glScissorIndexedOES(GLuint index, GLint left, GLint bottom, GLsizei width, GLsizei height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2373];
   ((void (APIENTRY *)(GLuint index, GLint left, GLint bottom, GLsizei width, GLsizei height)) _func)(index, left, bottom, width, height);
}

GLAPI void APIENTRY glScissorIndexedv(GLuint index, const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2374];
   ((void (APIENTRY *)(GLuint index, const GLint *v)) _func)(index, v);
}

GLAPI void APIENTRY glScissorIndexedvNV(GLuint index, const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2375];
   ((void (APIENTRY *)(GLuint index, const GLint *v)) _func)(index, v);
}

GLAPI void APIENTRY glScissorIndexedvOES(GLuint index, const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2376];
   ((void (APIENTRY *)(GLuint index, const GLint *v)) _func)(index, v);
}

GLAPI void APIENTRY glSecondaryColor3b(GLbyte red, GLbyte green, GLbyte blue)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2377];
   ((void (APIENTRY *)(GLbyte red, GLbyte green, GLbyte blue)) _func)(red, green, blue);
}

GLAPI void APIENTRY glSecondaryColor3bEXT(GLbyte red, GLbyte green, GLbyte blue)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2378];
   ((void (APIENTRY *)(GLbyte red, GLbyte green, GLbyte blue)) _func)(red, green, blue);
}

GLAPI void APIENTRY glSecondaryColor3bv(const GLbyte *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2379];
   ((void (APIENTRY *)(const GLbyte *v)) _func)(v);
}

GLAPI void APIENTRY glSecondaryColor3bvEXT(const GLbyte *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2380];
   ((void (APIENTRY *)(const GLbyte *v)) _func)(v);
}

GLAPI void APIENTRY glSecondaryColor3d(GLdouble red, GLdouble green, GLdouble blue)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2381];
   ((void (APIENTRY *)(GLdouble red, GLdouble green, GLdouble blue)) _func)(red, green, blue);
}

GLAPI void APIENTRY glSecondaryColor3dEXT(GLdouble red, GLdouble green, GLdouble blue)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2382];
   ((void (APIENTRY *)(GLdouble red, GLdouble green, GLdouble blue)) _func)(red, green, blue);
}

GLAPI void APIENTRY glSecondaryColor3dv(const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2383];
   ((void (APIENTRY *)(const GLdouble *v)) _func)(v);
}

GLAPI void APIENTRY glSecondaryColor3dvEXT(const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2384];
   ((void (APIENTRY *)(const GLdouble *v)) _func)(v);
}

GLAPI void APIENTRY glSecondaryColor3f(GLfloat red, GLfloat green, GLfloat blue)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2385];
   ((void (APIENTRY *)(GLfloat red, GLfloat green, GLfloat blue)) _func)(red, green, blue);
}

GLAPI void APIENTRY glSecondaryColor3fEXT(GLfloat red, GLfloat green, GLfloat blue)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2386];
   ((void (APIENTRY *)(GLfloat red, GLfloat green, GLfloat blue)) _func)(red, green, blue);
}

GLAPI void APIENTRY glSecondaryColor3fv(const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2387];
   ((void (APIENTRY *)(const GLfloat *v)) _func)(v);
}

GLAPI void APIENTRY glSecondaryColor3fvEXT(const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2388];
   ((void (APIENTRY *)(const GLfloat *v)) _func)(v);
}

GLAPI void APIENTRY glSecondaryColor3hNV(GLhalf red, GLhalf green, GLhalf blue)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2389];
   ((void (APIENTRY *)(GLhalf red, GLhalf green, GLhalf blue)) _func)(red, green, blue);
}

GLAPI void APIENTRY glSecondaryColor3hvNV(const GLhalf *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2390];
   ((void (APIENTRY *)(const GLhalf *v)) _func)(v);
}

GLAPI void APIENTRY glSecondaryColor3i(GLint red, GLint green, GLint blue)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2391];
   ((void (APIENTRY *)(GLint red, GLint green, GLint blue)) _func)(red, green, blue);
}

GLAPI void APIENTRY glSecondaryColor3iEXT(GLint red, GLint green, GLint blue)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2392];
   ((void (APIENTRY *)(GLint red, GLint green, GLint blue)) _func)(red, green, blue);
}

GLAPI void APIENTRY glSecondaryColor3iv(const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2393];
   ((void (APIENTRY *)(const GLint *v)) _func)(v);
}

GLAPI void APIENTRY glSecondaryColor3ivEXT(const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2394];
   ((void (APIENTRY *)(const GLint *v)) _func)(v);
}

GLAPI void APIENTRY glSecondaryColor3s(GLshort red, GLshort green, GLshort blue)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2395];
   ((void (APIENTRY *)(GLshort red, GLshort green, GLshort blue)) _func)(red, green, blue);
}

GLAPI void APIENTRY glSecondaryColor3sEXT(GLshort red, GLshort green, GLshort blue)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2396];
   ((void (APIENTRY *)(GLshort red, GLshort green, GLshort blue)) _func)(red, green, blue);
}

GLAPI void APIENTRY glSecondaryColor3sv(const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2397];
   ((void (APIENTRY *)(const GLshort *v)) _func)(v);
}

GLAPI void APIENTRY glSecondaryColor3svEXT(const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2398];
   ((void (APIENTRY *)(const GLshort *v)) _func)(v);
}

GLAPI void APIENTRY glSecondaryColor3ub(GLubyte red, GLubyte green, GLubyte blue)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2399];
   ((void (APIENTRY *)(GLubyte red, GLubyte green, GLubyte blue)) _func)(red, green, blue);
}

GLAPI void APIENTRY glSecondaryColor3ubEXT(GLubyte red, GLubyte green, GLubyte blue)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2400];
   ((void (APIENTRY *)(GLubyte red, GLubyte green, GLubyte blue)) _func)(red, green, blue);
}

GLAPI void APIENTRY glSecondaryColor3ubv(const GLubyte *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2401];
   ((void (APIENTRY *)(const GLubyte *v)) _func)(v);
}

GLAPI void APIENTRY glSecondaryColor3ubvEXT(const GLubyte *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2402];
   ((void (APIENTRY *)(const GLubyte *v)) _func)(v);
}

GLAPI void APIENTRY glSecondaryColor3ui(GLuint red, GLuint green, GLuint blue)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2403];
   ((void (APIENTRY *)(GLuint red, GLuint green, GLuint blue)) _func)(red, green, blue);
}

GLAPI void APIENTRY glSecondaryColor3uiEXT(GLuint red, GLuint green, GLuint blue)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2404];
   ((void (APIENTRY *)(GLuint red, GLuint green, GLuint blue)) _func)(red, green, blue);
}

GLAPI void APIENTRY glSecondaryColor3uiv(const GLuint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2405];
   ((void (APIENTRY *)(const GLuint *v)) _func)(v);
}

GLAPI void APIENTRY glSecondaryColor3uivEXT(const GLuint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2406];
   ((void (APIENTRY *)(const GLuint *v)) _func)(v);
}

GLAPI void APIENTRY glSecondaryColor3us(GLushort red, GLushort green, GLushort blue)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2407];
   ((void (APIENTRY *)(GLushort red, GLushort green, GLushort blue)) _func)(red, green, blue);
}

GLAPI void APIENTRY glSecondaryColor3usEXT(GLushort red, GLushort green, GLushort blue)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2408];
   ((void (APIENTRY *)(GLushort red, GLushort green, GLushort blue)) _func)(red, green, blue);
}

GLAPI void APIENTRY glSecondaryColor3usv(const GLushort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2409];
   ((void (APIENTRY *)(const GLushort *v)) _func)(v);
}

GLAPI void APIENTRY glSecondaryColor3usvEXT(const GLushort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2410];
   ((void (APIENTRY *)(const GLushort *v)) _func)(v);
}

GLAPI void APIENTRY glSecondaryColorFormatNV(GLint size, GLenum type, GLsizei stride)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2411];
   ((void (APIENTRY *)(GLint size, GLenum type, GLsizei stride)) _func)(size, type, stride);
}

GLAPI void APIENTRY glSecondaryColorP3ui(GLenum type, GLuint color)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2412];
   ((void (APIENTRY *)(GLenum type, GLuint color)) _func)(type, color);
}

GLAPI void APIENTRY glSecondaryColorP3uiv(GLenum type, const GLuint *color)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2413];
   ((void (APIENTRY *)(GLenum type, const GLuint *color)) _func)(type, color);
}

GLAPI void APIENTRY glSecondaryColorPointer(GLint size, GLenum type, GLsizei stride, const void *pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2414];
   ((void (APIENTRY *)(GLint size, GLenum type, GLsizei stride, const void *pointer)) _func)(size, type, stride, pointer);
}

GLAPI void APIENTRY glSecondaryColorPointerEXT(GLint size, GLenum type, GLsizei stride, const void *pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2415];
   ((void (APIENTRY *)(GLint size, GLenum type, GLsizei stride, const void *pointer)) _func)(size, type, stride, pointer);
}

GLAPI void APIENTRY glSecondaryColorPointerListIBM(GLint size, GLenum type, GLint stride, const void **pointer, GLint ptrstride)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2416];
   ((void (APIENTRY *)(GLint size, GLenum type, GLint stride, const void **pointer, GLint ptrstride)) _func)(size, type, stride, pointer, ptrstride);
}

GLAPI void APIENTRY glSelectBuffer(GLsizei size, GLuint *buffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2417];
   ((void (APIENTRY *)(GLsizei size, GLuint *buffer)) _func)(size, buffer);
}

GLAPI void APIENTRY glSelectPerfMonitorCountersAMD(GLuint monitor, GLboolean enable, GLuint group, GLint numCounters, GLuint *counterList)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2418];
   ((void (APIENTRY *)(GLuint monitor, GLboolean enable, GLuint group, GLint numCounters, GLuint *counterList)) _func)(monitor, enable, group, numCounters, counterList);
}

GLAPI void APIENTRY glSemaphoreParameterui64vEXT(GLuint semaphore, GLenum pname, const GLuint64 *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2420];
   ((void (APIENTRY *)(GLuint semaphore, GLenum pname, const GLuint64 *params)) _func)(semaphore, pname, params);
}

GLAPI void APIENTRY glSeparableFilter2D(GLenum target, GLenum internalformat, GLsizei width, GLsizei height, GLenum format, GLenum type, const void *row, const void *column)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2421];
   ((void (APIENTRY *)(GLenum target, GLenum internalformat, GLsizei width, GLsizei height, GLenum format, GLenum type, const void *row, const void *column)) _func)(target, internalformat, width, height, format, type, row, column);
}

GLAPI void APIENTRY glSeparableFilter2DEXT(GLenum target, GLenum internalformat, GLsizei width, GLsizei height, GLenum format, GLenum type, const void *row, const void *column)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2422];
   ((void (APIENTRY *)(GLenum target, GLenum internalformat, GLsizei width, GLsizei height, GLenum format, GLenum type, const void *row, const void *column)) _func)(target, internalformat, width, height, format, type, row, column);
}

GLAPI void APIENTRY glSetFenceAPPLE(GLuint fence)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2423];
   ((void (APIENTRY *)(GLuint fence)) _func)(fence);
}

GLAPI void APIENTRY glSetFenceNV(GLuint fence, GLenum condition)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2424];
   ((void (APIENTRY *)(GLuint fence, GLenum condition)) _func)(fence, condition);
}

GLAPI void APIENTRY glSetFragmentShaderConstantATI(GLuint dst, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2425];
   ((void (APIENTRY *)(GLuint dst, const GLfloat *value)) _func)(dst, value);
}

GLAPI void APIENTRY glSetInvariantEXT(GLuint id, GLenum type, const void *addr)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2426];
   ((void (APIENTRY *)(GLuint id, GLenum type, const void *addr)) _func)(id, type, addr);
}

GLAPI void APIENTRY glSetLocalConstantEXT(GLuint id, GLenum type, const void *addr)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2427];
   ((void (APIENTRY *)(GLuint id, GLenum type, const void *addr)) _func)(id, type, addr);
}

GLAPI void APIENTRY glSetMultisamplefvAMD(GLenum pname, GLuint index, const GLfloat *val)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2428];
   ((void (APIENTRY *)(GLenum pname, GLuint index, const GLfloat *val)) _func)(pname, index, val);
}

GLAPI void APIENTRY glShadeModel(GLenum mode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2429];
   ((void (APIENTRY *)(GLenum mode)) _func)(mode);
}

GLAPI void APIENTRY glShaderBinary(GLsizei count, const GLuint *shaders, GLenum binaryFormat, const void *binary, GLsizei length)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2430];
   ((void (APIENTRY *)(GLsizei count, const GLuint *shaders, GLenum binaryFormat, const void *binary, GLsizei length)) _func)(count, shaders, binaryFormat, binary, length);
}

GLAPI void APIENTRY glShaderOp1EXT(GLenum op, GLuint res, GLuint arg1)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2431];
   ((void (APIENTRY *)(GLenum op, GLuint res, GLuint arg1)) _func)(op, res, arg1);
}

GLAPI void APIENTRY glShaderOp2EXT(GLenum op, GLuint res, GLuint arg1, GLuint arg2)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2432];
   ((void (APIENTRY *)(GLenum op, GLuint res, GLuint arg1, GLuint arg2)) _func)(op, res, arg1, arg2);
}

GLAPI void APIENTRY glShaderOp3EXT(GLenum op, GLuint res, GLuint arg1, GLuint arg2, GLuint arg3)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2433];
   ((void (APIENTRY *)(GLenum op, GLuint res, GLuint arg1, GLuint arg2, GLuint arg3)) _func)(op, res, arg1, arg2, arg3);
}

GLAPI void APIENTRY glShaderSource(GLuint shader, GLsizei count, const GLchar *const *string, const GLint *length)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2434];
   ((void (APIENTRY *)(GLuint shader, GLsizei count, const GLchar *const *string, const GLint *length)) _func)(shader, count, string, length);
}

GLAPI void APIENTRY glShaderSourceARB(GLhandleARB shaderObj, GLsizei count, const GLcharARB **string, const GLint *length)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2435];
   ((void (APIENTRY *)(GLhandleARB shaderObj, GLsizei count, const GLcharARB **string, const GLint *length)) _func)(shaderObj, count, string, length);
}

GLAPI void APIENTRY glShaderStorageBlockBinding(GLuint program, GLuint storageBlockIndex, GLuint storageBlockBinding)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2436];
   ((void (APIENTRY *)(GLuint program, GLuint storageBlockIndex, GLuint storageBlockBinding)) _func)(program, storageBlockIndex, storageBlockBinding);
}

GLAPI void APIENTRY glShadingRateImageBarrierNV(GLboolean synchronize)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2439];
   ((void (APIENTRY *)(GLboolean synchronize)) _func)(synchronize);
}

GLAPI void APIENTRY glShadingRateImagePaletteNV(GLuint viewport, GLuint first, GLsizei count, const GLenum *rates)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2440];
   ((void (APIENTRY *)(GLuint viewport, GLuint first, GLsizei count, const GLenum *rates)) _func)(viewport, first, count, rates);
}

GLAPI void APIENTRY glShadingRateSampleOrderCustomNV(GLenum rate, GLuint samples, const GLint *locations)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2442];
   ((void (APIENTRY *)(GLenum rate, GLuint samples, const GLint *locations)) _func)(rate, samples, locations);
}

GLAPI void APIENTRY glShadingRateSampleOrderNV(GLenum order)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2443];
   ((void (APIENTRY *)(GLenum order)) _func)(order);
}

GLAPI void APIENTRY glSharpenTexFuncSGIS(GLenum target, GLsizei n, const GLfloat *points)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2444];
   ((void (APIENTRY *)(GLenum target, GLsizei n, const GLfloat *points)) _func)(target, n, points);
}

GLAPI void APIENTRY glSignalSemaphoreEXT(GLuint semaphore, GLuint numBufferBarriers, const GLuint *buffers, GLuint numTextureBarriers, const GLuint *textures, const GLenum *dstLayouts)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2445];
   ((void (APIENTRY *)(GLuint semaphore, GLuint numBufferBarriers, const GLuint *buffers, GLuint numTextureBarriers, const GLuint *textures, const GLenum *dstLayouts)) _func)(semaphore, numBufferBarriers, buffers, numTextureBarriers, textures, dstLayouts);
}

GLAPI void APIENTRY glSignalSemaphoreui64NVX(GLuint signalGpu, GLsizei fenceObjectCount, const GLuint *semaphoreArray, const GLuint64 *fenceValueArray)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2446];
   ((void (APIENTRY *)(GLuint signalGpu, GLsizei fenceObjectCount, const GLuint *semaphoreArray, const GLuint64 *fenceValueArray)) _func)(signalGpu, fenceObjectCount, semaphoreArray, fenceValueArray);
}

GLAPI void APIENTRY glSignalVkFenceNV(GLuint64 vkFence)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2447];
   ((void (APIENTRY *)(GLuint64 vkFence)) _func)(vkFence);
}

GLAPI void APIENTRY glSignalVkSemaphoreNV(GLuint64 vkSemaphore)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2448];
   ((void (APIENTRY *)(GLuint64 vkSemaphore)) _func)(vkSemaphore);
}

GLAPI void APIENTRY glSpecializeShader(GLuint shader, const GLchar *pEntryPoint, GLuint numSpecializationConstants, const GLuint *pConstantIndex, const GLuint *pConstantValue)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2449];
   ((void (APIENTRY *)(GLuint shader, const GLchar *pEntryPoint, GLuint numSpecializationConstants, const GLuint *pConstantIndex, const GLuint *pConstantValue)) _func)(shader, pEntryPoint, numSpecializationConstants, pConstantIndex, pConstantValue);
}

GLAPI void APIENTRY glSpecializeShaderARB(GLuint shader, const GLchar *pEntryPoint, GLuint numSpecializationConstants, const GLuint *pConstantIndex, const GLuint *pConstantValue)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2450];
   ((void (APIENTRY *)(GLuint shader, const GLchar *pEntryPoint, GLuint numSpecializationConstants, const GLuint *pConstantIndex, const GLuint *pConstantValue)) _func)(shader, pEntryPoint, numSpecializationConstants, pConstantIndex, pConstantValue);
}

GLAPI void APIENTRY glSpriteParameterfSGIX(GLenum pname, GLfloat param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2451];
   ((void (APIENTRY *)(GLenum pname, GLfloat param)) _func)(pname, param);
}

GLAPI void APIENTRY glSpriteParameterfvSGIX(GLenum pname, const GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2452];
   ((void (APIENTRY *)(GLenum pname, const GLfloat *params)) _func)(pname, params);
}

GLAPI void APIENTRY glSpriteParameteriSGIX(GLenum pname, GLint param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2453];
   ((void (APIENTRY *)(GLenum pname, GLint param)) _func)(pname, param);
}

GLAPI void APIENTRY glSpriteParameterivSGIX(GLenum pname, const GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2454];
   ((void (APIENTRY *)(GLenum pname, const GLint *params)) _func)(pname, params);
}

GLAPI void APIENTRY glStartInstrumentsSGIX(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2455];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glStartTilingQCOM(GLuint x, GLuint y, GLuint width, GLuint height, GLbitfield preserveMask)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2456];
   ((void (APIENTRY *)(GLuint x, GLuint y, GLuint width, GLuint height, GLbitfield preserveMask)) _func)(x, y, width, height, preserveMask);
}

GLAPI void APIENTRY glStateCaptureNV(GLuint state, GLenum mode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2457];
   ((void (APIENTRY *)(GLuint state, GLenum mode)) _func)(state, mode);
}

GLAPI void APIENTRY glStencilClearTagEXT(GLsizei stencilTagBits, GLuint stencilClearTag)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2458];
   ((void (APIENTRY *)(GLsizei stencilTagBits, GLuint stencilClearTag)) _func)(stencilTagBits, stencilClearTag);
}

GLAPI void APIENTRY glStencilFillPathInstancedNV(GLsizei numPaths, GLenum pathNameType, const void *paths, GLuint pathBase, GLenum fillMode, GLuint mask, GLenum transformType, const GLfloat *transformValues)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2459];
   ((void (APIENTRY *)(GLsizei numPaths, GLenum pathNameType, const void *paths, GLuint pathBase, GLenum fillMode, GLuint mask, GLenum transformType, const GLfloat *transformValues)) _func)(numPaths, pathNameType, paths, pathBase, fillMode, mask, transformType, transformValues);
}

GLAPI void APIENTRY glStencilFillPathNV(GLuint path, GLenum fillMode, GLuint mask)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2460];
   ((void (APIENTRY *)(GLuint path, GLenum fillMode, GLuint mask)) _func)(path, fillMode, mask);
}

GLAPI void APIENTRY glStencilFunc(GLenum func, GLint ref, GLuint mask)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2461];
   ((void (APIENTRY *)(GLenum func, GLint ref, GLuint mask)) _func)(func, ref, mask);
}

GLAPI void APIENTRY glStencilFuncSeparate(GLenum face, GLenum func, GLint ref, GLuint mask)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2462];
   ((void (APIENTRY *)(GLenum face, GLenum func, GLint ref, GLuint mask)) _func)(face, func, ref, mask);
}

GLAPI void APIENTRY glStencilFuncSeparateATI(GLenum frontfunc, GLenum backfunc, GLint ref, GLuint mask)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2463];
   ((void (APIENTRY *)(GLenum frontfunc, GLenum backfunc, GLint ref, GLuint mask)) _func)(frontfunc, backfunc, ref, mask);
}

GLAPI void APIENTRY glStencilMask(GLuint mask)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2464];
   ((void (APIENTRY *)(GLuint mask)) _func)(mask);
}

GLAPI void APIENTRY glStencilMaskSeparate(GLenum face, GLuint mask)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2465];
   ((void (APIENTRY *)(GLenum face, GLuint mask)) _func)(face, mask);
}

GLAPI void APIENTRY glStencilOp(GLenum fail, GLenum zfail, GLenum zpass)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2466];
   ((void (APIENTRY *)(GLenum fail, GLenum zfail, GLenum zpass)) _func)(fail, zfail, zpass);
}

GLAPI void APIENTRY glStencilOpSeparate(GLenum face, GLenum sfail, GLenum dpfail, GLenum dppass)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2467];
   ((void (APIENTRY *)(GLenum face, GLenum sfail, GLenum dpfail, GLenum dppass)) _func)(face, sfail, dpfail, dppass);
}

GLAPI void APIENTRY glStencilOpSeparateATI(GLenum face, GLenum sfail, GLenum dpfail, GLenum dppass)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2468];
   ((void (APIENTRY *)(GLenum face, GLenum sfail, GLenum dpfail, GLenum dppass)) _func)(face, sfail, dpfail, dppass);
}

GLAPI void APIENTRY glStencilOpValueAMD(GLenum face, GLuint value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2469];
   ((void (APIENTRY *)(GLenum face, GLuint value)) _func)(face, value);
}

GLAPI void APIENTRY glStencilStrokePathInstancedNV(GLsizei numPaths, GLenum pathNameType, const void *paths, GLuint pathBase, GLint reference, GLuint mask, GLenum transformType, const GLfloat *transformValues)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2470];
   ((void (APIENTRY *)(GLsizei numPaths, GLenum pathNameType, const void *paths, GLuint pathBase, GLint reference, GLuint mask, GLenum transformType, const GLfloat *transformValues)) _func)(numPaths, pathNameType, paths, pathBase, reference, mask, transformType, transformValues);
}

GLAPI void APIENTRY glStencilStrokePathNV(GLuint path, GLint reference, GLuint mask)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2471];
   ((void (APIENTRY *)(GLuint path, GLint reference, GLuint mask)) _func)(path, reference, mask);
}

GLAPI void APIENTRY glStencilThenCoverFillPathInstancedNV(GLsizei numPaths, GLenum pathNameType, const void *paths, GLuint pathBase, GLenum fillMode, GLuint mask, GLenum coverMode, GLenum transformType, const GLfloat *transformValues)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2472];
   ((void (APIENTRY *)(GLsizei numPaths, GLenum pathNameType, const void *paths, GLuint pathBase, GLenum fillMode, GLuint mask, GLenum coverMode, GLenum transformType, const GLfloat *transformValues)) _func)(numPaths, pathNameType, paths, pathBase, fillMode, mask, coverMode, transformType, transformValues);
}

GLAPI void APIENTRY glStencilThenCoverFillPathNV(GLuint path, GLenum fillMode, GLuint mask, GLenum coverMode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2473];
   ((void (APIENTRY *)(GLuint path, GLenum fillMode, GLuint mask, GLenum coverMode)) _func)(path, fillMode, mask, coverMode);
}

GLAPI void APIENTRY glStencilThenCoverStrokePathInstancedNV(GLsizei numPaths, GLenum pathNameType, const void *paths, GLuint pathBase, GLint reference, GLuint mask, GLenum coverMode, GLenum transformType, const GLfloat *transformValues)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2474];
   ((void (APIENTRY *)(GLsizei numPaths, GLenum pathNameType, const void *paths, GLuint pathBase, GLint reference, GLuint mask, GLenum coverMode, GLenum transformType, const GLfloat *transformValues)) _func)(numPaths, pathNameType, paths, pathBase, reference, mask, coverMode, transformType, transformValues);
}

GLAPI void APIENTRY glStencilThenCoverStrokePathNV(GLuint path, GLint reference, GLuint mask, GLenum coverMode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2475];
   ((void (APIENTRY *)(GLuint path, GLint reference, GLuint mask, GLenum coverMode)) _func)(path, reference, mask, coverMode);
}

GLAPI void APIENTRY glStopInstrumentsSGIX(GLint marker)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2476];
   ((void (APIENTRY *)(GLint marker)) _func)(marker);
}

GLAPI void APIENTRY glStringMarkerGREMEDY(GLsizei len, const void *string)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2477];
   ((void (APIENTRY *)(GLsizei len, const void *string)) _func)(len, string);
}

GLAPI void APIENTRY glSubpixelPrecisionBiasNV(GLuint xbits, GLuint ybits)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2478];
   ((void (APIENTRY *)(GLuint xbits, GLuint ybits)) _func)(xbits, ybits);
}

GLAPI void APIENTRY glSwizzleEXT(GLuint res, GLuint in, GLenum outX, GLenum outY, GLenum outZ, GLenum outW)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2479];
   ((void (APIENTRY *)(GLuint res, GLuint in, GLenum outX, GLenum outY, GLenum outZ, GLenum outW)) _func)(res, in, outX, outY, outZ, outW);
}

GLAPI void APIENTRY glSyncTextureINTEL(GLuint texture)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2480];
   ((void (APIENTRY *)(GLuint texture)) _func)(texture);
}

GLAPI void APIENTRY glTagSampleBufferSGIX(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2481];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glTangent3bEXT(GLbyte tx, GLbyte ty, GLbyte tz)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2482];
   ((void (APIENTRY *)(GLbyte tx, GLbyte ty, GLbyte tz)) _func)(tx, ty, tz);
}

GLAPI void APIENTRY glTangent3bvEXT(const GLbyte *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2483];
   ((void (APIENTRY *)(const GLbyte *v)) _func)(v);
}

GLAPI void APIENTRY glTangent3dEXT(GLdouble tx, GLdouble ty, GLdouble tz)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2484];
   ((void (APIENTRY *)(GLdouble tx, GLdouble ty, GLdouble tz)) _func)(tx, ty, tz);
}

GLAPI void APIENTRY glTangent3dvEXT(const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2485];
   ((void (APIENTRY *)(const GLdouble *v)) _func)(v);
}

GLAPI void APIENTRY glTangent3fEXT(GLfloat tx, GLfloat ty, GLfloat tz)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2486];
   ((void (APIENTRY *)(GLfloat tx, GLfloat ty, GLfloat tz)) _func)(tx, ty, tz);
}

GLAPI void APIENTRY glTangent3fvEXT(const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2487];
   ((void (APIENTRY *)(const GLfloat *v)) _func)(v);
}

GLAPI void APIENTRY glTangent3iEXT(GLint tx, GLint ty, GLint tz)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2488];
   ((void (APIENTRY *)(GLint tx, GLint ty, GLint tz)) _func)(tx, ty, tz);
}

GLAPI void APIENTRY glTangent3ivEXT(const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2489];
   ((void (APIENTRY *)(const GLint *v)) _func)(v);
}

GLAPI void APIENTRY glTangent3sEXT(GLshort tx, GLshort ty, GLshort tz)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2490];
   ((void (APIENTRY *)(GLshort tx, GLshort ty, GLshort tz)) _func)(tx, ty, tz);
}

GLAPI void APIENTRY glTangent3svEXT(const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2491];
   ((void (APIENTRY *)(const GLshort *v)) _func)(v);
}

GLAPI void APIENTRY glTangentPointerEXT(GLenum type, GLsizei stride, const void *pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2492];
   ((void (APIENTRY *)(GLenum type, GLsizei stride, const void *pointer)) _func)(type, stride, pointer);
}

GLAPI void APIENTRY glTbufferMask3DFX(GLuint mask)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2493];
   ((void (APIENTRY *)(GLuint mask)) _func)(mask);
}

GLAPI void APIENTRY glTessellationFactorAMD(GLfloat factor)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2494];
   ((void (APIENTRY *)(GLfloat factor)) _func)(factor);
}

GLAPI void APIENTRY glTessellationModeAMD(GLenum mode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2495];
   ((void (APIENTRY *)(GLenum mode)) _func)(mode);
}

GLAPI GLboolean APIENTRY glTestFenceAPPLE(GLuint fence)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2496];
   return ((GLboolean (APIENTRY *)(GLuint fence)) _func)(fence);
}

GLAPI GLboolean APIENTRY glTestFenceNV(GLuint fence)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2497];
   return ((GLboolean (APIENTRY *)(GLuint fence)) _func)(fence);
}

GLAPI GLboolean APIENTRY glTestObjectAPPLE(GLenum object, GLuint name)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2498];
   return ((GLboolean (APIENTRY *)(GLenum object, GLuint name)) _func)(object, name);
}

GLAPI void APIENTRY glTexAttachMemoryNV(GLenum target, GLuint memory, GLuint64 offset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2499];
   ((void (APIENTRY *)(GLenum target, GLuint memory, GLuint64 offset)) _func)(target, memory, offset);
}

GLAPI void APIENTRY glTexBuffer(GLenum target, GLenum internalformat, GLuint buffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2500];
   ((void (APIENTRY *)(GLenum target, GLenum internalformat, GLuint buffer)) _func)(target, internalformat, buffer);
}

GLAPI void APIENTRY glTexBufferARB(GLenum target, GLenum internalformat, GLuint buffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2501];
   ((void (APIENTRY *)(GLenum target, GLenum internalformat, GLuint buffer)) _func)(target, internalformat, buffer);
}

GLAPI void APIENTRY glTexBufferEXT(GLenum target, GLenum internalformat, GLuint buffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2502];
   ((void (APIENTRY *)(GLenum target, GLenum internalformat, GLuint buffer)) _func)(target, internalformat, buffer);
}

GLAPI void APIENTRY glTexBufferOES(GLenum target, GLenum internalformat, GLuint buffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2503];
   ((void (APIENTRY *)(GLenum target, GLenum internalformat, GLuint buffer)) _func)(target, internalformat, buffer);
}

GLAPI void APIENTRY glTexBufferRange(GLenum target, GLenum internalformat, GLuint buffer, GLintptr offset, GLsizeiptr size)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2504];
   ((void (APIENTRY *)(GLenum target, GLenum internalformat, GLuint buffer, GLintptr offset, GLsizeiptr size)) _func)(target, internalformat, buffer, offset, size);
}

GLAPI void APIENTRY glTexBufferRangeEXT(GLenum target, GLenum internalformat, GLuint buffer, GLintptr offset, GLsizeiptr size)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2505];
   ((void (APIENTRY *)(GLenum target, GLenum internalformat, GLuint buffer, GLintptr offset, GLsizeiptr size)) _func)(target, internalformat, buffer, offset, size);
}

GLAPI void APIENTRY glTexBufferRangeOES(GLenum target, GLenum internalformat, GLuint buffer, GLintptr offset, GLsizeiptr size)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2506];
   ((void (APIENTRY *)(GLenum target, GLenum internalformat, GLuint buffer, GLintptr offset, GLsizeiptr size)) _func)(target, internalformat, buffer, offset, size);
}

GLAPI void APIENTRY glTexBumpParameterfvATI(GLenum pname, const GLfloat *param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2507];
   ((void (APIENTRY *)(GLenum pname, const GLfloat *param)) _func)(pname, param);
}

GLAPI void APIENTRY glTexBumpParameterivATI(GLenum pname, const GLint *param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2508];
   ((void (APIENTRY *)(GLenum pname, const GLint *param)) _func)(pname, param);
}

GLAPI void APIENTRY glTexCoord1bOES(GLbyte s)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2509];
   ((void (APIENTRY *)(GLbyte s)) _func)(s);
}

GLAPI void APIENTRY glTexCoord1bvOES(const GLbyte *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2510];
   ((void (APIENTRY *)(const GLbyte *coords)) _func)(coords);
}

GLAPI void APIENTRY glTexCoord1d(GLdouble s)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2511];
   ((void (APIENTRY *)(GLdouble s)) _func)(s);
}

GLAPI void APIENTRY glTexCoord1dv(const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2512];
   ((void (APIENTRY *)(const GLdouble *v)) _func)(v);
}

GLAPI void APIENTRY glTexCoord1f(GLfloat s)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2513];
   ((void (APIENTRY *)(GLfloat s)) _func)(s);
}

GLAPI void APIENTRY glTexCoord1fv(const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2514];
   ((void (APIENTRY *)(const GLfloat *v)) _func)(v);
}

GLAPI void APIENTRY glTexCoord1hNV(GLhalf s)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2515];
   ((void (APIENTRY *)(GLhalf s)) _func)(s);
}

GLAPI void APIENTRY glTexCoord1hvNV(const GLhalf *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2516];
   ((void (APIENTRY *)(const GLhalf *v)) _func)(v);
}

GLAPI void APIENTRY glTexCoord1i(GLint s)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2517];
   ((void (APIENTRY *)(GLint s)) _func)(s);
}

GLAPI void APIENTRY glTexCoord1iv(const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2518];
   ((void (APIENTRY *)(const GLint *v)) _func)(v);
}

GLAPI void APIENTRY glTexCoord1s(GLshort s)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2519];
   ((void (APIENTRY *)(GLshort s)) _func)(s);
}

GLAPI void APIENTRY glTexCoord1sv(const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2520];
   ((void (APIENTRY *)(const GLshort *v)) _func)(v);
}

GLAPI void APIENTRY glTexCoord1xOES(GLfixed s)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2521];
   ((void (APIENTRY *)(GLfixed s)) _func)(s);
}

GLAPI void APIENTRY glTexCoord1xvOES(const GLfixed *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2522];
   ((void (APIENTRY *)(const GLfixed *coords)) _func)(coords);
}

GLAPI void APIENTRY glTexCoord2bOES(GLbyte s, GLbyte t)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2523];
   ((void (APIENTRY *)(GLbyte s, GLbyte t)) _func)(s, t);
}

GLAPI void APIENTRY glTexCoord2bvOES(const GLbyte *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2524];
   ((void (APIENTRY *)(const GLbyte *coords)) _func)(coords);
}

GLAPI void APIENTRY glTexCoord2d(GLdouble s, GLdouble t)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2525];
   ((void (APIENTRY *)(GLdouble s, GLdouble t)) _func)(s, t);
}

GLAPI void APIENTRY glTexCoord2dv(const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2526];
   ((void (APIENTRY *)(const GLdouble *v)) _func)(v);
}

GLAPI void APIENTRY glTexCoord2f(GLfloat s, GLfloat t)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2527];
   ((void (APIENTRY *)(GLfloat s, GLfloat t)) _func)(s, t);
}

GLAPI void APIENTRY glTexCoord2fColor3fVertex3fSUN(GLfloat s, GLfloat t, GLfloat r, GLfloat g, GLfloat b, GLfloat x, GLfloat y, GLfloat z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2528];
   ((void (APIENTRY *)(GLfloat s, GLfloat t, GLfloat r, GLfloat g, GLfloat b, GLfloat x, GLfloat y, GLfloat z)) _func)(s, t, r, g, b, x, y, z);
}

GLAPI void APIENTRY glTexCoord2fColor3fVertex3fvSUN(const GLfloat *tc, const GLfloat *c, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2529];
   ((void (APIENTRY *)(const GLfloat *tc, const GLfloat *c, const GLfloat *v)) _func)(tc, c, v);
}

GLAPI void APIENTRY glTexCoord2fColor4fNormal3fVertex3fSUN(GLfloat s, GLfloat t, GLfloat r, GLfloat g, GLfloat b, GLfloat a, GLfloat nx, GLfloat ny, GLfloat nz, GLfloat x, GLfloat y, GLfloat z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2530];
   ((void (APIENTRY *)(GLfloat s, GLfloat t, GLfloat r, GLfloat g, GLfloat b, GLfloat a, GLfloat nx, GLfloat ny, GLfloat nz, GLfloat x, GLfloat y, GLfloat z)) _func)(s, t, r, g, b, a, nx, ny, nz, x, y, z);
}

GLAPI void APIENTRY glTexCoord2fColor4fNormal3fVertex3fvSUN(const GLfloat *tc, const GLfloat *c, const GLfloat *n, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2531];
   ((void (APIENTRY *)(const GLfloat *tc, const GLfloat *c, const GLfloat *n, const GLfloat *v)) _func)(tc, c, n, v);
}

GLAPI void APIENTRY glTexCoord2fColor4ubVertex3fSUN(GLfloat s, GLfloat t, GLubyte r, GLubyte g, GLubyte b, GLubyte a, GLfloat x, GLfloat y, GLfloat z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2532];
   ((void (APIENTRY *)(GLfloat s, GLfloat t, GLubyte r, GLubyte g, GLubyte b, GLubyte a, GLfloat x, GLfloat y, GLfloat z)) _func)(s, t, r, g, b, a, x, y, z);
}

GLAPI void APIENTRY glTexCoord2fColor4ubVertex3fvSUN(const GLfloat *tc, const GLubyte *c, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2533];
   ((void (APIENTRY *)(const GLfloat *tc, const GLubyte *c, const GLfloat *v)) _func)(tc, c, v);
}

GLAPI void APIENTRY glTexCoord2fNormal3fVertex3fSUN(GLfloat s, GLfloat t, GLfloat nx, GLfloat ny, GLfloat nz, GLfloat x, GLfloat y, GLfloat z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2534];
   ((void (APIENTRY *)(GLfloat s, GLfloat t, GLfloat nx, GLfloat ny, GLfloat nz, GLfloat x, GLfloat y, GLfloat z)) _func)(s, t, nx, ny, nz, x, y, z);
}

GLAPI void APIENTRY glTexCoord2fNormal3fVertex3fvSUN(const GLfloat *tc, const GLfloat *n, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2535];
   ((void (APIENTRY *)(const GLfloat *tc, const GLfloat *n, const GLfloat *v)) _func)(tc, n, v);
}

GLAPI void APIENTRY glTexCoord2fVertex3fSUN(GLfloat s, GLfloat t, GLfloat x, GLfloat y, GLfloat z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2536];
   ((void (APIENTRY *)(GLfloat s, GLfloat t, GLfloat x, GLfloat y, GLfloat z)) _func)(s, t, x, y, z);
}

GLAPI void APIENTRY glTexCoord2fVertex3fvSUN(const GLfloat *tc, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2537];
   ((void (APIENTRY *)(const GLfloat *tc, const GLfloat *v)) _func)(tc, v);
}

GLAPI void APIENTRY glTexCoord2fv(const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2538];
   ((void (APIENTRY *)(const GLfloat *v)) _func)(v);
}

GLAPI void APIENTRY glTexCoord2hNV(GLhalf s, GLhalf t)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2539];
   ((void (APIENTRY *)(GLhalf s, GLhalf t)) _func)(s, t);
}

GLAPI void APIENTRY glTexCoord2hvNV(const GLhalf *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2540];
   ((void (APIENTRY *)(const GLhalf *v)) _func)(v);
}

GLAPI void APIENTRY glTexCoord2i(GLint s, GLint t)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2541];
   ((void (APIENTRY *)(GLint s, GLint t)) _func)(s, t);
}

GLAPI void APIENTRY glTexCoord2iv(const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2542];
   ((void (APIENTRY *)(const GLint *v)) _func)(v);
}

GLAPI void APIENTRY glTexCoord2s(GLshort s, GLshort t)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2543];
   ((void (APIENTRY *)(GLshort s, GLshort t)) _func)(s, t);
}

GLAPI void APIENTRY glTexCoord2sv(const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2544];
   ((void (APIENTRY *)(const GLshort *v)) _func)(v);
}

GLAPI void APIENTRY glTexCoord2xOES(GLfixed s, GLfixed t)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2545];
   ((void (APIENTRY *)(GLfixed s, GLfixed t)) _func)(s, t);
}

GLAPI void APIENTRY glTexCoord2xvOES(const GLfixed *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2546];
   ((void (APIENTRY *)(const GLfixed *coords)) _func)(coords);
}

GLAPI void APIENTRY glTexCoord3bOES(GLbyte s, GLbyte t, GLbyte r)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2547];
   ((void (APIENTRY *)(GLbyte s, GLbyte t, GLbyte r)) _func)(s, t, r);
}

GLAPI void APIENTRY glTexCoord3bvOES(const GLbyte *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2548];
   ((void (APIENTRY *)(const GLbyte *coords)) _func)(coords);
}

GLAPI void APIENTRY glTexCoord3d(GLdouble s, GLdouble t, GLdouble r)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2549];
   ((void (APIENTRY *)(GLdouble s, GLdouble t, GLdouble r)) _func)(s, t, r);
}

GLAPI void APIENTRY glTexCoord3dv(const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2550];
   ((void (APIENTRY *)(const GLdouble *v)) _func)(v);
}

GLAPI void APIENTRY glTexCoord3f(GLfloat s, GLfloat t, GLfloat r)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2551];
   ((void (APIENTRY *)(GLfloat s, GLfloat t, GLfloat r)) _func)(s, t, r);
}

GLAPI void APIENTRY glTexCoord3fv(const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2552];
   ((void (APIENTRY *)(const GLfloat *v)) _func)(v);
}

GLAPI void APIENTRY glTexCoord3hNV(GLhalf s, GLhalf t, GLhalf r)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2553];
   ((void (APIENTRY *)(GLhalf s, GLhalf t, GLhalf r)) _func)(s, t, r);
}

GLAPI void APIENTRY glTexCoord3hvNV(const GLhalf *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2554];
   ((void (APIENTRY *)(const GLhalf *v)) _func)(v);
}

GLAPI void APIENTRY glTexCoord3i(GLint s, GLint t, GLint r)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2555];
   ((void (APIENTRY *)(GLint s, GLint t, GLint r)) _func)(s, t, r);
}

GLAPI void APIENTRY glTexCoord3iv(const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2556];
   ((void (APIENTRY *)(const GLint *v)) _func)(v);
}

GLAPI void APIENTRY glTexCoord3s(GLshort s, GLshort t, GLshort r)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2557];
   ((void (APIENTRY *)(GLshort s, GLshort t, GLshort r)) _func)(s, t, r);
}

GLAPI void APIENTRY glTexCoord3sv(const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2558];
   ((void (APIENTRY *)(const GLshort *v)) _func)(v);
}

GLAPI void APIENTRY glTexCoord3xOES(GLfixed s, GLfixed t, GLfixed r)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2559];
   ((void (APIENTRY *)(GLfixed s, GLfixed t, GLfixed r)) _func)(s, t, r);
}

GLAPI void APIENTRY glTexCoord3xvOES(const GLfixed *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2560];
   ((void (APIENTRY *)(const GLfixed *coords)) _func)(coords);
}

GLAPI void APIENTRY glTexCoord4bOES(GLbyte s, GLbyte t, GLbyte r, GLbyte q)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2561];
   ((void (APIENTRY *)(GLbyte s, GLbyte t, GLbyte r, GLbyte q)) _func)(s, t, r, q);
}

GLAPI void APIENTRY glTexCoord4bvOES(const GLbyte *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2562];
   ((void (APIENTRY *)(const GLbyte *coords)) _func)(coords);
}

GLAPI void APIENTRY glTexCoord4d(GLdouble s, GLdouble t, GLdouble r, GLdouble q)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2563];
   ((void (APIENTRY *)(GLdouble s, GLdouble t, GLdouble r, GLdouble q)) _func)(s, t, r, q);
}

GLAPI void APIENTRY glTexCoord4dv(const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2564];
   ((void (APIENTRY *)(const GLdouble *v)) _func)(v);
}

GLAPI void APIENTRY glTexCoord4f(GLfloat s, GLfloat t, GLfloat r, GLfloat q)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2565];
   ((void (APIENTRY *)(GLfloat s, GLfloat t, GLfloat r, GLfloat q)) _func)(s, t, r, q);
}

GLAPI void APIENTRY glTexCoord4fColor4fNormal3fVertex4fSUN(GLfloat s, GLfloat t, GLfloat p, GLfloat q, GLfloat r, GLfloat g, GLfloat b, GLfloat a, GLfloat nx, GLfloat ny, GLfloat nz, GLfloat x, GLfloat y, GLfloat z, GLfloat w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2566];
   ((void (APIENTRY *)(GLfloat s, GLfloat t, GLfloat p, GLfloat q, GLfloat r, GLfloat g, GLfloat b, GLfloat a, GLfloat nx, GLfloat ny, GLfloat nz, GLfloat x, GLfloat y, GLfloat z, GLfloat w)) _func)(s, t, p, q, r, g, b, a, nx, ny, nz, x, y, z, w);
}

GLAPI void APIENTRY glTexCoord4fColor4fNormal3fVertex4fvSUN(const GLfloat *tc, const GLfloat *c, const GLfloat *n, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2567];
   ((void (APIENTRY *)(const GLfloat *tc, const GLfloat *c, const GLfloat *n, const GLfloat *v)) _func)(tc, c, n, v);
}

GLAPI void APIENTRY glTexCoord4fVertex4fSUN(GLfloat s, GLfloat t, GLfloat p, GLfloat q, GLfloat x, GLfloat y, GLfloat z, GLfloat w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2568];
   ((void (APIENTRY *)(GLfloat s, GLfloat t, GLfloat p, GLfloat q, GLfloat x, GLfloat y, GLfloat z, GLfloat w)) _func)(s, t, p, q, x, y, z, w);
}

GLAPI void APIENTRY glTexCoord4fVertex4fvSUN(const GLfloat *tc, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2569];
   ((void (APIENTRY *)(const GLfloat *tc, const GLfloat *v)) _func)(tc, v);
}

GLAPI void APIENTRY glTexCoord4fv(const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2570];
   ((void (APIENTRY *)(const GLfloat *v)) _func)(v);
}

GLAPI void APIENTRY glTexCoord4hNV(GLhalf s, GLhalf t, GLhalf r, GLhalf q)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2571];
   ((void (APIENTRY *)(GLhalf s, GLhalf t, GLhalf r, GLhalf q)) _func)(s, t, r, q);
}

GLAPI void APIENTRY glTexCoord4hvNV(const GLhalf *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2572];
   ((void (APIENTRY *)(const GLhalf *v)) _func)(v);
}

GLAPI void APIENTRY glTexCoord4i(GLint s, GLint t, GLint r, GLint q)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2573];
   ((void (APIENTRY *)(GLint s, GLint t, GLint r, GLint q)) _func)(s, t, r, q);
}

GLAPI void APIENTRY glTexCoord4iv(const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2574];
   ((void (APIENTRY *)(const GLint *v)) _func)(v);
}

GLAPI void APIENTRY glTexCoord4s(GLshort s, GLshort t, GLshort r, GLshort q)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2575];
   ((void (APIENTRY *)(GLshort s, GLshort t, GLshort r, GLshort q)) _func)(s, t, r, q);
}

GLAPI void APIENTRY glTexCoord4sv(const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2576];
   ((void (APIENTRY *)(const GLshort *v)) _func)(v);
}

GLAPI void APIENTRY glTexCoord4xOES(GLfixed s, GLfixed t, GLfixed r, GLfixed q)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2577];
   ((void (APIENTRY *)(GLfixed s, GLfixed t, GLfixed r, GLfixed q)) _func)(s, t, r, q);
}

GLAPI void APIENTRY glTexCoord4xvOES(const GLfixed *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2578];
   ((void (APIENTRY *)(const GLfixed *coords)) _func)(coords);
}

GLAPI void APIENTRY glTexCoordFormatNV(GLint size, GLenum type, GLsizei stride)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2579];
   ((void (APIENTRY *)(GLint size, GLenum type, GLsizei stride)) _func)(size, type, stride);
}

GLAPI void APIENTRY glTexCoordP1ui(GLenum type, GLuint coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2580];
   ((void (APIENTRY *)(GLenum type, GLuint coords)) _func)(type, coords);
}

GLAPI void APIENTRY glTexCoordP1uiv(GLenum type, const GLuint *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2581];
   ((void (APIENTRY *)(GLenum type, const GLuint *coords)) _func)(type, coords);
}

GLAPI void APIENTRY glTexCoordP2ui(GLenum type, GLuint coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2582];
   ((void (APIENTRY *)(GLenum type, GLuint coords)) _func)(type, coords);
}

GLAPI void APIENTRY glTexCoordP2uiv(GLenum type, const GLuint *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2583];
   ((void (APIENTRY *)(GLenum type, const GLuint *coords)) _func)(type, coords);
}

GLAPI void APIENTRY glTexCoordP3ui(GLenum type, GLuint coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2584];
   ((void (APIENTRY *)(GLenum type, GLuint coords)) _func)(type, coords);
}

GLAPI void APIENTRY glTexCoordP3uiv(GLenum type, const GLuint *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2585];
   ((void (APIENTRY *)(GLenum type, const GLuint *coords)) _func)(type, coords);
}

GLAPI void APIENTRY glTexCoordP4ui(GLenum type, GLuint coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2586];
   ((void (APIENTRY *)(GLenum type, GLuint coords)) _func)(type, coords);
}

GLAPI void APIENTRY glTexCoordP4uiv(GLenum type, const GLuint *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2587];
   ((void (APIENTRY *)(GLenum type, const GLuint *coords)) _func)(type, coords);
}

GLAPI void APIENTRY glTexCoordPointer(GLint size, GLenum type, GLsizei stride, const void *pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2588];
   ((void (APIENTRY *)(GLint size, GLenum type, GLsizei stride, const void *pointer)) _func)(size, type, stride, pointer);
}

GLAPI void APIENTRY glTexCoordPointerEXT(GLint size, GLenum type, GLsizei stride, GLsizei count, const void *pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2589];
   ((void (APIENTRY *)(GLint size, GLenum type, GLsizei stride, GLsizei count, const void *pointer)) _func)(size, type, stride, count, pointer);
}

GLAPI void APIENTRY glTexCoordPointerListIBM(GLint size, GLenum type, GLint stride, const void **pointer, GLint ptrstride)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2590];
   ((void (APIENTRY *)(GLint size, GLenum type, GLint stride, const void **pointer, GLint ptrstride)) _func)(size, type, stride, pointer, ptrstride);
}

GLAPI void APIENTRY glTexCoordPointervINTEL(GLint size, GLenum type, const void **pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2591];
   ((void (APIENTRY *)(GLint size, GLenum type, const void **pointer)) _func)(size, type, pointer);
}

GLAPI void APIENTRY glTexEnvf(GLenum target, GLenum pname, GLfloat param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2592];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLfloat param)) _func)(target, pname, param);
}

GLAPI void APIENTRY glTexEnvfv(GLenum target, GLenum pname, const GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2593];
   ((void (APIENTRY *)(GLenum target, GLenum pname, const GLfloat *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glTexEnvi(GLenum target, GLenum pname, GLint param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2594];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLint param)) _func)(target, pname, param);
}

GLAPI void APIENTRY glTexEnviv(GLenum target, GLenum pname, const GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2595];
   ((void (APIENTRY *)(GLenum target, GLenum pname, const GLint *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glTexEnvx(GLenum target, GLenum pname, GLfixed param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2596];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLfixed param)) _func)(target, pname, param);
}

GLAPI void APIENTRY glTexEnvxOES(GLenum target, GLenum pname, GLfixed param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2597];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLfixed param)) _func)(target, pname, param);
}

GLAPI void APIENTRY glTexEnvxv(GLenum target, GLenum pname, const GLfixed *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2598];
   ((void (APIENTRY *)(GLenum target, GLenum pname, const GLfixed *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glTexEnvxvOES(GLenum target, GLenum pname, const GLfixed *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2599];
   ((void (APIENTRY *)(GLenum target, GLenum pname, const GLfixed *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glTexFilterFuncSGIS(GLenum target, GLenum filter, GLsizei n, const GLfloat *weights)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2602];
   ((void (APIENTRY *)(GLenum target, GLenum filter, GLsizei n, const GLfloat *weights)) _func)(target, filter, n, weights);
}

GLAPI void APIENTRY glTexGend(GLenum coord, GLenum pname, GLdouble param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2603];
   ((void (APIENTRY *)(GLenum coord, GLenum pname, GLdouble param)) _func)(coord, pname, param);
}

GLAPI void APIENTRY glTexGendv(GLenum coord, GLenum pname, const GLdouble *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2604];
   ((void (APIENTRY *)(GLenum coord, GLenum pname, const GLdouble *params)) _func)(coord, pname, params);
}

GLAPI void APIENTRY glTexGenf(GLenum coord, GLenum pname, GLfloat param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2605];
   ((void (APIENTRY *)(GLenum coord, GLenum pname, GLfloat param)) _func)(coord, pname, param);
}

GLAPI void APIENTRY glTexGenfOES(GLenum coord, GLenum pname, GLfloat param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2606];
   ((void (APIENTRY *)(GLenum coord, GLenum pname, GLfloat param)) _func)(coord, pname, param);
}

GLAPI void APIENTRY glTexGenfv(GLenum coord, GLenum pname, const GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2607];
   ((void (APIENTRY *)(GLenum coord, GLenum pname, const GLfloat *params)) _func)(coord, pname, params);
}

GLAPI void APIENTRY glTexGenfvOES(GLenum coord, GLenum pname, const GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2608];
   ((void (APIENTRY *)(GLenum coord, GLenum pname, const GLfloat *params)) _func)(coord, pname, params);
}

GLAPI void APIENTRY glTexGeni(GLenum coord, GLenum pname, GLint param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2609];
   ((void (APIENTRY *)(GLenum coord, GLenum pname, GLint param)) _func)(coord, pname, param);
}

GLAPI void APIENTRY glTexGeniOES(GLenum coord, GLenum pname, GLint param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2610];
   ((void (APIENTRY *)(GLenum coord, GLenum pname, GLint param)) _func)(coord, pname, param);
}

GLAPI void APIENTRY glTexGeniv(GLenum coord, GLenum pname, const GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2611];
   ((void (APIENTRY *)(GLenum coord, GLenum pname, const GLint *params)) _func)(coord, pname, params);
}

GLAPI void APIENTRY glTexGenivOES(GLenum coord, GLenum pname, const GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2612];
   ((void (APIENTRY *)(GLenum coord, GLenum pname, const GLint *params)) _func)(coord, pname, params);
}

GLAPI void APIENTRY glTexGenxOES(GLenum coord, GLenum pname, GLfixed param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2613];
   ((void (APIENTRY *)(GLenum coord, GLenum pname, GLfixed param)) _func)(coord, pname, param);
}

GLAPI void APIENTRY glTexGenxvOES(GLenum coord, GLenum pname, const GLfixed *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2614];
   ((void (APIENTRY *)(GLenum coord, GLenum pname, const GLfixed *params)) _func)(coord, pname, params);
}

GLAPI void APIENTRY glTexImage1D(GLenum target, GLint level, GLint internalformat, GLsizei width, GLint border, GLenum format, GLenum type, const void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2615];
   ((void (APIENTRY *)(GLenum target, GLint level, GLint internalformat, GLsizei width, GLint border, GLenum format, GLenum type, const void *pixels)) _func)(target, level, internalformat, width, border, format, type, pixels);
}

GLAPI void APIENTRY glTexImage2D(GLenum target, GLint level, GLint internalformat, GLsizei width, GLsizei height, GLint border, GLenum format, GLenum type, const void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2616];
   ((void (APIENTRY *)(GLenum target, GLint level, GLint internalformat, GLsizei width, GLsizei height, GLint border, GLenum format, GLenum type, const void *pixels)) _func)(target, level, internalformat, width, height, border, format, type, pixels);
}

GLAPI void APIENTRY glTexImage2DMultisample(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLboolean fixedsamplelocations)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2617];
   ((void (APIENTRY *)(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLboolean fixedsamplelocations)) _func)(target, samples, internalformat, width, height, fixedsamplelocations);
}

GLAPI void APIENTRY glTexImage2DMultisampleCoverageNV(GLenum target, GLsizei coverageSamples, GLsizei colorSamples, GLint internalFormat, GLsizei width, GLsizei height, GLboolean fixedSampleLocations)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2618];
   ((void (APIENTRY *)(GLenum target, GLsizei coverageSamples, GLsizei colorSamples, GLint internalFormat, GLsizei width, GLsizei height, GLboolean fixedSampleLocations)) _func)(target, coverageSamples, colorSamples, internalFormat, width, height, fixedSampleLocations);
}

GLAPI void APIENTRY glTexImage3D(GLenum target, GLint level, GLint internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLenum format, GLenum type, const void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2619];
   ((void (APIENTRY *)(GLenum target, GLint level, GLint internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLenum format, GLenum type, const void *pixels)) _func)(target, level, internalformat, width, height, depth, border, format, type, pixels);
}

GLAPI void APIENTRY glTexImage3DEXT(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLenum format, GLenum type, const void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2620];
   ((void (APIENTRY *)(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLenum format, GLenum type, const void *pixels)) _func)(target, level, internalformat, width, height, depth, border, format, type, pixels);
}

GLAPI void APIENTRY glTexImage3DMultisample(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedsamplelocations)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2621];
   ((void (APIENTRY *)(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedsamplelocations)) _func)(target, samples, internalformat, width, height, depth, fixedsamplelocations);
}

GLAPI void APIENTRY glTexImage3DMultisampleCoverageNV(GLenum target, GLsizei coverageSamples, GLsizei colorSamples, GLint internalFormat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedSampleLocations)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2622];
   ((void (APIENTRY *)(GLenum target, GLsizei coverageSamples, GLsizei colorSamples, GLint internalFormat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedSampleLocations)) _func)(target, coverageSamples, colorSamples, internalFormat, width, height, depth, fixedSampleLocations);
}

GLAPI void APIENTRY glTexImage3DNV(GLenum target, GLint level, GLint internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLenum format, GLenum type, const void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2623];
   ((void (APIENTRY *)(GLenum target, GLint level, GLint internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLenum format, GLenum type, const void *pixels)) _func)(target, level, internalformat, width, height, depth, border, format, type, pixels);
}

GLAPI void APIENTRY glTexImage3DOES(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLenum format, GLenum type, const void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2624];
   ((void (APIENTRY *)(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLenum format, GLenum type, const void *pixels)) _func)(target, level, internalformat, width, height, depth, border, format, type, pixels);
}

GLAPI void APIENTRY glTexImage4DSGIS(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLsizei size4d, GLint border, GLenum format, GLenum type, const void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2625];
   ((void (APIENTRY *)(GLenum target, GLint level, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLsizei size4d, GLint border, GLenum format, GLenum type, const void *pixels)) _func)(target, level, internalformat, width, height, depth, size4d, border, format, type, pixels);
}

GLAPI void APIENTRY glTexPageCommitmentARB(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLboolean commit)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2626];
   ((void (APIENTRY *)(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLboolean commit)) _func)(target, level, xoffset, yoffset, zoffset, width, height, depth, commit);
}

GLAPI void APIENTRY glTexPageCommitmentEXT(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLboolean commit)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2627];
   ((void (APIENTRY *)(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLboolean commit)) _func)(target, level, xoffset, yoffset, zoffset, width, height, depth, commit);
}

GLAPI void APIENTRY glTexParameterIiv(GLenum target, GLenum pname, const GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2629];
   ((void (APIENTRY *)(GLenum target, GLenum pname, const GLint *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glTexParameterIivEXT(GLenum target, GLenum pname, const GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2630];
   ((void (APIENTRY *)(GLenum target, GLenum pname, const GLint *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glTexParameterIivOES(GLenum target, GLenum pname, const GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2631];
   ((void (APIENTRY *)(GLenum target, GLenum pname, const GLint *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glTexParameterIuiv(GLenum target, GLenum pname, const GLuint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2632];
   ((void (APIENTRY *)(GLenum target, GLenum pname, const GLuint *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glTexParameterIuivEXT(GLenum target, GLenum pname, const GLuint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2633];
   ((void (APIENTRY *)(GLenum target, GLenum pname, const GLuint *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glTexParameterIuivOES(GLenum target, GLenum pname, const GLuint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2634];
   ((void (APIENTRY *)(GLenum target, GLenum pname, const GLuint *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glTexParameterf(GLenum target, GLenum pname, GLfloat param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2635];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLfloat param)) _func)(target, pname, param);
}

GLAPI void APIENTRY glTexParameterfv(GLenum target, GLenum pname, const GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2636];
   ((void (APIENTRY *)(GLenum target, GLenum pname, const GLfloat *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glTexParameteri(GLenum target, GLenum pname, GLint param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2637];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLint param)) _func)(target, pname, param);
}

GLAPI void APIENTRY glTexParameteriv(GLenum target, GLenum pname, const GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2638];
   ((void (APIENTRY *)(GLenum target, GLenum pname, const GLint *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glTexParameterx(GLenum target, GLenum pname, GLfixed param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2639];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLfixed param)) _func)(target, pname, param);
}

GLAPI void APIENTRY glTexParameterxOES(GLenum target, GLenum pname, GLfixed param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2640];
   ((void (APIENTRY *)(GLenum target, GLenum pname, GLfixed param)) _func)(target, pname, param);
}

GLAPI void APIENTRY glTexParameterxv(GLenum target, GLenum pname, const GLfixed *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2641];
   ((void (APIENTRY *)(GLenum target, GLenum pname, const GLfixed *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glTexParameterxvOES(GLenum target, GLenum pname, const GLfixed *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2642];
   ((void (APIENTRY *)(GLenum target, GLenum pname, const GLfixed *params)) _func)(target, pname, params);
}

GLAPI void APIENTRY glTexRenderbufferNV(GLenum target, GLuint renderbuffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2643];
   ((void (APIENTRY *)(GLenum target, GLuint renderbuffer)) _func)(target, renderbuffer);
}

GLAPI void APIENTRY glTexStorage1D(GLenum target, GLsizei levels, GLenum internalformat, GLsizei width)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2644];
   ((void (APIENTRY *)(GLenum target, GLsizei levels, GLenum internalformat, GLsizei width)) _func)(target, levels, internalformat, width);
}

GLAPI void APIENTRY glTexStorage1DEXT(GLenum target, GLsizei levels, GLenum internalformat, GLsizei width)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2645];
   ((void (APIENTRY *)(GLenum target, GLsizei levels, GLenum internalformat, GLsizei width)) _func)(target, levels, internalformat, width);
}

GLAPI void APIENTRY glTexStorage2D(GLenum target, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2646];
   ((void (APIENTRY *)(GLenum target, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height)) _func)(target, levels, internalformat, width, height);
}

GLAPI void APIENTRY glTexStorage2DEXT(GLenum target, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2647];
   ((void (APIENTRY *)(GLenum target, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height)) _func)(target, levels, internalformat, width, height);
}

GLAPI void APIENTRY glTexStorage2DMultisample(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLboolean fixedsamplelocations)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2648];
   ((void (APIENTRY *)(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLboolean fixedsamplelocations)) _func)(target, samples, internalformat, width, height, fixedsamplelocations);
}

GLAPI void APIENTRY glTexStorage3D(GLenum target, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2649];
   ((void (APIENTRY *)(GLenum target, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth)) _func)(target, levels, internalformat, width, height, depth);
}

GLAPI void APIENTRY glTexStorage3DEXT(GLenum target, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2650];
   ((void (APIENTRY *)(GLenum target, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth)) _func)(target, levels, internalformat, width, height, depth);
}

GLAPI void APIENTRY glTexStorage3DMultisample(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedsamplelocations)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2651];
   ((void (APIENTRY *)(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedsamplelocations)) _func)(target, samples, internalformat, width, height, depth, fixedsamplelocations);
}

GLAPI void APIENTRY glTexStorage3DMultisampleOES(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedsamplelocations)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2652];
   ((void (APIENTRY *)(GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedsamplelocations)) _func)(target, samples, internalformat, width, height, depth, fixedsamplelocations);
}

GLAPI void APIENTRY glTexStorageMem1DEXT(GLenum target, GLsizei levels, GLenum internalFormat, GLsizei width, GLuint memory, GLuint64 offset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2655];
   ((void (APIENTRY *)(GLenum target, GLsizei levels, GLenum internalFormat, GLsizei width, GLuint memory, GLuint64 offset)) _func)(target, levels, internalFormat, width, memory, offset);
}

GLAPI void APIENTRY glTexStorageMem2DEXT(GLenum target, GLsizei levels, GLenum internalFormat, GLsizei width, GLsizei height, GLuint memory, GLuint64 offset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2656];
   ((void (APIENTRY *)(GLenum target, GLsizei levels, GLenum internalFormat, GLsizei width, GLsizei height, GLuint memory, GLuint64 offset)) _func)(target, levels, internalFormat, width, height, memory, offset);
}

GLAPI void APIENTRY glTexStorageMem2DMultisampleEXT(GLenum target, GLsizei samples, GLenum internalFormat, GLsizei width, GLsizei height, GLboolean fixedSampleLocations, GLuint memory, GLuint64 offset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2657];
   ((void (APIENTRY *)(GLenum target, GLsizei samples, GLenum internalFormat, GLsizei width, GLsizei height, GLboolean fixedSampleLocations, GLuint memory, GLuint64 offset)) _func)(target, samples, internalFormat, width, height, fixedSampleLocations, memory, offset);
}

GLAPI void APIENTRY glTexStorageMem3DEXT(GLenum target, GLsizei levels, GLenum internalFormat, GLsizei width, GLsizei height, GLsizei depth, GLuint memory, GLuint64 offset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2658];
   ((void (APIENTRY *)(GLenum target, GLsizei levels, GLenum internalFormat, GLsizei width, GLsizei height, GLsizei depth, GLuint memory, GLuint64 offset)) _func)(target, levels, internalFormat, width, height, depth, memory, offset);
}

GLAPI void APIENTRY glTexStorageMem3DMultisampleEXT(GLenum target, GLsizei samples, GLenum internalFormat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedSampleLocations, GLuint memory, GLuint64 offset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2659];
   ((void (APIENTRY *)(GLenum target, GLsizei samples, GLenum internalFormat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedSampleLocations, GLuint memory, GLuint64 offset)) _func)(target, samples, internalFormat, width, height, depth, fixedSampleLocations, memory, offset);
}

GLAPI void APIENTRY glTexStorageSparseAMD(GLenum target, GLenum internalFormat, GLsizei width, GLsizei height, GLsizei depth, GLsizei layers, GLbitfield flags)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2660];
   ((void (APIENTRY *)(GLenum target, GLenum internalFormat, GLsizei width, GLsizei height, GLsizei depth, GLsizei layers, GLbitfield flags)) _func)(target, internalFormat, width, height, depth, layers, flags);
}

GLAPI void APIENTRY glTexSubImage1D(GLenum target, GLint level, GLint xoffset, GLsizei width, GLenum format, GLenum type, const void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2661];
   ((void (APIENTRY *)(GLenum target, GLint level, GLint xoffset, GLsizei width, GLenum format, GLenum type, const void *pixels)) _func)(target, level, xoffset, width, format, type, pixels);
}

GLAPI void APIENTRY glTexSubImage1DEXT(GLenum target, GLint level, GLint xoffset, GLsizei width, GLenum format, GLenum type, const void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2662];
   ((void (APIENTRY *)(GLenum target, GLint level, GLint xoffset, GLsizei width, GLenum format, GLenum type, const void *pixels)) _func)(target, level, xoffset, width, format, type, pixels);
}

GLAPI void APIENTRY glTexSubImage2D(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLenum type, const void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2663];
   ((void (APIENTRY *)(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLenum type, const void *pixels)) _func)(target, level, xoffset, yoffset, width, height, format, type, pixels);
}

GLAPI void APIENTRY glTexSubImage2DEXT(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLenum type, const void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2664];
   ((void (APIENTRY *)(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLenum type, const void *pixels)) _func)(target, level, xoffset, yoffset, width, height, format, type, pixels);
}

GLAPI void APIENTRY glTexSubImage3D(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2665];
   ((void (APIENTRY *)(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void *pixels)) _func)(target, level, xoffset, yoffset, zoffset, width, height, depth, format, type, pixels);
}

GLAPI void APIENTRY glTexSubImage3DEXT(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2666];
   ((void (APIENTRY *)(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void *pixels)) _func)(target, level, xoffset, yoffset, zoffset, width, height, depth, format, type, pixels);
}

GLAPI void APIENTRY glTexSubImage3DNV(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2667];
   ((void (APIENTRY *)(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void *pixels)) _func)(target, level, xoffset, yoffset, zoffset, width, height, depth, format, type, pixels);
}

GLAPI void APIENTRY glTexSubImage3DOES(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2668];
   ((void (APIENTRY *)(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void *pixels)) _func)(target, level, xoffset, yoffset, zoffset, width, height, depth, format, type, pixels);
}

GLAPI void APIENTRY glTexSubImage4DSGIS(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLint woffset, GLsizei width, GLsizei height, GLsizei depth, GLsizei size4d, GLenum format, GLenum type, const void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2669];
   ((void (APIENTRY *)(GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLint woffset, GLsizei width, GLsizei height, GLsizei depth, GLsizei size4d, GLenum format, GLenum type, const void *pixels)) _func)(target, level, xoffset, yoffset, zoffset, woffset, width, height, depth, size4d, format, type, pixels);
}

GLAPI void APIENTRY glTextureAttachMemoryNV(GLuint texture, GLuint memory, GLuint64 offset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2670];
   ((void (APIENTRY *)(GLuint texture, GLuint memory, GLuint64 offset)) _func)(texture, memory, offset);
}

GLAPI void APIENTRY glTextureBarrier(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2671];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glTextureBarrierNV(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2672];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glTextureBuffer(GLuint texture, GLenum internalformat, GLuint buffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2673];
   ((void (APIENTRY *)(GLuint texture, GLenum internalformat, GLuint buffer)) _func)(texture, internalformat, buffer);
}

GLAPI void APIENTRY glTextureBufferEXT(GLuint texture, GLenum target, GLenum internalformat, GLuint buffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2674];
   ((void (APIENTRY *)(GLuint texture, GLenum target, GLenum internalformat, GLuint buffer)) _func)(texture, target, internalformat, buffer);
}

GLAPI void APIENTRY glTextureBufferRange(GLuint texture, GLenum internalformat, GLuint buffer, GLintptr offset, GLsizeiptr size)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2675];
   ((void (APIENTRY *)(GLuint texture, GLenum internalformat, GLuint buffer, GLintptr offset, GLsizeiptr size)) _func)(texture, internalformat, buffer, offset, size);
}

GLAPI void APIENTRY glTextureBufferRangeEXT(GLuint texture, GLenum target, GLenum internalformat, GLuint buffer, GLintptr offset, GLsizeiptr size)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2676];
   ((void (APIENTRY *)(GLuint texture, GLenum target, GLenum internalformat, GLuint buffer, GLintptr offset, GLsizeiptr size)) _func)(texture, target, internalformat, buffer, offset, size);
}

GLAPI void APIENTRY glTextureColorMaskSGIS(GLboolean red, GLboolean green, GLboolean blue, GLboolean alpha)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2677];
   ((void (APIENTRY *)(GLboolean red, GLboolean green, GLboolean blue, GLboolean alpha)) _func)(red, green, blue, alpha);
}

GLAPI void APIENTRY glTextureFoveationParametersQCOM(GLuint texture, GLuint layer, GLuint focalPoint, GLfloat focalX, GLfloat focalY, GLfloat gainX, GLfloat gainY, GLfloat foveaArea)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2678];
   ((void (APIENTRY *)(GLuint texture, GLuint layer, GLuint focalPoint, GLfloat focalX, GLfloat focalY, GLfloat gainX, GLfloat gainY, GLfloat foveaArea)) _func)(texture, layer, focalPoint, focalX, focalY, gainX, gainY, foveaArea);
}

GLAPI void APIENTRY glTextureImage1DEXT(GLuint texture, GLenum target, GLint level, GLint internalformat, GLsizei width, GLint border, GLenum format, GLenum type, const void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2679];
   ((void (APIENTRY *)(GLuint texture, GLenum target, GLint level, GLint internalformat, GLsizei width, GLint border, GLenum format, GLenum type, const void *pixels)) _func)(texture, target, level, internalformat, width, border, format, type, pixels);
}

GLAPI void APIENTRY glTextureImage2DEXT(GLuint texture, GLenum target, GLint level, GLint internalformat, GLsizei width, GLsizei height, GLint border, GLenum format, GLenum type, const void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2680];
   ((void (APIENTRY *)(GLuint texture, GLenum target, GLint level, GLint internalformat, GLsizei width, GLsizei height, GLint border, GLenum format, GLenum type, const void *pixels)) _func)(texture, target, level, internalformat, width, height, border, format, type, pixels);
}

GLAPI void APIENTRY glTextureImage2DMultisampleCoverageNV(GLuint texture, GLenum target, GLsizei coverageSamples, GLsizei colorSamples, GLint internalFormat, GLsizei width, GLsizei height, GLboolean fixedSampleLocations)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2681];
   ((void (APIENTRY *)(GLuint texture, GLenum target, GLsizei coverageSamples, GLsizei colorSamples, GLint internalFormat, GLsizei width, GLsizei height, GLboolean fixedSampleLocations)) _func)(texture, target, coverageSamples, colorSamples, internalFormat, width, height, fixedSampleLocations);
}

GLAPI void APIENTRY glTextureImage2DMultisampleNV(GLuint texture, GLenum target, GLsizei samples, GLint internalFormat, GLsizei width, GLsizei height, GLboolean fixedSampleLocations)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2682];
   ((void (APIENTRY *)(GLuint texture, GLenum target, GLsizei samples, GLint internalFormat, GLsizei width, GLsizei height, GLboolean fixedSampleLocations)) _func)(texture, target, samples, internalFormat, width, height, fixedSampleLocations);
}

GLAPI void APIENTRY glTextureImage3DEXT(GLuint texture, GLenum target, GLint level, GLint internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLenum format, GLenum type, const void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2683];
   ((void (APIENTRY *)(GLuint texture, GLenum target, GLint level, GLint internalformat, GLsizei width, GLsizei height, GLsizei depth, GLint border, GLenum format, GLenum type, const void *pixels)) _func)(texture, target, level, internalformat, width, height, depth, border, format, type, pixels);
}

GLAPI void APIENTRY glTextureImage3DMultisampleCoverageNV(GLuint texture, GLenum target, GLsizei coverageSamples, GLsizei colorSamples, GLint internalFormat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedSampleLocations)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2684];
   ((void (APIENTRY *)(GLuint texture, GLenum target, GLsizei coverageSamples, GLsizei colorSamples, GLint internalFormat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedSampleLocations)) _func)(texture, target, coverageSamples, colorSamples, internalFormat, width, height, depth, fixedSampleLocations);
}

GLAPI void APIENTRY glTextureImage3DMultisampleNV(GLuint texture, GLenum target, GLsizei samples, GLint internalFormat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedSampleLocations)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2685];
   ((void (APIENTRY *)(GLuint texture, GLenum target, GLsizei samples, GLint internalFormat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedSampleLocations)) _func)(texture, target, samples, internalFormat, width, height, depth, fixedSampleLocations);
}

GLAPI void APIENTRY glTextureLightEXT(GLenum pname)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2686];
   ((void (APIENTRY *)(GLenum pname)) _func)(pname);
}

GLAPI void APIENTRY glTextureMaterialEXT(GLenum face, GLenum mode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2687];
   ((void (APIENTRY *)(GLenum face, GLenum mode)) _func)(face, mode);
}

GLAPI void APIENTRY glTextureNormalEXT(GLenum mode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2688];
   ((void (APIENTRY *)(GLenum mode)) _func)(mode);
}

GLAPI void APIENTRY glTexturePageCommitmentEXT(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLboolean commit)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2689];
   ((void (APIENTRY *)(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLboolean commit)) _func)(texture, level, xoffset, yoffset, zoffset, width, height, depth, commit);
}

GLAPI void APIENTRY glTextureParameterIiv(GLuint texture, GLenum pname, const GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2691];
   ((void (APIENTRY *)(GLuint texture, GLenum pname, const GLint *params)) _func)(texture, pname, params);
}

GLAPI void APIENTRY glTextureParameterIivEXT(GLuint texture, GLenum target, GLenum pname, const GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2692];
   ((void (APIENTRY *)(GLuint texture, GLenum target, GLenum pname, const GLint *params)) _func)(texture, target, pname, params);
}

GLAPI void APIENTRY glTextureParameterIuiv(GLuint texture, GLenum pname, const GLuint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2693];
   ((void (APIENTRY *)(GLuint texture, GLenum pname, const GLuint *params)) _func)(texture, pname, params);
}

GLAPI void APIENTRY glTextureParameterIuivEXT(GLuint texture, GLenum target, GLenum pname, const GLuint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2694];
   ((void (APIENTRY *)(GLuint texture, GLenum target, GLenum pname, const GLuint *params)) _func)(texture, target, pname, params);
}

GLAPI void APIENTRY glTextureParameterf(GLuint texture, GLenum pname, GLfloat param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2695];
   ((void (APIENTRY *)(GLuint texture, GLenum pname, GLfloat param)) _func)(texture, pname, param);
}

GLAPI void APIENTRY glTextureParameterfEXT(GLuint texture, GLenum target, GLenum pname, GLfloat param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2696];
   ((void (APIENTRY *)(GLuint texture, GLenum target, GLenum pname, GLfloat param)) _func)(texture, target, pname, param);
}

GLAPI void APIENTRY glTextureParameterfv(GLuint texture, GLenum pname, const GLfloat *param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2697];
   ((void (APIENTRY *)(GLuint texture, GLenum pname, const GLfloat *param)) _func)(texture, pname, param);
}

GLAPI void APIENTRY glTextureParameterfvEXT(GLuint texture, GLenum target, GLenum pname, const GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2698];
   ((void (APIENTRY *)(GLuint texture, GLenum target, GLenum pname, const GLfloat *params)) _func)(texture, target, pname, params);
}

GLAPI void APIENTRY glTextureParameteri(GLuint texture, GLenum pname, GLint param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2699];
   ((void (APIENTRY *)(GLuint texture, GLenum pname, GLint param)) _func)(texture, pname, param);
}

GLAPI void APIENTRY glTextureParameteriEXT(GLuint texture, GLenum target, GLenum pname, GLint param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2700];
   ((void (APIENTRY *)(GLuint texture, GLenum target, GLenum pname, GLint param)) _func)(texture, target, pname, param);
}

GLAPI void APIENTRY glTextureParameteriv(GLuint texture, GLenum pname, const GLint *param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2701];
   ((void (APIENTRY *)(GLuint texture, GLenum pname, const GLint *param)) _func)(texture, pname, param);
}

GLAPI void APIENTRY glTextureParameterivEXT(GLuint texture, GLenum target, GLenum pname, const GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2702];
   ((void (APIENTRY *)(GLuint texture, GLenum target, GLenum pname, const GLint *params)) _func)(texture, target, pname, params);
}

GLAPI void APIENTRY glTextureRangeAPPLE(GLenum target, GLsizei length, const void *pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2703];
   ((void (APIENTRY *)(GLenum target, GLsizei length, const void *pointer)) _func)(target, length, pointer);
}

GLAPI void APIENTRY glTextureRenderbufferEXT(GLuint texture, GLenum target, GLuint renderbuffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2704];
   ((void (APIENTRY *)(GLuint texture, GLenum target, GLuint renderbuffer)) _func)(texture, target, renderbuffer);
}

GLAPI void APIENTRY glTextureStorage1D(GLuint texture, GLsizei levels, GLenum internalformat, GLsizei width)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2705];
   ((void (APIENTRY *)(GLuint texture, GLsizei levels, GLenum internalformat, GLsizei width)) _func)(texture, levels, internalformat, width);
}

GLAPI void APIENTRY glTextureStorage1DEXT(GLuint texture, GLenum target, GLsizei levels, GLenum internalformat, GLsizei width)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2706];
   ((void (APIENTRY *)(GLuint texture, GLenum target, GLsizei levels, GLenum internalformat, GLsizei width)) _func)(texture, target, levels, internalformat, width);
}

GLAPI void APIENTRY glTextureStorage2D(GLuint texture, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2707];
   ((void (APIENTRY *)(GLuint texture, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height)) _func)(texture, levels, internalformat, width, height);
}

GLAPI void APIENTRY glTextureStorage2DEXT(GLuint texture, GLenum target, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2708];
   ((void (APIENTRY *)(GLuint texture, GLenum target, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height)) _func)(texture, target, levels, internalformat, width, height);
}

GLAPI void APIENTRY glTextureStorage2DMultisample(GLuint texture, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLboolean fixedsamplelocations)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2709];
   ((void (APIENTRY *)(GLuint texture, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLboolean fixedsamplelocations)) _func)(texture, samples, internalformat, width, height, fixedsamplelocations);
}

GLAPI void APIENTRY glTextureStorage2DMultisampleEXT(GLuint texture, GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLboolean fixedsamplelocations)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2710];
   ((void (APIENTRY *)(GLuint texture, GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLboolean fixedsamplelocations)) _func)(texture, target, samples, internalformat, width, height, fixedsamplelocations);
}

GLAPI void APIENTRY glTextureStorage3D(GLuint texture, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2711];
   ((void (APIENTRY *)(GLuint texture, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth)) _func)(texture, levels, internalformat, width, height, depth);
}

GLAPI void APIENTRY glTextureStorage3DEXT(GLuint texture, GLenum target, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2712];
   ((void (APIENTRY *)(GLuint texture, GLenum target, GLsizei levels, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth)) _func)(texture, target, levels, internalformat, width, height, depth);
}

GLAPI void APIENTRY glTextureStorage3DMultisample(GLuint texture, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedsamplelocations)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2713];
   ((void (APIENTRY *)(GLuint texture, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedsamplelocations)) _func)(texture, samples, internalformat, width, height, depth, fixedsamplelocations);
}

GLAPI void APIENTRY glTextureStorage3DMultisampleEXT(GLuint texture, GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedsamplelocations)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2714];
   ((void (APIENTRY *)(GLuint texture, GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedsamplelocations)) _func)(texture, target, samples, internalformat, width, height, depth, fixedsamplelocations);
}

GLAPI void APIENTRY glTextureStorageMem1DEXT(GLuint texture, GLsizei levels, GLenum internalFormat, GLsizei width, GLuint memory, GLuint64 offset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2715];
   ((void (APIENTRY *)(GLuint texture, GLsizei levels, GLenum internalFormat, GLsizei width, GLuint memory, GLuint64 offset)) _func)(texture, levels, internalFormat, width, memory, offset);
}

GLAPI void APIENTRY glTextureStorageMem2DEXT(GLuint texture, GLsizei levels, GLenum internalFormat, GLsizei width, GLsizei height, GLuint memory, GLuint64 offset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2716];
   ((void (APIENTRY *)(GLuint texture, GLsizei levels, GLenum internalFormat, GLsizei width, GLsizei height, GLuint memory, GLuint64 offset)) _func)(texture, levels, internalFormat, width, height, memory, offset);
}

GLAPI void APIENTRY glTextureStorageMem2DMultisampleEXT(GLuint texture, GLsizei samples, GLenum internalFormat, GLsizei width, GLsizei height, GLboolean fixedSampleLocations, GLuint memory, GLuint64 offset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2717];
   ((void (APIENTRY *)(GLuint texture, GLsizei samples, GLenum internalFormat, GLsizei width, GLsizei height, GLboolean fixedSampleLocations, GLuint memory, GLuint64 offset)) _func)(texture, samples, internalFormat, width, height, fixedSampleLocations, memory, offset);
}

GLAPI void APIENTRY glTextureStorageMem3DEXT(GLuint texture, GLsizei levels, GLenum internalFormat, GLsizei width, GLsizei height, GLsizei depth, GLuint memory, GLuint64 offset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2718];
   ((void (APIENTRY *)(GLuint texture, GLsizei levels, GLenum internalFormat, GLsizei width, GLsizei height, GLsizei depth, GLuint memory, GLuint64 offset)) _func)(texture, levels, internalFormat, width, height, depth, memory, offset);
}

GLAPI void APIENTRY glTextureStorageMem3DMultisampleEXT(GLuint texture, GLsizei samples, GLenum internalFormat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedSampleLocations, GLuint memory, GLuint64 offset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2719];
   ((void (APIENTRY *)(GLuint texture, GLsizei samples, GLenum internalFormat, GLsizei width, GLsizei height, GLsizei depth, GLboolean fixedSampleLocations, GLuint memory, GLuint64 offset)) _func)(texture, samples, internalFormat, width, height, depth, fixedSampleLocations, memory, offset);
}

GLAPI void APIENTRY glTextureStorageSparseAMD(GLuint texture, GLenum target, GLenum internalFormat, GLsizei width, GLsizei height, GLsizei depth, GLsizei layers, GLbitfield flags)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2720];
   ((void (APIENTRY *)(GLuint texture, GLenum target, GLenum internalFormat, GLsizei width, GLsizei height, GLsizei depth, GLsizei layers, GLbitfield flags)) _func)(texture, target, internalFormat, width, height, depth, layers, flags);
}

GLAPI void APIENTRY glTextureSubImage1D(GLuint texture, GLint level, GLint xoffset, GLsizei width, GLenum format, GLenum type, const void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2721];
   ((void (APIENTRY *)(GLuint texture, GLint level, GLint xoffset, GLsizei width, GLenum format, GLenum type, const void *pixels)) _func)(texture, level, xoffset, width, format, type, pixels);
}

GLAPI void APIENTRY glTextureSubImage1DEXT(GLuint texture, GLenum target, GLint level, GLint xoffset, GLsizei width, GLenum format, GLenum type, const void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2722];
   ((void (APIENTRY *)(GLuint texture, GLenum target, GLint level, GLint xoffset, GLsizei width, GLenum format, GLenum type, const void *pixels)) _func)(texture, target, level, xoffset, width, format, type, pixels);
}

GLAPI void APIENTRY glTextureSubImage2D(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLenum type, const void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2723];
   ((void (APIENTRY *)(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLenum type, const void *pixels)) _func)(texture, level, xoffset, yoffset, width, height, format, type, pixels);
}

GLAPI void APIENTRY glTextureSubImage2DEXT(GLuint texture, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLenum type, const void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2724];
   ((void (APIENTRY *)(GLuint texture, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLsizei width, GLsizei height, GLenum format, GLenum type, const void *pixels)) _func)(texture, target, level, xoffset, yoffset, width, height, format, type, pixels);
}

GLAPI void APIENTRY glTextureSubImage3D(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2725];
   ((void (APIENTRY *)(GLuint texture, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void *pixels)) _func)(texture, level, xoffset, yoffset, zoffset, width, height, depth, format, type, pixels);
}

GLAPI void APIENTRY glTextureSubImage3DEXT(GLuint texture, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void *pixels)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2726];
   ((void (APIENTRY *)(GLuint texture, GLenum target, GLint level, GLint xoffset, GLint yoffset, GLint zoffset, GLsizei width, GLsizei height, GLsizei depth, GLenum format, GLenum type, const void *pixels)) _func)(texture, target, level, xoffset, yoffset, zoffset, width, height, depth, format, type, pixels);
}

GLAPI void APIENTRY glTextureView(GLuint texture, GLenum target, GLuint origtexture, GLenum internalformat, GLuint minlevel, GLuint numlevels, GLuint minlayer, GLuint numlayers)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2727];
   ((void (APIENTRY *)(GLuint texture, GLenum target, GLuint origtexture, GLenum internalformat, GLuint minlevel, GLuint numlevels, GLuint minlayer, GLuint numlayers)) _func)(texture, target, origtexture, internalformat, minlevel, numlevels, minlayer, numlayers);
}

GLAPI void APIENTRY glTextureViewEXT(GLuint texture, GLenum target, GLuint origtexture, GLenum internalformat, GLuint minlevel, GLuint numlevels, GLuint minlayer, GLuint numlayers)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2728];
   ((void (APIENTRY *)(GLuint texture, GLenum target, GLuint origtexture, GLenum internalformat, GLuint minlevel, GLuint numlevels, GLuint minlayer, GLuint numlayers)) _func)(texture, target, origtexture, internalformat, minlevel, numlevels, minlayer, numlayers);
}

GLAPI void APIENTRY glTextureViewOES(GLuint texture, GLenum target, GLuint origtexture, GLenum internalformat, GLuint minlevel, GLuint numlevels, GLuint minlayer, GLuint numlayers)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2729];
   ((void (APIENTRY *)(GLuint texture, GLenum target, GLuint origtexture, GLenum internalformat, GLuint minlevel, GLuint numlevels, GLuint minlayer, GLuint numlayers)) _func)(texture, target, origtexture, internalformat, minlevel, numlevels, minlayer, numlayers);
}

GLAPI void APIENTRY glTrackMatrixNV(GLenum target, GLuint address, GLenum matrix, GLenum transform)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2730];
   ((void (APIENTRY *)(GLenum target, GLuint address, GLenum matrix, GLenum transform)) _func)(target, address, matrix, transform);
}

GLAPI void APIENTRY glTransformFeedbackAttribsNV(GLsizei count, const GLint *attribs, GLenum bufferMode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2731];
   ((void (APIENTRY *)(GLsizei count, const GLint *attribs, GLenum bufferMode)) _func)(count, attribs, bufferMode);
}

GLAPI void APIENTRY glTransformFeedbackBufferBase(GLuint xfb, GLuint index, GLuint buffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2732];
   ((void (APIENTRY *)(GLuint xfb, GLuint index, GLuint buffer)) _func)(xfb, index, buffer);
}

GLAPI void APIENTRY glTransformFeedbackBufferRange(GLuint xfb, GLuint index, GLuint buffer, GLintptr offset, GLsizeiptr size)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2733];
   ((void (APIENTRY *)(GLuint xfb, GLuint index, GLuint buffer, GLintptr offset, GLsizeiptr size)) _func)(xfb, index, buffer, offset, size);
}

GLAPI void APIENTRY glTransformFeedbackStreamAttribsNV(GLsizei count, const GLint *attribs, GLsizei nbuffers, const GLint *bufstreams, GLenum bufferMode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2734];
   ((void (APIENTRY *)(GLsizei count, const GLint *attribs, GLsizei nbuffers, const GLint *bufstreams, GLenum bufferMode)) _func)(count, attribs, nbuffers, bufstreams, bufferMode);
}

GLAPI void APIENTRY glTransformFeedbackVaryings(GLuint program, GLsizei count, const GLchar *const *varyings, GLenum bufferMode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2735];
   ((void (APIENTRY *)(GLuint program, GLsizei count, const GLchar *const *varyings, GLenum bufferMode)) _func)(program, count, varyings, bufferMode);
}

GLAPI void APIENTRY glTransformFeedbackVaryingsEXT(GLuint program, GLsizei count, const GLchar *const *varyings, GLenum bufferMode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2736];
   ((void (APIENTRY *)(GLuint program, GLsizei count, const GLchar *const *varyings, GLenum bufferMode)) _func)(program, count, varyings, bufferMode);
}

GLAPI void APIENTRY glTransformFeedbackVaryingsNV(GLuint program, GLsizei count, const GLint *locations, GLenum bufferMode)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2737];
   ((void (APIENTRY *)(GLuint program, GLsizei count, const GLint *locations, GLenum bufferMode)) _func)(program, count, locations, bufferMode);
}

GLAPI void APIENTRY glTransformPathNV(GLuint resultPath, GLuint srcPath, GLenum transformType, const GLfloat *transformValues)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2738];
   ((void (APIENTRY *)(GLuint resultPath, GLuint srcPath, GLenum transformType, const GLfloat *transformValues)) _func)(resultPath, srcPath, transformType, transformValues);
}

GLAPI void APIENTRY glTranslated(GLdouble x, GLdouble y, GLdouble z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2739];
   ((void (APIENTRY *)(GLdouble x, GLdouble y, GLdouble z)) _func)(x, y, z);
}

GLAPI void APIENTRY glTranslatef(GLfloat x, GLfloat y, GLfloat z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2740];
   ((void (APIENTRY *)(GLfloat x, GLfloat y, GLfloat z)) _func)(x, y, z);
}

GLAPI void APIENTRY glTranslatex(GLfixed x, GLfixed y, GLfixed z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2741];
   ((void (APIENTRY *)(GLfixed x, GLfixed y, GLfixed z)) _func)(x, y, z);
}

GLAPI void APIENTRY glTranslatexOES(GLfixed x, GLfixed y, GLfixed z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2742];
   ((void (APIENTRY *)(GLfixed x, GLfixed y, GLfixed z)) _func)(x, y, z);
}

GLAPI void APIENTRY glUniform1d(GLint location, GLdouble x)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2743];
   ((void (APIENTRY *)(GLint location, GLdouble x)) _func)(location, x);
}

GLAPI void APIENTRY glUniform1dv(GLint location, GLsizei count, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2744];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLdouble *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniform1f(GLint location, GLfloat v0)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2745];
   ((void (APIENTRY *)(GLint location, GLfloat v0)) _func)(location, v0);
}

GLAPI void APIENTRY glUniform1fARB(GLint location, GLfloat v0)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2746];
   ((void (APIENTRY *)(GLint location, GLfloat v0)) _func)(location, v0);
}

GLAPI void APIENTRY glUniform1fv(GLint location, GLsizei count, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2747];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLfloat *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniform1fvARB(GLint location, GLsizei count, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2748];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLfloat *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniform1i(GLint location, GLint v0)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2749];
   ((void (APIENTRY *)(GLint location, GLint v0)) _func)(location, v0);
}

GLAPI void APIENTRY glUniform1i64ARB(GLint location, GLint64 x)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2750];
   ((void (APIENTRY *)(GLint location, GLint64 x)) _func)(location, x);
}

GLAPI void APIENTRY glUniform1i64NV(GLint location, GLint64 x)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2751];
   ((void (APIENTRY *)(GLint location, GLint64 x)) _func)(location, x);
}

GLAPI void APIENTRY glUniform1i64vARB(GLint location, GLsizei count, const GLint64 *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2752];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLint64 *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniform1i64vNV(GLint location, GLsizei count, const GLint64 *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2753];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLint64 *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniform1iARB(GLint location, GLint v0)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2754];
   ((void (APIENTRY *)(GLint location, GLint v0)) _func)(location, v0);
}

GLAPI void APIENTRY glUniform1iv(GLint location, GLsizei count, const GLint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2755];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLint *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniform1ivARB(GLint location, GLsizei count, const GLint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2756];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLint *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniform1ui(GLint location, GLuint v0)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2757];
   ((void (APIENTRY *)(GLint location, GLuint v0)) _func)(location, v0);
}

GLAPI void APIENTRY glUniform1ui64ARB(GLint location, GLuint64 x)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2758];
   ((void (APIENTRY *)(GLint location, GLuint64 x)) _func)(location, x);
}

GLAPI void APIENTRY glUniform1ui64NV(GLint location, GLuint64 x)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2759];
   ((void (APIENTRY *)(GLint location, GLuint64 x)) _func)(location, x);
}

GLAPI void APIENTRY glUniform1ui64vARB(GLint location, GLsizei count, const GLuint64 *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2760];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLuint64 *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniform1ui64vNV(GLint location, GLsizei count, const GLuint64 *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2761];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLuint64 *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniform1uiEXT(GLint location, GLuint v0)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2762];
   ((void (APIENTRY *)(GLint location, GLuint v0)) _func)(location, v0);
}

GLAPI void APIENTRY glUniform1uiv(GLint location, GLsizei count, const GLuint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2763];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLuint *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniform1uivEXT(GLint location, GLsizei count, const GLuint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2764];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLuint *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniform2d(GLint location, GLdouble x, GLdouble y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2765];
   ((void (APIENTRY *)(GLint location, GLdouble x, GLdouble y)) _func)(location, x, y);
}

GLAPI void APIENTRY glUniform2dv(GLint location, GLsizei count, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2766];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLdouble *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniform2f(GLint location, GLfloat v0, GLfloat v1)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2767];
   ((void (APIENTRY *)(GLint location, GLfloat v0, GLfloat v1)) _func)(location, v0, v1);
}

GLAPI void APIENTRY glUniform2fARB(GLint location, GLfloat v0, GLfloat v1)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2768];
   ((void (APIENTRY *)(GLint location, GLfloat v0, GLfloat v1)) _func)(location, v0, v1);
}

GLAPI void APIENTRY glUniform2fv(GLint location, GLsizei count, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2769];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLfloat *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniform2fvARB(GLint location, GLsizei count, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2770];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLfloat *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniform2i(GLint location, GLint v0, GLint v1)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2771];
   ((void (APIENTRY *)(GLint location, GLint v0, GLint v1)) _func)(location, v0, v1);
}

GLAPI void APIENTRY glUniform2i64ARB(GLint location, GLint64 x, GLint64 y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2772];
   ((void (APIENTRY *)(GLint location, GLint64 x, GLint64 y)) _func)(location, x, y);
}

GLAPI void APIENTRY glUniform2i64NV(GLint location, GLint64 x, GLint64 y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2773];
   ((void (APIENTRY *)(GLint location, GLint64 x, GLint64 y)) _func)(location, x, y);
}

GLAPI void APIENTRY glUniform2i64vARB(GLint location, GLsizei count, const GLint64 *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2774];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLint64 *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniform2i64vNV(GLint location, GLsizei count, const GLint64 *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2775];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLint64 *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniform2iARB(GLint location, GLint v0, GLint v1)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2776];
   ((void (APIENTRY *)(GLint location, GLint v0, GLint v1)) _func)(location, v0, v1);
}

GLAPI void APIENTRY glUniform2iv(GLint location, GLsizei count, const GLint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2777];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLint *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniform2ivARB(GLint location, GLsizei count, const GLint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2778];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLint *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniform2ui(GLint location, GLuint v0, GLuint v1)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2779];
   ((void (APIENTRY *)(GLint location, GLuint v0, GLuint v1)) _func)(location, v0, v1);
}

GLAPI void APIENTRY glUniform2ui64ARB(GLint location, GLuint64 x, GLuint64 y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2780];
   ((void (APIENTRY *)(GLint location, GLuint64 x, GLuint64 y)) _func)(location, x, y);
}

GLAPI void APIENTRY glUniform2ui64NV(GLint location, GLuint64 x, GLuint64 y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2781];
   ((void (APIENTRY *)(GLint location, GLuint64 x, GLuint64 y)) _func)(location, x, y);
}

GLAPI void APIENTRY glUniform2ui64vARB(GLint location, GLsizei count, const GLuint64 *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2782];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLuint64 *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniform2ui64vNV(GLint location, GLsizei count, const GLuint64 *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2783];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLuint64 *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniform2uiEXT(GLint location, GLuint v0, GLuint v1)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2784];
   ((void (APIENTRY *)(GLint location, GLuint v0, GLuint v1)) _func)(location, v0, v1);
}

GLAPI void APIENTRY glUniform2uiv(GLint location, GLsizei count, const GLuint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2785];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLuint *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniform2uivEXT(GLint location, GLsizei count, const GLuint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2786];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLuint *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniform3d(GLint location, GLdouble x, GLdouble y, GLdouble z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2787];
   ((void (APIENTRY *)(GLint location, GLdouble x, GLdouble y, GLdouble z)) _func)(location, x, y, z);
}

GLAPI void APIENTRY glUniform3dv(GLint location, GLsizei count, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2788];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLdouble *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniform3f(GLint location, GLfloat v0, GLfloat v1, GLfloat v2)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2789];
   ((void (APIENTRY *)(GLint location, GLfloat v0, GLfloat v1, GLfloat v2)) _func)(location, v0, v1, v2);
}

GLAPI void APIENTRY glUniform3fARB(GLint location, GLfloat v0, GLfloat v1, GLfloat v2)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2790];
   ((void (APIENTRY *)(GLint location, GLfloat v0, GLfloat v1, GLfloat v2)) _func)(location, v0, v1, v2);
}

GLAPI void APIENTRY glUniform3fv(GLint location, GLsizei count, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2791];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLfloat *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniform3fvARB(GLint location, GLsizei count, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2792];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLfloat *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniform3i(GLint location, GLint v0, GLint v1, GLint v2)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2793];
   ((void (APIENTRY *)(GLint location, GLint v0, GLint v1, GLint v2)) _func)(location, v0, v1, v2);
}

GLAPI void APIENTRY glUniform3i64ARB(GLint location, GLint64 x, GLint64 y, GLint64 z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2794];
   ((void (APIENTRY *)(GLint location, GLint64 x, GLint64 y, GLint64 z)) _func)(location, x, y, z);
}

GLAPI void APIENTRY glUniform3i64NV(GLint location, GLint64 x, GLint64 y, GLint64 z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2795];
   ((void (APIENTRY *)(GLint location, GLint64 x, GLint64 y, GLint64 z)) _func)(location, x, y, z);
}

GLAPI void APIENTRY glUniform3i64vARB(GLint location, GLsizei count, const GLint64 *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2796];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLint64 *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniform3i64vNV(GLint location, GLsizei count, const GLint64 *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2797];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLint64 *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniform3iARB(GLint location, GLint v0, GLint v1, GLint v2)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2798];
   ((void (APIENTRY *)(GLint location, GLint v0, GLint v1, GLint v2)) _func)(location, v0, v1, v2);
}

GLAPI void APIENTRY glUniform3iv(GLint location, GLsizei count, const GLint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2799];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLint *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniform3ivARB(GLint location, GLsizei count, const GLint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2800];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLint *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniform3ui(GLint location, GLuint v0, GLuint v1, GLuint v2)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2801];
   ((void (APIENTRY *)(GLint location, GLuint v0, GLuint v1, GLuint v2)) _func)(location, v0, v1, v2);
}

GLAPI void APIENTRY glUniform3ui64ARB(GLint location, GLuint64 x, GLuint64 y, GLuint64 z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2802];
   ((void (APIENTRY *)(GLint location, GLuint64 x, GLuint64 y, GLuint64 z)) _func)(location, x, y, z);
}

GLAPI void APIENTRY glUniform3ui64NV(GLint location, GLuint64 x, GLuint64 y, GLuint64 z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2803];
   ((void (APIENTRY *)(GLint location, GLuint64 x, GLuint64 y, GLuint64 z)) _func)(location, x, y, z);
}

GLAPI void APIENTRY glUniform3ui64vARB(GLint location, GLsizei count, const GLuint64 *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2804];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLuint64 *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniform3ui64vNV(GLint location, GLsizei count, const GLuint64 *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2805];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLuint64 *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniform3uiEXT(GLint location, GLuint v0, GLuint v1, GLuint v2)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2806];
   ((void (APIENTRY *)(GLint location, GLuint v0, GLuint v1, GLuint v2)) _func)(location, v0, v1, v2);
}

GLAPI void APIENTRY glUniform3uiv(GLint location, GLsizei count, const GLuint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2807];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLuint *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniform3uivEXT(GLint location, GLsizei count, const GLuint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2808];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLuint *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniform4d(GLint location, GLdouble x, GLdouble y, GLdouble z, GLdouble w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2809];
   ((void (APIENTRY *)(GLint location, GLdouble x, GLdouble y, GLdouble z, GLdouble w)) _func)(location, x, y, z, w);
}

GLAPI void APIENTRY glUniform4dv(GLint location, GLsizei count, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2810];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLdouble *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniform4f(GLint location, GLfloat v0, GLfloat v1, GLfloat v2, GLfloat v3)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2811];
   ((void (APIENTRY *)(GLint location, GLfloat v0, GLfloat v1, GLfloat v2, GLfloat v3)) _func)(location, v0, v1, v2, v3);
}

GLAPI void APIENTRY glUniform4fARB(GLint location, GLfloat v0, GLfloat v1, GLfloat v2, GLfloat v3)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2812];
   ((void (APIENTRY *)(GLint location, GLfloat v0, GLfloat v1, GLfloat v2, GLfloat v3)) _func)(location, v0, v1, v2, v3);
}

GLAPI void APIENTRY glUniform4fv(GLint location, GLsizei count, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2813];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLfloat *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniform4fvARB(GLint location, GLsizei count, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2814];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLfloat *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniform4i(GLint location, GLint v0, GLint v1, GLint v2, GLint v3)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2815];
   ((void (APIENTRY *)(GLint location, GLint v0, GLint v1, GLint v2, GLint v3)) _func)(location, v0, v1, v2, v3);
}

GLAPI void APIENTRY glUniform4i64ARB(GLint location, GLint64 x, GLint64 y, GLint64 z, GLint64 w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2816];
   ((void (APIENTRY *)(GLint location, GLint64 x, GLint64 y, GLint64 z, GLint64 w)) _func)(location, x, y, z, w);
}

GLAPI void APIENTRY glUniform4i64NV(GLint location, GLint64 x, GLint64 y, GLint64 z, GLint64 w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2817];
   ((void (APIENTRY *)(GLint location, GLint64 x, GLint64 y, GLint64 z, GLint64 w)) _func)(location, x, y, z, w);
}

GLAPI void APIENTRY glUniform4i64vARB(GLint location, GLsizei count, const GLint64 *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2818];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLint64 *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniform4i64vNV(GLint location, GLsizei count, const GLint64 *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2819];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLint64 *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniform4iARB(GLint location, GLint v0, GLint v1, GLint v2, GLint v3)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2820];
   ((void (APIENTRY *)(GLint location, GLint v0, GLint v1, GLint v2, GLint v3)) _func)(location, v0, v1, v2, v3);
}

GLAPI void APIENTRY glUniform4iv(GLint location, GLsizei count, const GLint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2821];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLint *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniform4ivARB(GLint location, GLsizei count, const GLint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2822];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLint *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniform4ui(GLint location, GLuint v0, GLuint v1, GLuint v2, GLuint v3)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2823];
   ((void (APIENTRY *)(GLint location, GLuint v0, GLuint v1, GLuint v2, GLuint v3)) _func)(location, v0, v1, v2, v3);
}

GLAPI void APIENTRY glUniform4ui64ARB(GLint location, GLuint64 x, GLuint64 y, GLuint64 z, GLuint64 w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2824];
   ((void (APIENTRY *)(GLint location, GLuint64 x, GLuint64 y, GLuint64 z, GLuint64 w)) _func)(location, x, y, z, w);
}

GLAPI void APIENTRY glUniform4ui64NV(GLint location, GLuint64 x, GLuint64 y, GLuint64 z, GLuint64 w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2825];
   ((void (APIENTRY *)(GLint location, GLuint64 x, GLuint64 y, GLuint64 z, GLuint64 w)) _func)(location, x, y, z, w);
}

GLAPI void APIENTRY glUniform4ui64vARB(GLint location, GLsizei count, const GLuint64 *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2826];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLuint64 *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniform4ui64vNV(GLint location, GLsizei count, const GLuint64 *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2827];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLuint64 *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniform4uiEXT(GLint location, GLuint v0, GLuint v1, GLuint v2, GLuint v3)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2828];
   ((void (APIENTRY *)(GLint location, GLuint v0, GLuint v1, GLuint v2, GLuint v3)) _func)(location, v0, v1, v2, v3);
}

GLAPI void APIENTRY glUniform4uiv(GLint location, GLsizei count, const GLuint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2829];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLuint *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniform4uivEXT(GLint location, GLsizei count, const GLuint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2830];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLuint *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniformBlockBinding(GLuint program, GLuint uniformBlockIndex, GLuint uniformBlockBinding)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2831];
   ((void (APIENTRY *)(GLuint program, GLuint uniformBlockIndex, GLuint uniformBlockBinding)) _func)(program, uniformBlockIndex, uniformBlockBinding);
}

GLAPI void APIENTRY glUniformBufferEXT(GLuint program, GLint location, GLuint buffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2832];
   ((void (APIENTRY *)(GLuint program, GLint location, GLuint buffer)) _func)(program, location, buffer);
}

GLAPI void APIENTRY glUniformHandleui64ARB(GLint location, GLuint64 value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2833];
   ((void (APIENTRY *)(GLint location, GLuint64 value)) _func)(location, value);
}

GLAPI void APIENTRY glUniformHandleui64IMG(GLint location, GLuint64 value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2834];
   ((void (APIENTRY *)(GLint location, GLuint64 value)) _func)(location, value);
}

GLAPI void APIENTRY glUniformHandleui64NV(GLint location, GLuint64 value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2835];
   ((void (APIENTRY *)(GLint location, GLuint64 value)) _func)(location, value);
}

GLAPI void APIENTRY glUniformHandleui64vARB(GLint location, GLsizei count, const GLuint64 *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2836];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLuint64 *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniformHandleui64vIMG(GLint location, GLsizei count, const GLuint64 *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2837];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLuint64 *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniformHandleui64vNV(GLint location, GLsizei count, const GLuint64 *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2838];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLuint64 *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUniformMatrix2dv(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2839];
   ((void (APIENTRY *)(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)) _func)(location, count, transpose, value);
}

GLAPI void APIENTRY glUniformMatrix2fv(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2840];
   ((void (APIENTRY *)(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)) _func)(location, count, transpose, value);
}

GLAPI void APIENTRY glUniformMatrix2fvARB(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2841];
   ((void (APIENTRY *)(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)) _func)(location, count, transpose, value);
}

GLAPI void APIENTRY glUniformMatrix2x3dv(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2842];
   ((void (APIENTRY *)(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)) _func)(location, count, transpose, value);
}

GLAPI void APIENTRY glUniformMatrix2x3fv(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2843];
   ((void (APIENTRY *)(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)) _func)(location, count, transpose, value);
}

GLAPI void APIENTRY glUniformMatrix2x3fvNV(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2844];
   ((void (APIENTRY *)(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)) _func)(location, count, transpose, value);
}

GLAPI void APIENTRY glUniformMatrix2x4dv(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2845];
   ((void (APIENTRY *)(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)) _func)(location, count, transpose, value);
}

GLAPI void APIENTRY glUniformMatrix2x4fv(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2846];
   ((void (APIENTRY *)(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)) _func)(location, count, transpose, value);
}

GLAPI void APIENTRY glUniformMatrix2x4fvNV(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2847];
   ((void (APIENTRY *)(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)) _func)(location, count, transpose, value);
}

GLAPI void APIENTRY glUniformMatrix3dv(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2848];
   ((void (APIENTRY *)(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)) _func)(location, count, transpose, value);
}

GLAPI void APIENTRY glUniformMatrix3fv(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2849];
   ((void (APIENTRY *)(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)) _func)(location, count, transpose, value);
}

GLAPI void APIENTRY glUniformMatrix3fvARB(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2850];
   ((void (APIENTRY *)(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)) _func)(location, count, transpose, value);
}

GLAPI void APIENTRY glUniformMatrix3x2dv(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2851];
   ((void (APIENTRY *)(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)) _func)(location, count, transpose, value);
}

GLAPI void APIENTRY glUniformMatrix3x2fv(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2852];
   ((void (APIENTRY *)(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)) _func)(location, count, transpose, value);
}

GLAPI void APIENTRY glUniformMatrix3x2fvNV(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2853];
   ((void (APIENTRY *)(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)) _func)(location, count, transpose, value);
}

GLAPI void APIENTRY glUniformMatrix3x4dv(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2854];
   ((void (APIENTRY *)(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)) _func)(location, count, transpose, value);
}

GLAPI void APIENTRY glUniformMatrix3x4fv(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2855];
   ((void (APIENTRY *)(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)) _func)(location, count, transpose, value);
}

GLAPI void APIENTRY glUniformMatrix3x4fvNV(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2856];
   ((void (APIENTRY *)(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)) _func)(location, count, transpose, value);
}

GLAPI void APIENTRY glUniformMatrix4dv(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2857];
   ((void (APIENTRY *)(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)) _func)(location, count, transpose, value);
}

GLAPI void APIENTRY glUniformMatrix4fv(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2858];
   ((void (APIENTRY *)(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)) _func)(location, count, transpose, value);
}

GLAPI void APIENTRY glUniformMatrix4fvARB(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2859];
   ((void (APIENTRY *)(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)) _func)(location, count, transpose, value);
}

GLAPI void APIENTRY glUniformMatrix4x2dv(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2860];
   ((void (APIENTRY *)(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)) _func)(location, count, transpose, value);
}

GLAPI void APIENTRY glUniformMatrix4x2fv(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2861];
   ((void (APIENTRY *)(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)) _func)(location, count, transpose, value);
}

GLAPI void APIENTRY glUniformMatrix4x2fvNV(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2862];
   ((void (APIENTRY *)(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)) _func)(location, count, transpose, value);
}

GLAPI void APIENTRY glUniformMatrix4x3dv(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2863];
   ((void (APIENTRY *)(GLint location, GLsizei count, GLboolean transpose, const GLdouble *value)) _func)(location, count, transpose, value);
}

GLAPI void APIENTRY glUniformMatrix4x3fv(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2864];
   ((void (APIENTRY *)(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)) _func)(location, count, transpose, value);
}

GLAPI void APIENTRY glUniformMatrix4x3fvNV(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2865];
   ((void (APIENTRY *)(GLint location, GLsizei count, GLboolean transpose, const GLfloat *value)) _func)(location, count, transpose, value);
}

GLAPI void APIENTRY glUniformSubroutinesuiv(GLenum shadertype, GLsizei count, const GLuint *indices)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2866];
   ((void (APIENTRY *)(GLenum shadertype, GLsizei count, const GLuint *indices)) _func)(shadertype, count, indices);
}

GLAPI void APIENTRY glUniformui64NV(GLint location, GLuint64 value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2867];
   ((void (APIENTRY *)(GLint location, GLuint64 value)) _func)(location, value);
}

GLAPI void APIENTRY glUniformui64vNV(GLint location, GLsizei count, const GLuint64 *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2868];
   ((void (APIENTRY *)(GLint location, GLsizei count, const GLuint64 *value)) _func)(location, count, value);
}

GLAPI void APIENTRY glUnlockArraysEXT(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2869];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI GLboolean APIENTRY glUnmapBuffer(GLenum target)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2870];
   return ((GLboolean (APIENTRY *)(GLenum target)) _func)(target);
}

GLAPI GLboolean APIENTRY glUnmapBufferARB(GLenum target)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2871];
   return ((GLboolean (APIENTRY *)(GLenum target)) _func)(target);
}

GLAPI GLboolean APIENTRY glUnmapBufferOES(GLenum target)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2872];
   return ((GLboolean (APIENTRY *)(GLenum target)) _func)(target);
}

GLAPI GLboolean APIENTRY glUnmapNamedBuffer(GLuint buffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2873];
   return ((GLboolean (APIENTRY *)(GLuint buffer)) _func)(buffer);
}

GLAPI GLboolean APIENTRY glUnmapNamedBufferEXT(GLuint buffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2874];
   return ((GLboolean (APIENTRY *)(GLuint buffer)) _func)(buffer);
}

GLAPI void APIENTRY glUnmapObjectBufferATI(GLuint buffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2875];
   ((void (APIENTRY *)(GLuint buffer)) _func)(buffer);
}

GLAPI void APIENTRY glUnmapTexture2DINTEL(GLuint texture, GLint level)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2876];
   ((void (APIENTRY *)(GLuint texture, GLint level)) _func)(texture, level);
}

GLAPI void APIENTRY glUpdateObjectBufferATI(GLuint buffer, GLuint offset, GLsizei size, const void *pointer, GLenum preserve)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2877];
   ((void (APIENTRY *)(GLuint buffer, GLuint offset, GLsizei size, const void *pointer, GLenum preserve)) _func)(buffer, offset, size, pointer, preserve);
}

GLAPI void APIENTRY glUploadGpuMaskNVX(GLbitfield mask)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2878];
   ((void (APIENTRY *)(GLbitfield mask)) _func)(mask);
}

GLAPI void APIENTRY glUseProgram(GLuint program)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2879];
   ((void (APIENTRY *)(GLuint program)) _func)(program);
}

GLAPI void APIENTRY glUseProgramObjectARB(GLhandleARB programObj)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2880];
   ((void (APIENTRY *)(GLhandleARB programObj)) _func)(programObj);
}

GLAPI void APIENTRY glUseProgramStages(GLuint pipeline, GLbitfield stages, GLuint program)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2881];
   ((void (APIENTRY *)(GLuint pipeline, GLbitfield stages, GLuint program)) _func)(pipeline, stages, program);
}

GLAPI void APIENTRY glUseProgramStagesEXT(GLuint pipeline, GLbitfield stages, GLuint program)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2882];
   ((void (APIENTRY *)(GLuint pipeline, GLbitfield stages, GLuint program)) _func)(pipeline, stages, program);
}

GLAPI void APIENTRY glUseShaderProgramEXT(GLenum type, GLuint program)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2883];
   ((void (APIENTRY *)(GLenum type, GLuint program)) _func)(type, program);
}

GLAPI void APIENTRY glVDPAUFiniNV(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2884];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glVDPAUGetSurfaceivNV(GLvdpauSurfaceNV surface, GLenum pname, GLsizei count, GLsizei *length, GLint *values)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2885];
   ((void (APIENTRY *)(GLvdpauSurfaceNV surface, GLenum pname, GLsizei count, GLsizei *length, GLint *values)) _func)(surface, pname, count, length, values);
}

GLAPI void APIENTRY glVDPAUInitNV(const void *vdpDevice, const void *getProcAddress)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2886];
   ((void (APIENTRY *)(const void *vdpDevice, const void *getProcAddress)) _func)(vdpDevice, getProcAddress);
}

GLAPI GLboolean APIENTRY glVDPAUIsSurfaceNV(GLvdpauSurfaceNV surface)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2887];
   return ((GLboolean (APIENTRY *)(GLvdpauSurfaceNV surface)) _func)(surface);
}

GLAPI void APIENTRY glVDPAUMapSurfacesNV(GLsizei numSurfaces, const GLvdpauSurfaceNV *surfaces)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2888];
   ((void (APIENTRY *)(GLsizei numSurfaces, const GLvdpauSurfaceNV *surfaces)) _func)(numSurfaces, surfaces);
}

GLAPI GLvdpauSurfaceNV APIENTRY glVDPAURegisterOutputSurfaceNV(const void *vdpSurface, GLenum target, GLsizei numTextureNames, const GLuint *textureNames)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2889];
   return ((GLvdpauSurfaceNV (APIENTRY *)(const void *vdpSurface, GLenum target, GLsizei numTextureNames, const GLuint *textureNames)) _func)(vdpSurface, target, numTextureNames, textureNames);
}

GLAPI GLvdpauSurfaceNV APIENTRY glVDPAURegisterVideoSurfaceNV(const void *vdpSurface, GLenum target, GLsizei numTextureNames, const GLuint *textureNames)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2890];
   return ((GLvdpauSurfaceNV (APIENTRY *)(const void *vdpSurface, GLenum target, GLsizei numTextureNames, const GLuint *textureNames)) _func)(vdpSurface, target, numTextureNames, textureNames);
}

GLAPI GLvdpauSurfaceNV APIENTRY glVDPAURegisterVideoSurfaceWithPictureStructureNV(const void *vdpSurface, GLenum target, GLsizei numTextureNames, const GLuint *textureNames, GLboolean isFrameStructure)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2891];
   return ((GLvdpauSurfaceNV (APIENTRY *)(const void *vdpSurface, GLenum target, GLsizei numTextureNames, const GLuint *textureNames, GLboolean isFrameStructure)) _func)(vdpSurface, target, numTextureNames, textureNames, isFrameStructure);
}

GLAPI void APIENTRY glVDPAUSurfaceAccessNV(GLvdpauSurfaceNV surface, GLenum access)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2892];
   ((void (APIENTRY *)(GLvdpauSurfaceNV surface, GLenum access)) _func)(surface, access);
}

GLAPI void APIENTRY glVDPAUUnmapSurfacesNV(GLsizei numSurface, const GLvdpauSurfaceNV *surfaces)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2893];
   ((void (APIENTRY *)(GLsizei numSurface, const GLvdpauSurfaceNV *surfaces)) _func)(numSurface, surfaces);
}

GLAPI void APIENTRY glVDPAUUnregisterSurfaceNV(GLvdpauSurfaceNV surface)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2894];
   ((void (APIENTRY *)(GLvdpauSurfaceNV surface)) _func)(surface);
}

GLAPI GLboolean APIENTRY glValidBackBufferHintAutodesk(GLint x, GLint y, GLsizei width, GLsizei height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2895];
   return ((GLboolean (APIENTRY *)(GLint x, GLint y, GLsizei width, GLsizei height)) _func)(x, y, width, height);
}

GLAPI void APIENTRY glValidateProgram(GLuint program)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2896];
   ((void (APIENTRY *)(GLuint program)) _func)(program);
}

GLAPI void APIENTRY glValidateProgramARB(GLhandleARB programObj)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2897];
   ((void (APIENTRY *)(GLhandleARB programObj)) _func)(programObj);
}

GLAPI void APIENTRY glValidateProgramPipeline(GLuint pipeline)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2898];
   ((void (APIENTRY *)(GLuint pipeline)) _func)(pipeline);
}

GLAPI void APIENTRY glValidateProgramPipelineEXT(GLuint pipeline)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2899];
   ((void (APIENTRY *)(GLuint pipeline)) _func)(pipeline);
}

GLAPI void APIENTRY glVariantArrayObjectATI(GLuint id, GLenum type, GLsizei stride, GLuint buffer, GLuint offset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2900];
   ((void (APIENTRY *)(GLuint id, GLenum type, GLsizei stride, GLuint buffer, GLuint offset)) _func)(id, type, stride, buffer, offset);
}

GLAPI void APIENTRY glVariantPointerEXT(GLuint id, GLenum type, GLuint stride, const void *addr)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2901];
   ((void (APIENTRY *)(GLuint id, GLenum type, GLuint stride, const void *addr)) _func)(id, type, stride, addr);
}

GLAPI void APIENTRY glVariantbvEXT(GLuint id, const GLbyte *addr)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2902];
   ((void (APIENTRY *)(GLuint id, const GLbyte *addr)) _func)(id, addr);
}

GLAPI void APIENTRY glVariantdvEXT(GLuint id, const GLdouble *addr)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2903];
   ((void (APIENTRY *)(GLuint id, const GLdouble *addr)) _func)(id, addr);
}

GLAPI void APIENTRY glVariantfvEXT(GLuint id, const GLfloat *addr)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2904];
   ((void (APIENTRY *)(GLuint id, const GLfloat *addr)) _func)(id, addr);
}

GLAPI void APIENTRY glVariantivEXT(GLuint id, const GLint *addr)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2905];
   ((void (APIENTRY *)(GLuint id, const GLint *addr)) _func)(id, addr);
}

GLAPI void APIENTRY glVariantsvEXT(GLuint id, const GLshort *addr)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2906];
   ((void (APIENTRY *)(GLuint id, const GLshort *addr)) _func)(id, addr);
}

GLAPI void APIENTRY glVariantubvEXT(GLuint id, const GLubyte *addr)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2907];
   ((void (APIENTRY *)(GLuint id, const GLubyte *addr)) _func)(id, addr);
}

GLAPI void APIENTRY glVariantuivEXT(GLuint id, const GLuint *addr)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2908];
   ((void (APIENTRY *)(GLuint id, const GLuint *addr)) _func)(id, addr);
}

GLAPI void APIENTRY glVariantusvEXT(GLuint id, const GLushort *addr)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2909];
   ((void (APIENTRY *)(GLuint id, const GLushort *addr)) _func)(id, addr);
}

GLAPI void APIENTRY glVertex2bOES(GLbyte x, GLbyte y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2910];
   ((void (APIENTRY *)(GLbyte x, GLbyte y)) _func)(x, y);
}

GLAPI void APIENTRY glVertex2bvOES(const GLbyte *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2911];
   ((void (APIENTRY *)(const GLbyte *coords)) _func)(coords);
}

GLAPI void APIENTRY glVertex2d(GLdouble x, GLdouble y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2912];
   ((void (APIENTRY *)(GLdouble x, GLdouble y)) _func)(x, y);
}

GLAPI void APIENTRY glVertex2dv(const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2913];
   ((void (APIENTRY *)(const GLdouble *v)) _func)(v);
}

GLAPI void APIENTRY glVertex2f(GLfloat x, GLfloat y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2914];
   ((void (APIENTRY *)(GLfloat x, GLfloat y)) _func)(x, y);
}

GLAPI void APIENTRY glVertex2fv(const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2915];
   ((void (APIENTRY *)(const GLfloat *v)) _func)(v);
}

GLAPI void APIENTRY glVertex2hNV(GLhalf x, GLhalf y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2916];
   ((void (APIENTRY *)(GLhalf x, GLhalf y)) _func)(x, y);
}

GLAPI void APIENTRY glVertex2hvNV(const GLhalf *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2917];
   ((void (APIENTRY *)(const GLhalf *v)) _func)(v);
}

GLAPI void APIENTRY glVertex2i(GLint x, GLint y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2918];
   ((void (APIENTRY *)(GLint x, GLint y)) _func)(x, y);
}

GLAPI void APIENTRY glVertex2iv(const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2919];
   ((void (APIENTRY *)(const GLint *v)) _func)(v);
}

GLAPI void APIENTRY glVertex2s(GLshort x, GLshort y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2920];
   ((void (APIENTRY *)(GLshort x, GLshort y)) _func)(x, y);
}

GLAPI void APIENTRY glVertex2sv(const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2921];
   ((void (APIENTRY *)(const GLshort *v)) _func)(v);
}

GLAPI void APIENTRY glVertex2xOES(GLfixed x)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2922];
   ((void (APIENTRY *)(GLfixed x)) _func)(x);
}

GLAPI void APIENTRY glVertex2xvOES(const GLfixed *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2923];
   ((void (APIENTRY *)(const GLfixed *coords)) _func)(coords);
}

GLAPI void APIENTRY glVertex3bOES(GLbyte x, GLbyte y, GLbyte z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2924];
   ((void (APIENTRY *)(GLbyte x, GLbyte y, GLbyte z)) _func)(x, y, z);
}

GLAPI void APIENTRY glVertex3bvOES(const GLbyte *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2925];
   ((void (APIENTRY *)(const GLbyte *coords)) _func)(coords);
}

GLAPI void APIENTRY glVertex3d(GLdouble x, GLdouble y, GLdouble z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2926];
   ((void (APIENTRY *)(GLdouble x, GLdouble y, GLdouble z)) _func)(x, y, z);
}

GLAPI void APIENTRY glVertex3dv(const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2927];
   ((void (APIENTRY *)(const GLdouble *v)) _func)(v);
}

GLAPI void APIENTRY glVertex3f(GLfloat x, GLfloat y, GLfloat z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2928];
   ((void (APIENTRY *)(GLfloat x, GLfloat y, GLfloat z)) _func)(x, y, z);
}

GLAPI void APIENTRY glVertex3fv(const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2929];
   ((void (APIENTRY *)(const GLfloat *v)) _func)(v);
}

GLAPI void APIENTRY glVertex3hNV(GLhalf x, GLhalf y, GLhalf z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2930];
   ((void (APIENTRY *)(GLhalf x, GLhalf y, GLhalf z)) _func)(x, y, z);
}

GLAPI void APIENTRY glVertex3hvNV(const GLhalf *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2931];
   ((void (APIENTRY *)(const GLhalf *v)) _func)(v);
}

GLAPI void APIENTRY glVertex3i(GLint x, GLint y, GLint z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2932];
   ((void (APIENTRY *)(GLint x, GLint y, GLint z)) _func)(x, y, z);
}

GLAPI void APIENTRY glVertex3iv(const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2933];
   ((void (APIENTRY *)(const GLint *v)) _func)(v);
}

GLAPI void APIENTRY glVertex3s(GLshort x, GLshort y, GLshort z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2934];
   ((void (APIENTRY *)(GLshort x, GLshort y, GLshort z)) _func)(x, y, z);
}

GLAPI void APIENTRY glVertex3sv(const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2935];
   ((void (APIENTRY *)(const GLshort *v)) _func)(v);
}

GLAPI void APIENTRY glVertex3xOES(GLfixed x, GLfixed y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2936];
   ((void (APIENTRY *)(GLfixed x, GLfixed y)) _func)(x, y);
}

GLAPI void APIENTRY glVertex3xvOES(const GLfixed *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2937];
   ((void (APIENTRY *)(const GLfixed *coords)) _func)(coords);
}

GLAPI void APIENTRY glVertex4bOES(GLbyte x, GLbyte y, GLbyte z, GLbyte w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2938];
   ((void (APIENTRY *)(GLbyte x, GLbyte y, GLbyte z, GLbyte w)) _func)(x, y, z, w);
}

GLAPI void APIENTRY glVertex4bvOES(const GLbyte *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2939];
   ((void (APIENTRY *)(const GLbyte *coords)) _func)(coords);
}

GLAPI void APIENTRY glVertex4d(GLdouble x, GLdouble y, GLdouble z, GLdouble w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2940];
   ((void (APIENTRY *)(GLdouble x, GLdouble y, GLdouble z, GLdouble w)) _func)(x, y, z, w);
}

GLAPI void APIENTRY glVertex4dv(const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2941];
   ((void (APIENTRY *)(const GLdouble *v)) _func)(v);
}

GLAPI void APIENTRY glVertex4f(GLfloat x, GLfloat y, GLfloat z, GLfloat w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2942];
   ((void (APIENTRY *)(GLfloat x, GLfloat y, GLfloat z, GLfloat w)) _func)(x, y, z, w);
}

GLAPI void APIENTRY glVertex4fv(const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2943];
   ((void (APIENTRY *)(const GLfloat *v)) _func)(v);
}

GLAPI void APIENTRY glVertex4hNV(GLhalf x, GLhalf y, GLhalf z, GLhalf w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2944];
   ((void (APIENTRY *)(GLhalf x, GLhalf y, GLhalf z, GLhalf w)) _func)(x, y, z, w);
}

GLAPI void APIENTRY glVertex4hvNV(const GLhalf *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2945];
   ((void (APIENTRY *)(const GLhalf *v)) _func)(v);
}

GLAPI void APIENTRY glVertex4i(GLint x, GLint y, GLint z, GLint w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2946];
   ((void (APIENTRY *)(GLint x, GLint y, GLint z, GLint w)) _func)(x, y, z, w);
}

GLAPI void APIENTRY glVertex4iv(const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2947];
   ((void (APIENTRY *)(const GLint *v)) _func)(v);
}

GLAPI void APIENTRY glVertex4s(GLshort x, GLshort y, GLshort z, GLshort w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2948];
   ((void (APIENTRY *)(GLshort x, GLshort y, GLshort z, GLshort w)) _func)(x, y, z, w);
}

GLAPI void APIENTRY glVertex4sv(const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2949];
   ((void (APIENTRY *)(const GLshort *v)) _func)(v);
}

GLAPI void APIENTRY glVertex4xOES(GLfixed x, GLfixed y, GLfixed z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2950];
   ((void (APIENTRY *)(GLfixed x, GLfixed y, GLfixed z)) _func)(x, y, z);
}

GLAPI void APIENTRY glVertex4xvOES(const GLfixed *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2951];
   ((void (APIENTRY *)(const GLfixed *coords)) _func)(coords);
}

GLAPI void APIENTRY glVertexArrayAttribBinding(GLuint vaobj, GLuint attribindex, GLuint bindingindex)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2952];
   ((void (APIENTRY *)(GLuint vaobj, GLuint attribindex, GLuint bindingindex)) _func)(vaobj, attribindex, bindingindex);
}

GLAPI void APIENTRY glVertexArrayAttribFormat(GLuint vaobj, GLuint attribindex, GLint size, GLenum type, GLboolean normalized, GLuint relativeoffset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2953];
   ((void (APIENTRY *)(GLuint vaobj, GLuint attribindex, GLint size, GLenum type, GLboolean normalized, GLuint relativeoffset)) _func)(vaobj, attribindex, size, type, normalized, relativeoffset);
}

GLAPI void APIENTRY glVertexArrayAttribIFormat(GLuint vaobj, GLuint attribindex, GLint size, GLenum type, GLuint relativeoffset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2954];
   ((void (APIENTRY *)(GLuint vaobj, GLuint attribindex, GLint size, GLenum type, GLuint relativeoffset)) _func)(vaobj, attribindex, size, type, relativeoffset);
}

GLAPI void APIENTRY glVertexArrayAttribLFormat(GLuint vaobj, GLuint attribindex, GLint size, GLenum type, GLuint relativeoffset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2955];
   ((void (APIENTRY *)(GLuint vaobj, GLuint attribindex, GLint size, GLenum type, GLuint relativeoffset)) _func)(vaobj, attribindex, size, type, relativeoffset);
}

GLAPI void APIENTRY glVertexArrayBindVertexBufferEXT(GLuint vaobj, GLuint bindingindex, GLuint buffer, GLintptr offset, GLsizei stride)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2956];
   ((void (APIENTRY *)(GLuint vaobj, GLuint bindingindex, GLuint buffer, GLintptr offset, GLsizei stride)) _func)(vaobj, bindingindex, buffer, offset, stride);
}

GLAPI void APIENTRY glVertexArrayBindingDivisor(GLuint vaobj, GLuint bindingindex, GLuint divisor)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2957];
   ((void (APIENTRY *)(GLuint vaobj, GLuint bindingindex, GLuint divisor)) _func)(vaobj, bindingindex, divisor);
}

GLAPI void APIENTRY glVertexArrayColorOffsetEXT(GLuint vaobj, GLuint buffer, GLint size, GLenum type, GLsizei stride, GLintptr offset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2958];
   ((void (APIENTRY *)(GLuint vaobj, GLuint buffer, GLint size, GLenum type, GLsizei stride, GLintptr offset)) _func)(vaobj, buffer, size, type, stride, offset);
}

GLAPI void APIENTRY glVertexArrayEdgeFlagOffsetEXT(GLuint vaobj, GLuint buffer, GLsizei stride, GLintptr offset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2959];
   ((void (APIENTRY *)(GLuint vaobj, GLuint buffer, GLsizei stride, GLintptr offset)) _func)(vaobj, buffer, stride, offset);
}

GLAPI void APIENTRY glVertexArrayElementBuffer(GLuint vaobj, GLuint buffer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2960];
   ((void (APIENTRY *)(GLuint vaobj, GLuint buffer)) _func)(vaobj, buffer);
}

GLAPI void APIENTRY glVertexArrayFogCoordOffsetEXT(GLuint vaobj, GLuint buffer, GLenum type, GLsizei stride, GLintptr offset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2961];
   ((void (APIENTRY *)(GLuint vaobj, GLuint buffer, GLenum type, GLsizei stride, GLintptr offset)) _func)(vaobj, buffer, type, stride, offset);
}

GLAPI void APIENTRY glVertexArrayIndexOffsetEXT(GLuint vaobj, GLuint buffer, GLenum type, GLsizei stride, GLintptr offset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2962];
   ((void (APIENTRY *)(GLuint vaobj, GLuint buffer, GLenum type, GLsizei stride, GLintptr offset)) _func)(vaobj, buffer, type, stride, offset);
}

GLAPI void APIENTRY glVertexArrayMultiTexCoordOffsetEXT(GLuint vaobj, GLuint buffer, GLenum texunit, GLint size, GLenum type, GLsizei stride, GLintptr offset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2963];
   ((void (APIENTRY *)(GLuint vaobj, GLuint buffer, GLenum texunit, GLint size, GLenum type, GLsizei stride, GLintptr offset)) _func)(vaobj, buffer, texunit, size, type, stride, offset);
}

GLAPI void APIENTRY glVertexArrayNormalOffsetEXT(GLuint vaobj, GLuint buffer, GLenum type, GLsizei stride, GLintptr offset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2964];
   ((void (APIENTRY *)(GLuint vaobj, GLuint buffer, GLenum type, GLsizei stride, GLintptr offset)) _func)(vaobj, buffer, type, stride, offset);
}

GLAPI void APIENTRY glVertexArrayParameteriAPPLE(GLenum pname, GLint param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2965];
   ((void (APIENTRY *)(GLenum pname, GLint param)) _func)(pname, param);
}

GLAPI void APIENTRY glVertexArrayRangeAPPLE(GLsizei length, void *pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2966];
   ((void (APIENTRY *)(GLsizei length, void *pointer)) _func)(length, pointer);
}

GLAPI void APIENTRY glVertexArrayRangeNV(GLsizei length, const void *pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2967];
   ((void (APIENTRY *)(GLsizei length, const void *pointer)) _func)(length, pointer);
}

GLAPI void APIENTRY glVertexArraySecondaryColorOffsetEXT(GLuint vaobj, GLuint buffer, GLint size, GLenum type, GLsizei stride, GLintptr offset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2968];
   ((void (APIENTRY *)(GLuint vaobj, GLuint buffer, GLint size, GLenum type, GLsizei stride, GLintptr offset)) _func)(vaobj, buffer, size, type, stride, offset);
}

GLAPI void APIENTRY glVertexArrayTexCoordOffsetEXT(GLuint vaobj, GLuint buffer, GLint size, GLenum type, GLsizei stride, GLintptr offset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2969];
   ((void (APIENTRY *)(GLuint vaobj, GLuint buffer, GLint size, GLenum type, GLsizei stride, GLintptr offset)) _func)(vaobj, buffer, size, type, stride, offset);
}

GLAPI void APIENTRY glVertexArrayVertexAttribBindingEXT(GLuint vaobj, GLuint attribindex, GLuint bindingindex)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2970];
   ((void (APIENTRY *)(GLuint vaobj, GLuint attribindex, GLuint bindingindex)) _func)(vaobj, attribindex, bindingindex);
}

GLAPI void APIENTRY glVertexArrayVertexAttribDivisorEXT(GLuint vaobj, GLuint index, GLuint divisor)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2971];
   ((void (APIENTRY *)(GLuint vaobj, GLuint index, GLuint divisor)) _func)(vaobj, index, divisor);
}

GLAPI void APIENTRY glVertexArrayVertexAttribFormatEXT(GLuint vaobj, GLuint attribindex, GLint size, GLenum type, GLboolean normalized, GLuint relativeoffset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2972];
   ((void (APIENTRY *)(GLuint vaobj, GLuint attribindex, GLint size, GLenum type, GLboolean normalized, GLuint relativeoffset)) _func)(vaobj, attribindex, size, type, normalized, relativeoffset);
}

GLAPI void APIENTRY glVertexArrayVertexAttribIFormatEXT(GLuint vaobj, GLuint attribindex, GLint size, GLenum type, GLuint relativeoffset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2973];
   ((void (APIENTRY *)(GLuint vaobj, GLuint attribindex, GLint size, GLenum type, GLuint relativeoffset)) _func)(vaobj, attribindex, size, type, relativeoffset);
}

GLAPI void APIENTRY glVertexArrayVertexAttribIOffsetEXT(GLuint vaobj, GLuint buffer, GLuint index, GLint size, GLenum type, GLsizei stride, GLintptr offset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2974];
   ((void (APIENTRY *)(GLuint vaobj, GLuint buffer, GLuint index, GLint size, GLenum type, GLsizei stride, GLintptr offset)) _func)(vaobj, buffer, index, size, type, stride, offset);
}

GLAPI void APIENTRY glVertexArrayVertexAttribLFormatEXT(GLuint vaobj, GLuint attribindex, GLint size, GLenum type, GLuint relativeoffset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2975];
   ((void (APIENTRY *)(GLuint vaobj, GLuint attribindex, GLint size, GLenum type, GLuint relativeoffset)) _func)(vaobj, attribindex, size, type, relativeoffset);
}

GLAPI void APIENTRY glVertexArrayVertexAttribLOffsetEXT(GLuint vaobj, GLuint buffer, GLuint index, GLint size, GLenum type, GLsizei stride, GLintptr offset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2976];
   ((void (APIENTRY *)(GLuint vaobj, GLuint buffer, GLuint index, GLint size, GLenum type, GLsizei stride, GLintptr offset)) _func)(vaobj, buffer, index, size, type, stride, offset);
}

GLAPI void APIENTRY glVertexArrayVertexAttribOffsetEXT(GLuint vaobj, GLuint buffer, GLuint index, GLint size, GLenum type, GLboolean normalized, GLsizei stride, GLintptr offset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2977];
   ((void (APIENTRY *)(GLuint vaobj, GLuint buffer, GLuint index, GLint size, GLenum type, GLboolean normalized, GLsizei stride, GLintptr offset)) _func)(vaobj, buffer, index, size, type, normalized, stride, offset);
}

GLAPI void APIENTRY glVertexArrayVertexBindingDivisorEXT(GLuint vaobj, GLuint bindingindex, GLuint divisor)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2978];
   ((void (APIENTRY *)(GLuint vaobj, GLuint bindingindex, GLuint divisor)) _func)(vaobj, bindingindex, divisor);
}

GLAPI void APIENTRY glVertexArrayVertexBuffer(GLuint vaobj, GLuint bindingindex, GLuint buffer, GLintptr offset, GLsizei stride)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2979];
   ((void (APIENTRY *)(GLuint vaobj, GLuint bindingindex, GLuint buffer, GLintptr offset, GLsizei stride)) _func)(vaobj, bindingindex, buffer, offset, stride);
}

GLAPI void APIENTRY glVertexArrayVertexBuffers(GLuint vaobj, GLuint first, GLsizei count, const GLuint *buffers, const GLintptr *offsets, const GLsizei *strides)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2980];
   ((void (APIENTRY *)(GLuint vaobj, GLuint first, GLsizei count, const GLuint *buffers, const GLintptr *offsets, const GLsizei *strides)) _func)(vaobj, first, count, buffers, offsets, strides);
}

GLAPI void APIENTRY glVertexArrayVertexOffsetEXT(GLuint vaobj, GLuint buffer, GLint size, GLenum type, GLsizei stride, GLintptr offset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2981];
   ((void (APIENTRY *)(GLuint vaobj, GLuint buffer, GLint size, GLenum type, GLsizei stride, GLintptr offset)) _func)(vaobj, buffer, size, type, stride, offset);
}

GLAPI void APIENTRY glVertexAttrib1d(GLuint index, GLdouble x)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2982];
   ((void (APIENTRY *)(GLuint index, GLdouble x)) _func)(index, x);
}

GLAPI void APIENTRY glVertexAttrib1dARB(GLuint index, GLdouble x)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2983];
   ((void (APIENTRY *)(GLuint index, GLdouble x)) _func)(index, x);
}

GLAPI void APIENTRY glVertexAttrib1dNV(GLuint index, GLdouble x)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2984];
   ((void (APIENTRY *)(GLuint index, GLdouble x)) _func)(index, x);
}

GLAPI void APIENTRY glVertexAttrib1dv(GLuint index, const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2985];
   ((void (APIENTRY *)(GLuint index, const GLdouble *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib1dvARB(GLuint index, const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2986];
   ((void (APIENTRY *)(GLuint index, const GLdouble *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib1dvNV(GLuint index, const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2987];
   ((void (APIENTRY *)(GLuint index, const GLdouble *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib1f(GLuint index, GLfloat x)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2988];
   ((void (APIENTRY *)(GLuint index, GLfloat x)) _func)(index, x);
}

GLAPI void APIENTRY glVertexAttrib1fARB(GLuint index, GLfloat x)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2989];
   ((void (APIENTRY *)(GLuint index, GLfloat x)) _func)(index, x);
}

GLAPI void APIENTRY glVertexAttrib1fNV(GLuint index, GLfloat x)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2990];
   ((void (APIENTRY *)(GLuint index, GLfloat x)) _func)(index, x);
}

GLAPI void APIENTRY glVertexAttrib1fv(GLuint index, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2991];
   ((void (APIENTRY *)(GLuint index, const GLfloat *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib1fvARB(GLuint index, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2992];
   ((void (APIENTRY *)(GLuint index, const GLfloat *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib1fvNV(GLuint index, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2993];
   ((void (APIENTRY *)(GLuint index, const GLfloat *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib1hNV(GLuint index, GLhalf x)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2994];
   ((void (APIENTRY *)(GLuint index, GLhalf x)) _func)(index, x);
}

GLAPI void APIENTRY glVertexAttrib1hvNV(GLuint index, const GLhalf *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2995];
   ((void (APIENTRY *)(GLuint index, const GLhalf *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib1s(GLuint index, GLshort x)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2996];
   ((void (APIENTRY *)(GLuint index, GLshort x)) _func)(index, x);
}

GLAPI void APIENTRY glVertexAttrib1sARB(GLuint index, GLshort x)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2997];
   ((void (APIENTRY *)(GLuint index, GLshort x)) _func)(index, x);
}

GLAPI void APIENTRY glVertexAttrib1sNV(GLuint index, GLshort x)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2998];
   ((void (APIENTRY *)(GLuint index, GLshort x)) _func)(index, x);
}

GLAPI void APIENTRY glVertexAttrib1sv(GLuint index, const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[2999];
   ((void (APIENTRY *)(GLuint index, const GLshort *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib1svARB(GLuint index, const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3000];
   ((void (APIENTRY *)(GLuint index, const GLshort *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib1svNV(GLuint index, const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3001];
   ((void (APIENTRY *)(GLuint index, const GLshort *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib2d(GLuint index, GLdouble x, GLdouble y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3002];
   ((void (APIENTRY *)(GLuint index, GLdouble x, GLdouble y)) _func)(index, x, y);
}

GLAPI void APIENTRY glVertexAttrib2dARB(GLuint index, GLdouble x, GLdouble y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3003];
   ((void (APIENTRY *)(GLuint index, GLdouble x, GLdouble y)) _func)(index, x, y);
}

GLAPI void APIENTRY glVertexAttrib2dNV(GLuint index, GLdouble x, GLdouble y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3004];
   ((void (APIENTRY *)(GLuint index, GLdouble x, GLdouble y)) _func)(index, x, y);
}

GLAPI void APIENTRY glVertexAttrib2dv(GLuint index, const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3005];
   ((void (APIENTRY *)(GLuint index, const GLdouble *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib2dvARB(GLuint index, const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3006];
   ((void (APIENTRY *)(GLuint index, const GLdouble *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib2dvNV(GLuint index, const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3007];
   ((void (APIENTRY *)(GLuint index, const GLdouble *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib2f(GLuint index, GLfloat x, GLfloat y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3008];
   ((void (APIENTRY *)(GLuint index, GLfloat x, GLfloat y)) _func)(index, x, y);
}

GLAPI void APIENTRY glVertexAttrib2fARB(GLuint index, GLfloat x, GLfloat y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3009];
   ((void (APIENTRY *)(GLuint index, GLfloat x, GLfloat y)) _func)(index, x, y);
}

GLAPI void APIENTRY glVertexAttrib2fNV(GLuint index, GLfloat x, GLfloat y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3010];
   ((void (APIENTRY *)(GLuint index, GLfloat x, GLfloat y)) _func)(index, x, y);
}

GLAPI void APIENTRY glVertexAttrib2fv(GLuint index, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3011];
   ((void (APIENTRY *)(GLuint index, const GLfloat *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib2fvARB(GLuint index, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3012];
   ((void (APIENTRY *)(GLuint index, const GLfloat *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib2fvNV(GLuint index, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3013];
   ((void (APIENTRY *)(GLuint index, const GLfloat *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib2hNV(GLuint index, GLhalf x, GLhalf y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3014];
   ((void (APIENTRY *)(GLuint index, GLhalf x, GLhalf y)) _func)(index, x, y);
}

GLAPI void APIENTRY glVertexAttrib2hvNV(GLuint index, const GLhalf *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3015];
   ((void (APIENTRY *)(GLuint index, const GLhalf *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib2s(GLuint index, GLshort x, GLshort y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3016];
   ((void (APIENTRY *)(GLuint index, GLshort x, GLshort y)) _func)(index, x, y);
}

GLAPI void APIENTRY glVertexAttrib2sARB(GLuint index, GLshort x, GLshort y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3017];
   ((void (APIENTRY *)(GLuint index, GLshort x, GLshort y)) _func)(index, x, y);
}

GLAPI void APIENTRY glVertexAttrib2sNV(GLuint index, GLshort x, GLshort y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3018];
   ((void (APIENTRY *)(GLuint index, GLshort x, GLshort y)) _func)(index, x, y);
}

GLAPI void APIENTRY glVertexAttrib2sv(GLuint index, const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3019];
   ((void (APIENTRY *)(GLuint index, const GLshort *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib2svARB(GLuint index, const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3020];
   ((void (APIENTRY *)(GLuint index, const GLshort *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib2svNV(GLuint index, const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3021];
   ((void (APIENTRY *)(GLuint index, const GLshort *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib3d(GLuint index, GLdouble x, GLdouble y, GLdouble z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3022];
   ((void (APIENTRY *)(GLuint index, GLdouble x, GLdouble y, GLdouble z)) _func)(index, x, y, z);
}

GLAPI void APIENTRY glVertexAttrib3dARB(GLuint index, GLdouble x, GLdouble y, GLdouble z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3023];
   ((void (APIENTRY *)(GLuint index, GLdouble x, GLdouble y, GLdouble z)) _func)(index, x, y, z);
}

GLAPI void APIENTRY glVertexAttrib3dNV(GLuint index, GLdouble x, GLdouble y, GLdouble z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3024];
   ((void (APIENTRY *)(GLuint index, GLdouble x, GLdouble y, GLdouble z)) _func)(index, x, y, z);
}

GLAPI void APIENTRY glVertexAttrib3dv(GLuint index, const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3025];
   ((void (APIENTRY *)(GLuint index, const GLdouble *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib3dvARB(GLuint index, const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3026];
   ((void (APIENTRY *)(GLuint index, const GLdouble *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib3dvNV(GLuint index, const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3027];
   ((void (APIENTRY *)(GLuint index, const GLdouble *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib3f(GLuint index, GLfloat x, GLfloat y, GLfloat z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3028];
   ((void (APIENTRY *)(GLuint index, GLfloat x, GLfloat y, GLfloat z)) _func)(index, x, y, z);
}

GLAPI void APIENTRY glVertexAttrib3fARB(GLuint index, GLfloat x, GLfloat y, GLfloat z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3029];
   ((void (APIENTRY *)(GLuint index, GLfloat x, GLfloat y, GLfloat z)) _func)(index, x, y, z);
}

GLAPI void APIENTRY glVertexAttrib3fNV(GLuint index, GLfloat x, GLfloat y, GLfloat z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3030];
   ((void (APIENTRY *)(GLuint index, GLfloat x, GLfloat y, GLfloat z)) _func)(index, x, y, z);
}

GLAPI void APIENTRY glVertexAttrib3fv(GLuint index, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3031];
   ((void (APIENTRY *)(GLuint index, const GLfloat *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib3fvARB(GLuint index, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3032];
   ((void (APIENTRY *)(GLuint index, const GLfloat *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib3fvNV(GLuint index, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3033];
   ((void (APIENTRY *)(GLuint index, const GLfloat *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib3hNV(GLuint index, GLhalf x, GLhalf y, GLhalf z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3034];
   ((void (APIENTRY *)(GLuint index, GLhalf x, GLhalf y, GLhalf z)) _func)(index, x, y, z);
}

GLAPI void APIENTRY glVertexAttrib3hvNV(GLuint index, const GLhalf *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3035];
   ((void (APIENTRY *)(GLuint index, const GLhalf *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib3s(GLuint index, GLshort x, GLshort y, GLshort z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3036];
   ((void (APIENTRY *)(GLuint index, GLshort x, GLshort y, GLshort z)) _func)(index, x, y, z);
}

GLAPI void APIENTRY glVertexAttrib3sARB(GLuint index, GLshort x, GLshort y, GLshort z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3037];
   ((void (APIENTRY *)(GLuint index, GLshort x, GLshort y, GLshort z)) _func)(index, x, y, z);
}

GLAPI void APIENTRY glVertexAttrib3sNV(GLuint index, GLshort x, GLshort y, GLshort z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3038];
   ((void (APIENTRY *)(GLuint index, GLshort x, GLshort y, GLshort z)) _func)(index, x, y, z);
}

GLAPI void APIENTRY glVertexAttrib3sv(GLuint index, const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3039];
   ((void (APIENTRY *)(GLuint index, const GLshort *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib3svARB(GLuint index, const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3040];
   ((void (APIENTRY *)(GLuint index, const GLshort *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib3svNV(GLuint index, const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3041];
   ((void (APIENTRY *)(GLuint index, const GLshort *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib4Nbv(GLuint index, const GLbyte *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3042];
   ((void (APIENTRY *)(GLuint index, const GLbyte *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib4NbvARB(GLuint index, const GLbyte *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3043];
   ((void (APIENTRY *)(GLuint index, const GLbyte *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib4Niv(GLuint index, const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3044];
   ((void (APIENTRY *)(GLuint index, const GLint *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib4NivARB(GLuint index, const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3045];
   ((void (APIENTRY *)(GLuint index, const GLint *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib4Nsv(GLuint index, const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3046];
   ((void (APIENTRY *)(GLuint index, const GLshort *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib4NsvARB(GLuint index, const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3047];
   ((void (APIENTRY *)(GLuint index, const GLshort *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib4Nub(GLuint index, GLubyte x, GLubyte y, GLubyte z, GLubyte w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3048];
   ((void (APIENTRY *)(GLuint index, GLubyte x, GLubyte y, GLubyte z, GLubyte w)) _func)(index, x, y, z, w);
}

GLAPI void APIENTRY glVertexAttrib4NubARB(GLuint index, GLubyte x, GLubyte y, GLubyte z, GLubyte w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3049];
   ((void (APIENTRY *)(GLuint index, GLubyte x, GLubyte y, GLubyte z, GLubyte w)) _func)(index, x, y, z, w);
}

GLAPI void APIENTRY glVertexAttrib4Nubv(GLuint index, const GLubyte *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3050];
   ((void (APIENTRY *)(GLuint index, const GLubyte *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib4NubvARB(GLuint index, const GLubyte *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3051];
   ((void (APIENTRY *)(GLuint index, const GLubyte *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib4Nuiv(GLuint index, const GLuint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3052];
   ((void (APIENTRY *)(GLuint index, const GLuint *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib4NuivARB(GLuint index, const GLuint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3053];
   ((void (APIENTRY *)(GLuint index, const GLuint *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib4Nusv(GLuint index, const GLushort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3054];
   ((void (APIENTRY *)(GLuint index, const GLushort *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib4NusvARB(GLuint index, const GLushort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3055];
   ((void (APIENTRY *)(GLuint index, const GLushort *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib4bv(GLuint index, const GLbyte *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3056];
   ((void (APIENTRY *)(GLuint index, const GLbyte *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib4bvARB(GLuint index, const GLbyte *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3057];
   ((void (APIENTRY *)(GLuint index, const GLbyte *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib4d(GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3058];
   ((void (APIENTRY *)(GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w)) _func)(index, x, y, z, w);
}

GLAPI void APIENTRY glVertexAttrib4dARB(GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3059];
   ((void (APIENTRY *)(GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w)) _func)(index, x, y, z, w);
}

GLAPI void APIENTRY glVertexAttrib4dNV(GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3060];
   ((void (APIENTRY *)(GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w)) _func)(index, x, y, z, w);
}

GLAPI void APIENTRY glVertexAttrib4dv(GLuint index, const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3061];
   ((void (APIENTRY *)(GLuint index, const GLdouble *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib4dvARB(GLuint index, const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3062];
   ((void (APIENTRY *)(GLuint index, const GLdouble *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib4dvNV(GLuint index, const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3063];
   ((void (APIENTRY *)(GLuint index, const GLdouble *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib4f(GLuint index, GLfloat x, GLfloat y, GLfloat z, GLfloat w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3064];
   ((void (APIENTRY *)(GLuint index, GLfloat x, GLfloat y, GLfloat z, GLfloat w)) _func)(index, x, y, z, w);
}

GLAPI void APIENTRY glVertexAttrib4fARB(GLuint index, GLfloat x, GLfloat y, GLfloat z, GLfloat w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3065];
   ((void (APIENTRY *)(GLuint index, GLfloat x, GLfloat y, GLfloat z, GLfloat w)) _func)(index, x, y, z, w);
}

GLAPI void APIENTRY glVertexAttrib4fNV(GLuint index, GLfloat x, GLfloat y, GLfloat z, GLfloat w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3066];
   ((void (APIENTRY *)(GLuint index, GLfloat x, GLfloat y, GLfloat z, GLfloat w)) _func)(index, x, y, z, w);
}

GLAPI void APIENTRY glVertexAttrib4fv(GLuint index, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3067];
   ((void (APIENTRY *)(GLuint index, const GLfloat *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib4fvARB(GLuint index, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3068];
   ((void (APIENTRY *)(GLuint index, const GLfloat *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib4fvNV(GLuint index, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3069];
   ((void (APIENTRY *)(GLuint index, const GLfloat *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib4hNV(GLuint index, GLhalf x, GLhalf y, GLhalf z, GLhalf w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3070];
   ((void (APIENTRY *)(GLuint index, GLhalf x, GLhalf y, GLhalf z, GLhalf w)) _func)(index, x, y, z, w);
}

GLAPI void APIENTRY glVertexAttrib4hvNV(GLuint index, const GLhalf *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3071];
   ((void (APIENTRY *)(GLuint index, const GLhalf *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib4iv(GLuint index, const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3072];
   ((void (APIENTRY *)(GLuint index, const GLint *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib4ivARB(GLuint index, const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3073];
   ((void (APIENTRY *)(GLuint index, const GLint *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib4s(GLuint index, GLshort x, GLshort y, GLshort z, GLshort w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3074];
   ((void (APIENTRY *)(GLuint index, GLshort x, GLshort y, GLshort z, GLshort w)) _func)(index, x, y, z, w);
}

GLAPI void APIENTRY glVertexAttrib4sARB(GLuint index, GLshort x, GLshort y, GLshort z, GLshort w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3075];
   ((void (APIENTRY *)(GLuint index, GLshort x, GLshort y, GLshort z, GLshort w)) _func)(index, x, y, z, w);
}

GLAPI void APIENTRY glVertexAttrib4sNV(GLuint index, GLshort x, GLshort y, GLshort z, GLshort w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3076];
   ((void (APIENTRY *)(GLuint index, GLshort x, GLshort y, GLshort z, GLshort w)) _func)(index, x, y, z, w);
}

GLAPI void APIENTRY glVertexAttrib4sv(GLuint index, const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3077];
   ((void (APIENTRY *)(GLuint index, const GLshort *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib4svARB(GLuint index, const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3078];
   ((void (APIENTRY *)(GLuint index, const GLshort *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib4svNV(GLuint index, const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3079];
   ((void (APIENTRY *)(GLuint index, const GLshort *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib4ubNV(GLuint index, GLubyte x, GLubyte y, GLubyte z, GLubyte w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3080];
   ((void (APIENTRY *)(GLuint index, GLubyte x, GLubyte y, GLubyte z, GLubyte w)) _func)(index, x, y, z, w);
}

GLAPI void APIENTRY glVertexAttrib4ubv(GLuint index, const GLubyte *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3081];
   ((void (APIENTRY *)(GLuint index, const GLubyte *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib4ubvARB(GLuint index, const GLubyte *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3082];
   ((void (APIENTRY *)(GLuint index, const GLubyte *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib4ubvNV(GLuint index, const GLubyte *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3083];
   ((void (APIENTRY *)(GLuint index, const GLubyte *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib4uiv(GLuint index, const GLuint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3084];
   ((void (APIENTRY *)(GLuint index, const GLuint *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib4uivARB(GLuint index, const GLuint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3085];
   ((void (APIENTRY *)(GLuint index, const GLuint *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib4usv(GLuint index, const GLushort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3086];
   ((void (APIENTRY *)(GLuint index, const GLushort *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttrib4usvARB(GLuint index, const GLushort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3087];
   ((void (APIENTRY *)(GLuint index, const GLushort *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttribArrayObjectATI(GLuint index, GLint size, GLenum type, GLboolean normalized, GLsizei stride, GLuint buffer, GLuint offset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3088];
   ((void (APIENTRY *)(GLuint index, GLint size, GLenum type, GLboolean normalized, GLsizei stride, GLuint buffer, GLuint offset)) _func)(index, size, type, normalized, stride, buffer, offset);
}

GLAPI void APIENTRY glVertexAttribBinding(GLuint attribindex, GLuint bindingindex)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3089];
   ((void (APIENTRY *)(GLuint attribindex, GLuint bindingindex)) _func)(attribindex, bindingindex);
}

GLAPI void APIENTRY glVertexAttribDivisor(GLuint index, GLuint divisor)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3090];
   ((void (APIENTRY *)(GLuint index, GLuint divisor)) _func)(index, divisor);
}

GLAPI void APIENTRY glVertexAttribDivisorANGLE(GLuint index, GLuint divisor)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3091];
   ((void (APIENTRY *)(GLuint index, GLuint divisor)) _func)(index, divisor);
}

GLAPI void APIENTRY glVertexAttribDivisorARB(GLuint index, GLuint divisor)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3092];
   ((void (APIENTRY *)(GLuint index, GLuint divisor)) _func)(index, divisor);
}

GLAPI void APIENTRY glVertexAttribDivisorEXT(GLuint index, GLuint divisor)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3093];
   ((void (APIENTRY *)(GLuint index, GLuint divisor)) _func)(index, divisor);
}

GLAPI void APIENTRY glVertexAttribDivisorNV(GLuint index, GLuint divisor)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3094];
   ((void (APIENTRY *)(GLuint index, GLuint divisor)) _func)(index, divisor);
}

GLAPI void APIENTRY glVertexAttribFormat(GLuint attribindex, GLint size, GLenum type, GLboolean normalized, GLuint relativeoffset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3095];
   ((void (APIENTRY *)(GLuint attribindex, GLint size, GLenum type, GLboolean normalized, GLuint relativeoffset)) _func)(attribindex, size, type, normalized, relativeoffset);
}

GLAPI void APIENTRY glVertexAttribFormatNV(GLuint index, GLint size, GLenum type, GLboolean normalized, GLsizei stride)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3096];
   ((void (APIENTRY *)(GLuint index, GLint size, GLenum type, GLboolean normalized, GLsizei stride)) _func)(index, size, type, normalized, stride);
}

GLAPI void APIENTRY glVertexAttribI1i(GLuint index, GLint x)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3097];
   ((void (APIENTRY *)(GLuint index, GLint x)) _func)(index, x);
}

GLAPI void APIENTRY glVertexAttribI1iEXT(GLuint index, GLint x)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3098];
   ((void (APIENTRY *)(GLuint index, GLint x)) _func)(index, x);
}

GLAPI void APIENTRY glVertexAttribI1iv(GLuint index, const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3099];
   ((void (APIENTRY *)(GLuint index, const GLint *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttribI1ivEXT(GLuint index, const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3100];
   ((void (APIENTRY *)(GLuint index, const GLint *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttribI1ui(GLuint index, GLuint x)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3101];
   ((void (APIENTRY *)(GLuint index, GLuint x)) _func)(index, x);
}

GLAPI void APIENTRY glVertexAttribI1uiEXT(GLuint index, GLuint x)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3102];
   ((void (APIENTRY *)(GLuint index, GLuint x)) _func)(index, x);
}

GLAPI void APIENTRY glVertexAttribI1uiv(GLuint index, const GLuint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3103];
   ((void (APIENTRY *)(GLuint index, const GLuint *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttribI1uivEXT(GLuint index, const GLuint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3104];
   ((void (APIENTRY *)(GLuint index, const GLuint *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttribI2i(GLuint index, GLint x, GLint y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3105];
   ((void (APIENTRY *)(GLuint index, GLint x, GLint y)) _func)(index, x, y);
}

GLAPI void APIENTRY glVertexAttribI2iEXT(GLuint index, GLint x, GLint y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3106];
   ((void (APIENTRY *)(GLuint index, GLint x, GLint y)) _func)(index, x, y);
}

GLAPI void APIENTRY glVertexAttribI2iv(GLuint index, const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3107];
   ((void (APIENTRY *)(GLuint index, const GLint *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttribI2ivEXT(GLuint index, const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3108];
   ((void (APIENTRY *)(GLuint index, const GLint *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttribI2ui(GLuint index, GLuint x, GLuint y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3109];
   ((void (APIENTRY *)(GLuint index, GLuint x, GLuint y)) _func)(index, x, y);
}

GLAPI void APIENTRY glVertexAttribI2uiEXT(GLuint index, GLuint x, GLuint y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3110];
   ((void (APIENTRY *)(GLuint index, GLuint x, GLuint y)) _func)(index, x, y);
}

GLAPI void APIENTRY glVertexAttribI2uiv(GLuint index, const GLuint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3111];
   ((void (APIENTRY *)(GLuint index, const GLuint *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttribI2uivEXT(GLuint index, const GLuint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3112];
   ((void (APIENTRY *)(GLuint index, const GLuint *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttribI3i(GLuint index, GLint x, GLint y, GLint z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3113];
   ((void (APIENTRY *)(GLuint index, GLint x, GLint y, GLint z)) _func)(index, x, y, z);
}

GLAPI void APIENTRY glVertexAttribI3iEXT(GLuint index, GLint x, GLint y, GLint z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3114];
   ((void (APIENTRY *)(GLuint index, GLint x, GLint y, GLint z)) _func)(index, x, y, z);
}

GLAPI void APIENTRY glVertexAttribI3iv(GLuint index, const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3115];
   ((void (APIENTRY *)(GLuint index, const GLint *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttribI3ivEXT(GLuint index, const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3116];
   ((void (APIENTRY *)(GLuint index, const GLint *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttribI3ui(GLuint index, GLuint x, GLuint y, GLuint z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3117];
   ((void (APIENTRY *)(GLuint index, GLuint x, GLuint y, GLuint z)) _func)(index, x, y, z);
}

GLAPI void APIENTRY glVertexAttribI3uiEXT(GLuint index, GLuint x, GLuint y, GLuint z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3118];
   ((void (APIENTRY *)(GLuint index, GLuint x, GLuint y, GLuint z)) _func)(index, x, y, z);
}

GLAPI void APIENTRY glVertexAttribI3uiv(GLuint index, const GLuint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3119];
   ((void (APIENTRY *)(GLuint index, const GLuint *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttribI3uivEXT(GLuint index, const GLuint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3120];
   ((void (APIENTRY *)(GLuint index, const GLuint *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttribI4bv(GLuint index, const GLbyte *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3121];
   ((void (APIENTRY *)(GLuint index, const GLbyte *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttribI4bvEXT(GLuint index, const GLbyte *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3122];
   ((void (APIENTRY *)(GLuint index, const GLbyte *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttribI4i(GLuint index, GLint x, GLint y, GLint z, GLint w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3123];
   ((void (APIENTRY *)(GLuint index, GLint x, GLint y, GLint z, GLint w)) _func)(index, x, y, z, w);
}

GLAPI void APIENTRY glVertexAttribI4iEXT(GLuint index, GLint x, GLint y, GLint z, GLint w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3124];
   ((void (APIENTRY *)(GLuint index, GLint x, GLint y, GLint z, GLint w)) _func)(index, x, y, z, w);
}

GLAPI void APIENTRY glVertexAttribI4iv(GLuint index, const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3125];
   ((void (APIENTRY *)(GLuint index, const GLint *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttribI4ivEXT(GLuint index, const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3126];
   ((void (APIENTRY *)(GLuint index, const GLint *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttribI4sv(GLuint index, const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3127];
   ((void (APIENTRY *)(GLuint index, const GLshort *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttribI4svEXT(GLuint index, const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3128];
   ((void (APIENTRY *)(GLuint index, const GLshort *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttribI4ubv(GLuint index, const GLubyte *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3129];
   ((void (APIENTRY *)(GLuint index, const GLubyte *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttribI4ubvEXT(GLuint index, const GLubyte *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3130];
   ((void (APIENTRY *)(GLuint index, const GLubyte *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttribI4ui(GLuint index, GLuint x, GLuint y, GLuint z, GLuint w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3131];
   ((void (APIENTRY *)(GLuint index, GLuint x, GLuint y, GLuint z, GLuint w)) _func)(index, x, y, z, w);
}

GLAPI void APIENTRY glVertexAttribI4uiEXT(GLuint index, GLuint x, GLuint y, GLuint z, GLuint w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3132];
   ((void (APIENTRY *)(GLuint index, GLuint x, GLuint y, GLuint z, GLuint w)) _func)(index, x, y, z, w);
}

GLAPI void APIENTRY glVertexAttribI4uiv(GLuint index, const GLuint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3133];
   ((void (APIENTRY *)(GLuint index, const GLuint *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttribI4uivEXT(GLuint index, const GLuint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3134];
   ((void (APIENTRY *)(GLuint index, const GLuint *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttribI4usv(GLuint index, const GLushort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3135];
   ((void (APIENTRY *)(GLuint index, const GLushort *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttribI4usvEXT(GLuint index, const GLushort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3136];
   ((void (APIENTRY *)(GLuint index, const GLushort *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttribIFormat(GLuint attribindex, GLint size, GLenum type, GLuint relativeoffset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3137];
   ((void (APIENTRY *)(GLuint attribindex, GLint size, GLenum type, GLuint relativeoffset)) _func)(attribindex, size, type, relativeoffset);
}

GLAPI void APIENTRY glVertexAttribIFormatNV(GLuint index, GLint size, GLenum type, GLsizei stride)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3138];
   ((void (APIENTRY *)(GLuint index, GLint size, GLenum type, GLsizei stride)) _func)(index, size, type, stride);
}

GLAPI void APIENTRY glVertexAttribIPointer(GLuint index, GLint size, GLenum type, GLsizei stride, const void *pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3139];
   ((void (APIENTRY *)(GLuint index, GLint size, GLenum type, GLsizei stride, const void *pointer)) _func)(index, size, type, stride, pointer);
}

GLAPI void APIENTRY glVertexAttribIPointerEXT(GLuint index, GLint size, GLenum type, GLsizei stride, const void *pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3140];
   ((void (APIENTRY *)(GLuint index, GLint size, GLenum type, GLsizei stride, const void *pointer)) _func)(index, size, type, stride, pointer);
}

GLAPI void APIENTRY glVertexAttribL1d(GLuint index, GLdouble x)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3141];
   ((void (APIENTRY *)(GLuint index, GLdouble x)) _func)(index, x);
}

GLAPI void APIENTRY glVertexAttribL1dEXT(GLuint index, GLdouble x)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3142];
   ((void (APIENTRY *)(GLuint index, GLdouble x)) _func)(index, x);
}

GLAPI void APIENTRY glVertexAttribL1dv(GLuint index, const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3143];
   ((void (APIENTRY *)(GLuint index, const GLdouble *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttribL1dvEXT(GLuint index, const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3144];
   ((void (APIENTRY *)(GLuint index, const GLdouble *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttribL1i64NV(GLuint index, GLint64 x)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3145];
   ((void (APIENTRY *)(GLuint index, GLint64 x)) _func)(index, x);
}

GLAPI void APIENTRY glVertexAttribL1i64vNV(GLuint index, const GLint64 *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3146];
   ((void (APIENTRY *)(GLuint index, const GLint64 *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttribL1ui64ARB(GLuint index, GLuint64 x)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3147];
   ((void (APIENTRY *)(GLuint index, GLuint64 x)) _func)(index, x);
}

GLAPI void APIENTRY glVertexAttribL1ui64NV(GLuint index, GLuint64 x)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3148];
   ((void (APIENTRY *)(GLuint index, GLuint64 x)) _func)(index, x);
}

GLAPI void APIENTRY glVertexAttribL1ui64vARB(GLuint index, const GLuint64 *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3149];
   ((void (APIENTRY *)(GLuint index, const GLuint64 *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttribL1ui64vNV(GLuint index, const GLuint64 *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3150];
   ((void (APIENTRY *)(GLuint index, const GLuint64 *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttribL2d(GLuint index, GLdouble x, GLdouble y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3151];
   ((void (APIENTRY *)(GLuint index, GLdouble x, GLdouble y)) _func)(index, x, y);
}

GLAPI void APIENTRY glVertexAttribL2dEXT(GLuint index, GLdouble x, GLdouble y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3152];
   ((void (APIENTRY *)(GLuint index, GLdouble x, GLdouble y)) _func)(index, x, y);
}

GLAPI void APIENTRY glVertexAttribL2dv(GLuint index, const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3153];
   ((void (APIENTRY *)(GLuint index, const GLdouble *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttribL2dvEXT(GLuint index, const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3154];
   ((void (APIENTRY *)(GLuint index, const GLdouble *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttribL2i64NV(GLuint index, GLint64 x, GLint64 y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3155];
   ((void (APIENTRY *)(GLuint index, GLint64 x, GLint64 y)) _func)(index, x, y);
}

GLAPI void APIENTRY glVertexAttribL2i64vNV(GLuint index, const GLint64 *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3156];
   ((void (APIENTRY *)(GLuint index, const GLint64 *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttribL2ui64NV(GLuint index, GLuint64 x, GLuint64 y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3157];
   ((void (APIENTRY *)(GLuint index, GLuint64 x, GLuint64 y)) _func)(index, x, y);
}

GLAPI void APIENTRY glVertexAttribL2ui64vNV(GLuint index, const GLuint64 *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3158];
   ((void (APIENTRY *)(GLuint index, const GLuint64 *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttribL3d(GLuint index, GLdouble x, GLdouble y, GLdouble z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3159];
   ((void (APIENTRY *)(GLuint index, GLdouble x, GLdouble y, GLdouble z)) _func)(index, x, y, z);
}

GLAPI void APIENTRY glVertexAttribL3dEXT(GLuint index, GLdouble x, GLdouble y, GLdouble z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3160];
   ((void (APIENTRY *)(GLuint index, GLdouble x, GLdouble y, GLdouble z)) _func)(index, x, y, z);
}

GLAPI void APIENTRY glVertexAttribL3dv(GLuint index, const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3161];
   ((void (APIENTRY *)(GLuint index, const GLdouble *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttribL3dvEXT(GLuint index, const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3162];
   ((void (APIENTRY *)(GLuint index, const GLdouble *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttribL3i64NV(GLuint index, GLint64 x, GLint64 y, GLint64 z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3163];
   ((void (APIENTRY *)(GLuint index, GLint64 x, GLint64 y, GLint64 z)) _func)(index, x, y, z);
}

GLAPI void APIENTRY glVertexAttribL3i64vNV(GLuint index, const GLint64 *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3164];
   ((void (APIENTRY *)(GLuint index, const GLint64 *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttribL3ui64NV(GLuint index, GLuint64 x, GLuint64 y, GLuint64 z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3165];
   ((void (APIENTRY *)(GLuint index, GLuint64 x, GLuint64 y, GLuint64 z)) _func)(index, x, y, z);
}

GLAPI void APIENTRY glVertexAttribL3ui64vNV(GLuint index, const GLuint64 *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3166];
   ((void (APIENTRY *)(GLuint index, const GLuint64 *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttribL4d(GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3167];
   ((void (APIENTRY *)(GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w)) _func)(index, x, y, z, w);
}

GLAPI void APIENTRY glVertexAttribL4dEXT(GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3168];
   ((void (APIENTRY *)(GLuint index, GLdouble x, GLdouble y, GLdouble z, GLdouble w)) _func)(index, x, y, z, w);
}

GLAPI void APIENTRY glVertexAttribL4dv(GLuint index, const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3169];
   ((void (APIENTRY *)(GLuint index, const GLdouble *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttribL4dvEXT(GLuint index, const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3170];
   ((void (APIENTRY *)(GLuint index, const GLdouble *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttribL4i64NV(GLuint index, GLint64 x, GLint64 y, GLint64 z, GLint64 w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3171];
   ((void (APIENTRY *)(GLuint index, GLint64 x, GLint64 y, GLint64 z, GLint64 w)) _func)(index, x, y, z, w);
}

GLAPI void APIENTRY glVertexAttribL4i64vNV(GLuint index, const GLint64 *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3172];
   ((void (APIENTRY *)(GLuint index, const GLint64 *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttribL4ui64NV(GLuint index, GLuint64 x, GLuint64 y, GLuint64 z, GLuint64 w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3173];
   ((void (APIENTRY *)(GLuint index, GLuint64 x, GLuint64 y, GLuint64 z, GLuint64 w)) _func)(index, x, y, z, w);
}

GLAPI void APIENTRY glVertexAttribL4ui64vNV(GLuint index, const GLuint64 *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3174];
   ((void (APIENTRY *)(GLuint index, const GLuint64 *v)) _func)(index, v);
}

GLAPI void APIENTRY glVertexAttribLFormat(GLuint attribindex, GLint size, GLenum type, GLuint relativeoffset)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3175];
   ((void (APIENTRY *)(GLuint attribindex, GLint size, GLenum type, GLuint relativeoffset)) _func)(attribindex, size, type, relativeoffset);
}

GLAPI void APIENTRY glVertexAttribLFormatNV(GLuint index, GLint size, GLenum type, GLsizei stride)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3176];
   ((void (APIENTRY *)(GLuint index, GLint size, GLenum type, GLsizei stride)) _func)(index, size, type, stride);
}

GLAPI void APIENTRY glVertexAttribLPointer(GLuint index, GLint size, GLenum type, GLsizei stride, const void *pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3177];
   ((void (APIENTRY *)(GLuint index, GLint size, GLenum type, GLsizei stride, const void *pointer)) _func)(index, size, type, stride, pointer);
}

GLAPI void APIENTRY glVertexAttribLPointerEXT(GLuint index, GLint size, GLenum type, GLsizei stride, const void *pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3178];
   ((void (APIENTRY *)(GLuint index, GLint size, GLenum type, GLsizei stride, const void *pointer)) _func)(index, size, type, stride, pointer);
}

GLAPI void APIENTRY glVertexAttribP1ui(GLuint index, GLenum type, GLboolean normalized, GLuint value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3179];
   ((void (APIENTRY *)(GLuint index, GLenum type, GLboolean normalized, GLuint value)) _func)(index, type, normalized, value);
}

GLAPI void APIENTRY glVertexAttribP1uiv(GLuint index, GLenum type, GLboolean normalized, const GLuint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3180];
   ((void (APIENTRY *)(GLuint index, GLenum type, GLboolean normalized, const GLuint *value)) _func)(index, type, normalized, value);
}

GLAPI void APIENTRY glVertexAttribP2ui(GLuint index, GLenum type, GLboolean normalized, GLuint value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3181];
   ((void (APIENTRY *)(GLuint index, GLenum type, GLboolean normalized, GLuint value)) _func)(index, type, normalized, value);
}

GLAPI void APIENTRY glVertexAttribP2uiv(GLuint index, GLenum type, GLboolean normalized, const GLuint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3182];
   ((void (APIENTRY *)(GLuint index, GLenum type, GLboolean normalized, const GLuint *value)) _func)(index, type, normalized, value);
}

GLAPI void APIENTRY glVertexAttribP3ui(GLuint index, GLenum type, GLboolean normalized, GLuint value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3183];
   ((void (APIENTRY *)(GLuint index, GLenum type, GLboolean normalized, GLuint value)) _func)(index, type, normalized, value);
}

GLAPI void APIENTRY glVertexAttribP3uiv(GLuint index, GLenum type, GLboolean normalized, const GLuint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3184];
   ((void (APIENTRY *)(GLuint index, GLenum type, GLboolean normalized, const GLuint *value)) _func)(index, type, normalized, value);
}

GLAPI void APIENTRY glVertexAttribP4ui(GLuint index, GLenum type, GLboolean normalized, GLuint value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3185];
   ((void (APIENTRY *)(GLuint index, GLenum type, GLboolean normalized, GLuint value)) _func)(index, type, normalized, value);
}

GLAPI void APIENTRY glVertexAttribP4uiv(GLuint index, GLenum type, GLboolean normalized, const GLuint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3186];
   ((void (APIENTRY *)(GLuint index, GLenum type, GLboolean normalized, const GLuint *value)) _func)(index, type, normalized, value);
}

GLAPI void APIENTRY glVertexAttribParameteriAMD(GLuint index, GLenum pname, GLint param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3187];
   ((void (APIENTRY *)(GLuint index, GLenum pname, GLint param)) _func)(index, pname, param);
}

GLAPI void APIENTRY glVertexAttribPointer(GLuint index, GLint size, GLenum type, GLboolean normalized, GLsizei stride, const void *pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3188];
   ((void (APIENTRY *)(GLuint index, GLint size, GLenum type, GLboolean normalized, GLsizei stride, const void *pointer)) _func)(index, size, type, normalized, stride, pointer);
}

GLAPI void APIENTRY glVertexAttribPointerARB(GLuint index, GLint size, GLenum type, GLboolean normalized, GLsizei stride, const void *pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3189];
   ((void (APIENTRY *)(GLuint index, GLint size, GLenum type, GLboolean normalized, GLsizei stride, const void *pointer)) _func)(index, size, type, normalized, stride, pointer);
}

GLAPI void APIENTRY glVertexAttribPointerNV(GLuint index, GLint fsize, GLenum type, GLsizei stride, const void *pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3190];
   ((void (APIENTRY *)(GLuint index, GLint fsize, GLenum type, GLsizei stride, const void *pointer)) _func)(index, fsize, type, stride, pointer);
}

GLAPI void APIENTRY glVertexAttribs1dvNV(GLuint index, GLsizei count, const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3191];
   ((void (APIENTRY *)(GLuint index, GLsizei count, const GLdouble *v)) _func)(index, count, v);
}

GLAPI void APIENTRY glVertexAttribs1fvNV(GLuint index, GLsizei count, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3192];
   ((void (APIENTRY *)(GLuint index, GLsizei count, const GLfloat *v)) _func)(index, count, v);
}

GLAPI void APIENTRY glVertexAttribs1hvNV(GLuint index, GLsizei n, const GLhalf *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3193];
   ((void (APIENTRY *)(GLuint index, GLsizei n, const GLhalf *v)) _func)(index, n, v);
}

GLAPI void APIENTRY glVertexAttribs1svNV(GLuint index, GLsizei count, const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3194];
   ((void (APIENTRY *)(GLuint index, GLsizei count, const GLshort *v)) _func)(index, count, v);
}

GLAPI void APIENTRY glVertexAttribs2dvNV(GLuint index, GLsizei count, const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3195];
   ((void (APIENTRY *)(GLuint index, GLsizei count, const GLdouble *v)) _func)(index, count, v);
}

GLAPI void APIENTRY glVertexAttribs2fvNV(GLuint index, GLsizei count, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3196];
   ((void (APIENTRY *)(GLuint index, GLsizei count, const GLfloat *v)) _func)(index, count, v);
}

GLAPI void APIENTRY glVertexAttribs2hvNV(GLuint index, GLsizei n, const GLhalf *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3197];
   ((void (APIENTRY *)(GLuint index, GLsizei n, const GLhalf *v)) _func)(index, n, v);
}

GLAPI void APIENTRY glVertexAttribs2svNV(GLuint index, GLsizei count, const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3198];
   ((void (APIENTRY *)(GLuint index, GLsizei count, const GLshort *v)) _func)(index, count, v);
}

GLAPI void APIENTRY glVertexAttribs3dvNV(GLuint index, GLsizei count, const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3199];
   ((void (APIENTRY *)(GLuint index, GLsizei count, const GLdouble *v)) _func)(index, count, v);
}

GLAPI void APIENTRY glVertexAttribs3fvNV(GLuint index, GLsizei count, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3200];
   ((void (APIENTRY *)(GLuint index, GLsizei count, const GLfloat *v)) _func)(index, count, v);
}

GLAPI void APIENTRY glVertexAttribs3hvNV(GLuint index, GLsizei n, const GLhalf *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3201];
   ((void (APIENTRY *)(GLuint index, GLsizei n, const GLhalf *v)) _func)(index, n, v);
}

GLAPI void APIENTRY glVertexAttribs3svNV(GLuint index, GLsizei count, const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3202];
   ((void (APIENTRY *)(GLuint index, GLsizei count, const GLshort *v)) _func)(index, count, v);
}

GLAPI void APIENTRY glVertexAttribs4dvNV(GLuint index, GLsizei count, const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3203];
   ((void (APIENTRY *)(GLuint index, GLsizei count, const GLdouble *v)) _func)(index, count, v);
}

GLAPI void APIENTRY glVertexAttribs4fvNV(GLuint index, GLsizei count, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3204];
   ((void (APIENTRY *)(GLuint index, GLsizei count, const GLfloat *v)) _func)(index, count, v);
}

GLAPI void APIENTRY glVertexAttribs4hvNV(GLuint index, GLsizei n, const GLhalf *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3205];
   ((void (APIENTRY *)(GLuint index, GLsizei n, const GLhalf *v)) _func)(index, n, v);
}

GLAPI void APIENTRY glVertexAttribs4svNV(GLuint index, GLsizei count, const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3206];
   ((void (APIENTRY *)(GLuint index, GLsizei count, const GLshort *v)) _func)(index, count, v);
}

GLAPI void APIENTRY glVertexAttribs4ubvNV(GLuint index, GLsizei count, const GLubyte *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3207];
   ((void (APIENTRY *)(GLuint index, GLsizei count, const GLubyte *v)) _func)(index, count, v);
}

GLAPI void APIENTRY glVertexBindingDivisor(GLuint bindingindex, GLuint divisor)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3208];
   ((void (APIENTRY *)(GLuint bindingindex, GLuint divisor)) _func)(bindingindex, divisor);
}

GLAPI void APIENTRY glVertexBlendARB(GLint count)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3209];
   ((void (APIENTRY *)(GLint count)) _func)(count);
}

GLAPI void APIENTRY glVertexBlendEnvfATI(GLenum pname, GLfloat param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3210];
   ((void (APIENTRY *)(GLenum pname, GLfloat param)) _func)(pname, param);
}

GLAPI void APIENTRY glVertexBlendEnviATI(GLenum pname, GLint param)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3211];
   ((void (APIENTRY *)(GLenum pname, GLint param)) _func)(pname, param);
}

GLAPI void APIENTRY glVertexFormatNV(GLint size, GLenum type, GLsizei stride)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3212];
   ((void (APIENTRY *)(GLint size, GLenum type, GLsizei stride)) _func)(size, type, stride);
}

GLAPI void APIENTRY glVertexP2ui(GLenum type, GLuint value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3213];
   ((void (APIENTRY *)(GLenum type, GLuint value)) _func)(type, value);
}

GLAPI void APIENTRY glVertexP2uiv(GLenum type, const GLuint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3214];
   ((void (APIENTRY *)(GLenum type, const GLuint *value)) _func)(type, value);
}

GLAPI void APIENTRY glVertexP3ui(GLenum type, GLuint value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3215];
   ((void (APIENTRY *)(GLenum type, GLuint value)) _func)(type, value);
}

GLAPI void APIENTRY glVertexP3uiv(GLenum type, const GLuint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3216];
   ((void (APIENTRY *)(GLenum type, const GLuint *value)) _func)(type, value);
}

GLAPI void APIENTRY glVertexP4ui(GLenum type, GLuint value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3217];
   ((void (APIENTRY *)(GLenum type, GLuint value)) _func)(type, value);
}

GLAPI void APIENTRY glVertexP4uiv(GLenum type, const GLuint *value)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3218];
   ((void (APIENTRY *)(GLenum type, const GLuint *value)) _func)(type, value);
}

GLAPI void APIENTRY glVertexPointer(GLint size, GLenum type, GLsizei stride, const void *pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3219];
   ((void (APIENTRY *)(GLint size, GLenum type, GLsizei stride, const void *pointer)) _func)(size, type, stride, pointer);
}

GLAPI void APIENTRY glVertexPointerEXT(GLint size, GLenum type, GLsizei stride, GLsizei count, const void *pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3220];
   ((void (APIENTRY *)(GLint size, GLenum type, GLsizei stride, GLsizei count, const void *pointer)) _func)(size, type, stride, count, pointer);
}

GLAPI void APIENTRY glVertexPointerListIBM(GLint size, GLenum type, GLint stride, const void **pointer, GLint ptrstride)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3221];
   ((void (APIENTRY *)(GLint size, GLenum type, GLint stride, const void **pointer, GLint ptrstride)) _func)(size, type, stride, pointer, ptrstride);
}

GLAPI void APIENTRY glVertexPointervINTEL(GLint size, GLenum type, const void **pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3222];
   ((void (APIENTRY *)(GLint size, GLenum type, const void **pointer)) _func)(size, type, pointer);
}

GLAPI void APIENTRY glVertexStream1dATI(GLenum stream, GLdouble x)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3223];
   ((void (APIENTRY *)(GLenum stream, GLdouble x)) _func)(stream, x);
}

GLAPI void APIENTRY glVertexStream1dvATI(GLenum stream, const GLdouble *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3224];
   ((void (APIENTRY *)(GLenum stream, const GLdouble *coords)) _func)(stream, coords);
}

GLAPI void APIENTRY glVertexStream1fATI(GLenum stream, GLfloat x)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3225];
   ((void (APIENTRY *)(GLenum stream, GLfloat x)) _func)(stream, x);
}

GLAPI void APIENTRY glVertexStream1fvATI(GLenum stream, const GLfloat *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3226];
   ((void (APIENTRY *)(GLenum stream, const GLfloat *coords)) _func)(stream, coords);
}

GLAPI void APIENTRY glVertexStream1iATI(GLenum stream, GLint x)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3227];
   ((void (APIENTRY *)(GLenum stream, GLint x)) _func)(stream, x);
}

GLAPI void APIENTRY glVertexStream1ivATI(GLenum stream, const GLint *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3228];
   ((void (APIENTRY *)(GLenum stream, const GLint *coords)) _func)(stream, coords);
}

GLAPI void APIENTRY glVertexStream1sATI(GLenum stream, GLshort x)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3229];
   ((void (APIENTRY *)(GLenum stream, GLshort x)) _func)(stream, x);
}

GLAPI void APIENTRY glVertexStream1svATI(GLenum stream, const GLshort *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3230];
   ((void (APIENTRY *)(GLenum stream, const GLshort *coords)) _func)(stream, coords);
}

GLAPI void APIENTRY glVertexStream2dATI(GLenum stream, GLdouble x, GLdouble y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3231];
   ((void (APIENTRY *)(GLenum stream, GLdouble x, GLdouble y)) _func)(stream, x, y);
}

GLAPI void APIENTRY glVertexStream2dvATI(GLenum stream, const GLdouble *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3232];
   ((void (APIENTRY *)(GLenum stream, const GLdouble *coords)) _func)(stream, coords);
}

GLAPI void APIENTRY glVertexStream2fATI(GLenum stream, GLfloat x, GLfloat y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3233];
   ((void (APIENTRY *)(GLenum stream, GLfloat x, GLfloat y)) _func)(stream, x, y);
}

GLAPI void APIENTRY glVertexStream2fvATI(GLenum stream, const GLfloat *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3234];
   ((void (APIENTRY *)(GLenum stream, const GLfloat *coords)) _func)(stream, coords);
}

GLAPI void APIENTRY glVertexStream2iATI(GLenum stream, GLint x, GLint y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3235];
   ((void (APIENTRY *)(GLenum stream, GLint x, GLint y)) _func)(stream, x, y);
}

GLAPI void APIENTRY glVertexStream2ivATI(GLenum stream, const GLint *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3236];
   ((void (APIENTRY *)(GLenum stream, const GLint *coords)) _func)(stream, coords);
}

GLAPI void APIENTRY glVertexStream2sATI(GLenum stream, GLshort x, GLshort y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3237];
   ((void (APIENTRY *)(GLenum stream, GLshort x, GLshort y)) _func)(stream, x, y);
}

GLAPI void APIENTRY glVertexStream2svATI(GLenum stream, const GLshort *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3238];
   ((void (APIENTRY *)(GLenum stream, const GLshort *coords)) _func)(stream, coords);
}

GLAPI void APIENTRY glVertexStream3dATI(GLenum stream, GLdouble x, GLdouble y, GLdouble z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3239];
   ((void (APIENTRY *)(GLenum stream, GLdouble x, GLdouble y, GLdouble z)) _func)(stream, x, y, z);
}

GLAPI void APIENTRY glVertexStream3dvATI(GLenum stream, const GLdouble *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3240];
   ((void (APIENTRY *)(GLenum stream, const GLdouble *coords)) _func)(stream, coords);
}

GLAPI void APIENTRY glVertexStream3fATI(GLenum stream, GLfloat x, GLfloat y, GLfloat z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3241];
   ((void (APIENTRY *)(GLenum stream, GLfloat x, GLfloat y, GLfloat z)) _func)(stream, x, y, z);
}

GLAPI void APIENTRY glVertexStream3fvATI(GLenum stream, const GLfloat *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3242];
   ((void (APIENTRY *)(GLenum stream, const GLfloat *coords)) _func)(stream, coords);
}

GLAPI void APIENTRY glVertexStream3iATI(GLenum stream, GLint x, GLint y, GLint z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3243];
   ((void (APIENTRY *)(GLenum stream, GLint x, GLint y, GLint z)) _func)(stream, x, y, z);
}

GLAPI void APIENTRY glVertexStream3ivATI(GLenum stream, const GLint *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3244];
   ((void (APIENTRY *)(GLenum stream, const GLint *coords)) _func)(stream, coords);
}

GLAPI void APIENTRY glVertexStream3sATI(GLenum stream, GLshort x, GLshort y, GLshort z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3245];
   ((void (APIENTRY *)(GLenum stream, GLshort x, GLshort y, GLshort z)) _func)(stream, x, y, z);
}

GLAPI void APIENTRY glVertexStream3svATI(GLenum stream, const GLshort *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3246];
   ((void (APIENTRY *)(GLenum stream, const GLshort *coords)) _func)(stream, coords);
}

GLAPI void APIENTRY glVertexStream4dATI(GLenum stream, GLdouble x, GLdouble y, GLdouble z, GLdouble w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3247];
   ((void (APIENTRY *)(GLenum stream, GLdouble x, GLdouble y, GLdouble z, GLdouble w)) _func)(stream, x, y, z, w);
}

GLAPI void APIENTRY glVertexStream4dvATI(GLenum stream, const GLdouble *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3248];
   ((void (APIENTRY *)(GLenum stream, const GLdouble *coords)) _func)(stream, coords);
}

GLAPI void APIENTRY glVertexStream4fATI(GLenum stream, GLfloat x, GLfloat y, GLfloat z, GLfloat w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3249];
   ((void (APIENTRY *)(GLenum stream, GLfloat x, GLfloat y, GLfloat z, GLfloat w)) _func)(stream, x, y, z, w);
}

GLAPI void APIENTRY glVertexStream4fvATI(GLenum stream, const GLfloat *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3250];
   ((void (APIENTRY *)(GLenum stream, const GLfloat *coords)) _func)(stream, coords);
}

GLAPI void APIENTRY glVertexStream4iATI(GLenum stream, GLint x, GLint y, GLint z, GLint w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3251];
   ((void (APIENTRY *)(GLenum stream, GLint x, GLint y, GLint z, GLint w)) _func)(stream, x, y, z, w);
}

GLAPI void APIENTRY glVertexStream4ivATI(GLenum stream, const GLint *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3252];
   ((void (APIENTRY *)(GLenum stream, const GLint *coords)) _func)(stream, coords);
}

GLAPI void APIENTRY glVertexStream4sATI(GLenum stream, GLshort x, GLshort y, GLshort z, GLshort w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3253];
   ((void (APIENTRY *)(GLenum stream, GLshort x, GLshort y, GLshort z, GLshort w)) _func)(stream, x, y, z, w);
}

GLAPI void APIENTRY glVertexStream4svATI(GLenum stream, const GLshort *coords)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3254];
   ((void (APIENTRY *)(GLenum stream, const GLshort *coords)) _func)(stream, coords);
}

GLAPI void APIENTRY glVertexWeightPointerEXT(GLint size, GLenum type, GLsizei stride, const void *pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3255];
   ((void (APIENTRY *)(GLint size, GLenum type, GLsizei stride, const void *pointer)) _func)(size, type, stride, pointer);
}

GLAPI void APIENTRY glVertexWeightfEXT(GLfloat weight)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3256];
   ((void (APIENTRY *)(GLfloat weight)) _func)(weight);
}

GLAPI void APIENTRY glVertexWeightfvEXT(const GLfloat *weight)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3257];
   ((void (APIENTRY *)(const GLfloat *weight)) _func)(weight);
}

GLAPI void APIENTRY glVertexWeighthNV(GLhalf weight)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3258];
   ((void (APIENTRY *)(GLhalf weight)) _func)(weight);
}

GLAPI void APIENTRY glVertexWeighthvNV(const GLhalf *weight)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3259];
   ((void (APIENTRY *)(const GLhalf *weight)) _func)(weight);
}

GLAPI GLenum APIENTRY glVideoCaptureNV(GLuint video_capture_slot, GLuint *sequence_num, GLuint64 *capture_time)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3260];
   return ((GLenum (APIENTRY *)(GLuint video_capture_slot, GLuint *sequence_num, GLuint64 *capture_time)) _func)(video_capture_slot, sequence_num, capture_time);
}

GLAPI void APIENTRY glVideoCaptureStreamParameterdvNV(GLuint video_capture_slot, GLuint stream, GLenum pname, const GLdouble *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3261];
   ((void (APIENTRY *)(GLuint video_capture_slot, GLuint stream, GLenum pname, const GLdouble *params)) _func)(video_capture_slot, stream, pname, params);
}

GLAPI void APIENTRY glVideoCaptureStreamParameterfvNV(GLuint video_capture_slot, GLuint stream, GLenum pname, const GLfloat *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3262];
   ((void (APIENTRY *)(GLuint video_capture_slot, GLuint stream, GLenum pname, const GLfloat *params)) _func)(video_capture_slot, stream, pname, params);
}

GLAPI void APIENTRY glVideoCaptureStreamParameterivNV(GLuint video_capture_slot, GLuint stream, GLenum pname, const GLint *params)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3263];
   ((void (APIENTRY *)(GLuint video_capture_slot, GLuint stream, GLenum pname, const GLint *params)) _func)(video_capture_slot, stream, pname, params);
}

GLAPI void APIENTRY glViewport(GLint x, GLint y, GLsizei width, GLsizei height)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3264];
   ((void (APIENTRY *)(GLint x, GLint y, GLsizei width, GLsizei height)) _func)(x, y, width, height);
}

GLAPI void APIENTRY glViewportArrayv(GLuint first, GLsizei count, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3265];
   ((void (APIENTRY *)(GLuint first, GLsizei count, const GLfloat *v)) _func)(first, count, v);
}

GLAPI void APIENTRY glViewportArrayvNV(GLuint first, GLsizei count, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3266];
   ((void (APIENTRY *)(GLuint first, GLsizei count, const GLfloat *v)) _func)(first, count, v);
}

GLAPI void APIENTRY glViewportArrayvOES(GLuint first, GLsizei count, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3267];
   ((void (APIENTRY *)(GLuint first, GLsizei count, const GLfloat *v)) _func)(first, count, v);
}

GLAPI void APIENTRY glViewportIndexedf(GLuint index, GLfloat x, GLfloat y, GLfloat w, GLfloat h)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3268];
   ((void (APIENTRY *)(GLuint index, GLfloat x, GLfloat y, GLfloat w, GLfloat h)) _func)(index, x, y, w, h);
}

GLAPI void APIENTRY glViewportIndexedfNV(GLuint index, GLfloat x, GLfloat y, GLfloat w, GLfloat h)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3269];
   ((void (APIENTRY *)(GLuint index, GLfloat x, GLfloat y, GLfloat w, GLfloat h)) _func)(index, x, y, w, h);
}

GLAPI void APIENTRY glViewportIndexedfOES(GLuint index, GLfloat x, GLfloat y, GLfloat w, GLfloat h)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3270];
   ((void (APIENTRY *)(GLuint index, GLfloat x, GLfloat y, GLfloat w, GLfloat h)) _func)(index, x, y, w, h);
}

GLAPI void APIENTRY glViewportIndexedfv(GLuint index, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3271];
   ((void (APIENTRY *)(GLuint index, const GLfloat *v)) _func)(index, v);
}

GLAPI void APIENTRY glViewportIndexedfvNV(GLuint index, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3272];
   ((void (APIENTRY *)(GLuint index, const GLfloat *v)) _func)(index, v);
}

GLAPI void APIENTRY glViewportIndexedfvOES(GLuint index, const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3273];
   ((void (APIENTRY *)(GLuint index, const GLfloat *v)) _func)(index, v);
}

GLAPI void APIENTRY glViewportPositionWScaleNV(GLuint index, GLfloat xcoeff, GLfloat ycoeff)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3274];
   ((void (APIENTRY *)(GLuint index, GLfloat xcoeff, GLfloat ycoeff)) _func)(index, xcoeff, ycoeff);
}

GLAPI void APIENTRY glViewportSwizzleNV(GLuint index, GLenum swizzlex, GLenum swizzley, GLenum swizzlez, GLenum swizzlew)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3275];
   ((void (APIENTRY *)(GLuint index, GLenum swizzlex, GLenum swizzley, GLenum swizzlez, GLenum swizzlew)) _func)(index, swizzlex, swizzley, swizzlez, swizzlew);
}

GLAPI void APIENTRY glWaitSemaphoreEXT(GLuint semaphore, GLuint numBufferBarriers, const GLuint *buffers, GLuint numTextureBarriers, const GLuint *textures, const GLenum *srcLayouts)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3276];
   ((void (APIENTRY *)(GLuint semaphore, GLuint numBufferBarriers, const GLuint *buffers, GLuint numTextureBarriers, const GLuint *textures, const GLenum *srcLayouts)) _func)(semaphore, numBufferBarriers, buffers, numTextureBarriers, textures, srcLayouts);
}

GLAPI void APIENTRY glWaitSemaphoreui64NVX(GLuint waitGpu, GLsizei fenceObjectCount, const GLuint *semaphoreArray, const GLuint64 *fenceValueArray)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3277];
   ((void (APIENTRY *)(GLuint waitGpu, GLsizei fenceObjectCount, const GLuint *semaphoreArray, const GLuint64 *fenceValueArray)) _func)(waitGpu, fenceObjectCount, semaphoreArray, fenceValueArray);
}

GLAPI void APIENTRY glWaitSync(GLsync sync, GLbitfield flags, GLuint64 timeout)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3278];
   ((void (APIENTRY *)(GLsync sync, GLbitfield flags, GLuint64 timeout)) _func)(sync, flags, timeout);
}

GLAPI void APIENTRY glWaitSyncAPPLE(GLsync sync, GLbitfield flags, GLuint64 timeout)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3279];
   ((void (APIENTRY *)(GLsync sync, GLbitfield flags, GLuint64 timeout)) _func)(sync, flags, timeout);
}

GLAPI void APIENTRY glWaitSyncValueuiNVX(GLsync sync, GLbitfield flags, GLuint64 timeout, GLuint value, GLboolean GEQ)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3280];
   ((void (APIENTRY *)(GLsync sync, GLbitfield flags, GLuint64 timeout, GLuint value, GLboolean GEQ)) _func)(sync, flags, timeout, value, GEQ);
}

GLAPI void APIENTRY glWaitVkSemaphoreNV(GLuint64 vkSemaphore)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3281];
   ((void (APIENTRY *)(GLuint64 vkSemaphore)) _func)(vkSemaphore);
}

GLAPI void APIENTRY glWeightPathsNV(GLuint resultPath, GLsizei numPaths, const GLuint *paths, const GLfloat *weights)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3282];
   ((void (APIENTRY *)(GLuint resultPath, GLsizei numPaths, const GLuint *paths, const GLfloat *weights)) _func)(resultPath, numPaths, paths, weights);
}

GLAPI void APIENTRY glWeightPointerARB(GLint size, GLenum type, GLsizei stride, const void *pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3283];
   ((void (APIENTRY *)(GLint size, GLenum type, GLsizei stride, const void *pointer)) _func)(size, type, stride, pointer);
}

GLAPI void APIENTRY glWeightPointerOES(GLint size, GLenum type, GLsizei stride, const void *pointer)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3284];
   ((void (APIENTRY *)(GLint size, GLenum type, GLsizei stride, const void *pointer)) _func)(size, type, stride, pointer);
}

GLAPI void APIENTRY glWeightbvARB(GLint size, const GLbyte *weights)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3285];
   ((void (APIENTRY *)(GLint size, const GLbyte *weights)) _func)(size, weights);
}

GLAPI void APIENTRY glWeightdvARB(GLint size, const GLdouble *weights)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3286];
   ((void (APIENTRY *)(GLint size, const GLdouble *weights)) _func)(size, weights);
}

GLAPI void APIENTRY glWeightfvARB(GLint size, const GLfloat *weights)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3287];
   ((void (APIENTRY *)(GLint size, const GLfloat *weights)) _func)(size, weights);
}

GLAPI void APIENTRY glWeightivARB(GLint size, const GLint *weights)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3288];
   ((void (APIENTRY *)(GLint size, const GLint *weights)) _func)(size, weights);
}

GLAPI void APIENTRY glWeightsvARB(GLint size, const GLshort *weights)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3289];
   ((void (APIENTRY *)(GLint size, const GLshort *weights)) _func)(size, weights);
}

GLAPI void APIENTRY glWeightubvARB(GLint size, const GLubyte *weights)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3290];
   ((void (APIENTRY *)(GLint size, const GLubyte *weights)) _func)(size, weights);
}

GLAPI void APIENTRY glWeightuivARB(GLint size, const GLuint *weights)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3291];
   ((void (APIENTRY *)(GLint size, const GLuint *weights)) _func)(size, weights);
}

GLAPI void APIENTRY glWeightusvARB(GLint size, const GLushort *weights)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3292];
   ((void (APIENTRY *)(GLint size, const GLushort *weights)) _func)(size, weights);
}

GLAPI void APIENTRY glWindowBackBufferHintAutodesk(void)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3293];
   ((void (APIENTRY *)(void)) _func)();
}

GLAPI void APIENTRY glWindowPos2d(GLdouble x, GLdouble y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3294];
   ((void (APIENTRY *)(GLdouble x, GLdouble y)) _func)(x, y);
}

GLAPI void APIENTRY glWindowPos2dARB(GLdouble x, GLdouble y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3295];
   ((void (APIENTRY *)(GLdouble x, GLdouble y)) _func)(x, y);
}

GLAPI void APIENTRY glWindowPos2dMESA(GLdouble x, GLdouble y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3296];
   ((void (APIENTRY *)(GLdouble x, GLdouble y)) _func)(x, y);
}

GLAPI void APIENTRY glWindowPos2dv(const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3297];
   ((void (APIENTRY *)(const GLdouble *v)) _func)(v);
}

GLAPI void APIENTRY glWindowPos2dvARB(const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3298];
   ((void (APIENTRY *)(const GLdouble *v)) _func)(v);
}

GLAPI void APIENTRY glWindowPos2dvMESA(const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3299];
   ((void (APIENTRY *)(const GLdouble *v)) _func)(v);
}

GLAPI void APIENTRY glWindowPos2f(GLfloat x, GLfloat y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3300];
   ((void (APIENTRY *)(GLfloat x, GLfloat y)) _func)(x, y);
}

GLAPI void APIENTRY glWindowPos2fARB(GLfloat x, GLfloat y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3301];
   ((void (APIENTRY *)(GLfloat x, GLfloat y)) _func)(x, y);
}

GLAPI void APIENTRY glWindowPos2fMESA(GLfloat x, GLfloat y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3302];
   ((void (APIENTRY *)(GLfloat x, GLfloat y)) _func)(x, y);
}

GLAPI void APIENTRY glWindowPos2fv(const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3303];
   ((void (APIENTRY *)(const GLfloat *v)) _func)(v);
}

GLAPI void APIENTRY glWindowPos2fvARB(const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3304];
   ((void (APIENTRY *)(const GLfloat *v)) _func)(v);
}

GLAPI void APIENTRY glWindowPos2fvMESA(const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3305];
   ((void (APIENTRY *)(const GLfloat *v)) _func)(v);
}

GLAPI void APIENTRY glWindowPos2i(GLint x, GLint y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3306];
   ((void (APIENTRY *)(GLint x, GLint y)) _func)(x, y);
}

GLAPI void APIENTRY glWindowPos2iARB(GLint x, GLint y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3307];
   ((void (APIENTRY *)(GLint x, GLint y)) _func)(x, y);
}

GLAPI void APIENTRY glWindowPos2iMESA(GLint x, GLint y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3308];
   ((void (APIENTRY *)(GLint x, GLint y)) _func)(x, y);
}

GLAPI void APIENTRY glWindowPos2iv(const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3309];
   ((void (APIENTRY *)(const GLint *v)) _func)(v);
}

GLAPI void APIENTRY glWindowPos2ivARB(const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3310];
   ((void (APIENTRY *)(const GLint *v)) _func)(v);
}

GLAPI void APIENTRY glWindowPos2ivMESA(const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3311];
   ((void (APIENTRY *)(const GLint *v)) _func)(v);
}

GLAPI void APIENTRY glWindowPos2s(GLshort x, GLshort y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3312];
   ((void (APIENTRY *)(GLshort x, GLshort y)) _func)(x, y);
}

GLAPI void APIENTRY glWindowPos2sARB(GLshort x, GLshort y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3313];
   ((void (APIENTRY *)(GLshort x, GLshort y)) _func)(x, y);
}

GLAPI void APIENTRY glWindowPos2sMESA(GLshort x, GLshort y)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3314];
   ((void (APIENTRY *)(GLshort x, GLshort y)) _func)(x, y);
}

GLAPI void APIENTRY glWindowPos2sv(const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3315];
   ((void (APIENTRY *)(const GLshort *v)) _func)(v);
}

GLAPI void APIENTRY glWindowPos2svARB(const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3316];
   ((void (APIENTRY *)(const GLshort *v)) _func)(v);
}

GLAPI void APIENTRY glWindowPos2svMESA(const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3317];
   ((void (APIENTRY *)(const GLshort *v)) _func)(v);
}

GLAPI void APIENTRY glWindowPos3d(GLdouble x, GLdouble y, GLdouble z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3318];
   ((void (APIENTRY *)(GLdouble x, GLdouble y, GLdouble z)) _func)(x, y, z);
}

GLAPI void APIENTRY glWindowPos3dARB(GLdouble x, GLdouble y, GLdouble z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3319];
   ((void (APIENTRY *)(GLdouble x, GLdouble y, GLdouble z)) _func)(x, y, z);
}

GLAPI void APIENTRY glWindowPos3dMESA(GLdouble x, GLdouble y, GLdouble z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3320];
   ((void (APIENTRY *)(GLdouble x, GLdouble y, GLdouble z)) _func)(x, y, z);
}

GLAPI void APIENTRY glWindowPos3dv(const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3321];
   ((void (APIENTRY *)(const GLdouble *v)) _func)(v);
}

GLAPI void APIENTRY glWindowPos3dvARB(const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3322];
   ((void (APIENTRY *)(const GLdouble *v)) _func)(v);
}

GLAPI void APIENTRY glWindowPos3dvMESA(const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3323];
   ((void (APIENTRY *)(const GLdouble *v)) _func)(v);
}

GLAPI void APIENTRY glWindowPos3f(GLfloat x, GLfloat y, GLfloat z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3324];
   ((void (APIENTRY *)(GLfloat x, GLfloat y, GLfloat z)) _func)(x, y, z);
}

GLAPI void APIENTRY glWindowPos3fARB(GLfloat x, GLfloat y, GLfloat z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3325];
   ((void (APIENTRY *)(GLfloat x, GLfloat y, GLfloat z)) _func)(x, y, z);
}

GLAPI void APIENTRY glWindowPos3fMESA(GLfloat x, GLfloat y, GLfloat z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3326];
   ((void (APIENTRY *)(GLfloat x, GLfloat y, GLfloat z)) _func)(x, y, z);
}

GLAPI void APIENTRY glWindowPos3fv(const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3327];
   ((void (APIENTRY *)(const GLfloat *v)) _func)(v);
}

GLAPI void APIENTRY glWindowPos3fvARB(const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3328];
   ((void (APIENTRY *)(const GLfloat *v)) _func)(v);
}

GLAPI void APIENTRY glWindowPos3fvMESA(const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3329];
   ((void (APIENTRY *)(const GLfloat *v)) _func)(v);
}

GLAPI void APIENTRY glWindowPos3i(GLint x, GLint y, GLint z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3330];
   ((void (APIENTRY *)(GLint x, GLint y, GLint z)) _func)(x, y, z);
}

GLAPI void APIENTRY glWindowPos3iARB(GLint x, GLint y, GLint z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3331];
   ((void (APIENTRY *)(GLint x, GLint y, GLint z)) _func)(x, y, z);
}

GLAPI void APIENTRY glWindowPos3iMESA(GLint x, GLint y, GLint z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3332];
   ((void (APIENTRY *)(GLint x, GLint y, GLint z)) _func)(x, y, z);
}

GLAPI void APIENTRY glWindowPos3iv(const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3333];
   ((void (APIENTRY *)(const GLint *v)) _func)(v);
}

GLAPI void APIENTRY glWindowPos3ivARB(const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3334];
   ((void (APIENTRY *)(const GLint *v)) _func)(v);
}

GLAPI void APIENTRY glWindowPos3ivMESA(const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3335];
   ((void (APIENTRY *)(const GLint *v)) _func)(v);
}

GLAPI void APIENTRY glWindowPos3s(GLshort x, GLshort y, GLshort z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3336];
   ((void (APIENTRY *)(GLshort x, GLshort y, GLshort z)) _func)(x, y, z);
}

GLAPI void APIENTRY glWindowPos3sARB(GLshort x, GLshort y, GLshort z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3337];
   ((void (APIENTRY *)(GLshort x, GLshort y, GLshort z)) _func)(x, y, z);
}

GLAPI void APIENTRY glWindowPos3sMESA(GLshort x, GLshort y, GLshort z)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3338];
   ((void (APIENTRY *)(GLshort x, GLshort y, GLshort z)) _func)(x, y, z);
}

GLAPI void APIENTRY glWindowPos3sv(const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3339];
   ((void (APIENTRY *)(const GLshort *v)) _func)(v);
}

GLAPI void APIENTRY glWindowPos3svARB(const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3340];
   ((void (APIENTRY *)(const GLshort *v)) _func)(v);
}

GLAPI void APIENTRY glWindowPos3svMESA(const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3341];
   ((void (APIENTRY *)(const GLshort *v)) _func)(v);
}

GLAPI void APIENTRY glWindowPos4dMESA(GLdouble x, GLdouble y, GLdouble z, GLdouble w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3342];
   ((void (APIENTRY *)(GLdouble x, GLdouble y, GLdouble z, GLdouble w)) _func)(x, y, z, w);
}

GLAPI void APIENTRY glWindowPos4dvMESA(const GLdouble *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3343];
   ((void (APIENTRY *)(const GLdouble *v)) _func)(v);
}

GLAPI void APIENTRY glWindowPos4fMESA(GLfloat x, GLfloat y, GLfloat z, GLfloat w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3344];
   ((void (APIENTRY *)(GLfloat x, GLfloat y, GLfloat z, GLfloat w)) _func)(x, y, z, w);
}

GLAPI void APIENTRY glWindowPos4fvMESA(const GLfloat *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3345];
   ((void (APIENTRY *)(const GLfloat *v)) _func)(v);
}

GLAPI void APIENTRY glWindowPos4iMESA(GLint x, GLint y, GLint z, GLint w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3346];
   ((void (APIENTRY *)(GLint x, GLint y, GLint z, GLint w)) _func)(x, y, z, w);
}

GLAPI void APIENTRY glWindowPos4ivMESA(const GLint *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3347];
   ((void (APIENTRY *)(const GLint *v)) _func)(v);
}

GLAPI void APIENTRY glWindowPos4sMESA(GLshort x, GLshort y, GLshort z, GLshort w)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3348];
   ((void (APIENTRY *)(GLshort x, GLshort y, GLshort z, GLshort w)) _func)(x, y, z, w);
}

GLAPI void APIENTRY glWindowPos4svMESA(const GLshort *v)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3349];
   ((void (APIENTRY *)(const GLshort *v)) _func)(v);
}

GLAPI void APIENTRY glWindowRectanglesEXT(GLenum mode, GLsizei count, const GLint *box)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3350];
   ((void (APIENTRY *)(GLenum mode, GLsizei count, const GLint *box)) _func)(mode, count, box);
}

GLAPI void APIENTRY glWriteMaskEXT(GLuint res, GLuint in, GLenum outX, GLenum outY, GLenum outZ, GLenum outW)
{
   const struct _glapi_table *_tbl = entry_current_get();
   mapi_func _func = ((const mapi_func *) _tbl)[3351];
   ((void (APIENTRY *)(GLuint res, GLuint in, GLenum outX, GLenum outY, GLenum outZ, GLenum outW)) _func)(res, in, outX, outY, outZ, outW);
}


static const mapi_func public_entries[] = {
   (mapi_func) glAccum,
   (mapi_func) glAccumxOES,
   (mapi_func) glAcquireKeyedMutexWin32EXT,
   (mapi_func) glActiveProgramEXT,
   (mapi_func) glActiveShaderProgram,
   (mapi_func) glActiveShaderProgramEXT,
   (mapi_func) glActiveStencilFaceEXT,
   (mapi_func) glActiveTexture,
   (mapi_func) glActiveTextureARB,
   (mapi_func) glActiveVaryingNV,
   (mapi_func) glAlphaFragmentOp1ATI,
   (mapi_func) glAlphaFragmentOp2ATI,
   (mapi_func) glAlphaFragmentOp3ATI,
   (mapi_func) glAlphaFunc,
   (mapi_func) glAlphaFuncQCOM,
   (mapi_func) glAlphaFuncx,
   (mapi_func) glAlphaFuncxOES,
   (mapi_func) glAlphaToCoverageDitherControlNV,
   (mapi_func) glApplyFramebufferAttachmentCMAAINTEL,
   (mapi_func) glApplyTextureEXT,
   (mapi_func) glAreProgramsResidentNV,
   (mapi_func) glAreTexturesResident,
   (mapi_func) glAreTexturesResidentEXT,
   (mapi_func) glArrayElement,
   (mapi_func) glArrayElementEXT,
   (mapi_func) glArrayObjectATI,
   (mapi_func) glAsyncCopyBufferSubDataNVX,
   (mapi_func) glAsyncCopyImageSubDataNVX,
   (mapi_func) glAsyncMarkerSGIX,
   (mapi_func) glAttachObjectARB,
   (mapi_func) glAttachShader,
   (mapi_func) glBegin,
   (mapi_func) glBeginConditionalRender,
   (mapi_func) glBeginConditionalRenderNV,
   (mapi_func) glBeginConditionalRenderNVX,
   (mapi_func) glBeginFragmentShaderATI,
   (mapi_func) glBeginOcclusionQueryNV,
   (mapi_func) glBeginPerfMonitorAMD,
   (mapi_func) glBeginPerfQueryINTEL,
   (mapi_func) glBeginQuery,
   (mapi_func) glBeginQueryARB,
   (mapi_func) glBeginQueryEXT,
   (mapi_func) glBeginQueryIndexed,
   (mapi_func) glBeginTransformFeedback,
   (mapi_func) glBeginTransformFeedbackEXT,
   (mapi_func) glBeginTransformFeedbackNV,
   (mapi_func) glBeginVertexShaderEXT,
   (mapi_func) glBeginVideoCaptureNV,
   (mapi_func) glBindANCCaptureStreamBufferNVX,
   (mapi_func) glBindAttribLocation,
   (mapi_func) glBindAttribLocationARB,
   (mapi_func) glBindBuffer,
   (mapi_func) glBindBufferARB,
   (mapi_func) glBindBufferBase,
   (mapi_func) glBindBufferBaseEXT,
   (mapi_func) glBindBufferBaseNV,
   (mapi_func) glBindBufferOffsetEXT,
   (mapi_func) glBindBufferOffsetNV,
   (mapi_func) glBindBufferRange,
   (mapi_func) glBindBufferRangeEXT,
   (mapi_func) glBindBufferRangeNV,
   (mapi_func) glBindBuffersBase,
   (mapi_func) glBindBuffersRange,
   (mapi_func) glBindFragDataLocation,
   (mapi_func) glBindFragDataLocationEXT,
   (mapi_func) glBindFragDataLocationIndexed,
   (mapi_func) glBindFragDataLocationIndexedEXT,
   (mapi_func) glBindFragmentShaderATI,
   (mapi_func) glBindFramebuffer,
   (mapi_func) glBindFramebufferEXT,
   (mapi_func) glBindFramebufferOES,
   (mapi_func) glBindImageTexture,
   (mapi_func) glBindImageTextureEXT,
   (mapi_func) glBindImageTextures,
   (mapi_func) glBindLightParameterEXT,
   (mapi_func) glBindMaterialParameterEXT,
   (mapi_func) glBindMultiTextureEXT,
   (mapi_func) glBindParameterEXT,
   (mapi_func) glBindProgramARB,
   (mapi_func) glBindProgramNV,
   (mapi_func) glBindProgramPipeline,
   (mapi_func) glBindProgramPipelineEXT,
   (mapi_func) glBindRenderbuffer,
   (mapi_func) glBindRenderbufferEXT,
   (mapi_func) glBindRenderbufferOES,
   (mapi_func) glBindSampler,
   (mapi_func) glBindSamplers,
   (mapi_func) glBindShadingRateImageNV,
   (mapi_func) glBindTexGenParameterEXT,
   (mapi_func) glBindTexture,
   (mapi_func) glBindTextureEXT,
   (mapi_func) glBindTextureUnit,
   (mapi_func) glBindTextureUnitParameterEXT,
   (mapi_func) glBindTextures,
   (mapi_func) glBindTransformFeedback,
   (mapi_func) glBindTransformFeedbackEXT,
   (mapi_func) glBindTransformFeedbackNV,
   (mapi_func) glBindVertexArray,
   (mapi_func) glBindVertexArrayAPPLE,
   (mapi_func) glBindVertexArrayOES,
   (mapi_func) glBindVertexBuffer,
   (mapi_func) glBindVertexBuffers,
   (mapi_func) glBindVertexShaderEXT,
   (mapi_func) glBindVideoCaptureStreamBufferNV,
   (mapi_func) glBindVideoCaptureStreamTextureNV,
   (mapi_func) glBinormal3bEXT,
   (mapi_func) glBinormal3bvEXT,
   (mapi_func) glBinormal3dEXT,
   (mapi_func) glBinormal3dvEXT,
   (mapi_func) glBinormal3fEXT,
   (mapi_func) glBinormal3fvEXT,
   (mapi_func) glBinormal3iEXT,
   (mapi_func) glBinormal3ivEXT,
   (mapi_func) glBinormal3sEXT,
   (mapi_func) glBinormal3svEXT,
   (mapi_func) glBinormalPointerEXT,
   (mapi_func) glBitmap,
   (mapi_func) glBitmapxOES,
   (mapi_func) glBlendBarrier,
   (mapi_func) glBlendBarrierKHR,
   (mapi_func) glBlendBarrierNV,
   (mapi_func) glBlendColor,
   (mapi_func) glBlendColorEXT,
   (mapi_func) glBlendColorxOES,
   (mapi_func) glBlendEquation,
   (mapi_func) glBlendEquationEXT,
   (mapi_func) glBlendEquationIndexedAMD,
   (mapi_func) glBlendEquationOES,
   (mapi_func) glBlendEquationSeparate,
   (mapi_func) glBlendEquationSeparateEXT,
   (mapi_func) glBlendEquationSeparateIndexedAMD,
   (mapi_func) glBlendEquationSeparateOES,
   (mapi_func) glBlendEquationSeparatei,
   (mapi_func) glBlendEquationSeparateiARB,
   (mapi_func) glBlendEquationSeparateiEXT,
   (mapi_func) glBlendEquationSeparateiOES,
   (mapi_func) glBlendEquationi,
   (mapi_func) glBlendEquationiARB,
   (mapi_func) glBlendEquationiEXT,
   (mapi_func) glBlendEquationiOES,
   (mapi_func) glBlendFunc,
   (mapi_func) glBlendFuncIndexedAMD,
   (mapi_func) glBlendFuncSeparate,
   (mapi_func) glBlendFuncSeparateEXT,
   (mapi_func) glBlendFuncSeparateINGR,
   (mapi_func) glBlendFuncSeparateIndexedAMD,
   (mapi_func) glBlendFuncSeparateOES,
   (mapi_func) glBlendFuncSeparatei,
   (mapi_func) glBlendFuncSeparateiARB,
   (mapi_func) glBlendFuncSeparateiEXT,
   (mapi_func) glBlendFuncSeparateiOES,
   (mapi_func) glBlendFunci,
   (mapi_func) glBlendFunciARB,
   (mapi_func) glBlendFunciEXT,
   (mapi_func) glBlendFunciOES,
   (mapi_func) glBlendParameteriNV,
   (mapi_func) glBlitFramebuffer,
   (mapi_func) glBlitFramebufferANGLE,
   (mapi_func) glBlitFramebufferEXT,
   (mapi_func) glBlitFramebufferNV,
   (mapi_func) glBlitNamedFramebuffer,
   (mapi_func) glBufferAddressRangeNV,
   (mapi_func) glBufferAttachMemoryNV,
   (mapi_func) glBufferData,
   (mapi_func) glBufferDataARB,
   (mapi_func) glBufferDataSysmem,
   (mapi_func) glBufferPageCommitmentARB,
   (mapi_func) glBufferParameteriAPPLE,
   (mapi_func) glBufferStorage,
   (mapi_func) glBufferStorageEXT,
   (mapi_func) glBufferStorageExternalEXT,
   (mapi_func) glBufferStorageMemEXT,
   (mapi_func) glBufferSubData,
   (mapi_func) glBufferSubDataARB,
   (mapi_func) glCallCommandListNV,
   (mapi_func) glCallList,
   (mapi_func) glCallLists,
   (mapi_func) glCheckFramebufferStatus,
   (mapi_func) glCheckFramebufferStatusEXT,
   (mapi_func) glCheckFramebufferStatusOES,
   (mapi_func) glCheckNamedFramebufferStatus,
   (mapi_func) glCheckNamedFramebufferStatusEXT,
   (mapi_func) glClampColor,
   (mapi_func) glClampColorARB,
   (mapi_func) glClear,
   (mapi_func) glClearAccum,
   (mapi_func) glClearAccumxOES,
   (mapi_func) glClearBufferData,
   (mapi_func) glClearBufferSubData,
   (mapi_func) glClearBufferfi,
   (mapi_func) glClearBufferfv,
   (mapi_func) glClearBufferiv,
   (mapi_func) glClearBufferuiv,
   (mapi_func) glClearColor,
   (mapi_func) glClearColorIiEXT,
   (mapi_func) glClearColorIuiEXT,
   (mapi_func) glClearColorx,
   (mapi_func) glClearColorxOES,
   (mapi_func) glClearDepth,
   (mapi_func) glClearDepthdNV,
   (mapi_func) glClearDepthf,
   (mapi_func) glClearDepthfOES,
   (mapi_func) glClearDepthx,
   (mapi_func) glClearDepthxOES,
   (mapi_func) glClearIndex,
   (mapi_func) glClearNamedBufferData,
   (mapi_func) glClearNamedBufferDataEXT,
   (mapi_func) glClearNamedBufferSubData,
   (mapi_func) glClearNamedBufferSubDataEXT,
   (mapi_func) glClearNamedFramebufferfi,
   (mapi_func) glClearNamedFramebufferfv,
   (mapi_func) glClearNamedFramebufferiv,
   (mapi_func) glClearNamedFramebufferuiv,
   (mapi_func) glClearPixelLocalStorageuiEXT,
   (mapi_func) glClearStencil,
   (mapi_func) glClearTexImage,
   (mapi_func) glClearTexImageEXT,
   (mapi_func) glClearTexSubImage,
   (mapi_func) glClearTexSubImageEXT,
   (mapi_func) glClientActiveTexture,
   (mapi_func) glClientActiveTextureARB,
   (mapi_func) glClientActiveVertexStreamATI,
   (mapi_func) glClientAttribDefaultEXT,
   (mapi_func) glClientWaitSemaphoreui64NVX,
   (mapi_func) glClientWaitSync,
   (mapi_func) glClientWaitSyncAPPLE,
   (mapi_func) glClientWaitSyncValueuiNVX,
   (mapi_func) glClipControl,
   (mapi_func) glClipControlEXT,
   (mapi_func) glClipPlane,
   (mapi_func) glClipPlanef,
   (mapi_func) glClipPlanefIMG,
   (mapi_func) glClipPlanefOES,
   (mapi_func) glClipPlanex,
   (mapi_func) glClipPlanexIMG,
   (mapi_func) glClipPlanexOES,
   (mapi_func) glColor3b,
   (mapi_func) glColor3bv,
   (mapi_func) glColor3d,
   (mapi_func) glColor3dv,
   (mapi_func) glColor3f,
   (mapi_func) glColor3fVertex3fSUN,
   (mapi_func) glColor3fVertex3fvSUN,
   (mapi_func) glColor3fv,
   (mapi_func) glColor3hNV,
   (mapi_func) glColor3hvNV,
   (mapi_func) glColor3i,
   (mapi_func) glColor3iv,
   (mapi_func) glColor3s,
   (mapi_func) glColor3sv,
   (mapi_func) glColor3ub,
   (mapi_func) glColor3ubv,
   (mapi_func) glColor3ui,
   (mapi_func) glColor3uiv,
   (mapi_func) glColor3us,
   (mapi_func) glColor3usv,
   (mapi_func) glColor3x,
   (mapi_func) glColor3xOES,
   (mapi_func) glColor3xvOES,
   (mapi_func) glColor4b,
   (mapi_func) glColor4bv,
   (mapi_func) glColor4d,
   (mapi_func) glColor4dv,
   (mapi_func) glColor4f,
   (mapi_func) glColor4fNormal3fVertex3fSUN,
   (mapi_func) glColor4fNormal3fVertex3fvSUN,
   (mapi_func) glColor4fv,
   (mapi_func) glColor4hNV,
   (mapi_func) glColor4hvNV,
   (mapi_func) glColor4i,
   (mapi_func) glColor4iv,
   (mapi_func) glColor4s,
   (mapi_func) glColor4sv,
   (mapi_func) glColor4ub,
   (mapi_func) glColor4ubVertex2fSUN,
   (mapi_func) glColor4ubVertex2fvSUN,
   (mapi_func) glColor4ubVertex3fSUN,
   (mapi_func) glColor4ubVertex3fvSUN,
   (mapi_func) glColor4ubv,
   (mapi_func) glColor4ui,
   (mapi_func) glColor4uiv,
   (mapi_func) glColor4us,
   (mapi_func) glColor4usv,
   (mapi_func) glColor4x,
   (mapi_func) glColor4xOES,
   (mapi_func) glColor4xvOES,
   (mapi_func) glColorFormatNV,
   (mapi_func) glColorFragmentOp1ATI,
   (mapi_func) glColorFragmentOp2ATI,
   (mapi_func) glColorFragmentOp3ATI,
   (mapi_func) glColorMask,
   (mapi_func) glColorMaskIndexedEXT,
   (mapi_func) glColorMaski,
   (mapi_func) glColorMaskiEXT,
   (mapi_func) glColorMaskiOES,
   (mapi_func) glColorMaterial,
   (mapi_func) glColorP3ui,
   (mapi_func) glColorP3uiv,
   (mapi_func) glColorP4ui,
   (mapi_func) glColorP4uiv,
   (mapi_func) glColorPointer,
   (mapi_func) glColorPointerEXT,
   (mapi_func) glColorPointerListIBM,
   (mapi_func) glColorPointervINTEL,
   (mapi_func) glColorSubTable,
   (mapi_func) glColorSubTableEXT,
   (mapi_func) glColorTable,
   (mapi_func) glColorTableEXT,
   (mapi_func) glColorTableParameterfv,
   (mapi_func) glColorTableParameterfvSGI,
   (mapi_func) glColorTableParameteriv,
   (mapi_func) glColorTableParameterivSGI,
   (mapi_func) glColorTableSGI,
   (mapi_func) glCombinerInputNV,
   (mapi_func) glCombinerOutputNV,
   (mapi_func) glCombinerParameterfNV,
   (mapi_func) glCombinerParameterfvNV,
   (mapi_func) glCombinerParameteriNV,
   (mapi_func) glCombinerParameterivNV,
   (mapi_func) glCombinerStageParameterfvNV,
   (mapi_func) glCommandListSegmentsNV,
   (mapi_func) glCompileCommandListNV,
   (mapi_func) glCompileShader,
   (mapi_func) glCompileShaderARB,
   (mapi_func) glCompileShaderIncludeARB,
   (mapi_func) glCompressedMultiTexImage1DEXT,
   (mapi_func) glCompressedMultiTexImage2DEXT,
   (mapi_func) glCompressedMultiTexImage3DEXT,
   (mapi_func) glCompressedMultiTexSubImage1DEXT,
   (mapi_func) glCompressedMultiTexSubImage2DEXT,
   (mapi_func) glCompressedMultiTexSubImage3DEXT,
   (mapi_func) glCompressedTexImage1D,
   (mapi_func) glCompressedTexImage1DARB,
   (mapi_func) glCompressedTexImage2D,
   (mapi_func) glCompressedTexImage2DARB,
   (mapi_func) glCompressedTexImage3D,
   (mapi_func) glCompressedTexImage3DARB,
   (mapi_func) glCompressedTexImage3DNV,
   (mapi_func) glCompressedTexImage3DOES,
   (mapi_func) glCompressedTexSubImage1D,
   (mapi_func) glCompressedTexSubImage1DARB,
   (mapi_func) glCompressedTexSubImage2D,
   (mapi_func) glCompressedTexSubImage2DARB,
   (mapi_func) glCompressedTexSubImage3D,
   (mapi_func) glCompressedTexSubImage3DARB,
   (mapi_func) glCompressedTexSubImage3DNV,
   (mapi_func) glCompressedTexSubImage3DOES,
   (mapi_func) glCompressedTextureImage1DEXT,
   (mapi_func) glCompressedTextureImage2DEXT,
   (mapi_func) glCompressedTextureImage3DEXT,
   (mapi_func) glCompressedTextureSubImage1D,
   (mapi_func) glCompressedTextureSubImage1DEXT,
   (mapi_func) glCompressedTextureSubImage2D,
   (mapi_func) glCompressedTextureSubImage2DEXT,
   (mapi_func) glCompressedTextureSubImage3D,
   (mapi_func) glCompressedTextureSubImage3DEXT,
   (mapi_func) glConservativeRasterParameterfNV,
   (mapi_func) glConservativeRasterParameteriNV,
   (mapi_func) glConvolutionFilter1D,
   (mapi_func) glConvolutionFilter1DEXT,
   (mapi_func) glConvolutionFilter2D,
   (mapi_func) glConvolutionFilter2DEXT,
   (mapi_func) glConvolutionParameterf,
   (mapi_func) glConvolutionParameterfEXT,
   (mapi_func) glConvolutionParameterfv,
   (mapi_func) glConvolutionParameterfvEXT,
   (mapi_func) glConvolutionParameteri,
   (mapi_func) glConvolutionParameteriEXT,
   (mapi_func) glConvolutionParameteriv,
   (mapi_func) glConvolutionParameterivEXT,
   (mapi_func) glConvolutionParameterxOES,
   (mapi_func) glConvolutionParameterxvOES,
   (mapi_func) glCopyBufferSubData,
   (mapi_func) glCopyBufferSubDataNV,
   (mapi_func) glCopyColorSubTable,
   (mapi_func) glCopyColorSubTableEXT,
   (mapi_func) glCopyColorTable,
   (mapi_func) glCopyColorTableSGI,
   (mapi_func) glCopyConvolutionFilter1D,
   (mapi_func) glCopyConvolutionFilter1DEXT,
   (mapi_func) glCopyConvolutionFilter2D,
   (mapi_func) glCopyConvolutionFilter2DEXT,
   (mapi_func) glCopyImageSubData,
   (mapi_func) glCopyImageSubDataEXT,
   (mapi_func) glCopyImageSubDataNV,
   (mapi_func) glCopyImageSubDataOES,
   (mapi_func) glCopyMultiTexImage1DEXT,
   (mapi_func) glCopyMultiTexImage2DEXT,
   (mapi_func) glCopyMultiTexSubImage1DEXT,
   (mapi_func) glCopyMultiTexSubImage2DEXT,
   (mapi_func) glCopyMultiTexSubImage3DEXT,
   (mapi_func) glCopyNamedBufferSubData,
   (mapi_func) glCopyPathNV,
   (mapi_func) glCopyPixels,
   (mapi_func) glCopyTexImage1D,
   (mapi_func) glCopyTexImage1DEXT,
   (mapi_func) glCopyTexImage2D,
   (mapi_func) glCopyTexImage2DEXT,
   (mapi_func) glCopyTexSubImage1D,
   (mapi_func) glCopyTexSubImage1DEXT,
   (mapi_func) glCopyTexSubImage2D,
   (mapi_func) glCopyTexSubImage2DEXT,
   (mapi_func) glCopyTexSubImage3D,
   (mapi_func) glCopyTexSubImage3DEXT,
   (mapi_func) glCopyTexSubImage3DNV,
   (mapi_func) glCopyTexSubImage3DOES,
   (mapi_func) glCopyTextureImage1DEXT,
   (mapi_func) glCopyTextureImage2DEXT,
   (mapi_func) glCopyTextureLevelsAPPLE,
   (mapi_func) glCopyTextureSubImage1D,
   (mapi_func) glCopyTextureSubImage1DEXT,
   (mapi_func) glCopyTextureSubImage2D,
   (mapi_func) glCopyTextureSubImage2DEXT,
   (mapi_func) glCopyTextureSubImage3D,
   (mapi_func) glCopyTextureSubImage3DEXT,
   (mapi_func) glCoverFillPathInstancedNV,
   (mapi_func) glCoverFillPathNV,
   (mapi_func) glCoverStrokePathInstancedNV,
   (mapi_func) glCoverStrokePathNV,
   (mapi_func) glCoverageMaskNV,
   (mapi_func) glCoverageModulationNV,
   (mapi_func) glCoverageModulationTableNV,
   (mapi_func) glCoverageOperationNV,
   (mapi_func) glCreateBuffers,
   (mapi_func) glCreateCommandListsNV,
   (mapi_func) glCreateFramebuffers,
   (mapi_func) glCreateMemoryObjectsEXT,
   (mapi_func) glCreatePerfQueryINTEL,
   (mapi_func) glCreateProgram,
   (mapi_func) glCreateProgramObjectARB,
   (mapi_func) glCreateProgramPipelines,
   (mapi_func) glCreateProgressFenceNVX,
   (mapi_func) glCreateQueries,
   (mapi_func) glCreateRenderbuffers,
   (mapi_func) glCreateSamplers,
   (mapi_func) glCreateShader,
   (mapi_func) glCreateShaderObjectARB,
   (mapi_func) glCreateShaderProgramEXT,
   (mapi_func) glCreateShaderProgramv,
   (mapi_func) glCreateShaderProgramvEXT,
   (mapi_func) glCreateStatesNV,
   (mapi_func) glCreateSyncFromCLeventARB,
   (mapi_func) glCreateTextures,
   (mapi_func) glCreateTransformFeedbacks,
   (mapi_func) glCreateVertexArrays,
   (mapi_func) glCullFace,
   (mapi_func) glCullParameterdvEXT,
   (mapi_func) glCullParameterfvEXT,
   (mapi_func) glCurrentPaletteMatrixARB,
   (mapi_func) glCurrentPaletteMatrixOES,
   (mapi_func) glDebugMessageCallback,
   (mapi_func) glDebugMessageCallbackAMD,
   (mapi_func) glDebugMessageCallbackARB,
   (mapi_func) glDebugMessageCallbackKHR,
   (mapi_func) glDebugMessageCallbackOES,
   (mapi_func) glDebugMessageControl,
   (mapi_func) glDebugMessageControlARB,
   (mapi_func) glDebugMessageControlKHR,
   (mapi_func) glDebugMessageControlOES,
   (mapi_func) glDebugMessageEnableAMD,
   (mapi_func) glDebugMessageInsert,
   (mapi_func) glDebugMessageInsertAMD,
   (mapi_func) glDebugMessageInsertARB,
   (mapi_func) glDebugMessageInsertKHR,
   (mapi_func) glDebugMessageInsertOES,
   (mapi_func) glDeformSGIX,
   (mapi_func) glDeformationMap3dSGIX,
   (mapi_func) glDeformationMap3fSGIX,
   (mapi_func) glDeleteAsyncMarkersSGIX,
   (mapi_func) glDeleteBuffers,
   (mapi_func) glDeleteBuffersARB,
   (mapi_func) glDeleteCommandListsNV,
   (mapi_func) glDeleteFencesAPPLE,
   (mapi_func) glDeleteFencesNV,
   (mapi_func) glDeleteFragmentShaderATI,
   (mapi_func) glDeleteFramebuffers,
   (mapi_func) glDeleteFramebuffersEXT,
   (mapi_func) glDeleteFramebuffersOES,
   (mapi_func) glDeleteLists,
   (mapi_func) glDeleteMemoryObjectsEXT,
   (mapi_func) glDeleteNamedStringARB,
   (mapi_func) glDeleteNamesAMD,
   (mapi_func) glDeleteObjectARB,
   (mapi_func) glDeleteOcclusionQueriesNV,
   (mapi_func) glDeletePathsNV,
   (mapi_func) glDeletePerfMonitorsAMD,
   (mapi_func) glDeletePerfQueryINTEL,
   (mapi_func) glDeleteProgram,
   (mapi_func) glDeleteProgramPipelines,
   (mapi_func) glDeleteProgramPipelinesEXT,
   (mapi_func) glDeleteProgramsARB,
   (mapi_func) glDeleteProgramsNV,
   (mapi_func) glDeleteQueries,
   (mapi_func) glDeleteQueriesARB,
   (mapi_func) glDeleteQueriesEXT,
   (mapi_func) glDeleteQueryResourceTagNV,
   (mapi_func) glDeleteRenderbuffers,
   (mapi_func) glDeleteRenderbuffersEXT,
   (mapi_func) glDeleteRenderbuffersOES,
   (mapi_func) glDeleteSamplers,
   (mapi_func) glDeleteSemaphoresEXT,
   (mapi_func) glDeleteShader,
   (mapi_func) glDeleteStatesNV,
   (mapi_func) glDeleteSync,
   (mapi_func) glDeleteSyncAPPLE,
   (mapi_func) glDeleteTextures,
   (mapi_func) glDeleteTexturesEXT,
   (mapi_func) glDeleteTransformFeedbacks,
   (mapi_func) glDeleteTransformFeedbacksEXT,
   (mapi_func) glDeleteTransformFeedbacksNV,
   (mapi_func) glDeleteVertexArrays,
   (mapi_func) glDeleteVertexArraysAPPLE,
   (mapi_func) glDeleteVertexArraysOES,
   (mapi_func) glDeleteVertexShaderEXT,
   (mapi_func) glDepthBoundsEXT,
   (mapi_func) glDepthBoundsdNV,
   (mapi_func) glDepthFunc,
   (mapi_func) glDepthMask,
   (mapi_func) glDepthRange,
   (mapi_func) glDepthRangeArraydvNV,
   (mapi_func) glDepthRangeArrayfvNV,
   (mapi_func) glDepthRangeArrayfvOES,
   (mapi_func) glDepthRangeArrayv,
   (mapi_func) glDepthRangeIndexed,
   (mapi_func) glDepthRangeIndexeddNV,
   (mapi_func) glDepthRangeIndexedfNV,
   (mapi_func) glDepthRangeIndexedfOES,
   (mapi_func) glDepthRangedNV,
   (mapi_func) glDepthRangef,
   (mapi_func) glDepthRangefOES,
   (mapi_func) glDepthRangex,
   (mapi_func) glDepthRangexOES,
   (mapi_func) glDetachObjectARB,
   (mapi_func) glDetachShader,
   (mapi_func) glDetailTexFuncSGIS,
   (mapi_func) glDevtoolsCorrelationIdNVX,
   (mapi_func) glDevtoolsInvokeStreamedCallbackNVX,
   (mapi_func) glDisable,
   (mapi_func) glDisableClientState,
   (mapi_func) glDisableClientStateIndexedEXT,
   (mapi_func) glDisableClientStateiEXT,
   (mapi_func) glDisableDriverControlQCOM,
   (mapi_func) glDisableIndexedEXT,
   (mapi_func) glDisableVariantClientStateEXT,
   (mapi_func) glDisableVertexArrayAttrib,
   (mapi_func) glDisableVertexArrayAttribEXT,
   (mapi_func) glDisableVertexArrayEXT,
   (mapi_func) glDisableVertexAttribAPPLE,
   (mapi_func) glDisableVertexAttribArray,
   (mapi_func) glDisableVertexAttribArrayARB,
   (mapi_func) glDisablei,
   (mapi_func) glDisableiEXT,
   (mapi_func) glDisableiNV,
   (mapi_func) glDisableiOES,
   (mapi_func) glDiscardFramebufferEXT,
   (mapi_func) glDispatchCompute,
   (mapi_func) glDispatchComputeGroupSizeARB,
   (mapi_func) glDispatchComputeIndirect,
   (mapi_func) glDrawArrays,
   (mapi_func) glDrawArraysEXT,
   (mapi_func) glDrawArraysIndirect,
   (mapi_func) glDrawArraysInstanced,
   (mapi_func) glDrawArraysInstancedANGLE,
   (mapi_func) glDrawArraysInstancedARB,
   (mapi_func) glDrawArraysInstancedBaseInstance,
   (mapi_func) glDrawArraysInstancedBaseInstanceEXT,
   (mapi_func) glDrawArraysInstancedEXT,
   (mapi_func) glDrawArraysInstancedNV,
   (mapi_func) glDrawBuffer,
   (mapi_func) glDrawBuffers,
   (mapi_func) glDrawBuffersARB,
   (mapi_func) glDrawBuffersATI,
   (mapi_func) glDrawBuffersEXT,
   (mapi_func) glDrawBuffersIndexedEXT,
   (mapi_func) glDrawBuffersNV,
   (mapi_func) glDrawCommandsAddressNV,
   (mapi_func) glDrawCommandsNV,
   (mapi_func) glDrawCommandsStatesAddressNV,
   (mapi_func) glDrawCommandsStatesNV,
   (mapi_func) glDrawElementArrayAPPLE,
   (mapi_func) glDrawElementArrayATI,
   (mapi_func) glDrawElements,
   (mapi_func) glDrawElementsBaseVertex,
   (mapi_func) glDrawElementsBaseVertexEXT,
   (mapi_func) glDrawElementsBaseVertexOES,
   (mapi_func) glDrawElementsIndirect,
   (mapi_func) glDrawElementsInstanced,
   (mapi_func) glDrawElementsInstancedANGLE,
   (mapi_func) glDrawElementsInstancedARB,
   (mapi_func) glDrawElementsInstancedBaseInstance,
   (mapi_func) glDrawElementsInstancedBaseInstanceEXT,
   (mapi_func) glDrawElementsInstancedBaseVertex,
   (mapi_func) glDrawElementsInstancedBaseVertexBaseInstance,
   (mapi_func) glDrawElementsInstancedBaseVertexBaseInstanceEXT,
   (mapi_func) glDrawElementsInstancedBaseVertexEXT,
   (mapi_func) glDrawElementsInstancedBaseVertexOES,
   (mapi_func) glDrawElementsInstancedEXT,
   (mapi_func) glDrawElementsInstancedNV,
   (mapi_func) glDrawMeshArraysSUN,
   (mapi_func) glDrawMeshNV,
   (mapi_func) glDrawMeshTasksIndirectNV,
   (mapi_func) glDrawMeshTasksNV,
   (mapi_func) glDrawPixels,
   (mapi_func) glDrawRangeElementArrayAPPLE,
   (mapi_func) glDrawRangeElementArrayATI,
   (mapi_func) glDrawRangeElements,
   (mapi_func) glDrawRangeElementsBaseVertex,
   (mapi_func) glDrawRangeElementsBaseVertexEXT,
   (mapi_func) glDrawRangeElementsBaseVertexOES,
   (mapi_func) glDrawRangeElementsEXT,
   (mapi_func) glDrawTexfOES,
   (mapi_func) glDrawTexfvOES,
   (mapi_func) glDrawTexiOES,
   (mapi_func) glDrawTexivOES,
   (mapi_func) glDrawTexsOES,
   (mapi_func) glDrawTexsvOES,
   (mapi_func) glDrawTextureNV,
   (mapi_func) glDrawTexxOES,
   (mapi_func) glDrawTexxvOES,
   (mapi_func) glDrawTransformFeedback,
   (mapi_func) glDrawTransformFeedbackEXT,
   (mapi_func) glDrawTransformFeedbackInstanced,
   (mapi_func) glDrawTransformFeedbackInstancedEXT,
   (mapi_func) glDrawTransformFeedbackNV,
   (mapi_func) glDrawTransformFeedbackStream,
   (mapi_func) glDrawTransformFeedbackStreamInstanced,
   (mapi_func) glDrawVkImageNV,
   (mapi_func) glEGLImageTargetRenderbufferStorageOES,
   (mapi_func) glEGLImageTargetTexStorageEXT,
   (mapi_func) glEGLImageTargetTexture2DOES,
   (mapi_func) glEGLImageTargetTextureStorageEXT,
   (mapi_func) glEdgeFlag,
   (mapi_func) glEdgeFlagFormatNV,
   (mapi_func) glEdgeFlagPointer,
   (mapi_func) glEdgeFlagPointerEXT,
   (mapi_func) glEdgeFlagPointerListIBM,
   (mapi_func) glEdgeFlagv,
   (mapi_func) glElementPointerAPPLE,
   (mapi_func) glElementPointerATI,
   (mapi_func) glEnable,
   (mapi_func) glEnableClientState,
   (mapi_func) glEnableClientStateIndexedEXT,
   (mapi_func) glEnableClientStateiEXT,
   (mapi_func) glEnableDriverControlQCOM,
   (mapi_func) glEnableIndexedEXT,
   (mapi_func) glEnableVariantClientStateEXT,
   (mapi_func) glEnableVertexArrayAttrib,
   (mapi_func) glEnableVertexArrayAttribEXT,
   (mapi_func) glEnableVertexArrayEXT,
   (mapi_func) glEnableVertexAttribAPPLE,
   (mapi_func) glEnableVertexAttribArray,
   (mapi_func) glEnableVertexAttribArrayARB,
   (mapi_func) glEnablei,
   (mapi_func) glEnableiEXT,
   (mapi_func) glEnableiNV,
   (mapi_func) glEnableiOES,
   (mapi_func) glEnd,
   (mapi_func) glEndConditionalRender,
   (mapi_func) glEndConditionalRenderNV,
   (mapi_func) glEndConditionalRenderNVX,
   (mapi_func) glEndFragmentShaderATI,
   (mapi_func) glEndList,
   (mapi_func) glEndOcclusionQueryNV,
   (mapi_func) glEndPerfMonitorAMD,
   (mapi_func) glEndPerfQueryINTEL,
   (mapi_func) glEndQuery,
   (mapi_func) glEndQueryARB,
   (mapi_func) glEndQueryEXT,
   (mapi_func) glEndQueryIndexed,
   (mapi_func) glEndTilingQCOM,
   (mapi_func) glEndTransformFeedback,
   (mapi_func) glEndTransformFeedbackEXT,
   (mapi_func) glEndTransformFeedbackNV,
   (mapi_func) glEndVertexShaderEXT,
   (mapi_func) glEndVideoCaptureNV,
   (mapi_func) glEvalCoord1d,
   (mapi_func) glEvalCoord1dv,
   (mapi_func) glEvalCoord1f,
   (mapi_func) glEvalCoord1fv,
   (mapi_func) glEvalCoord1xOES,
   (mapi_func) glEvalCoord1xvOES,
   (mapi_func) glEvalCoord2d,
   (mapi_func) glEvalCoord2dv,
   (mapi_func) glEvalCoord2f,
   (mapi_func) glEvalCoord2fv,
   (mapi_func) glEvalCoord2xOES,
   (mapi_func) glEvalCoord2xvOES,
   (mapi_func) glEvalMapsNV,
   (mapi_func) glEvalMesh1,
   (mapi_func) glEvalMesh2,
   (mapi_func) glEvalPoint1,
   (mapi_func) glEvalPoint2,
   (mapi_func) glEvaluateDepthValuesARB,
   (mapi_func) glExecuteProgramNV,
   (mapi_func) glExtGetBufferPointervQCOM,
   (mapi_func) glExtGetBuffersQCOM,
   (mapi_func) glExtGetFramebuffersQCOM,
   (mapi_func) glExtGetProgramBinarySourceQCOM,
   (mapi_func) glExtGetProgramsQCOM,
   (mapi_func) glExtGetRenderbuffersQCOM,
   (mapi_func) glExtGetShadersQCOM,
   (mapi_func) glExtGetTexLevelParameterivQCOM,
   (mapi_func) glExtGetTexSubImageQCOM,
   (mapi_func) glExtGetTexturesQCOM,
   (mapi_func) glExtIsProgramBinaryQCOM,
   (mapi_func) glExtTexObjectStateOverrideiQCOM,
   (mapi_func) glExtractComponentEXT,
   (mapi_func) glFeedbackBuffer,
   (mapi_func) glFeedbackBufferxOES,
   (mapi_func) glFenceSync,
   (mapi_func) glFenceSyncAPPLE,
   (mapi_func) glFenceValueuiNVX,
   (mapi_func) glFinalCombinerInputNV,
   (mapi_func) glFinish,
   (mapi_func) glFinishAsyncSGIX,
   (mapi_func) glFinishFenceAPPLE,
   (mapi_func) glFinishFenceNV,
   (mapi_func) glFinishObjectAPPLE,
   (mapi_func) glFinishTextureSUNX,
   (mapi_func) glFlush,
   (mapi_func) glFlushMappedBufferRange,
   (mapi_func) glFlushMappedBufferRangeAPPLE,
   (mapi_func) glFlushMappedBufferRangeEXT,
   (mapi_func) glFlushMappedNamedBufferRange,
   (mapi_func) glFlushMappedNamedBufferRangeEXT,
   (mapi_func) glFlushPixelDataRangeNV,
   (mapi_func) glFlushRasterSGIX,
   (mapi_func) glFlushStaticDataIBM,
   (mapi_func) glFlushVertexArrayRangeAPPLE,
   (mapi_func) glFlushVertexArrayRangeNV,
   (mapi_func) glFogCoordFormatNV,
   (mapi_func) glFogCoordPointer,
   (mapi_func) glFogCoordPointerEXT,
   (mapi_func) glFogCoordPointerListIBM,
   (mapi_func) glFogCoordd,
   (mapi_func) glFogCoorddEXT,
   (mapi_func) glFogCoorddv,
   (mapi_func) glFogCoorddvEXT,
   (mapi_func) glFogCoordf,
   (mapi_func) glFogCoordfEXT,
   (mapi_func) glFogCoordfv,
   (mapi_func) glFogCoordfvEXT,
   (mapi_func) glFogCoordhNV,
   (mapi_func) glFogCoordhvNV,
   (mapi_func) glFogFuncSGIS,
   (mapi_func) glFogf,
   (mapi_func) glFogfv,
   (mapi_func) glFogi,
   (mapi_func) glFogiv,
   (mapi_func) glFogx,
   (mapi_func) glFogxOES,
   (mapi_func) glFogxv,
   (mapi_func) glFogxvOES,
   (mapi_func) glFragmentColorMaterialSGIX,
   (mapi_func) glFragmentCoverageColorNV,
   (mapi_func) glFragmentLightModelfSGIX,
   (mapi_func) glFragmentLightModelfvSGIX,
   (mapi_func) glFragmentLightModeliSGIX,
   (mapi_func) glFragmentLightModelivSGIX,
   (mapi_func) glFragmentLightfSGIX,
   (mapi_func) glFragmentLightfvSGIX,
   (mapi_func) glFragmentLightiSGIX,
   (mapi_func) glFragmentLightivSGIX,
   (mapi_func) glFragmentMaterialfSGIX,
   (mapi_func) glFragmentMaterialfvSGIX,
   (mapi_func) glFragmentMaterialiSGIX,
   (mapi_func) glFragmentMaterialivSGIX,
   (mapi_func) glFrameTerminatorGREMEDY,
   (mapi_func) glFrameZoomSGIX,
   (mapi_func) glFramebufferDrawBufferEXT,
   (mapi_func) glFramebufferDrawBuffersEXT,
   (mapi_func) glFramebufferFetchBarrierEXT,
   (mapi_func) glFramebufferFetchBarrierQCOM,
   (mapi_func) glFramebufferFoveationConfigQCOM,
   (mapi_func) glFramebufferFoveationParametersQCOM,
   (mapi_func) glFramebufferParameteri,
   (mapi_func) glFramebufferParameteriMESA,
   (mapi_func) glFramebufferPixelLocalStorageSizeEXT,
   (mapi_func) glFramebufferReadBufferEXT,
   (mapi_func) glFramebufferRenderbuffer,
   (mapi_func) glFramebufferRenderbufferEXT,
   (mapi_func) glFramebufferRenderbufferOES,
   (mapi_func) glFramebufferSampleLocationsfvARB,
   (mapi_func) glFramebufferSampleLocationsfvNV,
   (mapi_func) glFramebufferSamplePositionsfvAMD,
   (mapi_func) glFramebufferTexture,
   (mapi_func) glFramebufferTexture1D,
   (mapi_func) glFramebufferTexture1DEXT,
   (mapi_func) glFramebufferTexture2D,
   (mapi_func) glFramebufferTexture2DDownsampleIMG,
   (mapi_func) glFramebufferTexture2DEXT,
   (mapi_func) glFramebufferTexture2DMultisampleEXT,
   (mapi_func) glFramebufferTexture2DMultisampleIMG,
   (mapi_func) glFramebufferTexture2DOES,
   (mapi_func) glFramebufferTexture3D,
   (mapi_func) glFramebufferTexture3DEXT,
   (mapi_func) glFramebufferTexture3DOES,
   (mapi_func) glFramebufferTextureARB,
   (mapi_func) glFramebufferTextureEXT,
   (mapi_func) glFramebufferTextureFaceARB,
   (mapi_func) glFramebufferTextureFaceEXT,
   (mapi_func) glFramebufferTextureLayer,
   (mapi_func) glFramebufferTextureLayerARB,
   (mapi_func) glFramebufferTextureLayerDownsampleIMG,
   (mapi_func) glFramebufferTextureLayerEXT,
   (mapi_func) glFramebufferTextureLayerNV,
   (mapi_func) glFramebufferTextureMultisampleMultiviewOVR,
   (mapi_func) glFramebufferTextureMultiviewOVR,
   (mapi_func) glFramebufferTextureOES,
   (mapi_func) glFreeObjectBufferATI,
   (mapi_func) glFrontFace,
   (mapi_func) glFrustum,
   (mapi_func) glFrustumf,
   (mapi_func) glFrustumfOES,
   (mapi_func) glFrustumx,
   (mapi_func) glFrustumxOES,
   (mapi_func) glGenAsyncMarkersSGIX,
   (mapi_func) glGenBuffers,
   (mapi_func) glGenBuffersARB,
   (mapi_func) glGenFencesAPPLE,
   (mapi_func) glGenFencesNV,
   (mapi_func) glGenFragmentShadersATI,
   (mapi_func) glGenFramebuffers,
   (mapi_func) glGenFramebuffersEXT,
   (mapi_func) glGenFramebuffersOES,
   (mapi_func) glGenLists,
   (mapi_func) glGenNamesAMD,
   (mapi_func) glGenOcclusionQueriesNV,
   (mapi_func) glGenPathsNV,
   (mapi_func) glGenPerfMonitorsAMD,
   (mapi_func) glGenProgramPipelines,
   (mapi_func) glGenProgramPipelinesEXT,
   (mapi_func) glGenProgramsARB,
   (mapi_func) glGenProgramsNV,
   (mapi_func) glGenQueries,
   (mapi_func) glGenQueriesARB,
   (mapi_func) glGenQueriesEXT,
   (mapi_func) glGenQueryResourceTagNV,
   (mapi_func) glGenRenderbuffers,
   (mapi_func) glGenRenderbuffersEXT,
   (mapi_func) glGenRenderbuffersOES,
   (mapi_func) glGenSamplers,
   (mapi_func) glGenSemaphoresEXT,
   (mapi_func) glGenSymbolsEXT,
   (mapi_func) glGenTextures,
   (mapi_func) glGenTexturesEXT,
   (mapi_func) glGenTransformFeedbacks,
   (mapi_func) glGenTransformFeedbacksEXT,
   (mapi_func) glGenTransformFeedbacksNV,
   (mapi_func) glGenVertexArrays,
   (mapi_func) glGenVertexArraysAPPLE,
   (mapi_func) glGenVertexArraysOES,
   (mapi_func) glGenVertexShadersEXT,
   (mapi_func) glGenerateMipmap,
   (mapi_func) glGenerateMipmapEXT,
   (mapi_func) glGenerateMipmapOES,
   (mapi_func) glGenerateMultiTexMipmapEXT,
   (mapi_func) glGenerateTextureMipmap,
   (mapi_func) glGenerateTextureMipmapEXT,
   (mapi_func) glGetActiveAtomicCounterBufferiv,
   (mapi_func) glGetActiveAttrib,
   (mapi_func) glGetActiveAttribARB,
   (mapi_func) glGetActiveSubroutineName,
   (mapi_func) glGetActiveSubroutineUniformName,
   (mapi_func) glGetActiveSubroutineUniformiv,
   (mapi_func) glGetActiveUniform,
   (mapi_func) glGetActiveUniformARB,
   (mapi_func) glGetActiveUniformBlockName,
   (mapi_func) glGetActiveUniformBlockiv,
   (mapi_func) glGetActiveUniformName,
   (mapi_func) glGetActiveUniformsiv,
   (mapi_func) glGetActiveVaryingNV,
   (mapi_func) glGetArrayObjectfvATI,
   (mapi_func) glGetArrayObjectivATI,
   (mapi_func) glGetAttachedObjectsARB,
   (mapi_func) glGetAttachedShaders,
   (mapi_func) glGetAttribLocation,
   (mapi_func) glGetAttribLocationARB,
   (mapi_func) glGetBooleanIndexedvEXT,
   (mapi_func) glGetBooleani_v,
   (mapi_func) glGetBooleanv,
   (mapi_func) glGetBufferParameteri64v,
   (mapi_func) glGetBufferParameteriv,
   (mapi_func) glGetBufferParameterivARB,
   (mapi_func) glGetBufferParameterui64vNV,
   (mapi_func) glGetBufferPointerv,
   (mapi_func) glGetBufferPointervARB,
   (mapi_func) glGetBufferPointervOES,
   (mapi_func) glGetBufferSubData,
   (mapi_func) glGetBufferSubDataARB,
   (mapi_func) glGetClipPlane,
   (mapi_func) glGetClipPlanef,
   (mapi_func) glGetClipPlanefOES,
   (mapi_func) glGetClipPlanex,
   (mapi_func) glGetClipPlanexOES,
   (mapi_func) glGetColorTable,
   (mapi_func) glGetColorTableEXT,
   (mapi_func) glGetColorTableParameterfv,
   (mapi_func) glGetColorTableParameterfvEXT,
   (mapi_func) glGetColorTableParameterfvSGI,
   (mapi_func) glGetColorTableParameteriv,
   (mapi_func) glGetColorTableParameterivEXT,
   (mapi_func) glGetColorTableParameterivSGI,
   (mapi_func) glGetColorTableSGI,
   (mapi_func) glGetCombinerInputParameterfvNV,
   (mapi_func) glGetCombinerInputParameterivNV,
   (mapi_func) glGetCombinerOutputParameterfvNV,
   (mapi_func) glGetCombinerOutputParameterivNV,
   (mapi_func) glGetCombinerStageParameterfvNV,
   (mapi_func) glGetCommandHeaderNV,
   (mapi_func) glGetCompressedMultiTexImageEXT,
   (mapi_func) glGetCompressedTexImage,
   (mapi_func) glGetCompressedTexImageARB,
   (mapi_func) glGetCompressedTexImageNV,
   (mapi_func) glGetCompressedTextureImage,
   (mapi_func) glGetCompressedTextureImageEXT,
   (mapi_func) glGetCompressedTextureSubImage,
   (mapi_func) glGetConvolutionFilter,
   (mapi_func) glGetConvolutionFilterEXT,
   (mapi_func) glGetConvolutionParameterfv,
   (mapi_func) glGetConvolutionParameterfvEXT,
   (mapi_func) glGetConvolutionParameteriv,
   (mapi_func) glGetConvolutionParameterivEXT,
   (mapi_func) glGetConvolutionParameterxvOES,
   (mapi_func) glGetCoverageModulationTableNV,
   (mapi_func) glGetDebugMessageLog,
   (mapi_func) glGetDebugMessageLogAMD,
   (mapi_func) glGetDebugMessageLogARB,
   (mapi_func) glGetDebugMessageLogKHR,
   (mapi_func) glGetDebugMessageLogOES,
   (mapi_func) glGetDetailTexFuncSGIS,
   (mapi_func) glGetDoubleIndexedvEXT,
   (mapi_func) glGetDoublei_v,
   (mapi_func) glGetDoublei_vEXT,
   (mapi_func) glGetDoublev,
   (mapi_func) glGetDriverControlStringQCOM,
   (mapi_func) glGetDriverControlsQCOM,
   (mapi_func) glGetError,
   (mapi_func) glGetFenceivNV,
   (mapi_func) glGetFinalCombinerInputParameterfvNV,
   (mapi_func) glGetFinalCombinerInputParameterivNV,
   (mapi_func) glGetFirstPerfQueryIdINTEL,
   (mapi_func) glGetFixedv,
   (mapi_func) glGetFixedvOES,
   (mapi_func) glGetFloatIndexedvEXT,
   (mapi_func) glGetFloati_v,
   (mapi_func) glGetFloati_vEXT,
   (mapi_func) glGetFloati_vNV,
   (mapi_func) glGetFloati_vOES,
   (mapi_func) glGetFloatv,
   (mapi_func) glGetFogFuncSGIS,
   (mapi_func) glGetFragDataIndex,
   (mapi_func) glGetFragDataIndexEXT,
   (mapi_func) glGetFragDataLocation,
   (mapi_func) glGetFragDataLocationEXT,
   (mapi_func) glGetFragmentLightfvSGIX,
   (mapi_func) glGetFragmentLightivSGIX,
   (mapi_func) glGetFragmentMaterialfvSGIX,
   (mapi_func) glGetFragmentMaterialivSGIX,
   (mapi_func) glGetFramebufferAttachmentParameteriv,
   (mapi_func) glGetFramebufferAttachmentParameterivEXT,
   (mapi_func) glGetFramebufferAttachmentParameterivOES,
   (mapi_func) glGetFramebufferParameterfvAMD,
   (mapi_func) glGetFramebufferParameteriv,
   (mapi_func) glGetFramebufferParameterivEXT,
   (mapi_func) glGetFramebufferParameterivMESA,
   (mapi_func) glGetFramebufferPixelLocalStorageSizeEXT,
   (mapi_func) glGetGraphicsResetStatus,
   (mapi_func) glGetGraphicsResetStatusARB,
   (mapi_func) glGetGraphicsResetStatusEXT,
   (mapi_func) glGetGraphicsResetStatusKHR,
   (mapi_func) glGetHandleARB,
   (mapi_func) glGetHistogram,
   (mapi_func) glGetHistogramEXT,
   (mapi_func) glGetHistogramParameterfv,
   (mapi_func) glGetHistogramParameterfvEXT,
   (mapi_func) glGetHistogramParameteriv,
   (mapi_func) glGetHistogramParameterivEXT,
   (mapi_func) glGetHistogramParameterxvOES,
   (mapi_func) glGetImageHandleARB,
   (mapi_func) glGetImageHandleNV,
   (mapi_func) glGetImageTransformParameterfvHP,
   (mapi_func) glGetImageTransformParameterivHP,
   (mapi_func) glGetInfoLogARB,
   (mapi_func) glGetInstrumentsSGIX,
   (mapi_func) glGetInteger64i_v,
   (mapi_func) glGetInteger64v,
   (mapi_func) glGetInteger64vAPPLE,
   (mapi_func) glGetIntegerIndexedvEXT,
   (mapi_func) glGetIntegeri_v,
   (mapi_func) glGetIntegeri_vEXT,
   (mapi_func) glGetIntegerui64i_vNV,
   (mapi_func) glGetIntegerui64vNV,
   (mapi_func) glGetIntegerv,
   (mapi_func) glGetInternalformatSampleivNV,
   (mapi_func) glGetInternalformati64v,
   (mapi_func) glGetInternalformativ,
   (mapi_func) glGetInvariantBooleanvEXT,
   (mapi_func) glGetInvariantFloatvEXT,
   (mapi_func) glGetInvariantIntegervEXT,
   (mapi_func) glGetLightfv,
   (mapi_func) glGetLightiv,
   (mapi_func) glGetLightxOES,
   (mapi_func) glGetLightxv,
   (mapi_func) glGetLightxvOES,
   (mapi_func) glGetListParameterfvSGIX,
   (mapi_func) glGetListParameterivSGIX,
   (mapi_func) glGetLocalConstantBooleanvEXT,
   (mapi_func) glGetLocalConstantFloatvEXT,
   (mapi_func) glGetLocalConstantIntegervEXT,
   (mapi_func) glGetMapAttribParameterfvNV,
   (mapi_func) glGetMapAttribParameterivNV,
   (mapi_func) glGetMapControlPointsNV,
   (mapi_func) glGetMapParameterfvNV,
   (mapi_func) glGetMapParameterivNV,
   (mapi_func) glGetMapdv,
   (mapi_func) glGetMapfv,
   (mapi_func) glGetMapiv,
   (mapi_func) glGetMapxvOES,
   (mapi_func) glGetMaterialfv,
   (mapi_func) glGetMaterialiv,
   (mapi_func) glGetMaterialxOES,
   (mapi_func) glGetMaterialxv,
   (mapi_func) glGetMaterialxvOES,
   (mapi_func) glGetMemoryObjectDetachedResourcesuivNV,
   (mapi_func) glGetMemoryObjectParameterivEXT,
   (mapi_func) glGetMinmax,
   (mapi_func) glGetMinmaxEXT,
   (mapi_func) glGetMinmaxParameterfv,
   (mapi_func) glGetMinmaxParameterfvEXT,
   (mapi_func) glGetMinmaxParameteriv,
   (mapi_func) glGetMinmaxParameterivEXT,
   (mapi_func) glGetMultiTexEnvfvEXT,
   (mapi_func) glGetMultiTexEnvivEXT,
   (mapi_func) glGetMultiTexGendvEXT,
   (mapi_func) glGetMultiTexGenfvEXT,
   (mapi_func) glGetMultiTexGenivEXT,
   (mapi_func) glGetMultiTexImageEXT,
   (mapi_func) glGetMultiTexLevelParameterfvEXT,
   (mapi_func) glGetMultiTexLevelParameterivEXT,
   (mapi_func) glGetMultiTexParameterIivEXT,
   (mapi_func) glGetMultiTexParameterIuivEXT,
   (mapi_func) glGetMultiTexParameterfvEXT,
   (mapi_func) glGetMultiTexParameterivEXT,
   (mapi_func) glGetMultisamplefv,
   (mapi_func) glGetMultisamplefvNV,
   (mapi_func) glGetNamedBufferParameteri64v,
   (mapi_func) glGetNamedBufferParameteri64vEXT,
   (mapi_func) glGetNamedBufferParameteriv,
   (mapi_func) glGetNamedBufferParameterivEXT,
   (mapi_func) glGetNamedBufferParameterui64vNV,
   (mapi_func) glGetNamedBufferPointerv,
   (mapi_func) glGetNamedBufferPointervEXT,
   (mapi_func) glGetNamedBufferSubData,
   (mapi_func) glGetNamedBufferSubDataEXT,
   (mapi_func) glGetNamedFramebufferAttachmentParameteriv,
   (mapi_func) glGetNamedFramebufferAttachmentParameterivEXT,
   (mapi_func) glGetNamedFramebufferParameterfvAMD,
   (mapi_func) glGetNamedFramebufferParameteriv,
   (mapi_func) glGetNamedFramebufferParameterivEXT,
   (mapi_func) glGetNamedProgramLocalParameterIivEXT,
   (mapi_func) glGetNamedProgramLocalParameterIuivEXT,
   (mapi_func) glGetNamedProgramLocalParameterdvEXT,
   (mapi_func) glGetNamedProgramLocalParameterfvEXT,
   (mapi_func) glGetNamedProgramStringEXT,
   (mapi_func) glGetNamedProgramivEXT,
   (mapi_func) glGetNamedRenderbufferParameteriv,
   (mapi_func) glGetNamedRenderbufferParameterivEXT,
   (mapi_func) glGetNamedStringARB,
   (mapi_func) glGetNamedStringivARB,
   (mapi_func) glGetNextPerfQueryIdINTEL,
   (mapi_func) glGetObjectBufferfvATI,
   (mapi_func) glGetObjectBufferivATI,
   (mapi_func) glGetObjectLabel,
   (mapi_func) glGetObjectLabelEXT,
   (mapi_func) glGetObjectLabelKHR,
   (mapi_func) glGetObjectLabelOES,
   (mapi_func) glGetObjectParameterfvARB,
   (mapi_func) glGetObjectParameterivAPPLE,
   (mapi_func) glGetObjectParameterivARB,
   (mapi_func) glGetObjectPtrLabel,
   (mapi_func) glGetObjectPtrLabelKHR,
   (mapi_func) glGetObjectPtrLabelOES,
   (mapi_func) glGetOcclusionQueryivNV,
   (mapi_func) glGetOcclusionQueryuivNV,
   (mapi_func) glGetPathColorGenfvNV,
   (mapi_func) glGetPathColorGenivNV,
   (mapi_func) glGetPathCommandsNV,
   (mapi_func) glGetPathCoordsNV,
   (mapi_func) glGetPathDashArrayNV,
   (mapi_func) glGetPathLengthNV,
   (mapi_func) glGetPathMetricRangeNV,
   (mapi_func) glGetPathMetricsNV,
   (mapi_func) glGetPathParameterfvNV,
   (mapi_func) glGetPathParameterivNV,
   (mapi_func) glGetPathSpacingNV,
   (mapi_func) glGetPathTexGenfvNV,
   (mapi_func) glGetPathTexGenivNV,
   (mapi_func) glGetPerfCounterInfoINTEL,
   (mapi_func) glGetPerfMonitorCounterDataAMD,
   (mapi_func) glGetPerfMonitorCounterInfoAMD,
   (mapi_func) glGetPerfMonitorCounterStringAMD,
   (mapi_func) glGetPerfMonitorCountersAMD,
   (mapi_func) glGetPerfMonitorGroupStringAMD,
   (mapi_func) glGetPerfMonitorGroupsAMD,
   (mapi_func) glGetPerfQueryDataINTEL,
   (mapi_func) glGetPerfQueryIdByNameINTEL,
   (mapi_func) glGetPerfQueryInfoINTEL,
   (mapi_func) glGetPixelMapfv,
   (mapi_func) glGetPixelMapuiv,
   (mapi_func) glGetPixelMapusv,
   (mapi_func) glGetPixelMapxv,
   (mapi_func) glGetPixelTexGenParameterfvSGIS,
   (mapi_func) glGetPixelTexGenParameterivSGIS,
   (mapi_func) glGetPixelTransformParameterfvEXT,
   (mapi_func) glGetPixelTransformParameterivEXT,
   (mapi_func) glGetPointerIndexedvEXT,
   (mapi_func) glGetPointeri_vEXT,
   (mapi_func) glGetPointerv,
   (mapi_func) glGetPointervEXT,
   (mapi_func) glGetPointervKHR,
   (mapi_func) glGetPointervOES,
   (mapi_func) glGetPolygonStipple,
   (mapi_func) glGetProgramBinary,
   (mapi_func) glGetProgramBinaryOES,
   (mapi_func) glGetProgramEnvParameterIivNV,
   (mapi_func) glGetProgramEnvParameterIuivNV,
   (mapi_func) glGetProgramEnvParameterdvARB,
   (mapi_func) glGetProgramEnvParameterfvARB,
   (mapi_func) glGetProgramInfoLog,
   (mapi_func) glGetProgramInterfaceiv,
   (mapi_func) glGetProgramLocalParameterIivNV,
   (mapi_func) glGetProgramLocalParameterIuivNV,
   (mapi_func) glGetProgramLocalParameterdvARB,
   (mapi_func) glGetProgramLocalParameterfvARB,
   (mapi_func) glGetProgramNamedParameterdvNV,
   (mapi_func) glGetProgramNamedParameterfvNV,
   (mapi_func) glGetProgramParameterdvNV,
   (mapi_func) glGetProgramParameterfvNV,
   (mapi_func) glGetProgramPipelineInfoLog,
   (mapi_func) glGetProgramPipelineInfoLogEXT,
   (mapi_func) glGetProgramPipelineiv,
   (mapi_func) glGetProgramPipelineivEXT,
   (mapi_func) glGetProgramResourceIndex,
   (mapi_func) glGetProgramResourceLocation,
   (mapi_func) glGetProgramResourceLocationIndex,
   (mapi_func) glGetProgramResourceLocationIndexEXT,
   (mapi_func) glGetProgramResourceName,
   (mapi_func) glGetProgramResourcefvNV,
   (mapi_func) glGetProgramResourceiv,
   (mapi_func) glGetProgramStageiv,
   (mapi_func) glGetProgramStringARB,
   (mapi_func) glGetProgramStringNV,
   (mapi_func) glGetProgramSubroutineParameteruivNV,
   (mapi_func) glGetProgramiv,
   (mapi_func) glGetProgramivARB,
   (mapi_func) glGetProgramivNV,
   (mapi_func) glGetQueryBufferObjecti64v,
   (mapi_func) glGetQueryBufferObjectiv,
   (mapi_func) glGetQueryBufferObjectui64v,
   (mapi_func) glGetQueryBufferObjectuiv,
   (mapi_func) glGetQueryIndexediv,
   (mapi_func) glGetQueryObjecti64v,
   (mapi_func) glGetQueryObjecti64vEXT,
   (mapi_func) glGetQueryObjectiv,
   (mapi_func) glGetQueryObjectivARB,
   (mapi_func) glGetQueryObjectivEXT,
   (mapi_func) glGetQueryObjectui64v,
   (mapi_func) glGetQueryObjectui64vEXT,
   (mapi_func) glGetQueryObjectui64vNV,
   (mapi_func) glGetQueryObjectuiv,
   (mapi_func) glGetQueryObjectuivARB,
   (mapi_func) glGetQueryObjectuivEXT,
   (mapi_func) glGetQueryiv,
   (mapi_func) glGetQueryivARB,
   (mapi_func) glGetQueryivEXT,
   (mapi_func) glGetRenderbufferParameteriv,
   (mapi_func) glGetRenderbufferParameterivEXT,
   (mapi_func) glGetRenderbufferParameterivOES,
   (mapi_func) glGetSamplerParameterIiv,
   (mapi_func) glGetSamplerParameterIivEXT,
   (mapi_func) glGetSamplerParameterIivOES,
   (mapi_func) glGetSamplerParameterIuiv,
   (mapi_func) glGetSamplerParameterIuivEXT,
   (mapi_func) glGetSamplerParameterIuivOES,
   (mapi_func) glGetSamplerParameterfv,
   (mapi_func) glGetSamplerParameteriv,
   (mapi_func) glGetSemaphoreParameterui64vEXT,
   (mapi_func) glGetSeparableFilter,
   (mapi_func) glGetSeparableFilterEXT,
   (mapi_func) glGetShaderInfoLog,
   (mapi_func) glGetShaderPrecisionFormat,
   (mapi_func) glGetShaderSource,
   (mapi_func) glGetShaderSourceARB,
   (mapi_func) glGetShaderiv,
   (mapi_func) glGetShadingRateImagePaletteNV,
   (mapi_func) glGetShadingRateSampleLocationivNV,
   (mapi_func) glGetSharpenTexFuncSGIS,
   (mapi_func) glGetStageIndexNV,
   (mapi_func) glGetString,
   (mapi_func) glGetStringi,
   (mapi_func) glGetSubroutineIndex,
   (mapi_func) glGetSubroutineUniformLocation,
   (mapi_func) glGetSynciv,
   (mapi_func) glGetSyncivAPPLE,
   (mapi_func) glGetSyncv64NVX,
   (mapi_func) glGetTexBumpParameterfvATI,
   (mapi_func) glGetTexBumpParameterivATI,
   (mapi_func) glGetTexEnvfv,
   (mapi_func) glGetTexEnviv,
   (mapi_func) glGetTexEnvxv,
   (mapi_func) glGetTexEnvxvOES,
   (mapi_func) glGetTexFilterFuncSGIS,
   (mapi_func) glGetTexGendv,
   (mapi_func) glGetTexGenfv,
   (mapi_func) glGetTexGenfvOES,
   (mapi_func) glGetTexGeniv,
   (mapi_func) glGetTexGenivOES,
   (mapi_func) glGetTexGenxvOES,
   (mapi_func) glGetTexImage,
   (mapi_func) glGetTexImageNV,
   (mapi_func) glGetTexLevelParameterfv,
   (mapi_func) glGetTexLevelParameterfvNV,
   (mapi_func) glGetTexLevelParameteriv,
   (mapi_func) glGetTexLevelParameterivNV,
   (mapi_func) glGetTexLevelParameterxvOES,
   (mapi_func) glGetTexParameterIiv,
   (mapi_func) glGetTexParameterIivEXT,
   (mapi_func) glGetTexParameterIivOES,
   (mapi_func) glGetTexParameterIuiv,
   (mapi_func) glGetTexParameterIuivEXT,
   (mapi_func) glGetTexParameterIuivOES,
   (mapi_func) glGetTexParameterPointervAPPLE,
   (mapi_func) glGetTexParameterfv,
   (mapi_func) glGetTexParameteriv,
   (mapi_func) glGetTexParameterxv,
   (mapi_func) glGetTexParameterxvOES,
   (mapi_func) glGetTextureHandleARB,
   (mapi_func) glGetTextureHandleIMG,
   (mapi_func) glGetTextureHandleNV,
   (mapi_func) glGetTextureImage,
   (mapi_func) glGetTextureImageEXT,
   (mapi_func) glGetTextureLevelParameterfv,
   (mapi_func) glGetTextureLevelParameterfvEXT,
   (mapi_func) glGetTextureLevelParameteriv,
   (mapi_func) glGetTextureLevelParameterivEXT,
   (mapi_func) glGetTextureParameterIiv,
   (mapi_func) glGetTextureParameterIivEXT,
   (mapi_func) glGetTextureParameterIuiv,
   (mapi_func) glGetTextureParameterIuivEXT,
   (mapi_func) glGetTextureParameterfv,
   (mapi_func) glGetTextureParameterfvEXT,
   (mapi_func) glGetTextureParameteriv,
   (mapi_func) glGetTextureParameterivEXT,
   (mapi_func) glGetTextureSamplerHandleARB,
   (mapi_func) glGetTextureSamplerHandleIMG,
   (mapi_func) glGetTextureSamplerHandleNV,
   (mapi_func) glGetTextureSubImage,
   (mapi_func) glGetTrackMatrixivNV,
   (mapi_func) glGetTransformFeedbackVarying,
   (mapi_func) glGetTransformFeedbackVaryingEXT,
   (mapi_func) glGetTransformFeedbackVaryingNV,
   (mapi_func) glGetTransformFeedbacki64_v,
   (mapi_func) glGetTransformFeedbacki_v,
   (mapi_func) glGetTransformFeedbackiv,
   (mapi_func) glGetTranslatedShaderSourceANGLE,
   (mapi_func) glGetUniformBlockIndex,
   (mapi_func) glGetUniformBufferSizeEXT,
   (mapi_func) glGetUniformIndices,
   (mapi_func) glGetUniformLocation,
   (mapi_func) glGetUniformLocationARB,
   (mapi_func) glGetUniformOffsetEXT,
   (mapi_func) glGetUniformSubroutineuiv,
   (mapi_func) glGetUniformdv,
   (mapi_func) glGetUniformfv,
   (mapi_func) glGetUniformfvARB,
   (mapi_func) glGetUniformi64vARB,
   (mapi_func) glGetUniformi64vNV,
   (mapi_func) glGetUniformiv,
   (mapi_func) glGetUniformivARB,
   (mapi_func) glGetUniformui64vARB,
   (mapi_func) glGetUniformui64vNV,
   (mapi_func) glGetUniformuiv,
   (mapi_func) glGetUniformuivEXT,
   (mapi_func) glGetUnsignedBytei_vEXT,
   (mapi_func) glGetUnsignedBytevEXT,
   (mapi_func) glGetVariantArrayObjectfvATI,
   (mapi_func) glGetVariantArrayObjectivATI,
   (mapi_func) glGetVariantBooleanvEXT,
   (mapi_func) glGetVariantFloatvEXT,
   (mapi_func) glGetVariantIntegervEXT,
   (mapi_func) glGetVariantPointervEXT,
   (mapi_func) glGetVaryingLocationNV,
   (mapi_func) glGetVertexArrayIndexed64iv,
   (mapi_func) glGetVertexArrayIndexediv,
   (mapi_func) glGetVertexArrayIntegeri_vEXT,
   (mapi_func) glGetVertexArrayIntegervEXT,
   (mapi_func) glGetVertexArrayPointeri_vEXT,
   (mapi_func) glGetVertexArrayPointervEXT,
   (mapi_func) glGetVertexArrayiv,
   (mapi_func) glGetVertexAttribArrayObjectfvATI,
   (mapi_func) glGetVertexAttribArrayObjectivATI,
   (mapi_func) glGetVertexAttribIiv,
   (mapi_func) glGetVertexAttribIivEXT,
   (mapi_func) glGetVertexAttribIuiv,
   (mapi_func) glGetVertexAttribIuivEXT,
   (mapi_func) glGetVertexAttribLdv,
   (mapi_func) glGetVertexAttribLdvEXT,
   (mapi_func) glGetVertexAttribLi64vNV,
   (mapi_func) glGetVertexAttribLui64vARB,
   (mapi_func) glGetVertexAttribLui64vNV,
   (mapi_func) glGetVertexAttribPointerv,
   (mapi_func) glGetVertexAttribPointervARB,
   (mapi_func) glGetVertexAttribPointervNV,
   (mapi_func) glGetVertexAttribdv,
   (mapi_func) glGetVertexAttribdvARB,
   (mapi_func) glGetVertexAttribdvNV,
   (mapi_func) glGetVertexAttribfv,
   (mapi_func) glGetVertexAttribfvARB,
   (mapi_func) glGetVertexAttribfvNV,
   (mapi_func) glGetVertexAttribiv,
   (mapi_func) glGetVertexAttribivARB,
   (mapi_func) glGetVertexAttribivNV,
   (mapi_func) glGetVideoCaptureANCStreamivNVX,
   (mapi_func) glGetVideoCaptureStreamdvNV,
   (mapi_func) glGetVideoCaptureStreamfvNV,
   (mapi_func) glGetVideoCaptureStreamivNV,
   (mapi_func) glGetVideoCaptureivNV,
   (mapi_func) glGetVideoi64vNV,
   (mapi_func) glGetVideoivNV,
   (mapi_func) glGetVideoui64vNV,
   (mapi_func) glGetVideouivNV,
   (mapi_func) glGetVkProcAddrNV,
   (mapi_func) glGetnColorTable,
   (mapi_func) glGetnColorTableARB,
   (mapi_func) glGetnCompressedTexImage,
   (mapi_func) glGetnCompressedTexImageARB,
   (mapi_func) glGetnConvolutionFilter,
   (mapi_func) glGetnConvolutionFilterARB,
   (mapi_func) glGetnHistogram,
   (mapi_func) glGetnHistogramARB,
   (mapi_func) glGetnMapdv,
   (mapi_func) glGetnMapdvARB,
   (mapi_func) glGetnMapfv,
   (mapi_func) glGetnMapfvARB,
   (mapi_func) glGetnMapiv,
   (mapi_func) glGetnMapivARB,
   (mapi_func) glGetnMinmax,
   (mapi_func) glGetnMinmaxARB,
   (mapi_func) glGetnPixelMapfv,
   (mapi_func) glGetnPixelMapfvARB,
   (mapi_func) glGetnPixelMapuiv,
   (mapi_func) glGetnPixelMapuivARB,
   (mapi_func) glGetnPixelMapusv,
   (mapi_func) glGetnPixelMapusvARB,
   (mapi_func) glGetnPolygonStipple,
   (mapi_func) glGetnPolygonStippleARB,
   (mapi_func) glGetnSeparableFilter,
   (mapi_func) glGetnSeparableFilterARB,
   (mapi_func) glGetnTexImage,
   (mapi_func) glGetnTexImageARB,
   (mapi_func) glGetnUniformdv,
   (mapi_func) glGetnUniformdvARB,
   (mapi_func) glGetnUniformfv,
   (mapi_func) glGetnUniformfvARB,
   (mapi_func) glGetnUniformfvEXT,
   (mapi_func) glGetnUniformfvKHR,
   (mapi_func) glGetnUniformi64vARB,
   (mapi_func) glGetnUniformiv,
   (mapi_func) glGetnUniformivARB,
   (mapi_func) glGetnUniformivEXT,
   (mapi_func) glGetnUniformivKHR,
   (mapi_func) glGetnUniformui64vARB,
   (mapi_func) glGetnUniformuiv,
   (mapi_func) glGetnUniformuivARB,
   (mapi_func) glGetnUniformuivKHR,
   (mapi_func) glGlobalAlphaFactorbSUN,
   (mapi_func) glGlobalAlphaFactordSUN,
   (mapi_func) glGlobalAlphaFactorfSUN,
   (mapi_func) glGlobalAlphaFactoriSUN,
   (mapi_func) glGlobalAlphaFactorsSUN,
   (mapi_func) glGlobalAlphaFactorubSUN,
   (mapi_func) glGlobalAlphaFactoruiSUN,
   (mapi_func) glGlobalAlphaFactorusSUN,
   (mapi_func) glGpuSyncAcquireNVX,
   (mapi_func) glGpuSyncCreateNVX,
   (mapi_func) glGpuSyncDestroyNVX,
   (mapi_func) glGpuSyncReleaseNVX,
   (mapi_func) glHint,
   (mapi_func) glHintPGI,
   (mapi_func) glHistogram,
   (mapi_func) glHistogramEXT,
   (mapi_func) glIglooInterfaceSGIX,
   (mapi_func) glImageTransformParameterfHP,
   (mapi_func) glImageTransformParameterfvHP,
   (mapi_func) glImageTransformParameteriHP,
   (mapi_func) glImageTransformParameterivHP,
   (mapi_func) glImportMemoryFdEXT,
   (mapi_func) glImportMemoryWin32HandleEXT,
   (mapi_func) glImportMemoryWin32NameEXT,
   (mapi_func) glImportSemaphoreFdEXT,
   (mapi_func) glImportSemaphoreWin32HandleEXT,
   (mapi_func) glImportSemaphoreWin32NameEXT,
   (mapi_func) glImportSyncEXT,
   (mapi_func) glIndexFormatNV,
   (mapi_func) glIndexFuncEXT,
   (mapi_func) glIndexMask,
   (mapi_func) glIndexMaterialEXT,
   (mapi_func) glIndexPointer,
   (mapi_func) glIndexPointerEXT,
   (mapi_func) glIndexPointerListIBM,
   (mapi_func) glIndexd,
   (mapi_func) glIndexdv,
   (mapi_func) glIndexf,
   (mapi_func) glIndexfv,
   (mapi_func) glIndexi,
   (mapi_func) glIndexiv,
   (mapi_func) glIndexs,
   (mapi_func) glIndexsv,
   (mapi_func) glIndexub,
   (mapi_func) glIndexubv,
   (mapi_func) glIndexxOES,
   (mapi_func) glIndexxvOES,
   (mapi_func) glInitNames,
   (mapi_func) glInsertComponentEXT,
   (mapi_func) glInsertEventMarkerEXT,
   (mapi_func) glInstrumentsBufferSGIX,
   (mapi_func) glInterleavedArrays,
   (mapi_func) glInterpolatePathsNV,
   (mapi_func) glInvalidateBufferData,
   (mapi_func) glInvalidateBufferSubData,
   (mapi_func) glInvalidateFramebuffer,
   (mapi_func) glInvalidateNamedFramebufferData,
   (mapi_func) glInvalidateNamedFramebufferSubData,
   (mapi_func) glInvalidateSubFramebuffer,
   (mapi_func) glInvalidateTexImage,
   (mapi_func) glInvalidateTexSubImage,
   (mapi_func) glIsAsyncMarkerSGIX,
   (mapi_func) glIsBuffer,
   (mapi_func) glIsBufferARB,
   (mapi_func) glIsBufferResidentNV,
   (mapi_func) glIsCommandListNV,
   (mapi_func) glIsEnabled,
   (mapi_func) glIsEnabledIndexedEXT,
   (mapi_func) glIsEnabledi,
   (mapi_func) glIsEnablediEXT,
   (mapi_func) glIsEnablediNV,
   (mapi_func) glIsEnablediOES,
   (mapi_func) glIsFenceAPPLE,
   (mapi_func) glIsFenceNV,
   (mapi_func) glIsFramebuffer,
   (mapi_func) glIsFramebufferEXT,
   (mapi_func) glIsFramebufferOES,
   (mapi_func) glIsImageHandleResidentARB,
   (mapi_func) glIsImageHandleResidentNV,
   (mapi_func) glIsList,
   (mapi_func) glIsMemoryObjectEXT,
   (mapi_func) glIsNameAMD,
   (mapi_func) glIsNamedBufferResidentNV,
   (mapi_func) glIsNamedStringARB,
   (mapi_func) glIsObjectBufferATI,
   (mapi_func) glIsOcclusionQueryNV,
   (mapi_func) glIsPathNV,
   (mapi_func) glIsPointInFillPathNV,
   (mapi_func) glIsPointInStrokePathNV,
   (mapi_func) glIsProgram,
   (mapi_func) glIsProgramARB,
   (mapi_func) glIsProgramNV,
   (mapi_func) glIsProgramPipeline,
   (mapi_func) glIsProgramPipelineEXT,
   (mapi_func) glIsQuery,
   (mapi_func) glIsQueryARB,
   (mapi_func) glIsQueryEXT,
   (mapi_func) glIsRenderbuffer,
   (mapi_func) glIsRenderbufferEXT,
   (mapi_func) glIsRenderbufferOES,
   (mapi_func) glIsSampler,
   (mapi_func) glIsSemaphoreEXT,
   (mapi_func) glIsShader,
   (mapi_func) glIsStateNV,
   (mapi_func) glIsSync,
   (mapi_func) glIsSyncAPPLE,
   (mapi_func) glIsTexture,
   (mapi_func) glIsTextureEXT,
   (mapi_func) glIsTextureHandleResidentARB,
   (mapi_func) glIsTextureHandleResidentNV,
   (mapi_func) glIsTransformFeedback,
   (mapi_func) glIsTransformFeedbackEXT,
   (mapi_func) glIsTransformFeedbackNV,
   (mapi_func) glIsVariantEnabledEXT,
   (mapi_func) glIsVertexArray,
   (mapi_func) glIsVertexArrayAPPLE,
   (mapi_func) glIsVertexArrayOES,
   (mapi_func) glIsVertexAttribEnabledAPPLE,
   (mapi_func) glLGPUCopyImageSubDataNVX,
   (mapi_func) glLGPUInterlockNVX,
   (mapi_func) glLGPUNamedBufferSubDataNVX,
   (mapi_func) glLabelObjectEXT,
   (mapi_func) glLightEnviSGIX,
   (mapi_func) glLightModelf,
   (mapi_func) glLightModelfv,
   (mapi_func) glLightModeli,
   (mapi_func) glLightModeliv,
   (mapi_func) glLightModelx,
   (mapi_func) glLightModelxOES,
   (mapi_func) glLightModelxv,
   (mapi_func) glLightModelxvOES,
   (mapi_func) glLightf,
   (mapi_func) glLightfv,
   (mapi_func) glLighti,
   (mapi_func) glLightiv,
   (mapi_func) glLightx,
   (mapi_func) glLightxOES,
   (mapi_func) glLightxv,
   (mapi_func) glLightxvOES,
   (mapi_func) glLineStipple,
   (mapi_func) glLineWidth,
   (mapi_func) glLineWidthx,
   (mapi_func) glLineWidthxOES,
   (mapi_func) glLinkProgram,
   (mapi_func) glLinkProgramARB,
   (mapi_func) glListBase,
   (mapi_func) glListDrawCommandsStatesClientNV,
   (mapi_func) glListParameterfSGIX,
   (mapi_func) glListParameterfvSGIX,
   (mapi_func) glListParameteriSGIX,
   (mapi_func) glListParameterivSGIX,
   (mapi_func) glLoadIdentity,
   (mapi_func) glLoadIdentityDeformationMapSGIX,
   (mapi_func) glLoadMatrixd,
   (mapi_func) glLoadMatrixf,
   (mapi_func) glLoadMatrixx,
   (mapi_func) glLoadMatrixxOES,
   (mapi_func) glLoadName,
   (mapi_func) glLoadPaletteFromModelViewMatrixOES,
   (mapi_func) glLoadProgramNV,
   (mapi_func) glLoadTransformEXT,
   (mapi_func) glLoadTransposeMatrixd,
   (mapi_func) glLoadTransposeMatrixdARB,
   (mapi_func) glLoadTransposeMatrixf,
   (mapi_func) glLoadTransposeMatrixfARB,
   (mapi_func) glLoadTransposeMatrixxOES,
   (mapi_func) glLockArraysEXT,
   (mapi_func) glLogicOp,
   (mapi_func) glMakeBufferNonResidentNV,
   (mapi_func) glMakeBufferResidentNV,
   (mapi_func) glMakeImageHandleNonResidentARB,
   (mapi_func) glMakeImageHandleNonResidentNV,
   (mapi_func) glMakeImageHandleResidentARB,
   (mapi_func) glMakeImageHandleResidentNV,
   (mapi_func) glMakeNamedBufferNonResidentNV,
   (mapi_func) glMakeNamedBufferResidentNV,
   (mapi_func) glMakeTextureHandleNonResidentARB,
   (mapi_func) glMakeTextureHandleNonResidentNV,
   (mapi_func) glMakeTextureHandleResidentARB,
   (mapi_func) glMakeTextureHandleResidentNV,
   (mapi_func) glMap1d,
   (mapi_func) glMap1f,
   (mapi_func) glMap1xOES,
   (mapi_func) glMap2d,
   (mapi_func) glMap2f,
   (mapi_func) glMap2xOES,
   (mapi_func) glMapBuffer,
   (mapi_func) glMapBufferARB,
   (mapi_func) glMapBufferOES,
   (mapi_func) glMapBufferRange,
   (mapi_func) glMapBufferRangeEXT,
   (mapi_func) glMapControlPointsNV,
   (mapi_func) glMapGrid1d,
   (mapi_func) glMapGrid1f,
   (mapi_func) glMapGrid1xOES,
   (mapi_func) glMapGrid2d,
   (mapi_func) glMapGrid2f,
   (mapi_func) glMapGrid2xOES,
   (mapi_func) glMapNamedBuffer,
   (mapi_func) glMapNamedBufferEXT,
   (mapi_func) glMapNamedBufferRange,
   (mapi_func) glMapNamedBufferRangeEXT,
   (mapi_func) glMapObjectBufferATI,
   (mapi_func) glMapParameterfvNV,
   (mapi_func) glMapParameterivNV,
   (mapi_func) glMapTexture2DINTEL,
   (mapi_func) glMapVertexAttrib1dAPPLE,
   (mapi_func) glMapVertexAttrib1fAPPLE,
   (mapi_func) glMapVertexAttrib2dAPPLE,
   (mapi_func) glMapVertexAttrib2fAPPLE,
   (mapi_func) glMaterialf,
   (mapi_func) glMaterialfv,
   (mapi_func) glMateriali,
   (mapi_func) glMaterialiv,
   (mapi_func) glMaterialx,
   (mapi_func) glMaterialxOES,
   (mapi_func) glMaterialxv,
   (mapi_func) glMaterialxvOES,
   (mapi_func) glMatrixFrustumEXT,
   (mapi_func) glMatrixIndexPointerARB,
   (mapi_func) glMatrixIndexPointerOES,
   (mapi_func) glMatrixIndexubvARB,
   (mapi_func) glMatrixIndexuivARB,
   (mapi_func) glMatrixIndexusvARB,
   (mapi_func) glMatrixLoad3x2fNV,
   (mapi_func) glMatrixLoad3x3fNV,
   (mapi_func) glMatrixLoadIdentityEXT,
   (mapi_func) glMatrixLoadTranspose3x3fNV,
   (mapi_func) glMatrixLoadTransposedEXT,
   (mapi_func) glMatrixLoadTransposefEXT,
   (mapi_func) glMatrixLoaddEXT,
   (mapi_func) glMatrixLoadfEXT,
   (mapi_func) glMatrixMode,
   (mapi_func) glMatrixMult3x2fNV,
   (mapi_func) glMatrixMult3x3fNV,
   (mapi_func) glMatrixMultTranspose3x3fNV,
   (mapi_func) glMatrixMultTransposedEXT,
   (mapi_func) glMatrixMultTransposefEXT,
   (mapi_func) glMatrixMultdEXT,
   (mapi_func) glMatrixMultfEXT,
   (mapi_func) glMatrixOrthoEXT,
   (mapi_func) glMatrixPopEXT,
   (mapi_func) glMatrixPushEXT,
   (mapi_func) glMatrixRotatedEXT,
   (mapi_func) glMatrixRotatefEXT,
   (mapi_func) glMatrixScaledEXT,
   (mapi_func) glMatrixScalefEXT,
   (mapi_func) glMatrixTranslatedEXT,
   (mapi_func) glMatrixTranslatefEXT,
   (mapi_func) glMaxShaderCompilerThreadsARB,
   (mapi_func) glMaxShaderCompilerThreadsKHR,
   (mapi_func) glMemoryBarrier,
   (mapi_func) glMemoryBarrierByRegion,
   (mapi_func) glMemoryBarrierEXT,
   (mapi_func) glMemoryObjectParameterivEXT,
   (mapi_func) glMinSampleShading,
   (mapi_func) glMinSampleShadingARB,
   (mapi_func) glMinSampleShadingOES,
   (mapi_func) glMinmax,
   (mapi_func) glMinmaxEXT,
   (mapi_func) glMultMatrixd,
   (mapi_func) glMultMatrixf,
   (mapi_func) glMultMatrixx,
   (mapi_func) glMultMatrixxOES,
   (mapi_func) glMultTransformEXT,
   (mapi_func) glMultTransposeMatrixd,
   (mapi_func) glMultTransposeMatrixdARB,
   (mapi_func) glMultTransposeMatrixf,
   (mapi_func) glMultTransposeMatrixfARB,
   (mapi_func) glMultTransposeMatrixxOES,
   (mapi_func) glMultiDrawArrays,
   (mapi_func) glMultiDrawArraysEXT,
   (mapi_func) glMultiDrawArraysIndirect,
   (mapi_func) glMultiDrawArraysIndirectAMD,
   (mapi_func) glMultiDrawArraysIndirectBindlessCountNV,
   (mapi_func) glMultiDrawArraysIndirectBindlessNV,
   (mapi_func) glMultiDrawArraysIndirectCount,
   (mapi_func) glMultiDrawArraysIndirectCountARB,
   (mapi_func) glMultiDrawArraysIndirectEXT,
   (mapi_func) glMultiDrawElementArrayAPPLE,
   (mapi_func) glMultiDrawElements,
   (mapi_func) glMultiDrawElementsBaseVertex,
   (mapi_func) glMultiDrawElementsBaseVertexEXT,
   (mapi_func) glMultiDrawElementsEXT,
   (mapi_func) glMultiDrawElementsIndirect,
   (mapi_func) glMultiDrawElementsIndirectAMD,
   (mapi_func) glMultiDrawElementsIndirectBindlessCountNV,
   (mapi_func) glMultiDrawElementsIndirectBindlessNV,
   (mapi_func) glMultiDrawElementsIndirectCount,
   (mapi_func) glMultiDrawElementsIndirectCountARB,
   (mapi_func) glMultiDrawElementsIndirectEXT,
   (mapi_func) glMultiDrawMeshTasksIndirectCountNV,
   (mapi_func) glMultiDrawMeshTasksIndirectNV,
   (mapi_func) glMultiDrawRangeElementArrayAPPLE,
   (mapi_func) glMultiModeDrawArraysIBM,
   (mapi_func) glMultiModeDrawElementsIBM,
   (mapi_func) glMultiTexBufferEXT,
   (mapi_func) glMultiTexCoord1bOES,
   (mapi_func) glMultiTexCoord1bvOES,
   (mapi_func) glMultiTexCoord1d,
   (mapi_func) glMultiTexCoord1dARB,
   (mapi_func) glMultiTexCoord1dv,
   (mapi_func) glMultiTexCoord1dvARB,
   (mapi_func) glMultiTexCoord1f,
   (mapi_func) glMultiTexCoord1fARB,
   (mapi_func) glMultiTexCoord1fv,
   (mapi_func) glMultiTexCoord1fvARB,
   (mapi_func) glMultiTexCoord1hNV,
   (mapi_func) glMultiTexCoord1hvNV,
   (mapi_func) glMultiTexCoord1i,
   (mapi_func) glMultiTexCoord1iARB,
   (mapi_func) glMultiTexCoord1iv,
   (mapi_func) glMultiTexCoord1ivARB,
   (mapi_func) glMultiTexCoord1s,
   (mapi_func) glMultiTexCoord1sARB,
   (mapi_func) glMultiTexCoord1sv,
   (mapi_func) glMultiTexCoord1svARB,
   (mapi_func) glMultiTexCoord1x,
   (mapi_func) glMultiTexCoord1xOES,
   (mapi_func) glMultiTexCoord1xv,
   (mapi_func) glMultiTexCoord1xvOES,
   (mapi_func) glMultiTexCoord2bOES,
   (mapi_func) glMultiTexCoord2bvOES,
   (mapi_func) glMultiTexCoord2d,
   (mapi_func) glMultiTexCoord2dARB,
   (mapi_func) glMultiTexCoord2dv,
   (mapi_func) glMultiTexCoord2dvARB,
   (mapi_func) glMultiTexCoord2f,
   (mapi_func) glMultiTexCoord2fARB,
   (mapi_func) glMultiTexCoord2fv,
   (mapi_func) glMultiTexCoord2fvARB,
   (mapi_func) glMultiTexCoord2hNV,
   (mapi_func) glMultiTexCoord2hvNV,
   (mapi_func) glMultiTexCoord2i,
   (mapi_func) glMultiTexCoord2iARB,
   (mapi_func) glMultiTexCoord2iv,
   (mapi_func) glMultiTexCoord2ivARB,
   (mapi_func) glMultiTexCoord2s,
   (mapi_func) glMultiTexCoord2sARB,
   (mapi_func) glMultiTexCoord2sv,
   (mapi_func) glMultiTexCoord2svARB,
   (mapi_func) glMultiTexCoord2x,
   (mapi_func) glMultiTexCoord2xOES,
   (mapi_func) glMultiTexCoord2xv,
   (mapi_func) glMultiTexCoord2xvOES,
   (mapi_func) glMultiTexCoord3bOES,
   (mapi_func) glMultiTexCoord3bvOES,
   (mapi_func) glMultiTexCoord3d,
   (mapi_func) glMultiTexCoord3dARB,
   (mapi_func) glMultiTexCoord3dv,
   (mapi_func) glMultiTexCoord3dvARB,
   (mapi_func) glMultiTexCoord3f,
   (mapi_func) glMultiTexCoord3fARB,
   (mapi_func) glMultiTexCoord3fv,
   (mapi_func) glMultiTexCoord3fvARB,
   (mapi_func) glMultiTexCoord3hNV,
   (mapi_func) glMultiTexCoord3hvNV,
   (mapi_func) glMultiTexCoord3i,
   (mapi_func) glMultiTexCoord3iARB,
   (mapi_func) glMultiTexCoord3iv,
   (mapi_func) glMultiTexCoord3ivARB,
   (mapi_func) glMultiTexCoord3s,
   (mapi_func) glMultiTexCoord3sARB,
   (mapi_func) glMultiTexCoord3sv,
   (mapi_func) glMultiTexCoord3svARB,
   (mapi_func) glMultiTexCoord3x,
   (mapi_func) glMultiTexCoord3xOES,
   (mapi_func) glMultiTexCoord3xv,
   (mapi_func) glMultiTexCoord3xvOES,
   (mapi_func) glMultiTexCoord4bOES,
   (mapi_func) glMultiTexCoord4bvOES,
   (mapi_func) glMultiTexCoord4d,
   (mapi_func) glMultiTexCoord4dARB,
   (mapi_func) glMultiTexCoord4dv,
   (mapi_func) glMultiTexCoord4dvARB,
   (mapi_func) glMultiTexCoord4f,
   (mapi_func) glMultiTexCoord4fARB,
   (mapi_func) glMultiTexCoord4fv,
   (mapi_func) glMultiTexCoord4fvARB,
   (mapi_func) glMultiTexCoord4hNV,
   (mapi_func) glMultiTexCoord4hvNV,
   (mapi_func) glMultiTexCoord4i,
   (mapi_func) glMultiTexCoord4iARB,
   (mapi_func) glMultiTexCoord4iv,
   (mapi_func) glMultiTexCoord4ivARB,
   (mapi_func) glMultiTexCoord4s,
   (mapi_func) glMultiTexCoord4sARB,
   (mapi_func) glMultiTexCoord4sv,
   (mapi_func) glMultiTexCoord4svARB,
   (mapi_func) glMultiTexCoord4x,
   (mapi_func) glMultiTexCoord4xOES,
   (mapi_func) glMultiTexCoord4xv,
   (mapi_func) glMultiTexCoord4xvOES,
   (mapi_func) glMultiTexCoordP1ui,
   (mapi_func) glMultiTexCoordP1uiv,
   (mapi_func) glMultiTexCoordP2ui,
   (mapi_func) glMultiTexCoordP2uiv,
   (mapi_func) glMultiTexCoordP3ui,
   (mapi_func) glMultiTexCoordP3uiv,
   (mapi_func) glMultiTexCoordP4ui,
   (mapi_func) glMultiTexCoordP4uiv,
   (mapi_func) glMultiTexCoordPointerEXT,
   (mapi_func) glMultiTexEnvfEXT,
   (mapi_func) glMultiTexEnvfvEXT,
   (mapi_func) glMultiTexEnviEXT,
   (mapi_func) glMultiTexEnvivEXT,
   (mapi_func) glMultiTexGendEXT,
   (mapi_func) glMultiTexGendvEXT,
   (mapi_func) glMultiTexGenfEXT,
   (mapi_func) glMultiTexGenfvEXT,
   (mapi_func) glMultiTexGeniEXT,
   (mapi_func) glMultiTexGenivEXT,
   (mapi_func) glMultiTexImage1DEXT,
   (mapi_func) glMultiTexImage2DEXT,
   (mapi_func) glMultiTexImage3DEXT,
   (mapi_func) glMultiTexParameterIivEXT,
   (mapi_func) glMultiTexParameterIuivEXT,
   (mapi_func) glMultiTexParameterfEXT,
   (mapi_func) glMultiTexParameterfvEXT,
   (mapi_func) glMultiTexParameteriEXT,
   (mapi_func) glMultiTexParameterivEXT,
   (mapi_func) glMultiTexRenderbufferEXT,
   (mapi_func) glMultiTexSubImage1DEXT,
   (mapi_func) glMultiTexSubImage2DEXT,
   (mapi_func) glMultiTexSubImage3DEXT,
   (mapi_func) glMulticastBarrierNV,
   (mapi_func) glMulticastBlitFramebufferNV,
   (mapi_func) glMulticastBufferSubDataNV,
   (mapi_func) glMulticastCopyBufferSubDataNV,
   (mapi_func) glMulticastCopyImageSubDataNV,
   (mapi_func) glMulticastFramebufferSampleLocationsfvNV,
   (mapi_func) glMulticastGetQueryObjecti64vNV,
   (mapi_func) glMulticastGetQueryObjectivNV,
   (mapi_func) glMulticastGetQueryObjectui64vNV,
   (mapi_func) glMulticastGetQueryObjectuivNV,
   (mapi_func) glMulticastScissorArrayvNVX,
   (mapi_func) glMulticastViewportArrayvNVX,
   (mapi_func) glMulticastViewportPositionWScaleNVX,
   (mapi_func) glMulticastWaitSyncNV,
   (mapi_func) glNVENCInterOpFunctionNVX,
   (mapi_func) glNamedBufferAttachMemoryNV,
   (mapi_func) glNamedBufferData,
   (mapi_func) glNamedBufferDataEXT,
   (mapi_func) glNamedBufferPageCommitmentARB,
   (mapi_func) glNamedBufferPageCommitmentEXT,
   (mapi_func) glNamedBufferStorage,
   (mapi_func) glNamedBufferStorageEXT,
   (mapi_func) glNamedBufferStorageExternalEXT,
   (mapi_func) glNamedBufferStorageMemEXT,
   (mapi_func) glNamedBufferSubData,
   (mapi_func) glNamedBufferSubDataEXT,
   (mapi_func) glNamedCopyBufferSubDataEXT,
   (mapi_func) glNamedFramebufferDrawBuffer,
   (mapi_func) glNamedFramebufferDrawBuffers,
   (mapi_func) glNamedFramebufferParameteri,
   (mapi_func) glNamedFramebufferParameteriEXT,
   (mapi_func) glNamedFramebufferReadBuffer,
   (mapi_func) glNamedFramebufferRenderbuffer,
   (mapi_func) glNamedFramebufferRenderbufferEXT,
   (mapi_func) glNamedFramebufferSampleLocationsfvARB,
   (mapi_func) glNamedFramebufferSampleLocationsfvNV,
   (mapi_func) glNamedFramebufferSamplePositionsfvAMD,
   (mapi_func) glNamedFramebufferTexture,
   (mapi_func) glNamedFramebufferTexture1DEXT,
   (mapi_func) glNamedFramebufferTexture2DEXT,
   (mapi_func) glNamedFramebufferTexture3DEXT,
   (mapi_func) glNamedFramebufferTextureEXT,
   (mapi_func) glNamedFramebufferTextureFaceEXT,
   (mapi_func) glNamedFramebufferTextureLayer,
   (mapi_func) glNamedFramebufferTextureLayerEXT,
   (mapi_func) glNamedProgramLocalParameter4dEXT,
   (mapi_func) glNamedProgramLocalParameter4dvEXT,
   (mapi_func) glNamedProgramLocalParameter4fEXT,
   (mapi_func) glNamedProgramLocalParameter4fvEXT,
   (mapi_func) glNamedProgramLocalParameterI4iEXT,
   (mapi_func) glNamedProgramLocalParameterI4ivEXT,
   (mapi_func) glNamedProgramLocalParameterI4uiEXT,
   (mapi_func) glNamedProgramLocalParameterI4uivEXT,
   (mapi_func) glNamedProgramLocalParameters4fvEXT,
   (mapi_func) glNamedProgramLocalParametersI4ivEXT,
   (mapi_func) glNamedProgramLocalParametersI4uivEXT,
   (mapi_func) glNamedProgramStringEXT,
   (mapi_func) glNamedRenderbufferStorage,
   (mapi_func) glNamedRenderbufferStorageEXT,
   (mapi_func) glNamedRenderbufferStorageMultisample,
   (mapi_func) glNamedRenderbufferStorageMultisampleAdvancedAMD,
   (mapi_func) glNamedRenderbufferStorageMultisampleCoverageEXT,
   (mapi_func) glNamedRenderbufferStorageMultisampleEXT,
   (mapi_func) glNamedStringARB,
   (mapi_func) glNewList,
   (mapi_func) glNewObjectBufferATI,
   (mapi_func) glNormal3b,
   (mapi_func) glNormal3bv,
   (mapi_func) glNormal3d,
   (mapi_func) glNormal3dv,
   (mapi_func) glNormal3f,
   (mapi_func) glNormal3fVertex3fSUN,
   (mapi_func) glNormal3fVertex3fvSUN,
   (mapi_func) glNormal3fv,
   (mapi_func) glNormal3hNV,
   (mapi_func) glNormal3hvNV,
   (mapi_func) glNormal3i,
   (mapi_func) glNormal3iv,
   (mapi_func) glNormal3s,
   (mapi_func) glNormal3sv,
   (mapi_func) glNormal3x,
   (mapi_func) glNormal3xOES,
   (mapi_func) glNormal3xvOES,
   (mapi_func) glNormalFormatNV,
   (mapi_func) glNormalP3ui,
   (mapi_func) glNormalP3uiv,
   (mapi_func) glNormalPointer,
   (mapi_func) glNormalPointerEXT,
   (mapi_func) glNormalPointerListIBM,
   (mapi_func) glNormalPointervINTEL,
   (mapi_func) glNormalStream3bATI,
   (mapi_func) glNormalStream3bvATI,
   (mapi_func) glNormalStream3dATI,
   (mapi_func) glNormalStream3dvATI,
   (mapi_func) glNormalStream3fATI,
   (mapi_func) glNormalStream3fvATI,
   (mapi_func) glNormalStream3iATI,
   (mapi_func) glNormalStream3ivATI,
   (mapi_func) glNormalStream3sATI,
   (mapi_func) glNormalStream3svATI,
   (mapi_func) glObjectLabel,
   (mapi_func) glObjectLabelKHR,
   (mapi_func) glObjectLabelOES,
   (mapi_func) glObjectPtrLabel,
   (mapi_func) glObjectPtrLabelKHR,
   (mapi_func) glObjectPtrLabelOES,
   (mapi_func) glObjectPurgeableAPPLE,
   (mapi_func) glObjectUnpurgeableAPPLE,
   (mapi_func) glOrtho,
   (mapi_func) glOrthof,
   (mapi_func) glOrthofOES,
   (mapi_func) glOrthox,
   (mapi_func) glOrthoxOES,
   (mapi_func) glPNTrianglesfATI,
   (mapi_func) glPNTrianglesiATI,
   (mapi_func) glPassTexCoordATI,
   (mapi_func) glPassThrough,
   (mapi_func) glPassThroughxOES,
   (mapi_func) glPatchParameterfv,
   (mapi_func) glPatchParameterfvEXT,
   (mapi_func) glPatchParameterfvNV,
   (mapi_func) glPatchParameteri,
   (mapi_func) glPatchParameteriEXT,
   (mapi_func) glPatchParameteriNV,
   (mapi_func) glPatchParameteriOES,
   (mapi_func) glPathColorGenNV,
   (mapi_func) glPathCommandsNV,
   (mapi_func) glPathCoordsNV,
   (mapi_func) glPathCoverDepthFuncNV,
   (mapi_func) glPathDashArrayNV,
   (mapi_func) glPathFogGenNV,
   (mapi_func) glPathGlyphIndexArrayNV,
   (mapi_func) glPathGlyphIndexRangeNV,
   (mapi_func) glPathGlyphRangeNV,
   (mapi_func) glPathGlyphsNV,
   (mapi_func) glPathMemoryGlyphIndexArrayNV,
   (mapi_func) glPathParameterfNV,
   (mapi_func) glPathParameterfvNV,
   (mapi_func) glPathParameteriNV,
   (mapi_func) glPathParameterivNV,
   (mapi_func) glPathStencilDepthOffsetNV,
   (mapi_func) glPathStencilFuncNV,
   (mapi_func) glPathStringNV,
   (mapi_func) glPathSubCommandsNV,
   (mapi_func) glPathSubCoordsNV,
   (mapi_func) glPathTexGenNV,
   (mapi_func) glPauseTransformFeedback,
   (mapi_func) glPauseTransformFeedbackEXT,
   (mapi_func) glPauseTransformFeedbackNV,
   (mapi_func) glPixelDataRangeNV,
   (mapi_func) glPixelMapfv,
   (mapi_func) glPixelMapuiv,
   (mapi_func) glPixelMapusv,
   (mapi_func) glPixelMapx,
   (mapi_func) glPixelStoref,
   (mapi_func) glPixelStorei,
   (mapi_func) glPixelStorex,
   (mapi_func) glPixelTexGenParameterfSGIS,
   (mapi_func) glPixelTexGenParameterfvSGIS,
   (mapi_func) glPixelTexGenParameteriSGIS,
   (mapi_func) glPixelTexGenParameterivSGIS,
   (mapi_func) glPixelTexGenSGIX,
   (mapi_func) glPixelTransferf,
   (mapi_func) glPixelTransferi,
   (mapi_func) glPixelTransferxOES,
   (mapi_func) glPixelTransformParameterfEXT,
   (mapi_func) glPixelTransformParameterfvEXT,
   (mapi_func) glPixelTransformParameteriEXT,
   (mapi_func) glPixelTransformParameterivEXT,
   (mapi_func) glPixelZoom,
   (mapi_func) glPixelZoomxOES,
   (mapi_func) glPointAlongPathNV,
   (mapi_func) glPointParameterf,
   (mapi_func) glPointParameterfARB,
   (mapi_func) glPointParameterfEXT,
   (mapi_func) glPointParameterfSGIS,
   (mapi_func) glPointParameterfv,
   (mapi_func) glPointParameterfvARB,
   (mapi_func) glPointParameterfvEXT,
   (mapi_func) glPointParameterfvSGIS,
   (mapi_func) glPointParameteri,
   (mapi_func) glPointParameteriNV,
   (mapi_func) glPointParameteriv,
   (mapi_func) glPointParameterivNV,
   (mapi_func) glPointParameterx,
   (mapi_func) glPointParameterxOES,
   (mapi_func) glPointParameterxv,
   (mapi_func) glPointParameterxvOES,
   (mapi_func) glPointSize,
   (mapi_func) glPointSizePointerOES,
   (mapi_func) glPointSizex,
   (mapi_func) glPointSizexOES,
   (mapi_func) glPollAsyncSGIX,
   (mapi_func) glPollInstrumentsSGIX,
   (mapi_func) glPolygonMode,
   (mapi_func) glPolygonModeNV,
   (mapi_func) glPolygonOffset,
   (mapi_func) glPolygonOffsetClamp,
   (mapi_func) glPolygonOffsetClampEXT,
   (mapi_func) glPolygonOffsetEXT,
   (mapi_func) glPolygonOffsetx,
   (mapi_func) glPolygonOffsetxOES,
   (mapi_func) glPolygonStipple,
   (mapi_func) glPopAttrib,
   (mapi_func) glPopClientAttrib,
   (mapi_func) glPopDebugGroup,
   (mapi_func) glPopDebugGroupKHR,
   (mapi_func) glPopDebugGroupOES,
   (mapi_func) glPopGroupMarkerEXT,
   (mapi_func) glPopMatrix,
   (mapi_func) glPopName,
   (mapi_func) glPresentFrameDualFillNV,
   (mapi_func) glPresentFrameKeyedNV,
   (mapi_func) glPrimitiveBoundingBox,
   (mapi_func) glPrimitiveBoundingBoxARB,
   (mapi_func) glPrimitiveBoundingBoxEXT,
   (mapi_func) glPrimitiveBoundingBoxOES,
   (mapi_func) glPrimitiveRestart,
   (mapi_func) glPrimitiveRestartIndex,
   (mapi_func) glPrimitiveRestartIndexNV,
   (mapi_func) glPrimitiveRestartNV,
   (mapi_func) glPrioritizeTextures,
   (mapi_func) glPrioritizeTexturesEXT,
   (mapi_func) glPrioritizeTexturesxOES,
   (mapi_func) glProgramBinary,
   (mapi_func) glProgramBinaryOES,
   (mapi_func) glProgramBufferParametersIivNV,
   (mapi_func) glProgramBufferParametersIuivNV,
   (mapi_func) glProgramBufferParametersfvNV,
   (mapi_func) glProgramEnvParameter4dARB,
   (mapi_func) glProgramEnvParameter4dvARB,
   (mapi_func) glProgramEnvParameter4fARB,
   (mapi_func) glProgramEnvParameter4fvARB,
   (mapi_func) glProgramEnvParameterI4iNV,
   (mapi_func) glProgramEnvParameterI4ivNV,
   (mapi_func) glProgramEnvParameterI4uiNV,
   (mapi_func) glProgramEnvParameterI4uivNV,
   (mapi_func) glProgramEnvParameters4fvEXT,
   (mapi_func) glProgramEnvParametersI4ivNV,
   (mapi_func) glProgramEnvParametersI4uivNV,
   (mapi_func) glProgramLocalParameter4dARB,
   (mapi_func) glProgramLocalParameter4dvARB,
   (mapi_func) glProgramLocalParameter4fARB,
   (mapi_func) glProgramLocalParameter4fvARB,
   (mapi_func) glProgramLocalParameterI4iNV,
   (mapi_func) glProgramLocalParameterI4ivNV,
   (mapi_func) glProgramLocalParameterI4uiNV,
   (mapi_func) glProgramLocalParameterI4uivNV,
   (mapi_func) glProgramLocalParameters4fvEXT,
   (mapi_func) glProgramLocalParametersI4ivNV,
   (mapi_func) glProgramLocalParametersI4uivNV,
   (mapi_func) glProgramNamedParameter4dNV,
   (mapi_func) glProgramNamedParameter4dvNV,
   (mapi_func) glProgramNamedParameter4fNV,
   (mapi_func) glProgramNamedParameter4fvNV,
   (mapi_func) glProgramParameter4dNV,
   (mapi_func) glProgramParameter4dvNV,
   (mapi_func) glProgramParameter4fNV,
   (mapi_func) glProgramParameter4fvNV,
   (mapi_func) glProgramParameteri,
   (mapi_func) glProgramParameteriARB,
   (mapi_func) glProgramParameteriEXT,
   (mapi_func) glProgramParameters4dvNV,
   (mapi_func) glProgramParameters4fvNV,
   (mapi_func) glProgramPathFragmentInputGenNV,
   (mapi_func) glProgramStringARB,
   (mapi_func) glProgramSubroutineParametersuivNV,
   (mapi_func) glProgramUniform1d,
   (mapi_func) glProgramUniform1dEXT,
   (mapi_func) glProgramUniform1dv,
   (mapi_func) glProgramUniform1dvEXT,
   (mapi_func) glProgramUniform1f,
   (mapi_func) glProgramUniform1fEXT,
   (mapi_func) glProgramUniform1fv,
   (mapi_func) glProgramUniform1fvEXT,
   (mapi_func) glProgramUniform1i,
   (mapi_func) glProgramUniform1i64ARB,
   (mapi_func) glProgramUniform1i64NV,
   (mapi_func) glProgramUniform1i64vARB,
   (mapi_func) glProgramUniform1i64vNV,
   (mapi_func) glProgramUniform1iEXT,
   (mapi_func) glProgramUniform1iv,
   (mapi_func) glProgramUniform1ivEXT,
   (mapi_func) glProgramUniform1ui,
   (mapi_func) glProgramUniform1ui64ARB,
   (mapi_func) glProgramUniform1ui64NV,
   (mapi_func) glProgramUniform1ui64vARB,
   (mapi_func) glProgramUniform1ui64vNV,
   (mapi_func) glProgramUniform1uiEXT,
   (mapi_func) glProgramUniform1uiv,
   (mapi_func) glProgramUniform1uivEXT,
   (mapi_func) glProgramUniform2d,
   (mapi_func) glProgramUniform2dEXT,
   (mapi_func) glProgramUniform2dv,
   (mapi_func) glProgramUniform2dvEXT,
   (mapi_func) glProgramUniform2f,
   (mapi_func) glProgramUniform2fEXT,
   (mapi_func) glProgramUniform2fv,
   (mapi_func) glProgramUniform2fvEXT,
   (mapi_func) glProgramUniform2i,
   (mapi_func) glProgramUniform2i64ARB,
   (mapi_func) glProgramUniform2i64NV,
   (mapi_func) glProgramUniform2i64vARB,
   (mapi_func) glProgramUniform2i64vNV,
   (mapi_func) glProgramUniform2iEXT,
   (mapi_func) glProgramUniform2iv,
   (mapi_func) glProgramUniform2ivEXT,
   (mapi_func) glProgramUniform2ui,
   (mapi_func) glProgramUniform2ui64ARB,
   (mapi_func) glProgramUniform2ui64NV,
   (mapi_func) glProgramUniform2ui64vARB,
   (mapi_func) glProgramUniform2ui64vNV,
   (mapi_func) glProgramUniform2uiEXT,
   (mapi_func) glProgramUniform2uiv,
   (mapi_func) glProgramUniform2uivEXT,
   (mapi_func) glProgramUniform3d,
   (mapi_func) glProgramUniform3dEXT,
   (mapi_func) glProgramUniform3dv,
   (mapi_func) glProgramUniform3dvEXT,
   (mapi_func) glProgramUniform3f,
   (mapi_func) glProgramUniform3fEXT,
   (mapi_func) glProgramUniform3fv,
   (mapi_func) glProgramUniform3fvEXT,
   (mapi_func) glProgramUniform3i,
   (mapi_func) glProgramUniform3i64ARB,
   (mapi_func) glProgramUniform3i64NV,
   (mapi_func) glProgramUniform3i64vARB,
   (mapi_func) glProgramUniform3i64vNV,
   (mapi_func) glProgramUniform3iEXT,
   (mapi_func) glProgramUniform3iv,
   (mapi_func) glProgramUniform3ivEXT,
   (mapi_func) glProgramUniform3ui,
   (mapi_func) glProgramUniform3ui64ARB,
   (mapi_func) glProgramUniform3ui64NV,
   (mapi_func) glProgramUniform3ui64vARB,
   (mapi_func) glProgramUniform3ui64vNV,
   (mapi_func) glProgramUniform3uiEXT,
   (mapi_func) glProgramUniform3uiv,
   (mapi_func) glProgramUniform3uivEXT,
   (mapi_func) glProgramUniform4d,
   (mapi_func) glProgramUniform4dEXT,
   (mapi_func) glProgramUniform4dv,
   (mapi_func) glProgramUniform4dvEXT,
   (mapi_func) glProgramUniform4f,
   (mapi_func) glProgramUniform4fEXT,
   (mapi_func) glProgramUniform4fv,
   (mapi_func) glProgramUniform4fvEXT,
   (mapi_func) glProgramUniform4i,
   (mapi_func) glProgramUniform4i64ARB,
   (mapi_func) glProgramUniform4i64NV,
   (mapi_func) glProgramUniform4i64vARB,
   (mapi_func) glProgramUniform4i64vNV,
   (mapi_func) glProgramUniform4iEXT,
   (mapi_func) glProgramUniform4iv,
   (mapi_func) glProgramUniform4ivEXT,
   (mapi_func) glProgramUniform4ui,
   (mapi_func) glProgramUniform4ui64ARB,
   (mapi_func) glProgramUniform4ui64NV,
   (mapi_func) glProgramUniform4ui64vARB,
   (mapi_func) glProgramUniform4ui64vNV,
   (mapi_func) glProgramUniform4uiEXT,
   (mapi_func) glProgramUniform4uiv,
   (mapi_func) glProgramUniform4uivEXT,
   (mapi_func) glProgramUniformHandleui64ARB,
   (mapi_func) glProgramUniformHandleui64IMG,
   (mapi_func) glProgramUniformHandleui64NV,
   (mapi_func) glProgramUniformHandleui64vARB,
   (mapi_func) glProgramUniformHandleui64vIMG,
   (mapi_func) glProgramUniformHandleui64vNV,
   (mapi_func) glProgramUniformMatrix2dv,
   (mapi_func) glProgramUniformMatrix2dvEXT,
   (mapi_func) glProgramUniformMatrix2fv,
   (mapi_func) glProgramUniformMatrix2fvEXT,
   (mapi_func) glProgramUniformMatrix2x3dv,
   (mapi_func) glProgramUniformMatrix2x3dvEXT,
   (mapi_func) glProgramUniformMatrix2x3fv,
   (mapi_func) glProgramUniformMatrix2x3fvEXT,
   (mapi_func) glProgramUniformMatrix2x4dv,
   (mapi_func) glProgramUniformMatrix2x4dvEXT,
   (mapi_func) glProgramUniformMatrix2x4fv,
   (mapi_func) glProgramUniformMatrix2x4fvEXT,
   (mapi_func) glProgramUniformMatrix3dv,
   (mapi_func) glProgramUniformMatrix3dvEXT,
   (mapi_func) glProgramUniformMatrix3fv,
   (mapi_func) glProgramUniformMatrix3fvEXT,
   (mapi_func) glProgramUniformMatrix3x2dv,
   (mapi_func) glProgramUniformMatrix3x2dvEXT,
   (mapi_func) glProgramUniformMatrix3x2fv,
   (mapi_func) glProgramUniformMatrix3x2fvEXT,
   (mapi_func) glProgramUniformMatrix3x4dv,
   (mapi_func) glProgramUniformMatrix3x4dvEXT,
   (mapi_func) glProgramUniformMatrix3x4fv,
   (mapi_func) glProgramUniformMatrix3x4fvEXT,
   (mapi_func) glProgramUniformMatrix4dv,
   (mapi_func) glProgramUniformMatrix4dvEXT,
   (mapi_func) glProgramUniformMatrix4fv,
   (mapi_func) glProgramUniformMatrix4fvEXT,
   (mapi_func) glProgramUniformMatrix4x2dv,
   (mapi_func) glProgramUniformMatrix4x2dvEXT,
   (mapi_func) glProgramUniformMatrix4x2fv,
   (mapi_func) glProgramUniformMatrix4x2fvEXT,
   (mapi_func) glProgramUniformMatrix4x3dv,
   (mapi_func) glProgramUniformMatrix4x3dvEXT,
   (mapi_func) glProgramUniformMatrix4x3fv,
   (mapi_func) glProgramUniformMatrix4x3fvEXT,
   (mapi_func) glProgramUniformui64NV,
   (mapi_func) glProgramUniformui64vNV,
   (mapi_func) glProgramVertexLimitNV,
   (mapi_func) glProvokingVertex,
   (mapi_func) glProvokingVertexEXT,
   (mapi_func) glPushAttrib,
   (mapi_func) glPushClientAttrib,
   (mapi_func) glPushClientAttribDefaultEXT,
   (mapi_func) glPushDebugGroup,
   (mapi_func) glPushDebugGroupKHR,
   (mapi_func) glPushDebugGroupOES,
   (mapi_func) glPushGroupMarkerEXT,
   (mapi_func) glPushMatrix,
   (mapi_func) glPushName,
   (mapi_func) glQueryCounter,
   (mapi_func) glQueryCounterEXT,
   (mapi_func) glQueryCounterNV,
   (mapi_func) glQueryMatrixxOES,
   (mapi_func) glQueryObjectParameteruiAMD,
   (mapi_func) glQueryResourceNV,
   (mapi_func) glQueryResourceTagNV,
   (mapi_func) glRasterPos2d,
   (mapi_func) glRasterPos2dv,
   (mapi_func) glRasterPos2f,
   (mapi_func) glRasterPos2fv,
   (mapi_func) glRasterPos2i,
   (mapi_func) glRasterPos2iv,
   (mapi_func) glRasterPos2s,
   (mapi_func) glRasterPos2sv,
   (mapi_func) glRasterPos2xOES,
   (mapi_func) glRasterPos2xvOES,
   (mapi_func) glRasterPos3d,
   (mapi_func) glRasterPos3dv,
   (mapi_func) glRasterPos3f,
   (mapi_func) glRasterPos3fv,
   (mapi_func) glRasterPos3i,
   (mapi_func) glRasterPos3iv,
   (mapi_func) glRasterPos3s,
   (mapi_func) glRasterPos3sv,
   (mapi_func) glRasterPos3xOES,
   (mapi_func) glRasterPos3xvOES,
   (mapi_func) glRasterPos4d,
   (mapi_func) glRasterPos4dv,
   (mapi_func) glRasterPos4f,
   (mapi_func) glRasterPos4fv,
   (mapi_func) glRasterPos4i,
   (mapi_func) glRasterPos4iv,
   (mapi_func) glRasterPos4s,
   (mapi_func) glRasterPos4sv,
   (mapi_func) glRasterPos4xOES,
   (mapi_func) glRasterPos4xvOES,
   (mapi_func) glRasterSamplesEXT,
   (mapi_func) glReadBuffer,
   (mapi_func) glReadBufferIndexedEXT,
   (mapi_func) glReadBufferNV,
   (mapi_func) glReadInstrumentsSGIX,
   (mapi_func) glReadPixels,
   (mapi_func) glReadnPixels,
   (mapi_func) glReadnPixelsARB,
   (mapi_func) glReadnPixelsEXT,
   (mapi_func) glReadnPixelsKHR,
   (mapi_func) glRectd,
   (mapi_func) glRectdv,
   (mapi_func) glRectf,
   (mapi_func) glRectfv,
   (mapi_func) glRecti,
   (mapi_func) glRectiv,
   (mapi_func) glRects,
   (mapi_func) glRectsv,
   (mapi_func) glRectxOES,
   (mapi_func) glRectxvOES,
   (mapi_func) glReferencePlaneSGIX,
   (mapi_func) glReleaseKeyedMutexWin32EXT,
   (mapi_func) glReleaseShaderCompiler,
   (mapi_func) glRenderGpuMaskNV,
   (mapi_func) glRenderMode,
   (mapi_func) glRenderbufferStorage,
   (mapi_func) glRenderbufferStorageEXT,
   (mapi_func) glRenderbufferStorageMultisample,
   (mapi_func) glRenderbufferStorageMultisampleANGLE,
   (mapi_func) glRenderbufferStorageMultisampleAPPLE,
   (mapi_func) glRenderbufferStorageMultisampleAdvancedAMD,
   (mapi_func) glRenderbufferStorageMultisampleCoverageNV,
   (mapi_func) glRenderbufferStorageMultisampleEXT,
   (mapi_func) glRenderbufferStorageMultisampleIMG,
   (mapi_func) glRenderbufferStorageMultisampleNV,
   (mapi_func) glRenderbufferStorageOES,
   (mapi_func) glReplacementCodePointerSUN,
   (mapi_func) glReplacementCodeubSUN,
   (mapi_func) glReplacementCodeubvSUN,
   (mapi_func) glReplacementCodeuiColor3fVertex3fSUN,
   (mapi_func) glReplacementCodeuiColor3fVertex3fvSUN,
   (mapi_func) glReplacementCodeuiColor4fNormal3fVertex3fSUN,
   (mapi_func) glReplacementCodeuiColor4fNormal3fVertex3fvSUN,
   (mapi_func) glReplacementCodeuiColor4ubVertex3fSUN,
   (mapi_func) glReplacementCodeuiColor4ubVertex3fvSUN,
   (mapi_func) glReplacementCodeuiNormal3fVertex3fSUN,
   (mapi_func) glReplacementCodeuiNormal3fVertex3fvSUN,
   (mapi_func) glReplacementCodeuiSUN,
   (mapi_func) glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fSUN,
   (mapi_func) glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fvSUN,
   (mapi_func) glReplacementCodeuiTexCoord2fNormal3fVertex3fSUN,
   (mapi_func) glReplacementCodeuiTexCoord2fNormal3fVertex3fvSUN,
   (mapi_func) glReplacementCodeuiTexCoord2fVertex3fSUN,
   (mapi_func) glReplacementCodeuiTexCoord2fVertex3fvSUN,
   (mapi_func) glReplacementCodeuiVertex3fSUN,
   (mapi_func) glReplacementCodeuiVertex3fvSUN,
   (mapi_func) glReplacementCodeuivSUN,
   (mapi_func) glReplacementCodeusSUN,
   (mapi_func) glReplacementCodeusvSUN,
   (mapi_func) glRequestResidentProgramsNV,
   (mapi_func) glResetHistogram,
   (mapi_func) glResetHistogramEXT,
   (mapi_func) glResetMemoryObjectParameterNV,
   (mapi_func) glResetMinmax,
   (mapi_func) glResetMinmaxEXT,
   (mapi_func) glResizeBuffersMESA,
   (mapi_func) glResolveDepthValuesNV,
   (mapi_func) glResolveMultisampleFramebufferAPPLE,
   (mapi_func) glResumeTransformFeedback,
   (mapi_func) glResumeTransformFeedbackEXT,
   (mapi_func) glResumeTransformFeedbackNV,
   (mapi_func) glRotated,
   (mapi_func) glRotatef,
   (mapi_func) glRotatex,
   (mapi_func) glRotatexOES,
   (mapi_func) glSampleCoverage,
   (mapi_func) glSampleCoverageARB,
   (mapi_func) glSampleCoveragex,
   (mapi_func) glSampleCoveragexOES,
   (mapi_func) glSampleMapATI,
   (mapi_func) glSampleMaskEXT,
   (mapi_func) glSampleMaskIndexedNV,
   (mapi_func) glSampleMaskSGIS,
   (mapi_func) glSampleMaski,
   (mapi_func) glSamplePatternEXT,
   (mapi_func) glSamplePatternSGIS,
   (mapi_func) glSamplerParameterIiv,
   (mapi_func) glSamplerParameterIivEXT,
   (mapi_func) glSamplerParameterIivOES,
   (mapi_func) glSamplerParameterIuiv,
   (mapi_func) glSamplerParameterIuivEXT,
   (mapi_func) glSamplerParameterIuivOES,
   (mapi_func) glSamplerParameterf,
   (mapi_func) glSamplerParameterfv,
   (mapi_func) glSamplerParameteri,
   (mapi_func) glSamplerParameteriv,
   (mapi_func) glScaled,
   (mapi_func) glScalef,
   (mapi_func) glScalex,
   (mapi_func) glScalexOES,
   (mapi_func) glScissor,
   (mapi_func) glScissorArrayv,
   (mapi_func) glScissorArrayvNV,
   (mapi_func) glScissorArrayvOES,
   (mapi_func) glScissorExclusiveArrayvNV,
   (mapi_func) glScissorExclusiveNV,
   (mapi_func) glScissorIndexed,
   (mapi_func) glScissorIndexedNV,
   (mapi_func) glScissorIndexedOES,
   (mapi_func) glScissorIndexedv,
   (mapi_func) glScissorIndexedvNV,
   (mapi_func) glScissorIndexedvOES,
   (mapi_func) glSecondaryColor3b,
   (mapi_func) glSecondaryColor3bEXT,
   (mapi_func) glSecondaryColor3bv,
   (mapi_func) glSecondaryColor3bvEXT,
   (mapi_func) glSecondaryColor3d,
   (mapi_func) glSecondaryColor3dEXT,
   (mapi_func) glSecondaryColor3dv,
   (mapi_func) glSecondaryColor3dvEXT,
   (mapi_func) glSecondaryColor3f,
   (mapi_func) glSecondaryColor3fEXT,
   (mapi_func) glSecondaryColor3fv,
   (mapi_func) glSecondaryColor3fvEXT,
   (mapi_func) glSecondaryColor3hNV,
   (mapi_func) glSecondaryColor3hvNV,
   (mapi_func) glSecondaryColor3i,
   (mapi_func) glSecondaryColor3iEXT,
   (mapi_func) glSecondaryColor3iv,
   (mapi_func) glSecondaryColor3ivEXT,
   (mapi_func) glSecondaryColor3s,
   (mapi_func) glSecondaryColor3sEXT,
   (mapi_func) glSecondaryColor3sv,
   (mapi_func) glSecondaryColor3svEXT,
   (mapi_func) glSecondaryColor3ub,
   (mapi_func) glSecondaryColor3ubEXT,
   (mapi_func) glSecondaryColor3ubv,
   (mapi_func) glSecondaryColor3ubvEXT,
   (mapi_func) glSecondaryColor3ui,
   (mapi_func) glSecondaryColor3uiEXT,
   (mapi_func) glSecondaryColor3uiv,
   (mapi_func) glSecondaryColor3uivEXT,
   (mapi_func) glSecondaryColor3us,
   (mapi_func) glSecondaryColor3usEXT,
   (mapi_func) glSecondaryColor3usv,
   (mapi_func) glSecondaryColor3usvEXT,
   (mapi_func) glSecondaryColorFormatNV,
   (mapi_func) glSecondaryColorP3ui,
   (mapi_func) glSecondaryColorP3uiv,
   (mapi_func) glSecondaryColorPointer,
   (mapi_func) glSecondaryColorPointerEXT,
   (mapi_func) glSecondaryColorPointerListIBM,
   (mapi_func) glSelectBuffer,
   (mapi_func) glSelectPerfMonitorCountersAMD,
   (mapi_func) glSemaphoreParameterui64vEXT,
   (mapi_func) glSeparableFilter2D,
   (mapi_func) glSeparableFilter2DEXT,
   (mapi_func) glSetFenceAPPLE,
   (mapi_func) glSetFenceNV,
   (mapi_func) glSetFragmentShaderConstantATI,
   (mapi_func) glSetInvariantEXT,
   (mapi_func) glSetLocalConstantEXT,
   (mapi_func) glSetMultisamplefvAMD,
   (mapi_func) glShadeModel,
   (mapi_func) glShaderBinary,
   (mapi_func) glShaderOp1EXT,
   (mapi_func) glShaderOp2EXT,
   (mapi_func) glShaderOp3EXT,
   (mapi_func) glShaderSource,
   (mapi_func) glShaderSourceARB,
   (mapi_func) glShaderStorageBlockBinding,
   (mapi_func) glShadingRateImageBarrierNV,
   (mapi_func) glShadingRateImagePaletteNV,
   (mapi_func) glShadingRateSampleOrderCustomNV,
   (mapi_func) glShadingRateSampleOrderNV,
   (mapi_func) glSharpenTexFuncSGIS,
   (mapi_func) glSignalSemaphoreEXT,
   (mapi_func) glSignalSemaphoreui64NVX,
   (mapi_func) glSignalVkFenceNV,
   (mapi_func) glSignalVkSemaphoreNV,
   (mapi_func) glSpecializeShader,
   (mapi_func) glSpecializeShaderARB,
   (mapi_func) glSpriteParameterfSGIX,
   (mapi_func) glSpriteParameterfvSGIX,
   (mapi_func) glSpriteParameteriSGIX,
   (mapi_func) glSpriteParameterivSGIX,
   (mapi_func) glStartInstrumentsSGIX,
   (mapi_func) glStartTilingQCOM,
   (mapi_func) glStateCaptureNV,
   (mapi_func) glStencilClearTagEXT,
   (mapi_func) glStencilFillPathInstancedNV,
   (mapi_func) glStencilFillPathNV,
   (mapi_func) glStencilFunc,
   (mapi_func) glStencilFuncSeparate,
   (mapi_func) glStencilFuncSeparateATI,
   (mapi_func) glStencilMask,
   (mapi_func) glStencilMaskSeparate,
   (mapi_func) glStencilOp,
   (mapi_func) glStencilOpSeparate,
   (mapi_func) glStencilOpSeparateATI,
   (mapi_func) glStencilOpValueAMD,
   (mapi_func) glStencilStrokePathInstancedNV,
   (mapi_func) glStencilStrokePathNV,
   (mapi_func) glStencilThenCoverFillPathInstancedNV,
   (mapi_func) glStencilThenCoverFillPathNV,
   (mapi_func) glStencilThenCoverStrokePathInstancedNV,
   (mapi_func) glStencilThenCoverStrokePathNV,
   (mapi_func) glStopInstrumentsSGIX,
   (mapi_func) glStringMarkerGREMEDY,
   (mapi_func) glSubpixelPrecisionBiasNV,
   (mapi_func) glSwizzleEXT,
   (mapi_func) glSyncTextureINTEL,
   (mapi_func) glTagSampleBufferSGIX,
   (mapi_func) glTangent3bEXT,
   (mapi_func) glTangent3bvEXT,
   (mapi_func) glTangent3dEXT,
   (mapi_func) glTangent3dvEXT,
   (mapi_func) glTangent3fEXT,
   (mapi_func) glTangent3fvEXT,
   (mapi_func) glTangent3iEXT,
   (mapi_func) glTangent3ivEXT,
   (mapi_func) glTangent3sEXT,
   (mapi_func) glTangent3svEXT,
   (mapi_func) glTangentPointerEXT,
   (mapi_func) glTbufferMask3DFX,
   (mapi_func) glTessellationFactorAMD,
   (mapi_func) glTessellationModeAMD,
   (mapi_func) glTestFenceAPPLE,
   (mapi_func) glTestFenceNV,
   (mapi_func) glTestObjectAPPLE,
   (mapi_func) glTexAttachMemoryNV,
   (mapi_func) glTexBuffer,
   (mapi_func) glTexBufferARB,
   (mapi_func) glTexBufferEXT,
   (mapi_func) glTexBufferOES,
   (mapi_func) glTexBufferRange,
   (mapi_func) glTexBufferRangeEXT,
   (mapi_func) glTexBufferRangeOES,
   (mapi_func) glTexBumpParameterfvATI,
   (mapi_func) glTexBumpParameterivATI,
   (mapi_func) glTexCoord1bOES,
   (mapi_func) glTexCoord1bvOES,
   (mapi_func) glTexCoord1d,
   (mapi_func) glTexCoord1dv,
   (mapi_func) glTexCoord1f,
   (mapi_func) glTexCoord1fv,
   (mapi_func) glTexCoord1hNV,
   (mapi_func) glTexCoord1hvNV,
   (mapi_func) glTexCoord1i,
   (mapi_func) glTexCoord1iv,
   (mapi_func) glTexCoord1s,
   (mapi_func) glTexCoord1sv,
   (mapi_func) glTexCoord1xOES,
   (mapi_func) glTexCoord1xvOES,
   (mapi_func) glTexCoord2bOES,
   (mapi_func) glTexCoord2bvOES,
   (mapi_func) glTexCoord2d,
   (mapi_func) glTexCoord2dv,
   (mapi_func) glTexCoord2f,
   (mapi_func) glTexCoord2fColor3fVertex3fSUN,
   (mapi_func) glTexCoord2fColor3fVertex3fvSUN,
   (mapi_func) glTexCoord2fColor4fNormal3fVertex3fSUN,
   (mapi_func) glTexCoord2fColor4fNormal3fVertex3fvSUN,
   (mapi_func) glTexCoord2fColor4ubVertex3fSUN,
   (mapi_func) glTexCoord2fColor4ubVertex3fvSUN,
   (mapi_func) glTexCoord2fNormal3fVertex3fSUN,
   (mapi_func) glTexCoord2fNormal3fVertex3fvSUN,
   (mapi_func) glTexCoord2fVertex3fSUN,
   (mapi_func) glTexCoord2fVertex3fvSUN,
   (mapi_func) glTexCoord2fv,
   (mapi_func) glTexCoord2hNV,
   (mapi_func) glTexCoord2hvNV,
   (mapi_func) glTexCoord2i,
   (mapi_func) glTexCoord2iv,
   (mapi_func) glTexCoord2s,
   (mapi_func) glTexCoord2sv,
   (mapi_func) glTexCoord2xOES,
   (mapi_func) glTexCoord2xvOES,
   (mapi_func) glTexCoord3bOES,
   (mapi_func) glTexCoord3bvOES,
   (mapi_func) glTexCoord3d,
   (mapi_func) glTexCoord3dv,
   (mapi_func) glTexCoord3f,
   (mapi_func) glTexCoord3fv,
   (mapi_func) glTexCoord3hNV,
   (mapi_func) glTexCoord3hvNV,
   (mapi_func) glTexCoord3i,
   (mapi_func) glTexCoord3iv,
   (mapi_func) glTexCoord3s,
   (mapi_func) glTexCoord3sv,
   (mapi_func) glTexCoord3xOES,
   (mapi_func) glTexCoord3xvOES,
   (mapi_func) glTexCoord4bOES,
   (mapi_func) glTexCoord4bvOES,
   (mapi_func) glTexCoord4d,
   (mapi_func) glTexCoord4dv,
   (mapi_func) glTexCoord4f,
   (mapi_func) glTexCoord4fColor4fNormal3fVertex4fSUN,
   (mapi_func) glTexCoord4fColor4fNormal3fVertex4fvSUN,
   (mapi_func) glTexCoord4fVertex4fSUN,
   (mapi_func) glTexCoord4fVertex4fvSUN,
   (mapi_func) glTexCoord4fv,
   (mapi_func) glTexCoord4hNV,
   (mapi_func) glTexCoord4hvNV,
   (mapi_func) glTexCoord4i,
   (mapi_func) glTexCoord4iv,
   (mapi_func) glTexCoord4s,
   (mapi_func) glTexCoord4sv,
   (mapi_func) glTexCoord4xOES,
   (mapi_func) glTexCoord4xvOES,
   (mapi_func) glTexCoordFormatNV,
   (mapi_func) glTexCoordP1ui,
   (mapi_func) glTexCoordP1uiv,
   (mapi_func) glTexCoordP2ui,
   (mapi_func) glTexCoordP2uiv,
   (mapi_func) glTexCoordP3ui,
   (mapi_func) glTexCoordP3uiv,
   (mapi_func) glTexCoordP4ui,
   (mapi_func) glTexCoordP4uiv,
   (mapi_func) glTexCoordPointer,
   (mapi_func) glTexCoordPointerEXT,
   (mapi_func) glTexCoordPointerListIBM,
   (mapi_func) glTexCoordPointervINTEL,
   (mapi_func) glTexEnvf,
   (mapi_func) glTexEnvfv,
   (mapi_func) glTexEnvi,
   (mapi_func) glTexEnviv,
   (mapi_func) glTexEnvx,
   (mapi_func) glTexEnvxOES,
   (mapi_func) glTexEnvxv,
   (mapi_func) glTexEnvxvOES,
   (mapi_func) glTexFilterFuncSGIS,
   (mapi_func) glTexGend,
   (mapi_func) glTexGendv,
   (mapi_func) glTexGenf,
   (mapi_func) glTexGenfOES,
   (mapi_func) glTexGenfv,
   (mapi_func) glTexGenfvOES,
   (mapi_func) glTexGeni,
   (mapi_func) glTexGeniOES,
   (mapi_func) glTexGeniv,
   (mapi_func) glTexGenivOES,
   (mapi_func) glTexGenxOES,
   (mapi_func) glTexGenxvOES,
   (mapi_func) glTexImage1D,
   (mapi_func) glTexImage2D,
   (mapi_func) glTexImage2DMultisample,
   (mapi_func) glTexImage2DMultisampleCoverageNV,
   (mapi_func) glTexImage3D,
   (mapi_func) glTexImage3DEXT,
   (mapi_func) glTexImage3DMultisample,
   (mapi_func) glTexImage3DMultisampleCoverageNV,
   (mapi_func) glTexImage3DNV,
   (mapi_func) glTexImage3DOES,
   (mapi_func) glTexImage4DSGIS,
   (mapi_func) glTexPageCommitmentARB,
   (mapi_func) glTexPageCommitmentEXT,
   (mapi_func) glTexParameterIiv,
   (mapi_func) glTexParameterIivEXT,
   (mapi_func) glTexParameterIivOES,
   (mapi_func) glTexParameterIuiv,
   (mapi_func) glTexParameterIuivEXT,
   (mapi_func) glTexParameterIuivOES,
   (mapi_func) glTexParameterf,
   (mapi_func) glTexParameterfv,
   (mapi_func) glTexParameteri,
   (mapi_func) glTexParameteriv,
   (mapi_func) glTexParameterx,
   (mapi_func) glTexParameterxOES,
   (mapi_func) glTexParameterxv,
   (mapi_func) glTexParameterxvOES,
   (mapi_func) glTexRenderbufferNV,
   (mapi_func) glTexStorage1D,
   (mapi_func) glTexStorage1DEXT,
   (mapi_func) glTexStorage2D,
   (mapi_func) glTexStorage2DEXT,
   (mapi_func) glTexStorage2DMultisample,
   (mapi_func) glTexStorage3D,
   (mapi_func) glTexStorage3DEXT,
   (mapi_func) glTexStorage3DMultisample,
   (mapi_func) glTexStorage3DMultisampleOES,
   (mapi_func) glTexStorageMem1DEXT,
   (mapi_func) glTexStorageMem2DEXT,
   (mapi_func) glTexStorageMem2DMultisampleEXT,
   (mapi_func) glTexStorageMem3DEXT,
   (mapi_func) glTexStorageMem3DMultisampleEXT,
   (mapi_func) glTexStorageSparseAMD,
   (mapi_func) glTexSubImage1D,
   (mapi_func) glTexSubImage1DEXT,
   (mapi_func) glTexSubImage2D,
   (mapi_func) glTexSubImage2DEXT,
   (mapi_func) glTexSubImage3D,
   (mapi_func) glTexSubImage3DEXT,
   (mapi_func) glTexSubImage3DNV,
   (mapi_func) glTexSubImage3DOES,
   (mapi_func) glTexSubImage4DSGIS,
   (mapi_func) glTextureAttachMemoryNV,
   (mapi_func) glTextureBarrier,
   (mapi_func) glTextureBarrierNV,
   (mapi_func) glTextureBuffer,
   (mapi_func) glTextureBufferEXT,
   (mapi_func) glTextureBufferRange,
   (mapi_func) glTextureBufferRangeEXT,
   (mapi_func) glTextureColorMaskSGIS,
   (mapi_func) glTextureFoveationParametersQCOM,
   (mapi_func) glTextureImage1DEXT,
   (mapi_func) glTextureImage2DEXT,
   (mapi_func) glTextureImage2DMultisampleCoverageNV,
   (mapi_func) glTextureImage2DMultisampleNV,
   (mapi_func) glTextureImage3DEXT,
   (mapi_func) glTextureImage3DMultisampleCoverageNV,
   (mapi_func) glTextureImage3DMultisampleNV,
   (mapi_func) glTextureLightEXT,
   (mapi_func) glTextureMaterialEXT,
   (mapi_func) glTextureNormalEXT,
   (mapi_func) glTexturePageCommitmentEXT,
   (mapi_func) glTextureParameterIiv,
   (mapi_func) glTextureParameterIivEXT,
   (mapi_func) glTextureParameterIuiv,
   (mapi_func) glTextureParameterIuivEXT,
   (mapi_func) glTextureParameterf,
   (mapi_func) glTextureParameterfEXT,
   (mapi_func) glTextureParameterfv,
   (mapi_func) glTextureParameterfvEXT,
   (mapi_func) glTextureParameteri,
   (mapi_func) glTextureParameteriEXT,
   (mapi_func) glTextureParameteriv,
   (mapi_func) glTextureParameterivEXT,
   (mapi_func) glTextureRangeAPPLE,
   (mapi_func) glTextureRenderbufferEXT,
   (mapi_func) glTextureStorage1D,
   (mapi_func) glTextureStorage1DEXT,
   (mapi_func) glTextureStorage2D,
   (mapi_func) glTextureStorage2DEXT,
   (mapi_func) glTextureStorage2DMultisample,
   (mapi_func) glTextureStorage2DMultisampleEXT,
   (mapi_func) glTextureStorage3D,
   (mapi_func) glTextureStorage3DEXT,
   (mapi_func) glTextureStorage3DMultisample,
   (mapi_func) glTextureStorage3DMultisampleEXT,
   (mapi_func) glTextureStorageMem1DEXT,
   (mapi_func) glTextureStorageMem2DEXT,
   (mapi_func) glTextureStorageMem2DMultisampleEXT,
   (mapi_func) glTextureStorageMem3DEXT,
   (mapi_func) glTextureStorageMem3DMultisampleEXT,
   (mapi_func) glTextureStorageSparseAMD,
   (mapi_func) glTextureSubImage1D,
   (mapi_func) glTextureSubImage1DEXT,
   (mapi_func) glTextureSubImage2D,
   (mapi_func) glTextureSubImage2DEXT,
   (mapi_func) glTextureSubImage3D,
   (mapi_func) glTextureSubImage3DEXT,
   (mapi_func) glTextureView,
   (mapi_func) glTextureViewEXT,
   (mapi_func) glTextureViewOES,
   (mapi_func) glTrackMatrixNV,
   (mapi_func) glTransformFeedbackAttribsNV,
   (mapi_func) glTransformFeedbackBufferBase,
   (mapi_func) glTransformFeedbackBufferRange,
   (mapi_func) glTransformFeedbackStreamAttribsNV,
   (mapi_func) glTransformFeedbackVaryings,
   (mapi_func) glTransformFeedbackVaryingsEXT,
   (mapi_func) glTransformFeedbackVaryingsNV,
   (mapi_func) glTransformPathNV,
   (mapi_func) glTranslated,
   (mapi_func) glTranslatef,
   (mapi_func) glTranslatex,
   (mapi_func) glTranslatexOES,
   (mapi_func) glUniform1d,
   (mapi_func) glUniform1dv,
   (mapi_func) glUniform1f,
   (mapi_func) glUniform1fARB,
   (mapi_func) glUniform1fv,
   (mapi_func) glUniform1fvARB,
   (mapi_func) glUniform1i,
   (mapi_func) glUniform1i64ARB,
   (mapi_func) glUniform1i64NV,
   (mapi_func) glUniform1i64vARB,
   (mapi_func) glUniform1i64vNV,
   (mapi_func) glUniform1iARB,
   (mapi_func) glUniform1iv,
   (mapi_func) glUniform1ivARB,
   (mapi_func) glUniform1ui,
   (mapi_func) glUniform1ui64ARB,
   (mapi_func) glUniform1ui64NV,
   (mapi_func) glUniform1ui64vARB,
   (mapi_func) glUniform1ui64vNV,
   (mapi_func) glUniform1uiEXT,
   (mapi_func) glUniform1uiv,
   (mapi_func) glUniform1uivEXT,
   (mapi_func) glUniform2d,
   (mapi_func) glUniform2dv,
   (mapi_func) glUniform2f,
   (mapi_func) glUniform2fARB,
   (mapi_func) glUniform2fv,
   (mapi_func) glUniform2fvARB,
   (mapi_func) glUniform2i,
   (mapi_func) glUniform2i64ARB,
   (mapi_func) glUniform2i64NV,
   (mapi_func) glUniform2i64vARB,
   (mapi_func) glUniform2i64vNV,
   (mapi_func) glUniform2iARB,
   (mapi_func) glUniform2iv,
   (mapi_func) glUniform2ivARB,
   (mapi_func) glUniform2ui,
   (mapi_func) glUniform2ui64ARB,
   (mapi_func) glUniform2ui64NV,
   (mapi_func) glUniform2ui64vARB,
   (mapi_func) glUniform2ui64vNV,
   (mapi_func) glUniform2uiEXT,
   (mapi_func) glUniform2uiv,
   (mapi_func) glUniform2uivEXT,
   (mapi_func) glUniform3d,
   (mapi_func) glUniform3dv,
   (mapi_func) glUniform3f,
   (mapi_func) glUniform3fARB,
   (mapi_func) glUniform3fv,
   (mapi_func) glUniform3fvARB,
   (mapi_func) glUniform3i,
   (mapi_func) glUniform3i64ARB,
   (mapi_func) glUniform3i64NV,
   (mapi_func) glUniform3i64vARB,
   (mapi_func) glUniform3i64vNV,
   (mapi_func) glUniform3iARB,
   (mapi_func) glUniform3iv,
   (mapi_func) glUniform3ivARB,
   (mapi_func) glUniform3ui,
   (mapi_func) glUniform3ui64ARB,
   (mapi_func) glUniform3ui64NV,
   (mapi_func) glUniform3ui64vARB,
   (mapi_func) glUniform3ui64vNV,
   (mapi_func) glUniform3uiEXT,
   (mapi_func) glUniform3uiv,
   (mapi_func) glUniform3uivEXT,
   (mapi_func) glUniform4d,
   (mapi_func) glUniform4dv,
   (mapi_func) glUniform4f,
   (mapi_func) glUniform4fARB,
   (mapi_func) glUniform4fv,
   (mapi_func) glUniform4fvARB,
   (mapi_func) glUniform4i,
   (mapi_func) glUniform4i64ARB,
   (mapi_func) glUniform4i64NV,
   (mapi_func) glUniform4i64vARB,
   (mapi_func) glUniform4i64vNV,
   (mapi_func) glUniform4iARB,
   (mapi_func) glUniform4iv,
   (mapi_func) glUniform4ivARB,
   (mapi_func) glUniform4ui,
   (mapi_func) glUniform4ui64ARB,
   (mapi_func) glUniform4ui64NV,
   (mapi_func) glUniform4ui64vARB,
   (mapi_func) glUniform4ui64vNV,
   (mapi_func) glUniform4uiEXT,
   (mapi_func) glUniform4uiv,
   (mapi_func) glUniform4uivEXT,
   (mapi_func) glUniformBlockBinding,
   (mapi_func) glUniformBufferEXT,
   (mapi_func) glUniformHandleui64ARB,
   (mapi_func) glUniformHandleui64IMG,
   (mapi_func) glUniformHandleui64NV,
   (mapi_func) glUniformHandleui64vARB,
   (mapi_func) glUniformHandleui64vIMG,
   (mapi_func) glUniformHandleui64vNV,
   (mapi_func) glUniformMatrix2dv,
   (mapi_func) glUniformMatrix2fv,
   (mapi_func) glUniformMatrix2fvARB,
   (mapi_func) glUniformMatrix2x3dv,
   (mapi_func) glUniformMatrix2x3fv,
   (mapi_func) glUniformMatrix2x3fvNV,
   (mapi_func) glUniformMatrix2x4dv,
   (mapi_func) glUniformMatrix2x4fv,
   (mapi_func) glUniformMatrix2x4fvNV,
   (mapi_func) glUniformMatrix3dv,
   (mapi_func) glUniformMatrix3fv,
   (mapi_func) glUniformMatrix3fvARB,
   (mapi_func) glUniformMatrix3x2dv,
   (mapi_func) glUniformMatrix3x2fv,
   (mapi_func) glUniformMatrix3x2fvNV,
   (mapi_func) glUniformMatrix3x4dv,
   (mapi_func) glUniformMatrix3x4fv,
   (mapi_func) glUniformMatrix3x4fvNV,
   (mapi_func) glUniformMatrix4dv,
   (mapi_func) glUniformMatrix4fv,
   (mapi_func) glUniformMatrix4fvARB,
   (mapi_func) glUniformMatrix4x2dv,
   (mapi_func) glUniformMatrix4x2fv,
   (mapi_func) glUniformMatrix4x2fvNV,
   (mapi_func) glUniformMatrix4x3dv,
   (mapi_func) glUniformMatrix4x3fv,
   (mapi_func) glUniformMatrix4x3fvNV,
   (mapi_func) glUniformSubroutinesuiv,
   (mapi_func) glUniformui64NV,
   (mapi_func) glUniformui64vNV,
   (mapi_func) glUnlockArraysEXT,
   (mapi_func) glUnmapBuffer,
   (mapi_func) glUnmapBufferARB,
   (mapi_func) glUnmapBufferOES,
   (mapi_func) glUnmapNamedBuffer,
   (mapi_func) glUnmapNamedBufferEXT,
   (mapi_func) glUnmapObjectBufferATI,
   (mapi_func) glUnmapTexture2DINTEL,
   (mapi_func) glUpdateObjectBufferATI,
   (mapi_func) glUploadGpuMaskNVX,
   (mapi_func) glUseProgram,
   (mapi_func) glUseProgramObjectARB,
   (mapi_func) glUseProgramStages,
   (mapi_func) glUseProgramStagesEXT,
   (mapi_func) glUseShaderProgramEXT,
   (mapi_func) glVDPAUFiniNV,
   (mapi_func) glVDPAUGetSurfaceivNV,
   (mapi_func) glVDPAUInitNV,
   (mapi_func) glVDPAUIsSurfaceNV,
   (mapi_func) glVDPAUMapSurfacesNV,
   (mapi_func) glVDPAURegisterOutputSurfaceNV,
   (mapi_func) glVDPAURegisterVideoSurfaceNV,
   (mapi_func) glVDPAURegisterVideoSurfaceWithPictureStructureNV,
   (mapi_func) glVDPAUSurfaceAccessNV,
   (mapi_func) glVDPAUUnmapSurfacesNV,
   (mapi_func) glVDPAUUnregisterSurfaceNV,
   (mapi_func) glValidBackBufferHintAutodesk,
   (mapi_func) glValidateProgram,
   (mapi_func) glValidateProgramARB,
   (mapi_func) glValidateProgramPipeline,
   (mapi_func) glValidateProgramPipelineEXT,
   (mapi_func) glVariantArrayObjectATI,
   (mapi_func) glVariantPointerEXT,
   (mapi_func) glVariantbvEXT,
   (mapi_func) glVariantdvEXT,
   (mapi_func) glVariantfvEXT,
   (mapi_func) glVariantivEXT,
   (mapi_func) glVariantsvEXT,
   (mapi_func) glVariantubvEXT,
   (mapi_func) glVariantuivEXT,
   (mapi_func) glVariantusvEXT,
   (mapi_func) glVertex2bOES,
   (mapi_func) glVertex2bvOES,
   (mapi_func) glVertex2d,
   (mapi_func) glVertex2dv,
   (mapi_func) glVertex2f,
   (mapi_func) glVertex2fv,
   (mapi_func) glVertex2hNV,
   (mapi_func) glVertex2hvNV,
   (mapi_func) glVertex2i,
   (mapi_func) glVertex2iv,
   (mapi_func) glVertex2s,
   (mapi_func) glVertex2sv,
   (mapi_func) glVertex2xOES,
   (mapi_func) glVertex2xvOES,
   (mapi_func) glVertex3bOES,
   (mapi_func) glVertex3bvOES,
   (mapi_func) glVertex3d,
   (mapi_func) glVertex3dv,
   (mapi_func) glVertex3f,
   (mapi_func) glVertex3fv,
   (mapi_func) glVertex3hNV,
   (mapi_func) glVertex3hvNV,
   (mapi_func) glVertex3i,
   (mapi_func) glVertex3iv,
   (mapi_func) glVertex3s,
   (mapi_func) glVertex3sv,
   (mapi_func) glVertex3xOES,
   (mapi_func) glVertex3xvOES,
   (mapi_func) glVertex4bOES,
   (mapi_func) glVertex4bvOES,
   (mapi_func) glVertex4d,
   (mapi_func) glVertex4dv,
   (mapi_func) glVertex4f,
   (mapi_func) glVertex4fv,
   (mapi_func) glVertex4hNV,
   (mapi_func) glVertex4hvNV,
   (mapi_func) glVertex4i,
   (mapi_func) glVertex4iv,
   (mapi_func) glVertex4s,
   (mapi_func) glVertex4sv,
   (mapi_func) glVertex4xOES,
   (mapi_func) glVertex4xvOES,
   (mapi_func) glVertexArrayAttribBinding,
   (mapi_func) glVertexArrayAttribFormat,
   (mapi_func) glVertexArrayAttribIFormat,
   (mapi_func) glVertexArrayAttribLFormat,
   (mapi_func) glVertexArrayBindVertexBufferEXT,
   (mapi_func) glVertexArrayBindingDivisor,
   (mapi_func) glVertexArrayColorOffsetEXT,
   (mapi_func) glVertexArrayEdgeFlagOffsetEXT,
   (mapi_func) glVertexArrayElementBuffer,
   (mapi_func) glVertexArrayFogCoordOffsetEXT,
   (mapi_func) glVertexArrayIndexOffsetEXT,
   (mapi_func) glVertexArrayMultiTexCoordOffsetEXT,
   (mapi_func) glVertexArrayNormalOffsetEXT,
   (mapi_func) glVertexArrayParameteriAPPLE,
   (mapi_func) glVertexArrayRangeAPPLE,
   (mapi_func) glVertexArrayRangeNV,
   (mapi_func) glVertexArraySecondaryColorOffsetEXT,
   (mapi_func) glVertexArrayTexCoordOffsetEXT,
   (mapi_func) glVertexArrayVertexAttribBindingEXT,
   (mapi_func) glVertexArrayVertexAttribDivisorEXT,
   (mapi_func) glVertexArrayVertexAttribFormatEXT,
   (mapi_func) glVertexArrayVertexAttribIFormatEXT,
   (mapi_func) glVertexArrayVertexAttribIOffsetEXT,
   (mapi_func) glVertexArrayVertexAttribLFormatEXT,
   (mapi_func) glVertexArrayVertexAttribLOffsetEXT,
   (mapi_func) glVertexArrayVertexAttribOffsetEXT,
   (mapi_func) glVertexArrayVertexBindingDivisorEXT,
   (mapi_func) glVertexArrayVertexBuffer,
   (mapi_func) glVertexArrayVertexBuffers,
   (mapi_func) glVertexArrayVertexOffsetEXT,
   (mapi_func) glVertexAttrib1d,
   (mapi_func) glVertexAttrib1dARB,
   (mapi_func) glVertexAttrib1dNV,
   (mapi_func) glVertexAttrib1dv,
   (mapi_func) glVertexAttrib1dvARB,
   (mapi_func) glVertexAttrib1dvNV,
   (mapi_func) glVertexAttrib1f,
   (mapi_func) glVertexAttrib1fARB,
   (mapi_func) glVertexAttrib1fNV,
   (mapi_func) glVertexAttrib1fv,
   (mapi_func) glVertexAttrib1fvARB,
   (mapi_func) glVertexAttrib1fvNV,
   (mapi_func) glVertexAttrib1hNV,
   (mapi_func) glVertexAttrib1hvNV,
   (mapi_func) glVertexAttrib1s,
   (mapi_func) glVertexAttrib1sARB,
   (mapi_func) glVertexAttrib1sNV,
   (mapi_func) glVertexAttrib1sv,
   (mapi_func) glVertexAttrib1svARB,
   (mapi_func) glVertexAttrib1svNV,
   (mapi_func) glVertexAttrib2d,
   (mapi_func) glVertexAttrib2dARB,
   (mapi_func) glVertexAttrib2dNV,
   (mapi_func) glVertexAttrib2dv,
   (mapi_func) glVertexAttrib2dvARB,
   (mapi_func) glVertexAttrib2dvNV,
   (mapi_func) glVertexAttrib2f,
   (mapi_func) glVertexAttrib2fARB,
   (mapi_func) glVertexAttrib2fNV,
   (mapi_func) glVertexAttrib2fv,
   (mapi_func) glVertexAttrib2fvARB,
   (mapi_func) glVertexAttrib2fvNV,
   (mapi_func) glVertexAttrib2hNV,
   (mapi_func) glVertexAttrib2hvNV,
   (mapi_func) glVertexAttrib2s,
   (mapi_func) glVertexAttrib2sARB,
   (mapi_func) glVertexAttrib2sNV,
   (mapi_func) glVertexAttrib2sv,
   (mapi_func) glVertexAttrib2svARB,
   (mapi_func) glVertexAttrib2svNV,
   (mapi_func) glVertexAttrib3d,
   (mapi_func) glVertexAttrib3dARB,
   (mapi_func) glVertexAttrib3dNV,
   (mapi_func) glVertexAttrib3dv,
   (mapi_func) glVertexAttrib3dvARB,
   (mapi_func) glVertexAttrib3dvNV,
   (mapi_func) glVertexAttrib3f,
   (mapi_func) glVertexAttrib3fARB,
   (mapi_func) glVertexAttrib3fNV,
   (mapi_func) glVertexAttrib3fv,
   (mapi_func) glVertexAttrib3fvARB,
   (mapi_func) glVertexAttrib3fvNV,
   (mapi_func) glVertexAttrib3hNV,
   (mapi_func) glVertexAttrib3hvNV,
   (mapi_func) glVertexAttrib3s,
   (mapi_func) glVertexAttrib3sARB,
   (mapi_func) glVertexAttrib3sNV,
   (mapi_func) glVertexAttrib3sv,
   (mapi_func) glVertexAttrib3svARB,
   (mapi_func) glVertexAttrib3svNV,
   (mapi_func) glVertexAttrib4Nbv,
   (mapi_func) glVertexAttrib4NbvARB,
   (mapi_func) glVertexAttrib4Niv,
   (mapi_func) glVertexAttrib4NivARB,
   (mapi_func) glVertexAttrib4Nsv,
   (mapi_func) glVertexAttrib4NsvARB,
   (mapi_func) glVertexAttrib4Nub,
   (mapi_func) glVertexAttrib4NubARB,
   (mapi_func) glVertexAttrib4Nubv,
   (mapi_func) glVertexAttrib4NubvARB,
   (mapi_func) glVertexAttrib4Nuiv,
   (mapi_func) glVertexAttrib4NuivARB,
   (mapi_func) glVertexAttrib4Nusv,
   (mapi_func) glVertexAttrib4NusvARB,
   (mapi_func) glVertexAttrib4bv,
   (mapi_func) glVertexAttrib4bvARB,
   (mapi_func) glVertexAttrib4d,
   (mapi_func) glVertexAttrib4dARB,
   (mapi_func) glVertexAttrib4dNV,
   (mapi_func) glVertexAttrib4dv,
   (mapi_func) glVertexAttrib4dvARB,
   (mapi_func) glVertexAttrib4dvNV,
   (mapi_func) glVertexAttrib4f,
   (mapi_func) glVertexAttrib4fARB,
   (mapi_func) glVertexAttrib4fNV,
   (mapi_func) glVertexAttrib4fv,
   (mapi_func) glVertexAttrib4fvARB,
   (mapi_func) glVertexAttrib4fvNV,
   (mapi_func) glVertexAttrib4hNV,
   (mapi_func) glVertexAttrib4hvNV,
   (mapi_func) glVertexAttrib4iv,
   (mapi_func) glVertexAttrib4ivARB,
   (mapi_func) glVertexAttrib4s,
   (mapi_func) glVertexAttrib4sARB,
   (mapi_func) glVertexAttrib4sNV,
   (mapi_func) glVertexAttrib4sv,
   (mapi_func) glVertexAttrib4svARB,
   (mapi_func) glVertexAttrib4svNV,
   (mapi_func) glVertexAttrib4ubNV,
   (mapi_func) glVertexAttrib4ubv,
   (mapi_func) glVertexAttrib4ubvARB,
   (mapi_func) glVertexAttrib4ubvNV,
   (mapi_func) glVertexAttrib4uiv,
   (mapi_func) glVertexAttrib4uivARB,
   (mapi_func) glVertexAttrib4usv,
   (mapi_func) glVertexAttrib4usvARB,
   (mapi_func) glVertexAttribArrayObjectATI,
   (mapi_func) glVertexAttribBinding,
   (mapi_func) glVertexAttribDivisor,
   (mapi_func) glVertexAttribDivisorANGLE,
   (mapi_func) glVertexAttribDivisorARB,
   (mapi_func) glVertexAttribDivisorEXT,
   (mapi_func) glVertexAttribDivisorNV,
   (mapi_func) glVertexAttribFormat,
   (mapi_func) glVertexAttribFormatNV,
   (mapi_func) glVertexAttribI1i,
   (mapi_func) glVertexAttribI1iEXT,
   (mapi_func) glVertexAttribI1iv,
   (mapi_func) glVertexAttribI1ivEXT,
   (mapi_func) glVertexAttribI1ui,
   (mapi_func) glVertexAttribI1uiEXT,
   (mapi_func) glVertexAttribI1uiv,
   (mapi_func) glVertexAttribI1uivEXT,
   (mapi_func) glVertexAttribI2i,
   (mapi_func) glVertexAttribI2iEXT,
   (mapi_func) glVertexAttribI2iv,
   (mapi_func) glVertexAttribI2ivEXT,
   (mapi_func) glVertexAttribI2ui,
   (mapi_func) glVertexAttribI2uiEXT,
   (mapi_func) glVertexAttribI2uiv,
   (mapi_func) glVertexAttribI2uivEXT,
   (mapi_func) glVertexAttribI3i,
   (mapi_func) glVertexAttribI3iEXT,
   (mapi_func) glVertexAttribI3iv,
   (mapi_func) glVertexAttribI3ivEXT,
   (mapi_func) glVertexAttribI3ui,
   (mapi_func) glVertexAttribI3uiEXT,
   (mapi_func) glVertexAttribI3uiv,
   (mapi_func) glVertexAttribI3uivEXT,
   (mapi_func) glVertexAttribI4bv,
   (mapi_func) glVertexAttribI4bvEXT,
   (mapi_func) glVertexAttribI4i,
   (mapi_func) glVertexAttribI4iEXT,
   (mapi_func) glVertexAttribI4iv,
   (mapi_func) glVertexAttribI4ivEXT,
   (mapi_func) glVertexAttribI4sv,
   (mapi_func) glVertexAttribI4svEXT,
   (mapi_func) glVertexAttribI4ubv,
   (mapi_func) glVertexAttribI4ubvEXT,
   (mapi_func) glVertexAttribI4ui,
   (mapi_func) glVertexAttribI4uiEXT,
   (mapi_func) glVertexAttribI4uiv,
   (mapi_func) glVertexAttribI4uivEXT,
   (mapi_func) glVertexAttribI4usv,
   (mapi_func) glVertexAttribI4usvEXT,
   (mapi_func) glVertexAttribIFormat,
   (mapi_func) glVertexAttribIFormatNV,
   (mapi_func) glVertexAttribIPointer,
   (mapi_func) glVertexAttribIPointerEXT,
   (mapi_func) glVertexAttribL1d,
   (mapi_func) glVertexAttribL1dEXT,
   (mapi_func) glVertexAttribL1dv,
   (mapi_func) glVertexAttribL1dvEXT,
   (mapi_func) glVertexAttribL1i64NV,
   (mapi_func) glVertexAttribL1i64vNV,
   (mapi_func) glVertexAttribL1ui64ARB,
   (mapi_func) glVertexAttribL1ui64NV,
   (mapi_func) glVertexAttribL1ui64vARB,
   (mapi_func) glVertexAttribL1ui64vNV,
   (mapi_func) glVertexAttribL2d,
   (mapi_func) glVertexAttribL2dEXT,
   (mapi_func) glVertexAttribL2dv,
   (mapi_func) glVertexAttribL2dvEXT,
   (mapi_func) glVertexAttribL2i64NV,
   (mapi_func) glVertexAttribL2i64vNV,
   (mapi_func) glVertexAttribL2ui64NV,
   (mapi_func) glVertexAttribL2ui64vNV,
   (mapi_func) glVertexAttribL3d,
   (mapi_func) glVertexAttribL3dEXT,
   (mapi_func) glVertexAttribL3dv,
   (mapi_func) glVertexAttribL3dvEXT,
   (mapi_func) glVertexAttribL3i64NV,
   (mapi_func) glVertexAttribL3i64vNV,
   (mapi_func) glVertexAttribL3ui64NV,
   (mapi_func) glVertexAttribL3ui64vNV,
   (mapi_func) glVertexAttribL4d,
   (mapi_func) glVertexAttribL4dEXT,
   (mapi_func) glVertexAttribL4dv,
   (mapi_func) glVertexAttribL4dvEXT,
   (mapi_func) glVertexAttribL4i64NV,
   (mapi_func) glVertexAttribL4i64vNV,
   (mapi_func) glVertexAttribL4ui64NV,
   (mapi_func) glVertexAttribL4ui64vNV,
   (mapi_func) glVertexAttribLFormat,
   (mapi_func) glVertexAttribLFormatNV,
   (mapi_func) glVertexAttribLPointer,
   (mapi_func) glVertexAttribLPointerEXT,
   (mapi_func) glVertexAttribP1ui,
   (mapi_func) glVertexAttribP1uiv,
   (mapi_func) glVertexAttribP2ui,
   (mapi_func) glVertexAttribP2uiv,
   (mapi_func) glVertexAttribP3ui,
   (mapi_func) glVertexAttribP3uiv,
   (mapi_func) glVertexAttribP4ui,
   (mapi_func) glVertexAttribP4uiv,
   (mapi_func) glVertexAttribParameteriAMD,
   (mapi_func) glVertexAttribPointer,
   (mapi_func) glVertexAttribPointerARB,
   (mapi_func) glVertexAttribPointerNV,
   (mapi_func) glVertexAttribs1dvNV,
   (mapi_func) glVertexAttribs1fvNV,
   (mapi_func) glVertexAttribs1hvNV,
   (mapi_func) glVertexAttribs1svNV,
   (mapi_func) glVertexAttribs2dvNV,
   (mapi_func) glVertexAttribs2fvNV,
   (mapi_func) glVertexAttribs2hvNV,
   (mapi_func) glVertexAttribs2svNV,
   (mapi_func) glVertexAttribs3dvNV,
   (mapi_func) glVertexAttribs3fvNV,
   (mapi_func) glVertexAttribs3hvNV,
   (mapi_func) glVertexAttribs3svNV,
   (mapi_func) glVertexAttribs4dvNV,
   (mapi_func) glVertexAttribs4fvNV,
   (mapi_func) glVertexAttribs4hvNV,
   (mapi_func) glVertexAttribs4svNV,
   (mapi_func) glVertexAttribs4ubvNV,
   (mapi_func) glVertexBindingDivisor,
   (mapi_func) glVertexBlendARB,
   (mapi_func) glVertexBlendEnvfATI,
   (mapi_func) glVertexBlendEnviATI,
   (mapi_func) glVertexFormatNV,
   (mapi_func) glVertexP2ui,
   (mapi_func) glVertexP2uiv,
   (mapi_func) glVertexP3ui,
   (mapi_func) glVertexP3uiv,
   (mapi_func) glVertexP4ui,
   (mapi_func) glVertexP4uiv,
   (mapi_func) glVertexPointer,
   (mapi_func) glVertexPointerEXT,
   (mapi_func) glVertexPointerListIBM,
   (mapi_func) glVertexPointervINTEL,
   (mapi_func) glVertexStream1dATI,
   (mapi_func) glVertexStream1dvATI,
   (mapi_func) glVertexStream1fATI,
   (mapi_func) glVertexStream1fvATI,
   (mapi_func) glVertexStream1iATI,
   (mapi_func) glVertexStream1ivATI,
   (mapi_func) glVertexStream1sATI,
   (mapi_func) glVertexStream1svATI,
   (mapi_func) glVertexStream2dATI,
   (mapi_func) glVertexStream2dvATI,
   (mapi_func) glVertexStream2fATI,
   (mapi_func) glVertexStream2fvATI,
   (mapi_func) glVertexStream2iATI,
   (mapi_func) glVertexStream2ivATI,
   (mapi_func) glVertexStream2sATI,
   (mapi_func) glVertexStream2svATI,
   (mapi_func) glVertexStream3dATI,
   (mapi_func) glVertexStream3dvATI,
   (mapi_func) glVertexStream3fATI,
   (mapi_func) glVertexStream3fvATI,
   (mapi_func) glVertexStream3iATI,
   (mapi_func) glVertexStream3ivATI,
   (mapi_func) glVertexStream3sATI,
   (mapi_func) glVertexStream3svATI,
   (mapi_func) glVertexStream4dATI,
   (mapi_func) glVertexStream4dvATI,
   (mapi_func) glVertexStream4fATI,
   (mapi_func) glVertexStream4fvATI,
   (mapi_func) glVertexStream4iATI,
   (mapi_func) glVertexStream4ivATI,
   (mapi_func) glVertexStream4sATI,
   (mapi_func) glVertexStream4svATI,
   (mapi_func) glVertexWeightPointerEXT,
   (mapi_func) glVertexWeightfEXT,
   (mapi_func) glVertexWeightfvEXT,
   (mapi_func) glVertexWeighthNV,
   (mapi_func) glVertexWeighthvNV,
   (mapi_func) glVideoCaptureNV,
   (mapi_func) glVideoCaptureStreamParameterdvNV,
   (mapi_func) glVideoCaptureStreamParameterfvNV,
   (mapi_func) glVideoCaptureStreamParameterivNV,
   (mapi_func) glViewport,
   (mapi_func) glViewportArrayv,
   (mapi_func) glViewportArrayvNV,
   (mapi_func) glViewportArrayvOES,
   (mapi_func) glViewportIndexedf,
   (mapi_func) glViewportIndexedfNV,
   (mapi_func) glViewportIndexedfOES,
   (mapi_func) glViewportIndexedfv,
   (mapi_func) glViewportIndexedfvNV,
   (mapi_func) glViewportIndexedfvOES,
   (mapi_func) glViewportPositionWScaleNV,
   (mapi_func) glViewportSwizzleNV,
   (mapi_func) glWaitSemaphoreEXT,
   (mapi_func) glWaitSemaphoreui64NVX,
   (mapi_func) glWaitSync,
   (mapi_func) glWaitSyncAPPLE,
   (mapi_func) glWaitSyncValueuiNVX,
   (mapi_func) glWaitVkSemaphoreNV,
   (mapi_func) glWeightPathsNV,
   (mapi_func) glWeightPointerARB,
   (mapi_func) glWeightPointerOES,
   (mapi_func) glWeightbvARB,
   (mapi_func) glWeightdvARB,
   (mapi_func) glWeightfvARB,
   (mapi_func) glWeightivARB,
   (mapi_func) glWeightsvARB,
   (mapi_func) glWeightubvARB,
   (mapi_func) glWeightuivARB,
   (mapi_func) glWeightusvARB,
   (mapi_func) glWindowBackBufferHintAutodesk,
   (mapi_func) glWindowPos2d,
   (mapi_func) glWindowPos2dARB,
   (mapi_func) glWindowPos2dMESA,
   (mapi_func) glWindowPos2dv,
   (mapi_func) glWindowPos2dvARB,
   (mapi_func) glWindowPos2dvMESA,
   (mapi_func) glWindowPos2f,
   (mapi_func) glWindowPos2fARB,
   (mapi_func) glWindowPos2fMESA,
   (mapi_func) glWindowPos2fv,
   (mapi_func) glWindowPos2fvARB,
   (mapi_func) glWindowPos2fvMESA,
   (mapi_func) glWindowPos2i,
   (mapi_func) glWindowPos2iARB,
   (mapi_func) glWindowPos2iMESA,
   (mapi_func) glWindowPos2iv,
   (mapi_func) glWindowPos2ivARB,
   (mapi_func) glWindowPos2ivMESA,
   (mapi_func) glWindowPos2s,
   (mapi_func) glWindowPos2sARB,
   (mapi_func) glWindowPos2sMESA,
   (mapi_func) glWindowPos2sv,
   (mapi_func) glWindowPos2svARB,
   (mapi_func) glWindowPos2svMESA,
   (mapi_func) glWindowPos3d,
   (mapi_func) glWindowPos3dARB,
   (mapi_func) glWindowPos3dMESA,
   (mapi_func) glWindowPos3dv,
   (mapi_func) glWindowPos3dvARB,
   (mapi_func) glWindowPos3dvMESA,
   (mapi_func) glWindowPos3f,
   (mapi_func) glWindowPos3fARB,
   (mapi_func) glWindowPos3fMESA,
   (mapi_func) glWindowPos3fv,
   (mapi_func) glWindowPos3fvARB,
   (mapi_func) glWindowPos3fvMESA,
   (mapi_func) glWindowPos3i,
   (mapi_func) glWindowPos3iARB,
   (mapi_func) glWindowPos3iMESA,
   (mapi_func) glWindowPos3iv,
   (mapi_func) glWindowPos3ivARB,
   (mapi_func) glWindowPos3ivMESA,
   (mapi_func) glWindowPos3s,
   (mapi_func) glWindowPos3sARB,
   (mapi_func) glWindowPos3sMESA,
   (mapi_func) glWindowPos3sv,
   (mapi_func) glWindowPos3svARB,
   (mapi_func) glWindowPos3svMESA,
   (mapi_func) glWindowPos4dMESA,
   (mapi_func) glWindowPos4dvMESA,
   (mapi_func) glWindowPos4fMESA,
   (mapi_func) glWindowPos4fvMESA,
   (mapi_func) glWindowPos4iMESA,
   (mapi_func) glWindowPos4ivMESA,
   (mapi_func) glWindowPos4sMESA,
   (mapi_func) glWindowPos4svMESA,
   (mapi_func) glWindowRectanglesEXT,
   (mapi_func) glWriteMaskEXT,
};
#undef MAPI_TMP_PUBLIC_ENTRIES
#endif /* MAPI_TMP_PUBLIC_ENTRIES */

#ifdef MAPI_TMP_STUB_ASM_GCC
__asm__(
STUB_ASM_ENTRY("glAccum")"\n"
"\t"STUB_ASM_CODE("0")"\n"

STUB_ASM_ENTRY("glAccumxOES")"\n"
"\t"STUB_ASM_CODE("1")"\n"

STUB_ASM_ENTRY("glAcquireKeyedMutexWin32EXT")"\n"
"\t"STUB_ASM_CODE("2")"\n"

STUB_ASM_ENTRY("glActiveProgramEXT")"\n"
"\t"STUB_ASM_CODE("3")"\n"

STUB_ASM_ENTRY("glActiveShaderProgram")"\n"
"\t"STUB_ASM_CODE("4")"\n"

STUB_ASM_ENTRY("glActiveShaderProgramEXT")"\n"
"\t"STUB_ASM_CODE("5")"\n"

STUB_ASM_ENTRY("glActiveStencilFaceEXT")"\n"
"\t"STUB_ASM_CODE("6")"\n"

STUB_ASM_ENTRY("glActiveTexture")"\n"
"\t"STUB_ASM_CODE("7")"\n"

STUB_ASM_ENTRY("glActiveTextureARB")"\n"
"\t"STUB_ASM_CODE("8")"\n"

STUB_ASM_ENTRY("glActiveVaryingNV")"\n"
"\t"STUB_ASM_CODE("9")"\n"

STUB_ASM_ENTRY("glAlphaFragmentOp1ATI")"\n"
"\t"STUB_ASM_CODE("10")"\n"

STUB_ASM_ENTRY("glAlphaFragmentOp2ATI")"\n"
"\t"STUB_ASM_CODE("11")"\n"

STUB_ASM_ENTRY("glAlphaFragmentOp3ATI")"\n"
"\t"STUB_ASM_CODE("12")"\n"

STUB_ASM_ENTRY("glAlphaFunc")"\n"
"\t"STUB_ASM_CODE("13")"\n"

STUB_ASM_ENTRY("glAlphaFuncQCOM")"\n"
"\t"STUB_ASM_CODE("14")"\n"

STUB_ASM_ENTRY("glAlphaFuncx")"\n"
"\t"STUB_ASM_CODE("15")"\n"

STUB_ASM_ENTRY("glAlphaFuncxOES")"\n"
"\t"STUB_ASM_CODE("16")"\n"

STUB_ASM_ENTRY("glAlphaToCoverageDitherControlNV")"\n"
"\t"STUB_ASM_CODE("17")"\n"

STUB_ASM_ENTRY("glApplyFramebufferAttachmentCMAAINTEL")"\n"
"\t"STUB_ASM_CODE("18")"\n"

STUB_ASM_ENTRY("glApplyTextureEXT")"\n"
"\t"STUB_ASM_CODE("19")"\n"

STUB_ASM_ENTRY("glAreProgramsResidentNV")"\n"
"\t"STUB_ASM_CODE("20")"\n"

STUB_ASM_ENTRY("glAreTexturesResident")"\n"
"\t"STUB_ASM_CODE("21")"\n"

STUB_ASM_ENTRY("glAreTexturesResidentEXT")"\n"
"\t"STUB_ASM_CODE("22")"\n"

STUB_ASM_ENTRY("glArrayElement")"\n"
"\t"STUB_ASM_CODE("23")"\n"

STUB_ASM_ENTRY("glArrayElementEXT")"\n"
"\t"STUB_ASM_CODE("24")"\n"

STUB_ASM_ENTRY("glArrayObjectATI")"\n"
"\t"STUB_ASM_CODE("25")"\n"

STUB_ASM_ENTRY("glAsyncCopyBufferSubDataNVX")"\n"
"\t"STUB_ASM_CODE("26")"\n"

STUB_ASM_ENTRY("glAsyncCopyImageSubDataNVX")"\n"
"\t"STUB_ASM_CODE("27")"\n"

STUB_ASM_ENTRY("glAsyncMarkerSGIX")"\n"
"\t"STUB_ASM_CODE("28")"\n"

STUB_ASM_ENTRY("glAttachObjectARB")"\n"
"\t"STUB_ASM_CODE("29")"\n"

STUB_ASM_ENTRY("glAttachShader")"\n"
"\t"STUB_ASM_CODE("30")"\n"

STUB_ASM_ENTRY("glBegin")"\n"
"\t"STUB_ASM_CODE("31")"\n"

STUB_ASM_ENTRY("glBeginConditionalRender")"\n"
"\t"STUB_ASM_CODE("32")"\n"

STUB_ASM_ENTRY("glBeginConditionalRenderNV")"\n"
"\t"STUB_ASM_CODE("33")"\n"

STUB_ASM_ENTRY("glBeginConditionalRenderNVX")"\n"
"\t"STUB_ASM_CODE("34")"\n"

STUB_ASM_ENTRY("glBeginFragmentShaderATI")"\n"
"\t"STUB_ASM_CODE("35")"\n"

STUB_ASM_ENTRY("glBeginOcclusionQueryNV")"\n"
"\t"STUB_ASM_CODE("36")"\n"

STUB_ASM_ENTRY("glBeginPerfMonitorAMD")"\n"
"\t"STUB_ASM_CODE("37")"\n"

STUB_ASM_ENTRY("glBeginPerfQueryINTEL")"\n"
"\t"STUB_ASM_CODE("38")"\n"

STUB_ASM_ENTRY("glBeginQuery")"\n"
"\t"STUB_ASM_CODE("39")"\n"

STUB_ASM_ENTRY("glBeginQueryARB")"\n"
"\t"STUB_ASM_CODE("40")"\n"

STUB_ASM_ENTRY("glBeginQueryEXT")"\n"
"\t"STUB_ASM_CODE("41")"\n"

STUB_ASM_ENTRY("glBeginQueryIndexed")"\n"
"\t"STUB_ASM_CODE("42")"\n"

STUB_ASM_ENTRY("glBeginTransformFeedback")"\n"
"\t"STUB_ASM_CODE("43")"\n"

STUB_ASM_ENTRY("glBeginTransformFeedbackEXT")"\n"
"\t"STUB_ASM_CODE("44")"\n"

STUB_ASM_ENTRY("glBeginTransformFeedbackNV")"\n"
"\t"STUB_ASM_CODE("45")"\n"

STUB_ASM_ENTRY("glBeginVertexShaderEXT")"\n"
"\t"STUB_ASM_CODE("46")"\n"

STUB_ASM_ENTRY("glBeginVideoCaptureNV")"\n"
"\t"STUB_ASM_CODE("47")"\n"

STUB_ASM_ENTRY("glBindANCCaptureStreamBufferNVX")"\n"
"\t"STUB_ASM_CODE("48")"\n"

STUB_ASM_ENTRY("glBindAttribLocation")"\n"
"\t"STUB_ASM_CODE("49")"\n"

STUB_ASM_ENTRY("glBindAttribLocationARB")"\n"
"\t"STUB_ASM_CODE("50")"\n"

STUB_ASM_ENTRY("glBindBuffer")"\n"
"\t"STUB_ASM_CODE("51")"\n"

STUB_ASM_ENTRY("glBindBufferARB")"\n"
"\t"STUB_ASM_CODE("52")"\n"

STUB_ASM_ENTRY("glBindBufferBase")"\n"
"\t"STUB_ASM_CODE("53")"\n"

STUB_ASM_ENTRY("glBindBufferBaseEXT")"\n"
"\t"STUB_ASM_CODE("54")"\n"

STUB_ASM_ENTRY("glBindBufferBaseNV")"\n"
"\t"STUB_ASM_CODE("55")"\n"

STUB_ASM_ENTRY("glBindBufferOffsetEXT")"\n"
"\t"STUB_ASM_CODE("56")"\n"

STUB_ASM_ENTRY("glBindBufferOffsetNV")"\n"
"\t"STUB_ASM_CODE("57")"\n"

STUB_ASM_ENTRY("glBindBufferRange")"\n"
"\t"STUB_ASM_CODE("58")"\n"

STUB_ASM_ENTRY("glBindBufferRangeEXT")"\n"
"\t"STUB_ASM_CODE("59")"\n"

STUB_ASM_ENTRY("glBindBufferRangeNV")"\n"
"\t"STUB_ASM_CODE("60")"\n"

STUB_ASM_ENTRY("glBindBuffersBase")"\n"
"\t"STUB_ASM_CODE("61")"\n"

STUB_ASM_ENTRY("glBindBuffersRange")"\n"
"\t"STUB_ASM_CODE("62")"\n"

STUB_ASM_ENTRY("glBindFragDataLocation")"\n"
"\t"STUB_ASM_CODE("63")"\n"

STUB_ASM_ENTRY("glBindFragDataLocationEXT")"\n"
"\t"STUB_ASM_CODE("64")"\n"

STUB_ASM_ENTRY("glBindFragDataLocationIndexed")"\n"
"\t"STUB_ASM_CODE("65")"\n"

STUB_ASM_ENTRY("glBindFragDataLocationIndexedEXT")"\n"
"\t"STUB_ASM_CODE("66")"\n"

STUB_ASM_ENTRY("glBindFragmentShaderATI")"\n"
"\t"STUB_ASM_CODE("67")"\n"

STUB_ASM_ENTRY("glBindFramebuffer")"\n"
"\t"STUB_ASM_CODE("68")"\n"

STUB_ASM_ENTRY("glBindFramebufferEXT")"\n"
"\t"STUB_ASM_CODE("69")"\n"

STUB_ASM_ENTRY("glBindFramebufferOES")"\n"
"\t"STUB_ASM_CODE("70")"\n"

STUB_ASM_ENTRY("glBindImageTexture")"\n"
"\t"STUB_ASM_CODE("71")"\n"

STUB_ASM_ENTRY("glBindImageTextureEXT")"\n"
"\t"STUB_ASM_CODE("72")"\n"

STUB_ASM_ENTRY("glBindImageTextures")"\n"
"\t"STUB_ASM_CODE("73")"\n"

STUB_ASM_ENTRY("glBindLightParameterEXT")"\n"
"\t"STUB_ASM_CODE("74")"\n"

STUB_ASM_ENTRY("glBindMaterialParameterEXT")"\n"
"\t"STUB_ASM_CODE("75")"\n"

STUB_ASM_ENTRY("glBindMultiTextureEXT")"\n"
"\t"STUB_ASM_CODE("76")"\n"

STUB_ASM_ENTRY("glBindParameterEXT")"\n"
"\t"STUB_ASM_CODE("77")"\n"

STUB_ASM_ENTRY("glBindProgramARB")"\n"
"\t"STUB_ASM_CODE("78")"\n"

STUB_ASM_ENTRY("glBindProgramNV")"\n"
"\t"STUB_ASM_CODE("79")"\n"

STUB_ASM_ENTRY("glBindProgramPipeline")"\n"
"\t"STUB_ASM_CODE("80")"\n"

STUB_ASM_ENTRY("glBindProgramPipelineEXT")"\n"
"\t"STUB_ASM_CODE("81")"\n"

STUB_ASM_ENTRY("glBindRenderbuffer")"\n"
"\t"STUB_ASM_CODE("82")"\n"

STUB_ASM_ENTRY("glBindRenderbufferEXT")"\n"
"\t"STUB_ASM_CODE("83")"\n"

STUB_ASM_ENTRY("glBindRenderbufferOES")"\n"
"\t"STUB_ASM_CODE("84")"\n"

STUB_ASM_ENTRY("glBindSampler")"\n"
"\t"STUB_ASM_CODE("85")"\n"

STUB_ASM_ENTRY("glBindSamplers")"\n"
"\t"STUB_ASM_CODE("86")"\n"

STUB_ASM_ENTRY("glBindShadingRateImageNV")"\n"
"\t"STUB_ASM_CODE("87")"\n"

STUB_ASM_ENTRY("glBindTexGenParameterEXT")"\n"
"\t"STUB_ASM_CODE("88")"\n"

STUB_ASM_ENTRY("glBindTexture")"\n"
"\t"STUB_ASM_CODE("89")"\n"

STUB_ASM_ENTRY("glBindTextureEXT")"\n"
"\t"STUB_ASM_CODE("90")"\n"

STUB_ASM_ENTRY("glBindTextureUnit")"\n"
"\t"STUB_ASM_CODE("91")"\n"

STUB_ASM_ENTRY("glBindTextureUnitParameterEXT")"\n"
"\t"STUB_ASM_CODE("92")"\n"

STUB_ASM_ENTRY("glBindTextures")"\n"
"\t"STUB_ASM_CODE("93")"\n"

STUB_ASM_ENTRY("glBindTransformFeedback")"\n"
"\t"STUB_ASM_CODE("94")"\n"

STUB_ASM_ENTRY("glBindTransformFeedbackEXT")"\n"
"\t"STUB_ASM_CODE("95")"\n"

STUB_ASM_ENTRY("glBindTransformFeedbackNV")"\n"
"\t"STUB_ASM_CODE("96")"\n"

STUB_ASM_ENTRY("glBindVertexArray")"\n"
"\t"STUB_ASM_CODE("97")"\n"

STUB_ASM_ENTRY("glBindVertexArrayAPPLE")"\n"
"\t"STUB_ASM_CODE("98")"\n"

STUB_ASM_ENTRY("glBindVertexArrayOES")"\n"
"\t"STUB_ASM_CODE("99")"\n"

STUB_ASM_ENTRY("glBindVertexBuffer")"\n"
"\t"STUB_ASM_CODE("100")"\n"

STUB_ASM_ENTRY("glBindVertexBuffers")"\n"
"\t"STUB_ASM_CODE("101")"\n"

STUB_ASM_ENTRY("glBindVertexShaderEXT")"\n"
"\t"STUB_ASM_CODE("102")"\n"

STUB_ASM_ENTRY("glBindVideoCaptureStreamBufferNV")"\n"
"\t"STUB_ASM_CODE("103")"\n"

STUB_ASM_ENTRY("glBindVideoCaptureStreamTextureNV")"\n"
"\t"STUB_ASM_CODE("104")"\n"

STUB_ASM_ENTRY("glBinormal3bEXT")"\n"
"\t"STUB_ASM_CODE("105")"\n"

STUB_ASM_ENTRY("glBinormal3bvEXT")"\n"
"\t"STUB_ASM_CODE("106")"\n"

STUB_ASM_ENTRY("glBinormal3dEXT")"\n"
"\t"STUB_ASM_CODE("107")"\n"

STUB_ASM_ENTRY("glBinormal3dvEXT")"\n"
"\t"STUB_ASM_CODE("108")"\n"

STUB_ASM_ENTRY("glBinormal3fEXT")"\n"
"\t"STUB_ASM_CODE("109")"\n"

STUB_ASM_ENTRY("glBinormal3fvEXT")"\n"
"\t"STUB_ASM_CODE("110")"\n"

STUB_ASM_ENTRY("glBinormal3iEXT")"\n"
"\t"STUB_ASM_CODE("111")"\n"

STUB_ASM_ENTRY("glBinormal3ivEXT")"\n"
"\t"STUB_ASM_CODE("112")"\n"

STUB_ASM_ENTRY("glBinormal3sEXT")"\n"
"\t"STUB_ASM_CODE("113")"\n"

STUB_ASM_ENTRY("glBinormal3svEXT")"\n"
"\t"STUB_ASM_CODE("114")"\n"

STUB_ASM_ENTRY("glBinormalPointerEXT")"\n"
"\t"STUB_ASM_CODE("115")"\n"

STUB_ASM_ENTRY("glBitmap")"\n"
"\t"STUB_ASM_CODE("116")"\n"

STUB_ASM_ENTRY("glBitmapxOES")"\n"
"\t"STUB_ASM_CODE("117")"\n"

STUB_ASM_ENTRY("glBlendBarrier")"\n"
"\t"STUB_ASM_CODE("118")"\n"

STUB_ASM_ENTRY("glBlendBarrierKHR")"\n"
"\t"STUB_ASM_CODE("119")"\n"

STUB_ASM_ENTRY("glBlendBarrierNV")"\n"
"\t"STUB_ASM_CODE("120")"\n"

STUB_ASM_ENTRY("glBlendColor")"\n"
"\t"STUB_ASM_CODE("121")"\n"

STUB_ASM_ENTRY("glBlendColorEXT")"\n"
"\t"STUB_ASM_CODE("122")"\n"

STUB_ASM_ENTRY("glBlendColorxOES")"\n"
"\t"STUB_ASM_CODE("123")"\n"

STUB_ASM_ENTRY("glBlendEquation")"\n"
"\t"STUB_ASM_CODE("124")"\n"

STUB_ASM_ENTRY("glBlendEquationEXT")"\n"
"\t"STUB_ASM_CODE("125")"\n"

STUB_ASM_ENTRY("glBlendEquationIndexedAMD")"\n"
"\t"STUB_ASM_CODE("126")"\n"

STUB_ASM_ENTRY("glBlendEquationOES")"\n"
"\t"STUB_ASM_CODE("127")"\n"

STUB_ASM_ENTRY("glBlendEquationSeparate")"\n"
"\t"STUB_ASM_CODE("128")"\n"

STUB_ASM_ENTRY("glBlendEquationSeparateEXT")"\n"
"\t"STUB_ASM_CODE("129")"\n"

STUB_ASM_ENTRY("glBlendEquationSeparateIndexedAMD")"\n"
"\t"STUB_ASM_CODE("130")"\n"

STUB_ASM_ENTRY("glBlendEquationSeparateOES")"\n"
"\t"STUB_ASM_CODE("131")"\n"

STUB_ASM_ENTRY("glBlendEquationSeparatei")"\n"
"\t"STUB_ASM_CODE("132")"\n"

STUB_ASM_ENTRY("glBlendEquationSeparateiARB")"\n"
"\t"STUB_ASM_CODE("133")"\n"

STUB_ASM_ENTRY("glBlendEquationSeparateiEXT")"\n"
"\t"STUB_ASM_CODE("134")"\n"

STUB_ASM_ENTRY("glBlendEquationSeparateiOES")"\n"
"\t"STUB_ASM_CODE("135")"\n"

STUB_ASM_ENTRY("glBlendEquationi")"\n"
"\t"STUB_ASM_CODE("136")"\n"

STUB_ASM_ENTRY("glBlendEquationiARB")"\n"
"\t"STUB_ASM_CODE("137")"\n"

STUB_ASM_ENTRY("glBlendEquationiEXT")"\n"
"\t"STUB_ASM_CODE("138")"\n"

STUB_ASM_ENTRY("glBlendEquationiOES")"\n"
"\t"STUB_ASM_CODE("139")"\n"

STUB_ASM_ENTRY("glBlendFunc")"\n"
"\t"STUB_ASM_CODE("140")"\n"

STUB_ASM_ENTRY("glBlendFuncIndexedAMD")"\n"
"\t"STUB_ASM_CODE("141")"\n"

STUB_ASM_ENTRY("glBlendFuncSeparate")"\n"
"\t"STUB_ASM_CODE("142")"\n"

STUB_ASM_ENTRY("glBlendFuncSeparateEXT")"\n"
"\t"STUB_ASM_CODE("143")"\n"

STUB_ASM_ENTRY("glBlendFuncSeparateINGR")"\n"
"\t"STUB_ASM_CODE("144")"\n"

STUB_ASM_ENTRY("glBlendFuncSeparateIndexedAMD")"\n"
"\t"STUB_ASM_CODE("145")"\n"

STUB_ASM_ENTRY("glBlendFuncSeparateOES")"\n"
"\t"STUB_ASM_CODE("146")"\n"

STUB_ASM_ENTRY("glBlendFuncSeparatei")"\n"
"\t"STUB_ASM_CODE("147")"\n"

STUB_ASM_ENTRY("glBlendFuncSeparateiARB")"\n"
"\t"STUB_ASM_CODE("148")"\n"

STUB_ASM_ENTRY("glBlendFuncSeparateiEXT")"\n"
"\t"STUB_ASM_CODE("149")"\n"

STUB_ASM_ENTRY("glBlendFuncSeparateiOES")"\n"
"\t"STUB_ASM_CODE("150")"\n"

STUB_ASM_ENTRY("glBlendFunci")"\n"
"\t"STUB_ASM_CODE("151")"\n"

STUB_ASM_ENTRY("glBlendFunciARB")"\n"
"\t"STUB_ASM_CODE("152")"\n"

STUB_ASM_ENTRY("glBlendFunciEXT")"\n"
"\t"STUB_ASM_CODE("153")"\n"

STUB_ASM_ENTRY("glBlendFunciOES")"\n"
"\t"STUB_ASM_CODE("154")"\n"

STUB_ASM_ENTRY("glBlendParameteriNV")"\n"
"\t"STUB_ASM_CODE("155")"\n"

STUB_ASM_ENTRY("glBlitFramebuffer")"\n"
"\t"STUB_ASM_CODE("156")"\n"

STUB_ASM_ENTRY("glBlitFramebufferANGLE")"\n"
"\t"STUB_ASM_CODE("157")"\n"

STUB_ASM_ENTRY("glBlitFramebufferEXT")"\n"
"\t"STUB_ASM_CODE("158")"\n"

STUB_ASM_ENTRY("glBlitFramebufferNV")"\n"
"\t"STUB_ASM_CODE("159")"\n"

STUB_ASM_ENTRY("glBlitNamedFramebuffer")"\n"
"\t"STUB_ASM_CODE("160")"\n"

STUB_ASM_ENTRY("glBufferAddressRangeNV")"\n"
"\t"STUB_ASM_CODE("161")"\n"

STUB_ASM_ENTRY("glBufferAttachMemoryNV")"\n"
"\t"STUB_ASM_CODE("162")"\n"

STUB_ASM_ENTRY("glBufferData")"\n"
"\t"STUB_ASM_CODE("163")"\n"

STUB_ASM_ENTRY("glBufferDataARB")"\n"
"\t"STUB_ASM_CODE("164")"\n"

STUB_ASM_ENTRY("glBufferDataSysmem")"\n"
"\t"STUB_ASM_CODE("165")"\n"

STUB_ASM_ENTRY("glBufferPageCommitmentARB")"\n"
"\t"STUB_ASM_CODE("166")"\n"

STUB_ASM_ENTRY("glBufferParameteriAPPLE")"\n"
"\t"STUB_ASM_CODE("168")"\n"

STUB_ASM_ENTRY("glBufferStorage")"\n"
"\t"STUB_ASM_CODE("169")"\n"

STUB_ASM_ENTRY("glBufferStorageEXT")"\n"
"\t"STUB_ASM_CODE("170")"\n"

STUB_ASM_ENTRY("glBufferStorageExternalEXT")"\n"
"\t"STUB_ASM_CODE("171")"\n"

STUB_ASM_ENTRY("glBufferStorageMemEXT")"\n"
"\t"STUB_ASM_CODE("172")"\n"

STUB_ASM_ENTRY("glBufferSubData")"\n"
"\t"STUB_ASM_CODE("173")"\n"

STUB_ASM_ENTRY("glBufferSubDataARB")"\n"
"\t"STUB_ASM_CODE("174")"\n"

STUB_ASM_ENTRY("glCallCommandListNV")"\n"
"\t"STUB_ASM_CODE("175")"\n"

STUB_ASM_ENTRY("glCallList")"\n"
"\t"STUB_ASM_CODE("176")"\n"

STUB_ASM_ENTRY("glCallLists")"\n"
"\t"STUB_ASM_CODE("177")"\n"

STUB_ASM_ENTRY("glCheckFramebufferStatus")"\n"
"\t"STUB_ASM_CODE("178")"\n"

STUB_ASM_ENTRY("glCheckFramebufferStatusEXT")"\n"
"\t"STUB_ASM_CODE("179")"\n"

STUB_ASM_ENTRY("glCheckFramebufferStatusOES")"\n"
"\t"STUB_ASM_CODE("180")"\n"

STUB_ASM_ENTRY("glCheckNamedFramebufferStatus")"\n"
"\t"STUB_ASM_CODE("181")"\n"

STUB_ASM_ENTRY("glCheckNamedFramebufferStatusEXT")"\n"
"\t"STUB_ASM_CODE("182")"\n"

STUB_ASM_ENTRY("glClampColor")"\n"
"\t"STUB_ASM_CODE("183")"\n"

STUB_ASM_ENTRY("glClampColorARB")"\n"
"\t"STUB_ASM_CODE("184")"\n"

STUB_ASM_ENTRY("glClear")"\n"
"\t"STUB_ASM_CODE("185")"\n"

STUB_ASM_ENTRY("glClearAccum")"\n"
"\t"STUB_ASM_CODE("186")"\n"

STUB_ASM_ENTRY("glClearAccumxOES")"\n"
"\t"STUB_ASM_CODE("187")"\n"

STUB_ASM_ENTRY("glClearBufferData")"\n"
"\t"STUB_ASM_CODE("188")"\n"

STUB_ASM_ENTRY("glClearBufferSubData")"\n"
"\t"STUB_ASM_CODE("189")"\n"

STUB_ASM_ENTRY("glClearBufferfi")"\n"
"\t"STUB_ASM_CODE("190")"\n"

STUB_ASM_ENTRY("glClearBufferfv")"\n"
"\t"STUB_ASM_CODE("191")"\n"

STUB_ASM_ENTRY("glClearBufferiv")"\n"
"\t"STUB_ASM_CODE("192")"\n"

STUB_ASM_ENTRY("glClearBufferuiv")"\n"
"\t"STUB_ASM_CODE("193")"\n"

STUB_ASM_ENTRY("glClearColor")"\n"
"\t"STUB_ASM_CODE("194")"\n"

STUB_ASM_ENTRY("glClearColorIiEXT")"\n"
"\t"STUB_ASM_CODE("195")"\n"

STUB_ASM_ENTRY("glClearColorIuiEXT")"\n"
"\t"STUB_ASM_CODE("196")"\n"

STUB_ASM_ENTRY("glClearColorx")"\n"
"\t"STUB_ASM_CODE("197")"\n"

STUB_ASM_ENTRY("glClearColorxOES")"\n"
"\t"STUB_ASM_CODE("198")"\n"

STUB_ASM_ENTRY("glClearDepth")"\n"
"\t"STUB_ASM_CODE("199")"\n"

STUB_ASM_ENTRY("glClearDepthdNV")"\n"
"\t"STUB_ASM_CODE("200")"\n"

STUB_ASM_ENTRY("glClearDepthf")"\n"
"\t"STUB_ASM_CODE("201")"\n"

STUB_ASM_ENTRY("glClearDepthfOES")"\n"
"\t"STUB_ASM_CODE("202")"\n"

STUB_ASM_ENTRY("glClearDepthx")"\n"
"\t"STUB_ASM_CODE("203")"\n"

STUB_ASM_ENTRY("glClearDepthxOES")"\n"
"\t"STUB_ASM_CODE("204")"\n"

STUB_ASM_ENTRY("glClearIndex")"\n"
"\t"STUB_ASM_CODE("205")"\n"

STUB_ASM_ENTRY("glClearNamedBufferData")"\n"
"\t"STUB_ASM_CODE("206")"\n"

STUB_ASM_ENTRY("glClearNamedBufferDataEXT")"\n"
"\t"STUB_ASM_CODE("207")"\n"

STUB_ASM_ENTRY("glClearNamedBufferSubData")"\n"
"\t"STUB_ASM_CODE("208")"\n"

STUB_ASM_ENTRY("glClearNamedBufferSubDataEXT")"\n"
"\t"STUB_ASM_CODE("209")"\n"

STUB_ASM_ENTRY("glClearNamedFramebufferfi")"\n"
"\t"STUB_ASM_CODE("210")"\n"

STUB_ASM_ENTRY("glClearNamedFramebufferfv")"\n"
"\t"STUB_ASM_CODE("211")"\n"

STUB_ASM_ENTRY("glClearNamedFramebufferiv")"\n"
"\t"STUB_ASM_CODE("212")"\n"

STUB_ASM_ENTRY("glClearNamedFramebufferuiv")"\n"
"\t"STUB_ASM_CODE("213")"\n"

STUB_ASM_ENTRY("glClearPixelLocalStorageuiEXT")"\n"
"\t"STUB_ASM_CODE("214")"\n"

STUB_ASM_ENTRY("glClearStencil")"\n"
"\t"STUB_ASM_CODE("215")"\n"

STUB_ASM_ENTRY("glClearTexImage")"\n"
"\t"STUB_ASM_CODE("216")"\n"

STUB_ASM_ENTRY("glClearTexImageEXT")"\n"
"\t"STUB_ASM_CODE("217")"\n"

STUB_ASM_ENTRY("glClearTexSubImage")"\n"
"\t"STUB_ASM_CODE("218")"\n"

STUB_ASM_ENTRY("glClearTexSubImageEXT")"\n"
"\t"STUB_ASM_CODE("219")"\n"

STUB_ASM_ENTRY("glClientActiveTexture")"\n"
"\t"STUB_ASM_CODE("220")"\n"

STUB_ASM_ENTRY("glClientActiveTextureARB")"\n"
"\t"STUB_ASM_CODE("221")"\n"

STUB_ASM_ENTRY("glClientActiveVertexStreamATI")"\n"
"\t"STUB_ASM_CODE("222")"\n"

STUB_ASM_ENTRY("glClientAttribDefaultEXT")"\n"
"\t"STUB_ASM_CODE("223")"\n"

STUB_ASM_ENTRY("glClientWaitSemaphoreui64NVX")"\n"
"\t"STUB_ASM_CODE("224")"\n"

STUB_ASM_ENTRY("glClientWaitSync")"\n"
"\t"STUB_ASM_CODE("225")"\n"

STUB_ASM_ENTRY("glClientWaitSyncAPPLE")"\n"
"\t"STUB_ASM_CODE("226")"\n"

STUB_ASM_ENTRY("glClientWaitSyncValueuiNVX")"\n"
"\t"STUB_ASM_CODE("227")"\n"

STUB_ASM_ENTRY("glClipControl")"\n"
"\t"STUB_ASM_CODE("228")"\n"

STUB_ASM_ENTRY("glClipControlEXT")"\n"
"\t"STUB_ASM_CODE("229")"\n"

STUB_ASM_ENTRY("glClipPlane")"\n"
"\t"STUB_ASM_CODE("230")"\n"

STUB_ASM_ENTRY("glClipPlanef")"\n"
"\t"STUB_ASM_CODE("231")"\n"

STUB_ASM_ENTRY("glClipPlanefIMG")"\n"
"\t"STUB_ASM_CODE("232")"\n"

STUB_ASM_ENTRY("glClipPlanefOES")"\n"
"\t"STUB_ASM_CODE("233")"\n"

STUB_ASM_ENTRY("glClipPlanex")"\n"
"\t"STUB_ASM_CODE("234")"\n"

STUB_ASM_ENTRY("glClipPlanexIMG")"\n"
"\t"STUB_ASM_CODE("235")"\n"

STUB_ASM_ENTRY("glClipPlanexOES")"\n"
"\t"STUB_ASM_CODE("236")"\n"

STUB_ASM_ENTRY("glColor3b")"\n"
"\t"STUB_ASM_CODE("237")"\n"

STUB_ASM_ENTRY("glColor3bv")"\n"
"\t"STUB_ASM_CODE("238")"\n"

STUB_ASM_ENTRY("glColor3d")"\n"
"\t"STUB_ASM_CODE("239")"\n"

STUB_ASM_ENTRY("glColor3dv")"\n"
"\t"STUB_ASM_CODE("240")"\n"

STUB_ASM_ENTRY("glColor3f")"\n"
"\t"STUB_ASM_CODE("241")"\n"

STUB_ASM_ENTRY("glColor3fVertex3fSUN")"\n"
"\t"STUB_ASM_CODE("242")"\n"

STUB_ASM_ENTRY("glColor3fVertex3fvSUN")"\n"
"\t"STUB_ASM_CODE("243")"\n"

STUB_ASM_ENTRY("glColor3fv")"\n"
"\t"STUB_ASM_CODE("244")"\n"

STUB_ASM_ENTRY("glColor3hNV")"\n"
"\t"STUB_ASM_CODE("245")"\n"

STUB_ASM_ENTRY("glColor3hvNV")"\n"
"\t"STUB_ASM_CODE("246")"\n"

STUB_ASM_ENTRY("glColor3i")"\n"
"\t"STUB_ASM_CODE("247")"\n"

STUB_ASM_ENTRY("glColor3iv")"\n"
"\t"STUB_ASM_CODE("248")"\n"

STUB_ASM_ENTRY("glColor3s")"\n"
"\t"STUB_ASM_CODE("249")"\n"

STUB_ASM_ENTRY("glColor3sv")"\n"
"\t"STUB_ASM_CODE("250")"\n"

STUB_ASM_ENTRY("glColor3ub")"\n"
"\t"STUB_ASM_CODE("251")"\n"

STUB_ASM_ENTRY("glColor3ubv")"\n"
"\t"STUB_ASM_CODE("252")"\n"

STUB_ASM_ENTRY("glColor3ui")"\n"
"\t"STUB_ASM_CODE("253")"\n"

STUB_ASM_ENTRY("glColor3uiv")"\n"
"\t"STUB_ASM_CODE("254")"\n"

STUB_ASM_ENTRY("glColor3us")"\n"
"\t"STUB_ASM_CODE("255")"\n"

STUB_ASM_ENTRY("glColor3usv")"\n"
"\t"STUB_ASM_CODE("256")"\n"

STUB_ASM_ENTRY("glColor3x")"\n"
"\t"STUB_ASM_CODE("257")"\n"

STUB_ASM_ENTRY("glColor3xOES")"\n"
"\t"STUB_ASM_CODE("258")"\n"

STUB_ASM_ENTRY("glColor3xvOES")"\n"
"\t"STUB_ASM_CODE("259")"\n"

STUB_ASM_ENTRY("glColor4b")"\n"
"\t"STUB_ASM_CODE("260")"\n"

STUB_ASM_ENTRY("glColor4bv")"\n"
"\t"STUB_ASM_CODE("261")"\n"

STUB_ASM_ENTRY("glColor4d")"\n"
"\t"STUB_ASM_CODE("262")"\n"

STUB_ASM_ENTRY("glColor4dv")"\n"
"\t"STUB_ASM_CODE("263")"\n"

STUB_ASM_ENTRY("glColor4f")"\n"
"\t"STUB_ASM_CODE("264")"\n"

STUB_ASM_ENTRY("glColor4fNormal3fVertex3fSUN")"\n"
"\t"STUB_ASM_CODE("265")"\n"

STUB_ASM_ENTRY("glColor4fNormal3fVertex3fvSUN")"\n"
"\t"STUB_ASM_CODE("266")"\n"

STUB_ASM_ENTRY("glColor4fv")"\n"
"\t"STUB_ASM_CODE("267")"\n"

STUB_ASM_ENTRY("glColor4hNV")"\n"
"\t"STUB_ASM_CODE("268")"\n"

STUB_ASM_ENTRY("glColor4hvNV")"\n"
"\t"STUB_ASM_CODE("269")"\n"

STUB_ASM_ENTRY("glColor4i")"\n"
"\t"STUB_ASM_CODE("270")"\n"

STUB_ASM_ENTRY("glColor4iv")"\n"
"\t"STUB_ASM_CODE("271")"\n"

STUB_ASM_ENTRY("glColor4s")"\n"
"\t"STUB_ASM_CODE("272")"\n"

STUB_ASM_ENTRY("glColor4sv")"\n"
"\t"STUB_ASM_CODE("273")"\n"

STUB_ASM_ENTRY("glColor4ub")"\n"
"\t"STUB_ASM_CODE("274")"\n"

STUB_ASM_ENTRY("glColor4ubVertex2fSUN")"\n"
"\t"STUB_ASM_CODE("275")"\n"

STUB_ASM_ENTRY("glColor4ubVertex2fvSUN")"\n"
"\t"STUB_ASM_CODE("276")"\n"

STUB_ASM_ENTRY("glColor4ubVertex3fSUN")"\n"
"\t"STUB_ASM_CODE("277")"\n"

STUB_ASM_ENTRY("glColor4ubVertex3fvSUN")"\n"
"\t"STUB_ASM_CODE("278")"\n"

STUB_ASM_ENTRY("glColor4ubv")"\n"
"\t"STUB_ASM_CODE("279")"\n"

STUB_ASM_ENTRY("glColor4ui")"\n"
"\t"STUB_ASM_CODE("280")"\n"

STUB_ASM_ENTRY("glColor4uiv")"\n"
"\t"STUB_ASM_CODE("281")"\n"

STUB_ASM_ENTRY("glColor4us")"\n"
"\t"STUB_ASM_CODE("282")"\n"

STUB_ASM_ENTRY("glColor4usv")"\n"
"\t"STUB_ASM_CODE("283")"\n"

STUB_ASM_ENTRY("glColor4x")"\n"
"\t"STUB_ASM_CODE("284")"\n"

STUB_ASM_ENTRY("glColor4xOES")"\n"
"\t"STUB_ASM_CODE("285")"\n"

STUB_ASM_ENTRY("glColor4xvOES")"\n"
"\t"STUB_ASM_CODE("286")"\n"

STUB_ASM_ENTRY("glColorFormatNV")"\n"
"\t"STUB_ASM_CODE("287")"\n"

STUB_ASM_ENTRY("glColorFragmentOp1ATI")"\n"
"\t"STUB_ASM_CODE("288")"\n"

STUB_ASM_ENTRY("glColorFragmentOp2ATI")"\n"
"\t"STUB_ASM_CODE("289")"\n"

STUB_ASM_ENTRY("glColorFragmentOp3ATI")"\n"
"\t"STUB_ASM_CODE("290")"\n"

STUB_ASM_ENTRY("glColorMask")"\n"
"\t"STUB_ASM_CODE("291")"\n"

STUB_ASM_ENTRY("glColorMaskIndexedEXT")"\n"
"\t"STUB_ASM_CODE("292")"\n"

STUB_ASM_ENTRY("glColorMaski")"\n"
"\t"STUB_ASM_CODE("293")"\n"

STUB_ASM_ENTRY("glColorMaskiEXT")"\n"
"\t"STUB_ASM_CODE("294")"\n"

STUB_ASM_ENTRY("glColorMaskiOES")"\n"
"\t"STUB_ASM_CODE("295")"\n"

STUB_ASM_ENTRY("glColorMaterial")"\n"
"\t"STUB_ASM_CODE("296")"\n"

STUB_ASM_ENTRY("glColorP3ui")"\n"
"\t"STUB_ASM_CODE("297")"\n"

STUB_ASM_ENTRY("glColorP3uiv")"\n"
"\t"STUB_ASM_CODE("298")"\n"

STUB_ASM_ENTRY("glColorP4ui")"\n"
"\t"STUB_ASM_CODE("299")"\n"

STUB_ASM_ENTRY("glColorP4uiv")"\n"
"\t"STUB_ASM_CODE("300")"\n"

STUB_ASM_ENTRY("glColorPointer")"\n"
"\t"STUB_ASM_CODE("301")"\n"

STUB_ASM_ENTRY("glColorPointerEXT")"\n"
"\t"STUB_ASM_CODE("302")"\n"

STUB_ASM_ENTRY("glColorPointerListIBM")"\n"
"\t"STUB_ASM_CODE("303")"\n"

STUB_ASM_ENTRY("glColorPointervINTEL")"\n"
"\t"STUB_ASM_CODE("304")"\n"

STUB_ASM_ENTRY("glColorSubTable")"\n"
"\t"STUB_ASM_CODE("305")"\n"

STUB_ASM_ENTRY("glColorSubTableEXT")"\n"
"\t"STUB_ASM_CODE("306")"\n"

STUB_ASM_ENTRY("glColorTable")"\n"
"\t"STUB_ASM_CODE("307")"\n"

STUB_ASM_ENTRY("glColorTableEXT")"\n"
"\t"STUB_ASM_CODE("308")"\n"

STUB_ASM_ENTRY("glColorTableParameterfv")"\n"
"\t"STUB_ASM_CODE("309")"\n"

STUB_ASM_ENTRY("glColorTableParameterfvSGI")"\n"
"\t"STUB_ASM_CODE("310")"\n"

STUB_ASM_ENTRY("glColorTableParameteriv")"\n"
"\t"STUB_ASM_CODE("311")"\n"

STUB_ASM_ENTRY("glColorTableParameterivSGI")"\n"
"\t"STUB_ASM_CODE("312")"\n"

STUB_ASM_ENTRY("glColorTableSGI")"\n"
"\t"STUB_ASM_CODE("313")"\n"

STUB_ASM_ENTRY("glCombinerInputNV")"\n"
"\t"STUB_ASM_CODE("314")"\n"

STUB_ASM_ENTRY("glCombinerOutputNV")"\n"
"\t"STUB_ASM_CODE("315")"\n"

STUB_ASM_ENTRY("glCombinerParameterfNV")"\n"
"\t"STUB_ASM_CODE("316")"\n"

STUB_ASM_ENTRY("glCombinerParameterfvNV")"\n"
"\t"STUB_ASM_CODE("317")"\n"

STUB_ASM_ENTRY("glCombinerParameteriNV")"\n"
"\t"STUB_ASM_CODE("318")"\n"

STUB_ASM_ENTRY("glCombinerParameterivNV")"\n"
"\t"STUB_ASM_CODE("319")"\n"

STUB_ASM_ENTRY("glCombinerStageParameterfvNV")"\n"
"\t"STUB_ASM_CODE("320")"\n"

STUB_ASM_ENTRY("glCommandListSegmentsNV")"\n"
"\t"STUB_ASM_CODE("321")"\n"

STUB_ASM_ENTRY("glCompileCommandListNV")"\n"
"\t"STUB_ASM_CODE("322")"\n"

STUB_ASM_ENTRY("glCompileShader")"\n"
"\t"STUB_ASM_CODE("323")"\n"

STUB_ASM_ENTRY("glCompileShaderARB")"\n"
"\t"STUB_ASM_CODE("324")"\n"

STUB_ASM_ENTRY("glCompileShaderIncludeARB")"\n"
"\t"STUB_ASM_CODE("325")"\n"

STUB_ASM_ENTRY("glCompressedMultiTexImage1DEXT")"\n"
"\t"STUB_ASM_CODE("326")"\n"

STUB_ASM_ENTRY("glCompressedMultiTexImage2DEXT")"\n"
"\t"STUB_ASM_CODE("327")"\n"

STUB_ASM_ENTRY("glCompressedMultiTexImage3DEXT")"\n"
"\t"STUB_ASM_CODE("328")"\n"

STUB_ASM_ENTRY("glCompressedMultiTexSubImage1DEXT")"\n"
"\t"STUB_ASM_CODE("329")"\n"

STUB_ASM_ENTRY("glCompressedMultiTexSubImage2DEXT")"\n"
"\t"STUB_ASM_CODE("330")"\n"

STUB_ASM_ENTRY("glCompressedMultiTexSubImage3DEXT")"\n"
"\t"STUB_ASM_CODE("331")"\n"

STUB_ASM_ENTRY("glCompressedTexImage1D")"\n"
"\t"STUB_ASM_CODE("332")"\n"

STUB_ASM_ENTRY("glCompressedTexImage1DARB")"\n"
"\t"STUB_ASM_CODE("333")"\n"

STUB_ASM_ENTRY("glCompressedTexImage2D")"\n"
"\t"STUB_ASM_CODE("334")"\n"

STUB_ASM_ENTRY("glCompressedTexImage2DARB")"\n"
"\t"STUB_ASM_CODE("335")"\n"

STUB_ASM_ENTRY("glCompressedTexImage3D")"\n"
"\t"STUB_ASM_CODE("336")"\n"

STUB_ASM_ENTRY("glCompressedTexImage3DARB")"\n"
"\t"STUB_ASM_CODE("337")"\n"

STUB_ASM_ENTRY("glCompressedTexImage3DNV")"\n"
"\t"STUB_ASM_CODE("338")"\n"

STUB_ASM_ENTRY("glCompressedTexImage3DOES")"\n"
"\t"STUB_ASM_CODE("339")"\n"

STUB_ASM_ENTRY("glCompressedTexSubImage1D")"\n"
"\t"STUB_ASM_CODE("340")"\n"

STUB_ASM_ENTRY("glCompressedTexSubImage1DARB")"\n"
"\t"STUB_ASM_CODE("341")"\n"

STUB_ASM_ENTRY("glCompressedTexSubImage2D")"\n"
"\t"STUB_ASM_CODE("342")"\n"

STUB_ASM_ENTRY("glCompressedTexSubImage2DARB")"\n"
"\t"STUB_ASM_CODE("343")"\n"

STUB_ASM_ENTRY("glCompressedTexSubImage3D")"\n"
"\t"STUB_ASM_CODE("344")"\n"

STUB_ASM_ENTRY("glCompressedTexSubImage3DARB")"\n"
"\t"STUB_ASM_CODE("345")"\n"

STUB_ASM_ENTRY("glCompressedTexSubImage3DNV")"\n"
"\t"STUB_ASM_CODE("346")"\n"

STUB_ASM_ENTRY("glCompressedTexSubImage3DOES")"\n"
"\t"STUB_ASM_CODE("347")"\n"

STUB_ASM_ENTRY("glCompressedTextureImage1DEXT")"\n"
"\t"STUB_ASM_CODE("348")"\n"

STUB_ASM_ENTRY("glCompressedTextureImage2DEXT")"\n"
"\t"STUB_ASM_CODE("349")"\n"

STUB_ASM_ENTRY("glCompressedTextureImage3DEXT")"\n"
"\t"STUB_ASM_CODE("350")"\n"

STUB_ASM_ENTRY("glCompressedTextureSubImage1D")"\n"
"\t"STUB_ASM_CODE("351")"\n"

STUB_ASM_ENTRY("glCompressedTextureSubImage1DEXT")"\n"
"\t"STUB_ASM_CODE("352")"\n"

STUB_ASM_ENTRY("glCompressedTextureSubImage2D")"\n"
"\t"STUB_ASM_CODE("353")"\n"

STUB_ASM_ENTRY("glCompressedTextureSubImage2DEXT")"\n"
"\t"STUB_ASM_CODE("354")"\n"

STUB_ASM_ENTRY("glCompressedTextureSubImage3D")"\n"
"\t"STUB_ASM_CODE("355")"\n"

STUB_ASM_ENTRY("glCompressedTextureSubImage3DEXT")"\n"
"\t"STUB_ASM_CODE("356")"\n"

STUB_ASM_ENTRY("glConservativeRasterParameterfNV")"\n"
"\t"STUB_ASM_CODE("357")"\n"

STUB_ASM_ENTRY("glConservativeRasterParameteriNV")"\n"
"\t"STUB_ASM_CODE("358")"\n"

STUB_ASM_ENTRY("glConvolutionFilter1D")"\n"
"\t"STUB_ASM_CODE("359")"\n"

STUB_ASM_ENTRY("glConvolutionFilter1DEXT")"\n"
"\t"STUB_ASM_CODE("360")"\n"

STUB_ASM_ENTRY("glConvolutionFilter2D")"\n"
"\t"STUB_ASM_CODE("361")"\n"

STUB_ASM_ENTRY("glConvolutionFilter2DEXT")"\n"
"\t"STUB_ASM_CODE("362")"\n"

STUB_ASM_ENTRY("glConvolutionParameterf")"\n"
"\t"STUB_ASM_CODE("363")"\n"

STUB_ASM_ENTRY("glConvolutionParameterfEXT")"\n"
"\t"STUB_ASM_CODE("364")"\n"

STUB_ASM_ENTRY("glConvolutionParameterfv")"\n"
"\t"STUB_ASM_CODE("365")"\n"

STUB_ASM_ENTRY("glConvolutionParameterfvEXT")"\n"
"\t"STUB_ASM_CODE("366")"\n"

STUB_ASM_ENTRY("glConvolutionParameteri")"\n"
"\t"STUB_ASM_CODE("367")"\n"

STUB_ASM_ENTRY("glConvolutionParameteriEXT")"\n"
"\t"STUB_ASM_CODE("368")"\n"

STUB_ASM_ENTRY("glConvolutionParameteriv")"\n"
"\t"STUB_ASM_CODE("369")"\n"

STUB_ASM_ENTRY("glConvolutionParameterivEXT")"\n"
"\t"STUB_ASM_CODE("370")"\n"

STUB_ASM_ENTRY("glConvolutionParameterxOES")"\n"
"\t"STUB_ASM_CODE("371")"\n"

STUB_ASM_ENTRY("glConvolutionParameterxvOES")"\n"
"\t"STUB_ASM_CODE("372")"\n"

STUB_ASM_ENTRY("glCopyBufferSubData")"\n"
"\t"STUB_ASM_CODE("373")"\n"

STUB_ASM_ENTRY("glCopyBufferSubDataNV")"\n"
"\t"STUB_ASM_CODE("374")"\n"

STUB_ASM_ENTRY("glCopyColorSubTable")"\n"
"\t"STUB_ASM_CODE("375")"\n"

STUB_ASM_ENTRY("glCopyColorSubTableEXT")"\n"
"\t"STUB_ASM_CODE("376")"\n"

STUB_ASM_ENTRY("glCopyColorTable")"\n"
"\t"STUB_ASM_CODE("377")"\n"

STUB_ASM_ENTRY("glCopyColorTableSGI")"\n"
"\t"STUB_ASM_CODE("378")"\n"

STUB_ASM_ENTRY("glCopyConvolutionFilter1D")"\n"
"\t"STUB_ASM_CODE("379")"\n"

STUB_ASM_ENTRY("glCopyConvolutionFilter1DEXT")"\n"
"\t"STUB_ASM_CODE("380")"\n"

STUB_ASM_ENTRY("glCopyConvolutionFilter2D")"\n"
"\t"STUB_ASM_CODE("381")"\n"

STUB_ASM_ENTRY("glCopyConvolutionFilter2DEXT")"\n"
"\t"STUB_ASM_CODE("382")"\n"

STUB_ASM_ENTRY("glCopyImageSubData")"\n"
"\t"STUB_ASM_CODE("383")"\n"

STUB_ASM_ENTRY("glCopyImageSubDataEXT")"\n"
"\t"STUB_ASM_CODE("384")"\n"

STUB_ASM_ENTRY("glCopyImageSubDataNV")"\n"
"\t"STUB_ASM_CODE("385")"\n"

STUB_ASM_ENTRY("glCopyImageSubDataOES")"\n"
"\t"STUB_ASM_CODE("386")"\n"

STUB_ASM_ENTRY("glCopyMultiTexImage1DEXT")"\n"
"\t"STUB_ASM_CODE("387")"\n"

STUB_ASM_ENTRY("glCopyMultiTexImage2DEXT")"\n"
"\t"STUB_ASM_CODE("388")"\n"

STUB_ASM_ENTRY("glCopyMultiTexSubImage1DEXT")"\n"
"\t"STUB_ASM_CODE("389")"\n"

STUB_ASM_ENTRY("glCopyMultiTexSubImage2DEXT")"\n"
"\t"STUB_ASM_CODE("390")"\n"

STUB_ASM_ENTRY("glCopyMultiTexSubImage3DEXT")"\n"
"\t"STUB_ASM_CODE("391")"\n"

STUB_ASM_ENTRY("glCopyNamedBufferSubData")"\n"
"\t"STUB_ASM_CODE("392")"\n"

STUB_ASM_ENTRY("glCopyPathNV")"\n"
"\t"STUB_ASM_CODE("393")"\n"

STUB_ASM_ENTRY("glCopyPixels")"\n"
"\t"STUB_ASM_CODE("394")"\n"

STUB_ASM_ENTRY("glCopyTexImage1D")"\n"
"\t"STUB_ASM_CODE("395")"\n"

STUB_ASM_ENTRY("glCopyTexImage1DEXT")"\n"
"\t"STUB_ASM_CODE("396")"\n"

STUB_ASM_ENTRY("glCopyTexImage2D")"\n"
"\t"STUB_ASM_CODE("397")"\n"

STUB_ASM_ENTRY("glCopyTexImage2DEXT")"\n"
"\t"STUB_ASM_CODE("398")"\n"

STUB_ASM_ENTRY("glCopyTexSubImage1D")"\n"
"\t"STUB_ASM_CODE("399")"\n"

STUB_ASM_ENTRY("glCopyTexSubImage1DEXT")"\n"
"\t"STUB_ASM_CODE("400")"\n"

STUB_ASM_ENTRY("glCopyTexSubImage2D")"\n"
"\t"STUB_ASM_CODE("401")"\n"

STUB_ASM_ENTRY("glCopyTexSubImage2DEXT")"\n"
"\t"STUB_ASM_CODE("402")"\n"

STUB_ASM_ENTRY("glCopyTexSubImage3D")"\n"
"\t"STUB_ASM_CODE("403")"\n"

STUB_ASM_ENTRY("glCopyTexSubImage3DEXT")"\n"
"\t"STUB_ASM_CODE("404")"\n"

STUB_ASM_ENTRY("glCopyTexSubImage3DNV")"\n"
"\t"STUB_ASM_CODE("405")"\n"

STUB_ASM_ENTRY("glCopyTexSubImage3DOES")"\n"
"\t"STUB_ASM_CODE("406")"\n"

STUB_ASM_ENTRY("glCopyTextureImage1DEXT")"\n"
"\t"STUB_ASM_CODE("407")"\n"

STUB_ASM_ENTRY("glCopyTextureImage2DEXT")"\n"
"\t"STUB_ASM_CODE("408")"\n"

STUB_ASM_ENTRY("glCopyTextureLevelsAPPLE")"\n"
"\t"STUB_ASM_CODE("409")"\n"

STUB_ASM_ENTRY("glCopyTextureSubImage1D")"\n"
"\t"STUB_ASM_CODE("410")"\n"

STUB_ASM_ENTRY("glCopyTextureSubImage1DEXT")"\n"
"\t"STUB_ASM_CODE("411")"\n"

STUB_ASM_ENTRY("glCopyTextureSubImage2D")"\n"
"\t"STUB_ASM_CODE("412")"\n"

STUB_ASM_ENTRY("glCopyTextureSubImage2DEXT")"\n"
"\t"STUB_ASM_CODE("413")"\n"

STUB_ASM_ENTRY("glCopyTextureSubImage3D")"\n"
"\t"STUB_ASM_CODE("414")"\n"

STUB_ASM_ENTRY("glCopyTextureSubImage3DEXT")"\n"
"\t"STUB_ASM_CODE("415")"\n"

STUB_ASM_ENTRY("glCoverFillPathInstancedNV")"\n"
"\t"STUB_ASM_CODE("416")"\n"

STUB_ASM_ENTRY("glCoverFillPathNV")"\n"
"\t"STUB_ASM_CODE("417")"\n"

STUB_ASM_ENTRY("glCoverStrokePathInstancedNV")"\n"
"\t"STUB_ASM_CODE("418")"\n"

STUB_ASM_ENTRY("glCoverStrokePathNV")"\n"
"\t"STUB_ASM_CODE("419")"\n"

STUB_ASM_ENTRY("glCoverageMaskNV")"\n"
"\t"STUB_ASM_CODE("420")"\n"

STUB_ASM_ENTRY("glCoverageModulationNV")"\n"
"\t"STUB_ASM_CODE("421")"\n"

STUB_ASM_ENTRY("glCoverageModulationTableNV")"\n"
"\t"STUB_ASM_CODE("422")"\n"

STUB_ASM_ENTRY("glCoverageOperationNV")"\n"
"\t"STUB_ASM_CODE("423")"\n"

STUB_ASM_ENTRY("glCreateBuffers")"\n"
"\t"STUB_ASM_CODE("424")"\n"

STUB_ASM_ENTRY("glCreateCommandListsNV")"\n"
"\t"STUB_ASM_CODE("425")"\n"

STUB_ASM_ENTRY("glCreateFramebuffers")"\n"
"\t"STUB_ASM_CODE("426")"\n"

STUB_ASM_ENTRY("glCreateMemoryObjectsEXT")"\n"
"\t"STUB_ASM_CODE("427")"\n"

STUB_ASM_ENTRY("glCreatePerfQueryINTEL")"\n"
"\t"STUB_ASM_CODE("428")"\n"

STUB_ASM_ENTRY("glCreateProgram")"\n"
"\t"STUB_ASM_CODE("429")"\n"

STUB_ASM_ENTRY("glCreateProgramObjectARB")"\n"
"\t"STUB_ASM_CODE("430")"\n"

STUB_ASM_ENTRY("glCreateProgramPipelines")"\n"
"\t"STUB_ASM_CODE("431")"\n"

STUB_ASM_ENTRY("glCreateProgressFenceNVX")"\n"
"\t"STUB_ASM_CODE("432")"\n"

STUB_ASM_ENTRY("glCreateQueries")"\n"
"\t"STUB_ASM_CODE("433")"\n"

STUB_ASM_ENTRY("glCreateRenderbuffers")"\n"
"\t"STUB_ASM_CODE("434")"\n"

STUB_ASM_ENTRY("glCreateSamplers")"\n"
"\t"STUB_ASM_CODE("435")"\n"

STUB_ASM_ENTRY("glCreateShader")"\n"
"\t"STUB_ASM_CODE("437")"\n"

STUB_ASM_ENTRY("glCreateShaderObjectARB")"\n"
"\t"STUB_ASM_CODE("438")"\n"

STUB_ASM_ENTRY("glCreateShaderProgramEXT")"\n"
"\t"STUB_ASM_CODE("439")"\n"

STUB_ASM_ENTRY("glCreateShaderProgramv")"\n"
"\t"STUB_ASM_CODE("440")"\n"

STUB_ASM_ENTRY("glCreateShaderProgramvEXT")"\n"
"\t"STUB_ASM_CODE("441")"\n"

STUB_ASM_ENTRY("glCreateStatesNV")"\n"
"\t"STUB_ASM_CODE("442")"\n"

STUB_ASM_ENTRY("glCreateSyncFromCLeventARB")"\n"
"\t"STUB_ASM_CODE("443")"\n"

STUB_ASM_ENTRY("glCreateTextures")"\n"
"\t"STUB_ASM_CODE("444")"\n"

STUB_ASM_ENTRY("glCreateTransformFeedbacks")"\n"
"\t"STUB_ASM_CODE("445")"\n"

STUB_ASM_ENTRY("glCreateVertexArrays")"\n"
"\t"STUB_ASM_CODE("446")"\n"

STUB_ASM_ENTRY("glCullFace")"\n"
"\t"STUB_ASM_CODE("447")"\n"

STUB_ASM_ENTRY("glCullParameterdvEXT")"\n"
"\t"STUB_ASM_CODE("448")"\n"

STUB_ASM_ENTRY("glCullParameterfvEXT")"\n"
"\t"STUB_ASM_CODE("449")"\n"

STUB_ASM_ENTRY("glCurrentPaletteMatrixARB")"\n"
"\t"STUB_ASM_CODE("450")"\n"

STUB_ASM_ENTRY("glCurrentPaletteMatrixOES")"\n"
"\t"STUB_ASM_CODE("451")"\n"

STUB_ASM_ENTRY("glDebugMessageCallback")"\n"
"\t"STUB_ASM_CODE("452")"\n"

STUB_ASM_ENTRY("glDebugMessageCallbackAMD")"\n"
"\t"STUB_ASM_CODE("453")"\n"

STUB_ASM_ENTRY("glDebugMessageCallbackARB")"\n"
"\t"STUB_ASM_CODE("454")"\n"

STUB_ASM_ENTRY("glDebugMessageCallbackKHR")"\n"
"\t"STUB_ASM_CODE("455")"\n"

STUB_ASM_ENTRY("glDebugMessageCallbackOES")"\n"
"\t"STUB_ASM_CODE("456")"\n"

STUB_ASM_ENTRY("glDebugMessageControl")"\n"
"\t"STUB_ASM_CODE("457")"\n"

STUB_ASM_ENTRY("glDebugMessageControlARB")"\n"
"\t"STUB_ASM_CODE("458")"\n"

STUB_ASM_ENTRY("glDebugMessageControlKHR")"\n"
"\t"STUB_ASM_CODE("459")"\n"

STUB_ASM_ENTRY("glDebugMessageControlOES")"\n"
"\t"STUB_ASM_CODE("460")"\n"

STUB_ASM_ENTRY("glDebugMessageEnableAMD")"\n"
"\t"STUB_ASM_CODE("461")"\n"

STUB_ASM_ENTRY("glDebugMessageInsert")"\n"
"\t"STUB_ASM_CODE("462")"\n"

STUB_ASM_ENTRY("glDebugMessageInsertAMD")"\n"
"\t"STUB_ASM_CODE("463")"\n"

STUB_ASM_ENTRY("glDebugMessageInsertARB")"\n"
"\t"STUB_ASM_CODE("464")"\n"

STUB_ASM_ENTRY("glDebugMessageInsertKHR")"\n"
"\t"STUB_ASM_CODE("465")"\n"

STUB_ASM_ENTRY("glDebugMessageInsertOES")"\n"
"\t"STUB_ASM_CODE("466")"\n"

STUB_ASM_ENTRY("glDeformSGIX")"\n"
"\t"STUB_ASM_CODE("467")"\n"

STUB_ASM_ENTRY("glDeformationMap3dSGIX")"\n"
"\t"STUB_ASM_CODE("468")"\n"

STUB_ASM_ENTRY("glDeformationMap3fSGIX")"\n"
"\t"STUB_ASM_CODE("469")"\n"

STUB_ASM_ENTRY("glDeleteAsyncMarkersSGIX")"\n"
"\t"STUB_ASM_CODE("470")"\n"

STUB_ASM_ENTRY("glDeleteBuffers")"\n"
"\t"STUB_ASM_CODE("471")"\n"

STUB_ASM_ENTRY("glDeleteBuffersARB")"\n"
"\t"STUB_ASM_CODE("472")"\n"

STUB_ASM_ENTRY("glDeleteCommandListsNV")"\n"
"\t"STUB_ASM_CODE("473")"\n"

STUB_ASM_ENTRY("glDeleteFencesAPPLE")"\n"
"\t"STUB_ASM_CODE("474")"\n"

STUB_ASM_ENTRY("glDeleteFencesNV")"\n"
"\t"STUB_ASM_CODE("475")"\n"

STUB_ASM_ENTRY("glDeleteFragmentShaderATI")"\n"
"\t"STUB_ASM_CODE("476")"\n"

STUB_ASM_ENTRY("glDeleteFramebuffers")"\n"
"\t"STUB_ASM_CODE("477")"\n"

STUB_ASM_ENTRY("glDeleteFramebuffersEXT")"\n"
"\t"STUB_ASM_CODE("478")"\n"

STUB_ASM_ENTRY("glDeleteFramebuffersOES")"\n"
"\t"STUB_ASM_CODE("479")"\n"

STUB_ASM_ENTRY("glDeleteLists")"\n"
"\t"STUB_ASM_CODE("480")"\n"

STUB_ASM_ENTRY("glDeleteMemoryObjectsEXT")"\n"
"\t"STUB_ASM_CODE("481")"\n"

STUB_ASM_ENTRY("glDeleteNamedStringARB")"\n"
"\t"STUB_ASM_CODE("482")"\n"

STUB_ASM_ENTRY("glDeleteNamesAMD")"\n"
"\t"STUB_ASM_CODE("483")"\n"

STUB_ASM_ENTRY("glDeleteObjectARB")"\n"
"\t"STUB_ASM_CODE("484")"\n"

STUB_ASM_ENTRY("glDeleteOcclusionQueriesNV")"\n"
"\t"STUB_ASM_CODE("485")"\n"

STUB_ASM_ENTRY("glDeletePathsNV")"\n"
"\t"STUB_ASM_CODE("486")"\n"

STUB_ASM_ENTRY("glDeletePerfMonitorsAMD")"\n"
"\t"STUB_ASM_CODE("487")"\n"

STUB_ASM_ENTRY("glDeletePerfQueryINTEL")"\n"
"\t"STUB_ASM_CODE("488")"\n"

STUB_ASM_ENTRY("glDeleteProgram")"\n"
"\t"STUB_ASM_CODE("489")"\n"

STUB_ASM_ENTRY("glDeleteProgramPipelines")"\n"
"\t"STUB_ASM_CODE("490")"\n"

STUB_ASM_ENTRY("glDeleteProgramPipelinesEXT")"\n"
"\t"STUB_ASM_CODE("491")"\n"

STUB_ASM_ENTRY("glDeleteProgramsARB")"\n"
"\t"STUB_ASM_CODE("492")"\n"

STUB_ASM_ENTRY("glDeleteProgramsNV")"\n"
"\t"STUB_ASM_CODE("493")"\n"

STUB_ASM_ENTRY("glDeleteQueries")"\n"
"\t"STUB_ASM_CODE("494")"\n"

STUB_ASM_ENTRY("glDeleteQueriesARB")"\n"
"\t"STUB_ASM_CODE("495")"\n"

STUB_ASM_ENTRY("glDeleteQueriesEXT")"\n"
"\t"STUB_ASM_CODE("496")"\n"

STUB_ASM_ENTRY("glDeleteQueryResourceTagNV")"\n"
"\t"STUB_ASM_CODE("497")"\n"

STUB_ASM_ENTRY("glDeleteRenderbuffers")"\n"
"\t"STUB_ASM_CODE("498")"\n"

STUB_ASM_ENTRY("glDeleteRenderbuffersEXT")"\n"
"\t"STUB_ASM_CODE("499")"\n"

STUB_ASM_ENTRY("glDeleteRenderbuffersOES")"\n"
"\t"STUB_ASM_CODE("500")"\n"

STUB_ASM_ENTRY("glDeleteSamplers")"\n"
"\t"STUB_ASM_CODE("501")"\n"

STUB_ASM_ENTRY("glDeleteSemaphoresEXT")"\n"
"\t"STUB_ASM_CODE("502")"\n"

STUB_ASM_ENTRY("glDeleteShader")"\n"
"\t"STUB_ASM_CODE("503")"\n"

STUB_ASM_ENTRY("glDeleteStatesNV")"\n"
"\t"STUB_ASM_CODE("504")"\n"

STUB_ASM_ENTRY("glDeleteSync")"\n"
"\t"STUB_ASM_CODE("505")"\n"

STUB_ASM_ENTRY("glDeleteSyncAPPLE")"\n"
"\t"STUB_ASM_CODE("506")"\n"

STUB_ASM_ENTRY("glDeleteTextures")"\n"
"\t"STUB_ASM_CODE("507")"\n"

STUB_ASM_ENTRY("glDeleteTexturesEXT")"\n"
"\t"STUB_ASM_CODE("508")"\n"

STUB_ASM_ENTRY("glDeleteTransformFeedbacks")"\n"
"\t"STUB_ASM_CODE("509")"\n"

STUB_ASM_ENTRY("glDeleteTransformFeedbacksEXT")"\n"
"\t"STUB_ASM_CODE("510")"\n"

STUB_ASM_ENTRY("glDeleteTransformFeedbacksNV")"\n"
"\t"STUB_ASM_CODE("511")"\n"

STUB_ASM_ENTRY("glDeleteVertexArrays")"\n"
"\t"STUB_ASM_CODE("512")"\n"

STUB_ASM_ENTRY("glDeleteVertexArraysAPPLE")"\n"
"\t"STUB_ASM_CODE("513")"\n"

STUB_ASM_ENTRY("glDeleteVertexArraysOES")"\n"
"\t"STUB_ASM_CODE("514")"\n"

STUB_ASM_ENTRY("glDeleteVertexShaderEXT")"\n"
"\t"STUB_ASM_CODE("515")"\n"

STUB_ASM_ENTRY("glDepthBoundsEXT")"\n"
"\t"STUB_ASM_CODE("516")"\n"

STUB_ASM_ENTRY("glDepthBoundsdNV")"\n"
"\t"STUB_ASM_CODE("517")"\n"

STUB_ASM_ENTRY("glDepthFunc")"\n"
"\t"STUB_ASM_CODE("518")"\n"

STUB_ASM_ENTRY("glDepthMask")"\n"
"\t"STUB_ASM_CODE("519")"\n"

STUB_ASM_ENTRY("glDepthRange")"\n"
"\t"STUB_ASM_CODE("520")"\n"

STUB_ASM_ENTRY("glDepthRangeArraydvNV")"\n"
"\t"STUB_ASM_CODE("521")"\n"

STUB_ASM_ENTRY("glDepthRangeArrayfvNV")"\n"
"\t"STUB_ASM_CODE("522")"\n"

STUB_ASM_ENTRY("glDepthRangeArrayfvOES")"\n"
"\t"STUB_ASM_CODE("523")"\n"

STUB_ASM_ENTRY("glDepthRangeArrayv")"\n"
"\t"STUB_ASM_CODE("524")"\n"

STUB_ASM_ENTRY("glDepthRangeIndexed")"\n"
"\t"STUB_ASM_CODE("525")"\n"

STUB_ASM_ENTRY("glDepthRangeIndexeddNV")"\n"
"\t"STUB_ASM_CODE("526")"\n"

STUB_ASM_ENTRY("glDepthRangeIndexedfNV")"\n"
"\t"STUB_ASM_CODE("527")"\n"

STUB_ASM_ENTRY("glDepthRangeIndexedfOES")"\n"
"\t"STUB_ASM_CODE("528")"\n"

STUB_ASM_ENTRY("glDepthRangedNV")"\n"
"\t"STUB_ASM_CODE("529")"\n"

STUB_ASM_ENTRY("glDepthRangef")"\n"
"\t"STUB_ASM_CODE("530")"\n"

STUB_ASM_ENTRY("glDepthRangefOES")"\n"
"\t"STUB_ASM_CODE("531")"\n"

STUB_ASM_ENTRY("glDepthRangex")"\n"
"\t"STUB_ASM_CODE("532")"\n"

STUB_ASM_ENTRY("glDepthRangexOES")"\n"
"\t"STUB_ASM_CODE("533")"\n"

STUB_ASM_ENTRY("glDetachObjectARB")"\n"
"\t"STUB_ASM_CODE("534")"\n"

STUB_ASM_ENTRY("glDetachShader")"\n"
"\t"STUB_ASM_CODE("535")"\n"

STUB_ASM_ENTRY("glDetailTexFuncSGIS")"\n"
"\t"STUB_ASM_CODE("536")"\n"

STUB_ASM_ENTRY("glDevtoolsCorrelationIdNVX")"\n"
"\t"STUB_ASM_CODE("537")"\n"

STUB_ASM_ENTRY("glDevtoolsInvokeStreamedCallbackNVX")"\n"
"\t"STUB_ASM_CODE("538")"\n"

STUB_ASM_ENTRY("glDisable")"\n"
"\t"STUB_ASM_CODE("539")"\n"

STUB_ASM_ENTRY("glDisableClientState")"\n"
"\t"STUB_ASM_CODE("540")"\n"

STUB_ASM_ENTRY("glDisableClientStateIndexedEXT")"\n"
"\t"STUB_ASM_CODE("541")"\n"

STUB_ASM_ENTRY("glDisableClientStateiEXT")"\n"
"\t"STUB_ASM_CODE("542")"\n"

STUB_ASM_ENTRY("glDisableDriverControlQCOM")"\n"
"\t"STUB_ASM_CODE("543")"\n"

STUB_ASM_ENTRY("glDisableIndexedEXT")"\n"
"\t"STUB_ASM_CODE("544")"\n"

STUB_ASM_ENTRY("glDisableVariantClientStateEXT")"\n"
"\t"STUB_ASM_CODE("545")"\n"

STUB_ASM_ENTRY("glDisableVertexArrayAttrib")"\n"
"\t"STUB_ASM_CODE("546")"\n"

STUB_ASM_ENTRY("glDisableVertexArrayAttribEXT")"\n"
"\t"STUB_ASM_CODE("547")"\n"

STUB_ASM_ENTRY("glDisableVertexArrayEXT")"\n"
"\t"STUB_ASM_CODE("548")"\n"

STUB_ASM_ENTRY("glDisableVertexAttribAPPLE")"\n"
"\t"STUB_ASM_CODE("549")"\n"

STUB_ASM_ENTRY("glDisableVertexAttribArray")"\n"
"\t"STUB_ASM_CODE("550")"\n"

STUB_ASM_ENTRY("glDisableVertexAttribArrayARB")"\n"
"\t"STUB_ASM_CODE("551")"\n"

STUB_ASM_ENTRY("glDisablei")"\n"
"\t"STUB_ASM_CODE("552")"\n"

STUB_ASM_ENTRY("glDisableiEXT")"\n"
"\t"STUB_ASM_CODE("553")"\n"

STUB_ASM_ENTRY("glDisableiNV")"\n"
"\t"STUB_ASM_CODE("554")"\n"

STUB_ASM_ENTRY("glDisableiOES")"\n"
"\t"STUB_ASM_CODE("555")"\n"

STUB_ASM_ENTRY("glDiscardFramebufferEXT")"\n"
"\t"STUB_ASM_CODE("556")"\n"

STUB_ASM_ENTRY("glDispatchCompute")"\n"
"\t"STUB_ASM_CODE("557")"\n"

STUB_ASM_ENTRY("glDispatchComputeGroupSizeARB")"\n"
"\t"STUB_ASM_CODE("558")"\n"

STUB_ASM_ENTRY("glDispatchComputeIndirect")"\n"
"\t"STUB_ASM_CODE("559")"\n"

STUB_ASM_ENTRY("glDrawArrays")"\n"
"\t"STUB_ASM_CODE("560")"\n"

STUB_ASM_ENTRY("glDrawArraysEXT")"\n"
"\t"STUB_ASM_CODE("561")"\n"

STUB_ASM_ENTRY("glDrawArraysIndirect")"\n"
"\t"STUB_ASM_CODE("562")"\n"

STUB_ASM_ENTRY("glDrawArraysInstanced")"\n"
"\t"STUB_ASM_CODE("563")"\n"

STUB_ASM_ENTRY("glDrawArraysInstancedANGLE")"\n"
"\t"STUB_ASM_CODE("564")"\n"

STUB_ASM_ENTRY("glDrawArraysInstancedARB")"\n"
"\t"STUB_ASM_CODE("565")"\n"

STUB_ASM_ENTRY("glDrawArraysInstancedBaseInstance")"\n"
"\t"STUB_ASM_CODE("566")"\n"

STUB_ASM_ENTRY("glDrawArraysInstancedBaseInstanceEXT")"\n"
"\t"STUB_ASM_CODE("567")"\n"

STUB_ASM_ENTRY("glDrawArraysInstancedEXT")"\n"
"\t"STUB_ASM_CODE("568")"\n"

STUB_ASM_ENTRY("glDrawArraysInstancedNV")"\n"
"\t"STUB_ASM_CODE("569")"\n"

STUB_ASM_ENTRY("glDrawBuffer")"\n"
"\t"STUB_ASM_CODE("570")"\n"

STUB_ASM_ENTRY("glDrawBuffers")"\n"
"\t"STUB_ASM_CODE("571")"\n"

STUB_ASM_ENTRY("glDrawBuffersARB")"\n"
"\t"STUB_ASM_CODE("572")"\n"

STUB_ASM_ENTRY("glDrawBuffersATI")"\n"
"\t"STUB_ASM_CODE("573")"\n"

STUB_ASM_ENTRY("glDrawBuffersEXT")"\n"
"\t"STUB_ASM_CODE("574")"\n"

STUB_ASM_ENTRY("glDrawBuffersIndexedEXT")"\n"
"\t"STUB_ASM_CODE("575")"\n"

STUB_ASM_ENTRY("glDrawBuffersNV")"\n"
"\t"STUB_ASM_CODE("576")"\n"

STUB_ASM_ENTRY("glDrawCommandsAddressNV")"\n"
"\t"STUB_ASM_CODE("577")"\n"

STUB_ASM_ENTRY("glDrawCommandsNV")"\n"
"\t"STUB_ASM_CODE("578")"\n"

STUB_ASM_ENTRY("glDrawCommandsStatesAddressNV")"\n"
"\t"STUB_ASM_CODE("579")"\n"

STUB_ASM_ENTRY("glDrawCommandsStatesNV")"\n"
"\t"STUB_ASM_CODE("580")"\n"

STUB_ASM_ENTRY("glDrawElementArrayAPPLE")"\n"
"\t"STUB_ASM_CODE("581")"\n"

STUB_ASM_ENTRY("glDrawElementArrayATI")"\n"
"\t"STUB_ASM_CODE("582")"\n"

STUB_ASM_ENTRY("glDrawElements")"\n"
"\t"STUB_ASM_CODE("583")"\n"

STUB_ASM_ENTRY("glDrawElementsBaseVertex")"\n"
"\t"STUB_ASM_CODE("584")"\n"

STUB_ASM_ENTRY("glDrawElementsBaseVertexEXT")"\n"
"\t"STUB_ASM_CODE("585")"\n"

STUB_ASM_ENTRY("glDrawElementsBaseVertexOES")"\n"
"\t"STUB_ASM_CODE("586")"\n"

STUB_ASM_ENTRY("glDrawElementsIndirect")"\n"
"\t"STUB_ASM_CODE("587")"\n"

STUB_ASM_ENTRY("glDrawElementsInstanced")"\n"
"\t"STUB_ASM_CODE("588")"\n"

STUB_ASM_ENTRY("glDrawElementsInstancedANGLE")"\n"
"\t"STUB_ASM_CODE("589")"\n"

STUB_ASM_ENTRY("glDrawElementsInstancedARB")"\n"
"\t"STUB_ASM_CODE("590")"\n"

STUB_ASM_ENTRY("glDrawElementsInstancedBaseInstance")"\n"
"\t"STUB_ASM_CODE("591")"\n"

STUB_ASM_ENTRY("glDrawElementsInstancedBaseInstanceEXT")"\n"
"\t"STUB_ASM_CODE("592")"\n"

STUB_ASM_ENTRY("glDrawElementsInstancedBaseVertex")"\n"
"\t"STUB_ASM_CODE("593")"\n"

STUB_ASM_ENTRY("glDrawElementsInstancedBaseVertexBaseInstance")"\n"
"\t"STUB_ASM_CODE("594")"\n"

STUB_ASM_ENTRY("glDrawElementsInstancedBaseVertexBaseInstanceEXT")"\n"
"\t"STUB_ASM_CODE("595")"\n"

STUB_ASM_ENTRY("glDrawElementsInstancedBaseVertexEXT")"\n"
"\t"STUB_ASM_CODE("596")"\n"

STUB_ASM_ENTRY("glDrawElementsInstancedBaseVertexOES")"\n"
"\t"STUB_ASM_CODE("597")"\n"

STUB_ASM_ENTRY("glDrawElementsInstancedEXT")"\n"
"\t"STUB_ASM_CODE("598")"\n"

STUB_ASM_ENTRY("glDrawElementsInstancedNV")"\n"
"\t"STUB_ASM_CODE("599")"\n"

STUB_ASM_ENTRY("glDrawMeshArraysSUN")"\n"
"\t"STUB_ASM_CODE("600")"\n"

STUB_ASM_ENTRY("glDrawMeshNV")"\n"
"\t"STUB_ASM_CODE("601")"\n"

STUB_ASM_ENTRY("glDrawMeshTasksIndirectNV")"\n"
"\t"STUB_ASM_CODE("602")"\n"

STUB_ASM_ENTRY("glDrawMeshTasksNV")"\n"
"\t"STUB_ASM_CODE("603")"\n"

STUB_ASM_ENTRY("glDrawPixels")"\n"
"\t"STUB_ASM_CODE("604")"\n"

STUB_ASM_ENTRY("glDrawRangeElementArrayAPPLE")"\n"
"\t"STUB_ASM_CODE("605")"\n"

STUB_ASM_ENTRY("glDrawRangeElementArrayATI")"\n"
"\t"STUB_ASM_CODE("606")"\n"

STUB_ASM_ENTRY("glDrawRangeElements")"\n"
"\t"STUB_ASM_CODE("607")"\n"

STUB_ASM_ENTRY("glDrawRangeElementsBaseVertex")"\n"
"\t"STUB_ASM_CODE("608")"\n"

STUB_ASM_ENTRY("glDrawRangeElementsBaseVertexEXT")"\n"
"\t"STUB_ASM_CODE("609")"\n"

STUB_ASM_ENTRY("glDrawRangeElementsBaseVertexOES")"\n"
"\t"STUB_ASM_CODE("610")"\n"

STUB_ASM_ENTRY("glDrawRangeElementsEXT")"\n"
"\t"STUB_ASM_CODE("611")"\n"

STUB_ASM_ENTRY("glDrawTexfOES")"\n"
"\t"STUB_ASM_CODE("612")"\n"

STUB_ASM_ENTRY("glDrawTexfvOES")"\n"
"\t"STUB_ASM_CODE("613")"\n"

STUB_ASM_ENTRY("glDrawTexiOES")"\n"
"\t"STUB_ASM_CODE("614")"\n"

STUB_ASM_ENTRY("glDrawTexivOES")"\n"
"\t"STUB_ASM_CODE("615")"\n"

STUB_ASM_ENTRY("glDrawTexsOES")"\n"
"\t"STUB_ASM_CODE("616")"\n"

STUB_ASM_ENTRY("glDrawTexsvOES")"\n"
"\t"STUB_ASM_CODE("617")"\n"

STUB_ASM_ENTRY("glDrawTextureNV")"\n"
"\t"STUB_ASM_CODE("618")"\n"

STUB_ASM_ENTRY("glDrawTexxOES")"\n"
"\t"STUB_ASM_CODE("619")"\n"

STUB_ASM_ENTRY("glDrawTexxvOES")"\n"
"\t"STUB_ASM_CODE("620")"\n"

STUB_ASM_ENTRY("glDrawTransformFeedback")"\n"
"\t"STUB_ASM_CODE("621")"\n"

STUB_ASM_ENTRY("glDrawTransformFeedbackEXT")"\n"
"\t"STUB_ASM_CODE("622")"\n"

STUB_ASM_ENTRY("glDrawTransformFeedbackInstanced")"\n"
"\t"STUB_ASM_CODE("623")"\n"

STUB_ASM_ENTRY("glDrawTransformFeedbackInstancedEXT")"\n"
"\t"STUB_ASM_CODE("624")"\n"

STUB_ASM_ENTRY("glDrawTransformFeedbackNV")"\n"
"\t"STUB_ASM_CODE("625")"\n"

STUB_ASM_ENTRY("glDrawTransformFeedbackStream")"\n"
"\t"STUB_ASM_CODE("626")"\n"

STUB_ASM_ENTRY("glDrawTransformFeedbackStreamInstanced")"\n"
"\t"STUB_ASM_CODE("627")"\n"

STUB_ASM_ENTRY("glDrawVkImageNV")"\n"
"\t"STUB_ASM_CODE("628")"\n"

STUB_ASM_ENTRY("glEGLImageTargetRenderbufferStorageOES")"\n"
"\t"STUB_ASM_CODE("629")"\n"

STUB_ASM_ENTRY("glEGLImageTargetTexStorageEXT")"\n"
"\t"STUB_ASM_CODE("630")"\n"

STUB_ASM_ENTRY("glEGLImageTargetTexture2DOES")"\n"
"\t"STUB_ASM_CODE("631")"\n"

STUB_ASM_ENTRY("glEGLImageTargetTextureStorageEXT")"\n"
"\t"STUB_ASM_CODE("632")"\n"

STUB_ASM_ENTRY("glEdgeFlag")"\n"
"\t"STUB_ASM_CODE("633")"\n"

STUB_ASM_ENTRY("glEdgeFlagFormatNV")"\n"
"\t"STUB_ASM_CODE("634")"\n"

STUB_ASM_ENTRY("glEdgeFlagPointer")"\n"
"\t"STUB_ASM_CODE("635")"\n"

STUB_ASM_ENTRY("glEdgeFlagPointerEXT")"\n"
"\t"STUB_ASM_CODE("636")"\n"

STUB_ASM_ENTRY("glEdgeFlagPointerListIBM")"\n"
"\t"STUB_ASM_CODE("637")"\n"

STUB_ASM_ENTRY("glEdgeFlagv")"\n"
"\t"STUB_ASM_CODE("638")"\n"

STUB_ASM_ENTRY("glElementPointerAPPLE")"\n"
"\t"STUB_ASM_CODE("639")"\n"

STUB_ASM_ENTRY("glElementPointerATI")"\n"
"\t"STUB_ASM_CODE("640")"\n"

STUB_ASM_ENTRY("glEnable")"\n"
"\t"STUB_ASM_CODE("641")"\n"

STUB_ASM_ENTRY("glEnableClientState")"\n"
"\t"STUB_ASM_CODE("642")"\n"

STUB_ASM_ENTRY("glEnableClientStateIndexedEXT")"\n"
"\t"STUB_ASM_CODE("643")"\n"

STUB_ASM_ENTRY("glEnableClientStateiEXT")"\n"
"\t"STUB_ASM_CODE("644")"\n"

STUB_ASM_ENTRY("glEnableDriverControlQCOM")"\n"
"\t"STUB_ASM_CODE("645")"\n"

STUB_ASM_ENTRY("glEnableIndexedEXT")"\n"
"\t"STUB_ASM_CODE("646")"\n"

STUB_ASM_ENTRY("glEnableVariantClientStateEXT")"\n"
"\t"STUB_ASM_CODE("647")"\n"

STUB_ASM_ENTRY("glEnableVertexArrayAttrib")"\n"
"\t"STUB_ASM_CODE("648")"\n"

STUB_ASM_ENTRY("glEnableVertexArrayAttribEXT")"\n"
"\t"STUB_ASM_CODE("649")"\n"

STUB_ASM_ENTRY("glEnableVertexArrayEXT")"\n"
"\t"STUB_ASM_CODE("650")"\n"

STUB_ASM_ENTRY("glEnableVertexAttribAPPLE")"\n"
"\t"STUB_ASM_CODE("651")"\n"

STUB_ASM_ENTRY("glEnableVertexAttribArray")"\n"
"\t"STUB_ASM_CODE("652")"\n"

STUB_ASM_ENTRY("glEnableVertexAttribArrayARB")"\n"
"\t"STUB_ASM_CODE("653")"\n"

STUB_ASM_ENTRY("glEnablei")"\n"
"\t"STUB_ASM_CODE("654")"\n"

STUB_ASM_ENTRY("glEnableiEXT")"\n"
"\t"STUB_ASM_CODE("655")"\n"

STUB_ASM_ENTRY("glEnableiNV")"\n"
"\t"STUB_ASM_CODE("656")"\n"

STUB_ASM_ENTRY("glEnableiOES")"\n"
"\t"STUB_ASM_CODE("657")"\n"

STUB_ASM_ENTRY("glEnd")"\n"
"\t"STUB_ASM_CODE("658")"\n"

STUB_ASM_ENTRY("glEndConditionalRender")"\n"
"\t"STUB_ASM_CODE("659")"\n"

STUB_ASM_ENTRY("glEndConditionalRenderNV")"\n"
"\t"STUB_ASM_CODE("660")"\n"

STUB_ASM_ENTRY("glEndConditionalRenderNVX")"\n"
"\t"STUB_ASM_CODE("661")"\n"

STUB_ASM_ENTRY("glEndFragmentShaderATI")"\n"
"\t"STUB_ASM_CODE("662")"\n"

STUB_ASM_ENTRY("glEndList")"\n"
"\t"STUB_ASM_CODE("663")"\n"

STUB_ASM_ENTRY("glEndOcclusionQueryNV")"\n"
"\t"STUB_ASM_CODE("664")"\n"

STUB_ASM_ENTRY("glEndPerfMonitorAMD")"\n"
"\t"STUB_ASM_CODE("665")"\n"

STUB_ASM_ENTRY("glEndPerfQueryINTEL")"\n"
"\t"STUB_ASM_CODE("666")"\n"

STUB_ASM_ENTRY("glEndQuery")"\n"
"\t"STUB_ASM_CODE("667")"\n"

STUB_ASM_ENTRY("glEndQueryARB")"\n"
"\t"STUB_ASM_CODE("668")"\n"

STUB_ASM_ENTRY("glEndQueryEXT")"\n"
"\t"STUB_ASM_CODE("669")"\n"

STUB_ASM_ENTRY("glEndQueryIndexed")"\n"
"\t"STUB_ASM_CODE("670")"\n"

STUB_ASM_ENTRY("glEndTilingQCOM")"\n"
"\t"STUB_ASM_CODE("671")"\n"

STUB_ASM_ENTRY("glEndTransformFeedback")"\n"
"\t"STUB_ASM_CODE("672")"\n"

STUB_ASM_ENTRY("glEndTransformFeedbackEXT")"\n"
"\t"STUB_ASM_CODE("673")"\n"

STUB_ASM_ENTRY("glEndTransformFeedbackNV")"\n"
"\t"STUB_ASM_CODE("674")"\n"

STUB_ASM_ENTRY("glEndVertexShaderEXT")"\n"
"\t"STUB_ASM_CODE("675")"\n"

STUB_ASM_ENTRY("glEndVideoCaptureNV")"\n"
"\t"STUB_ASM_CODE("676")"\n"

STUB_ASM_ENTRY("glEvalCoord1d")"\n"
"\t"STUB_ASM_CODE("677")"\n"

STUB_ASM_ENTRY("glEvalCoord1dv")"\n"
"\t"STUB_ASM_CODE("678")"\n"

STUB_ASM_ENTRY("glEvalCoord1f")"\n"
"\t"STUB_ASM_CODE("679")"\n"

STUB_ASM_ENTRY("glEvalCoord1fv")"\n"
"\t"STUB_ASM_CODE("680")"\n"

STUB_ASM_ENTRY("glEvalCoord1xOES")"\n"
"\t"STUB_ASM_CODE("681")"\n"

STUB_ASM_ENTRY("glEvalCoord1xvOES")"\n"
"\t"STUB_ASM_CODE("682")"\n"

STUB_ASM_ENTRY("glEvalCoord2d")"\n"
"\t"STUB_ASM_CODE("683")"\n"

STUB_ASM_ENTRY("glEvalCoord2dv")"\n"
"\t"STUB_ASM_CODE("684")"\n"

STUB_ASM_ENTRY("glEvalCoord2f")"\n"
"\t"STUB_ASM_CODE("685")"\n"

STUB_ASM_ENTRY("glEvalCoord2fv")"\n"
"\t"STUB_ASM_CODE("686")"\n"

STUB_ASM_ENTRY("glEvalCoord2xOES")"\n"
"\t"STUB_ASM_CODE("687")"\n"

STUB_ASM_ENTRY("glEvalCoord2xvOES")"\n"
"\t"STUB_ASM_CODE("688")"\n"

STUB_ASM_ENTRY("glEvalMapsNV")"\n"
"\t"STUB_ASM_CODE("689")"\n"

STUB_ASM_ENTRY("glEvalMesh1")"\n"
"\t"STUB_ASM_CODE("690")"\n"

STUB_ASM_ENTRY("glEvalMesh2")"\n"
"\t"STUB_ASM_CODE("691")"\n"

STUB_ASM_ENTRY("glEvalPoint1")"\n"
"\t"STUB_ASM_CODE("692")"\n"

STUB_ASM_ENTRY("glEvalPoint2")"\n"
"\t"STUB_ASM_CODE("693")"\n"

STUB_ASM_ENTRY("glEvaluateDepthValuesARB")"\n"
"\t"STUB_ASM_CODE("694")"\n"

STUB_ASM_ENTRY("glExecuteProgramNV")"\n"
"\t"STUB_ASM_CODE("695")"\n"

STUB_ASM_ENTRY("glExtGetBufferPointervQCOM")"\n"
"\t"STUB_ASM_CODE("696")"\n"

STUB_ASM_ENTRY("glExtGetBuffersQCOM")"\n"
"\t"STUB_ASM_CODE("697")"\n"

STUB_ASM_ENTRY("glExtGetFramebuffersQCOM")"\n"
"\t"STUB_ASM_CODE("698")"\n"

STUB_ASM_ENTRY("glExtGetProgramBinarySourceQCOM")"\n"
"\t"STUB_ASM_CODE("699")"\n"

STUB_ASM_ENTRY("glExtGetProgramsQCOM")"\n"
"\t"STUB_ASM_CODE("700")"\n"

STUB_ASM_ENTRY("glExtGetRenderbuffersQCOM")"\n"
"\t"STUB_ASM_CODE("701")"\n"

STUB_ASM_ENTRY("glExtGetShadersQCOM")"\n"
"\t"STUB_ASM_CODE("702")"\n"

STUB_ASM_ENTRY("glExtGetTexLevelParameterivQCOM")"\n"
"\t"STUB_ASM_CODE("703")"\n"

STUB_ASM_ENTRY("glExtGetTexSubImageQCOM")"\n"
"\t"STUB_ASM_CODE("704")"\n"

STUB_ASM_ENTRY("glExtGetTexturesQCOM")"\n"
"\t"STUB_ASM_CODE("705")"\n"

STUB_ASM_ENTRY("glExtIsProgramBinaryQCOM")"\n"
"\t"STUB_ASM_CODE("706")"\n"

STUB_ASM_ENTRY("glExtTexObjectStateOverrideiQCOM")"\n"
"\t"STUB_ASM_CODE("707")"\n"

STUB_ASM_ENTRY("glExtractComponentEXT")"\n"
"\t"STUB_ASM_CODE("708")"\n"

STUB_ASM_ENTRY("glFeedbackBuffer")"\n"
"\t"STUB_ASM_CODE("710")"\n"

STUB_ASM_ENTRY("glFeedbackBufferxOES")"\n"
"\t"STUB_ASM_CODE("711")"\n"

STUB_ASM_ENTRY("glFenceSync")"\n"
"\t"STUB_ASM_CODE("712")"\n"

STUB_ASM_ENTRY("glFenceSyncAPPLE")"\n"
"\t"STUB_ASM_CODE("713")"\n"

STUB_ASM_ENTRY("glFenceValueuiNVX")"\n"
"\t"STUB_ASM_CODE("714")"\n"

STUB_ASM_ENTRY("glFinalCombinerInputNV")"\n"
"\t"STUB_ASM_CODE("715")"\n"

STUB_ASM_ENTRY("glFinish")"\n"
"\t"STUB_ASM_CODE("716")"\n"

STUB_ASM_ENTRY("glFinishAsyncSGIX")"\n"
"\t"STUB_ASM_CODE("717")"\n"

STUB_ASM_ENTRY("glFinishFenceAPPLE")"\n"
"\t"STUB_ASM_CODE("718")"\n"

STUB_ASM_ENTRY("glFinishFenceNV")"\n"
"\t"STUB_ASM_CODE("719")"\n"

STUB_ASM_ENTRY("glFinishObjectAPPLE")"\n"
"\t"STUB_ASM_CODE("720")"\n"

STUB_ASM_ENTRY("glFinishTextureSUNX")"\n"
"\t"STUB_ASM_CODE("721")"\n"

STUB_ASM_ENTRY("glFlush")"\n"
"\t"STUB_ASM_CODE("722")"\n"

STUB_ASM_ENTRY("glFlushMappedBufferRange")"\n"
"\t"STUB_ASM_CODE("723")"\n"

STUB_ASM_ENTRY("glFlushMappedBufferRangeAPPLE")"\n"
"\t"STUB_ASM_CODE("724")"\n"

STUB_ASM_ENTRY("glFlushMappedBufferRangeEXT")"\n"
"\t"STUB_ASM_CODE("725")"\n"

STUB_ASM_ENTRY("glFlushMappedNamedBufferRange")"\n"
"\t"STUB_ASM_CODE("726")"\n"

STUB_ASM_ENTRY("glFlushMappedNamedBufferRangeEXT")"\n"
"\t"STUB_ASM_CODE("727")"\n"

STUB_ASM_ENTRY("glFlushPixelDataRangeNV")"\n"
"\t"STUB_ASM_CODE("728")"\n"

STUB_ASM_ENTRY("glFlushRasterSGIX")"\n"
"\t"STUB_ASM_CODE("729")"\n"

STUB_ASM_ENTRY("glFlushStaticDataIBM")"\n"
"\t"STUB_ASM_CODE("730")"\n"

STUB_ASM_ENTRY("glFlushVertexArrayRangeAPPLE")"\n"
"\t"STUB_ASM_CODE("731")"\n"

STUB_ASM_ENTRY("glFlushVertexArrayRangeNV")"\n"
"\t"STUB_ASM_CODE("732")"\n"

STUB_ASM_ENTRY("glFogCoordFormatNV")"\n"
"\t"STUB_ASM_CODE("733")"\n"

STUB_ASM_ENTRY("glFogCoordPointer")"\n"
"\t"STUB_ASM_CODE("734")"\n"

STUB_ASM_ENTRY("glFogCoordPointerEXT")"\n"
"\t"STUB_ASM_CODE("735")"\n"

STUB_ASM_ENTRY("glFogCoordPointerListIBM")"\n"
"\t"STUB_ASM_CODE("736")"\n"

STUB_ASM_ENTRY("glFogCoordd")"\n"
"\t"STUB_ASM_CODE("737")"\n"

STUB_ASM_ENTRY("glFogCoorddEXT")"\n"
"\t"STUB_ASM_CODE("738")"\n"

STUB_ASM_ENTRY("glFogCoorddv")"\n"
"\t"STUB_ASM_CODE("739")"\n"

STUB_ASM_ENTRY("glFogCoorddvEXT")"\n"
"\t"STUB_ASM_CODE("740")"\n"

STUB_ASM_ENTRY("glFogCoordf")"\n"
"\t"STUB_ASM_CODE("741")"\n"

STUB_ASM_ENTRY("glFogCoordfEXT")"\n"
"\t"STUB_ASM_CODE("742")"\n"

STUB_ASM_ENTRY("glFogCoordfv")"\n"
"\t"STUB_ASM_CODE("743")"\n"

STUB_ASM_ENTRY("glFogCoordfvEXT")"\n"
"\t"STUB_ASM_CODE("744")"\n"

STUB_ASM_ENTRY("glFogCoordhNV")"\n"
"\t"STUB_ASM_CODE("745")"\n"

STUB_ASM_ENTRY("glFogCoordhvNV")"\n"
"\t"STUB_ASM_CODE("746")"\n"

STUB_ASM_ENTRY("glFogFuncSGIS")"\n"
"\t"STUB_ASM_CODE("747")"\n"

STUB_ASM_ENTRY("glFogf")"\n"
"\t"STUB_ASM_CODE("748")"\n"

STUB_ASM_ENTRY("glFogfv")"\n"
"\t"STUB_ASM_CODE("749")"\n"

STUB_ASM_ENTRY("glFogi")"\n"
"\t"STUB_ASM_CODE("750")"\n"

STUB_ASM_ENTRY("glFogiv")"\n"
"\t"STUB_ASM_CODE("751")"\n"

STUB_ASM_ENTRY("glFogx")"\n"
"\t"STUB_ASM_CODE("752")"\n"

STUB_ASM_ENTRY("glFogxOES")"\n"
"\t"STUB_ASM_CODE("753")"\n"

STUB_ASM_ENTRY("glFogxv")"\n"
"\t"STUB_ASM_CODE("754")"\n"

STUB_ASM_ENTRY("glFogxvOES")"\n"
"\t"STUB_ASM_CODE("755")"\n"

STUB_ASM_ENTRY("glFragmentColorMaterialSGIX")"\n"
"\t"STUB_ASM_CODE("756")"\n"

STUB_ASM_ENTRY("glFragmentCoverageColorNV")"\n"
"\t"STUB_ASM_CODE("757")"\n"

STUB_ASM_ENTRY("glFragmentLightModelfSGIX")"\n"
"\t"STUB_ASM_CODE("758")"\n"

STUB_ASM_ENTRY("glFragmentLightModelfvSGIX")"\n"
"\t"STUB_ASM_CODE("759")"\n"

STUB_ASM_ENTRY("glFragmentLightModeliSGIX")"\n"
"\t"STUB_ASM_CODE("760")"\n"

STUB_ASM_ENTRY("glFragmentLightModelivSGIX")"\n"
"\t"STUB_ASM_CODE("761")"\n"

STUB_ASM_ENTRY("glFragmentLightfSGIX")"\n"
"\t"STUB_ASM_CODE("762")"\n"

STUB_ASM_ENTRY("glFragmentLightfvSGIX")"\n"
"\t"STUB_ASM_CODE("763")"\n"

STUB_ASM_ENTRY("glFragmentLightiSGIX")"\n"
"\t"STUB_ASM_CODE("764")"\n"

STUB_ASM_ENTRY("glFragmentLightivSGIX")"\n"
"\t"STUB_ASM_CODE("765")"\n"

STUB_ASM_ENTRY("glFragmentMaterialfSGIX")"\n"
"\t"STUB_ASM_CODE("766")"\n"

STUB_ASM_ENTRY("glFragmentMaterialfvSGIX")"\n"
"\t"STUB_ASM_CODE("767")"\n"

STUB_ASM_ENTRY("glFragmentMaterialiSGIX")"\n"
"\t"STUB_ASM_CODE("768")"\n"

STUB_ASM_ENTRY("glFragmentMaterialivSGIX")"\n"
"\t"STUB_ASM_CODE("769")"\n"

STUB_ASM_ENTRY("glFrameTerminatorGREMEDY")"\n"
"\t"STUB_ASM_CODE("770")"\n"

STUB_ASM_ENTRY("glFrameZoomSGIX")"\n"
"\t"STUB_ASM_CODE("771")"\n"

STUB_ASM_ENTRY("glFramebufferDrawBufferEXT")"\n"
"\t"STUB_ASM_CODE("772")"\n"

STUB_ASM_ENTRY("glFramebufferDrawBuffersEXT")"\n"
"\t"STUB_ASM_CODE("773")"\n"

STUB_ASM_ENTRY("glFramebufferFetchBarrierEXT")"\n"
"\t"STUB_ASM_CODE("774")"\n"

STUB_ASM_ENTRY("glFramebufferFetchBarrierQCOM")"\n"
"\t"STUB_ASM_CODE("775")"\n"

STUB_ASM_ENTRY("glFramebufferFoveationConfigQCOM")"\n"
"\t"STUB_ASM_CODE("776")"\n"

STUB_ASM_ENTRY("glFramebufferFoveationParametersQCOM")"\n"
"\t"STUB_ASM_CODE("777")"\n"

STUB_ASM_ENTRY("glFramebufferParameteri")"\n"
"\t"STUB_ASM_CODE("778")"\n"

STUB_ASM_ENTRY("glFramebufferParameteriMESA")"\n"
"\t"STUB_ASM_CODE("779")"\n"

STUB_ASM_ENTRY("glFramebufferPixelLocalStorageSizeEXT")"\n"
"\t"STUB_ASM_CODE("780")"\n"

STUB_ASM_ENTRY("glFramebufferReadBufferEXT")"\n"
"\t"STUB_ASM_CODE("781")"\n"

STUB_ASM_ENTRY("glFramebufferRenderbuffer")"\n"
"\t"STUB_ASM_CODE("782")"\n"

STUB_ASM_ENTRY("glFramebufferRenderbufferEXT")"\n"
"\t"STUB_ASM_CODE("783")"\n"

STUB_ASM_ENTRY("glFramebufferRenderbufferOES")"\n"
"\t"STUB_ASM_CODE("784")"\n"

STUB_ASM_ENTRY("glFramebufferSampleLocationsfvARB")"\n"
"\t"STUB_ASM_CODE("785")"\n"

STUB_ASM_ENTRY("glFramebufferSampleLocationsfvNV")"\n"
"\t"STUB_ASM_CODE("786")"\n"

STUB_ASM_ENTRY("glFramebufferSamplePositionsfvAMD")"\n"
"\t"STUB_ASM_CODE("787")"\n"

STUB_ASM_ENTRY("glFramebufferTexture")"\n"
"\t"STUB_ASM_CODE("789")"\n"

STUB_ASM_ENTRY("glFramebufferTexture1D")"\n"
"\t"STUB_ASM_CODE("790")"\n"

STUB_ASM_ENTRY("glFramebufferTexture1DEXT")"\n"
"\t"STUB_ASM_CODE("791")"\n"

STUB_ASM_ENTRY("glFramebufferTexture2D")"\n"
"\t"STUB_ASM_CODE("792")"\n"

STUB_ASM_ENTRY("glFramebufferTexture2DDownsampleIMG")"\n"
"\t"STUB_ASM_CODE("793")"\n"

STUB_ASM_ENTRY("glFramebufferTexture2DEXT")"\n"
"\t"STUB_ASM_CODE("794")"\n"

STUB_ASM_ENTRY("glFramebufferTexture2DMultisampleEXT")"\n"
"\t"STUB_ASM_CODE("795")"\n"

STUB_ASM_ENTRY("glFramebufferTexture2DMultisampleIMG")"\n"
"\t"STUB_ASM_CODE("796")"\n"

STUB_ASM_ENTRY("glFramebufferTexture2DOES")"\n"
"\t"STUB_ASM_CODE("797")"\n"

STUB_ASM_ENTRY("glFramebufferTexture3D")"\n"
"\t"STUB_ASM_CODE("798")"\n"

STUB_ASM_ENTRY("glFramebufferTexture3DEXT")"\n"
"\t"STUB_ASM_CODE("799")"\n"

STUB_ASM_ENTRY("glFramebufferTexture3DOES")"\n"
"\t"STUB_ASM_CODE("800")"\n"

STUB_ASM_ENTRY("glFramebufferTextureARB")"\n"
"\t"STUB_ASM_CODE("801")"\n"

STUB_ASM_ENTRY("glFramebufferTextureEXT")"\n"
"\t"STUB_ASM_CODE("802")"\n"

STUB_ASM_ENTRY("glFramebufferTextureFaceARB")"\n"
"\t"STUB_ASM_CODE("803")"\n"

STUB_ASM_ENTRY("glFramebufferTextureFaceEXT")"\n"
"\t"STUB_ASM_CODE("804")"\n"

STUB_ASM_ENTRY("glFramebufferTextureLayer")"\n"
"\t"STUB_ASM_CODE("805")"\n"

STUB_ASM_ENTRY("glFramebufferTextureLayerARB")"\n"
"\t"STUB_ASM_CODE("806")"\n"

STUB_ASM_ENTRY("glFramebufferTextureLayerDownsampleIMG")"\n"
"\t"STUB_ASM_CODE("807")"\n"

STUB_ASM_ENTRY("glFramebufferTextureLayerEXT")"\n"
"\t"STUB_ASM_CODE("808")"\n"

STUB_ASM_ENTRY("glFramebufferTextureLayerNV")"\n"
"\t"STUB_ASM_CODE("809")"\n"

STUB_ASM_ENTRY("glFramebufferTextureMultisampleMultiviewOVR")"\n"
"\t"STUB_ASM_CODE("810")"\n"

STUB_ASM_ENTRY("glFramebufferTextureMultiviewOVR")"\n"
"\t"STUB_ASM_CODE("811")"\n"

STUB_ASM_ENTRY("glFramebufferTextureOES")"\n"
"\t"STUB_ASM_CODE("812")"\n"

STUB_ASM_ENTRY("glFreeObjectBufferATI")"\n"
"\t"STUB_ASM_CODE("813")"\n"

STUB_ASM_ENTRY("glFrontFace")"\n"
"\t"STUB_ASM_CODE("814")"\n"

STUB_ASM_ENTRY("glFrustum")"\n"
"\t"STUB_ASM_CODE("815")"\n"

STUB_ASM_ENTRY("glFrustumf")"\n"
"\t"STUB_ASM_CODE("816")"\n"

STUB_ASM_ENTRY("glFrustumfOES")"\n"
"\t"STUB_ASM_CODE("817")"\n"

STUB_ASM_ENTRY("glFrustumx")"\n"
"\t"STUB_ASM_CODE("818")"\n"

STUB_ASM_ENTRY("glFrustumxOES")"\n"
"\t"STUB_ASM_CODE("819")"\n"

STUB_ASM_ENTRY("glGenAsyncMarkersSGIX")"\n"
"\t"STUB_ASM_CODE("820")"\n"

STUB_ASM_ENTRY("glGenBuffers")"\n"
"\t"STUB_ASM_CODE("821")"\n"

STUB_ASM_ENTRY("glGenBuffersARB")"\n"
"\t"STUB_ASM_CODE("822")"\n"

STUB_ASM_ENTRY("glGenFencesAPPLE")"\n"
"\t"STUB_ASM_CODE("823")"\n"

STUB_ASM_ENTRY("glGenFencesNV")"\n"
"\t"STUB_ASM_CODE("824")"\n"

STUB_ASM_ENTRY("glGenFragmentShadersATI")"\n"
"\t"STUB_ASM_CODE("825")"\n"

STUB_ASM_ENTRY("glGenFramebuffers")"\n"
"\t"STUB_ASM_CODE("826")"\n"

STUB_ASM_ENTRY("glGenFramebuffersEXT")"\n"
"\t"STUB_ASM_CODE("827")"\n"

STUB_ASM_ENTRY("glGenFramebuffersOES")"\n"
"\t"STUB_ASM_CODE("828")"\n"

STUB_ASM_ENTRY("glGenLists")"\n"
"\t"STUB_ASM_CODE("829")"\n"

STUB_ASM_ENTRY("glGenNamesAMD")"\n"
"\t"STUB_ASM_CODE("830")"\n"

STUB_ASM_ENTRY("glGenOcclusionQueriesNV")"\n"
"\t"STUB_ASM_CODE("831")"\n"

STUB_ASM_ENTRY("glGenPathsNV")"\n"
"\t"STUB_ASM_CODE("832")"\n"

STUB_ASM_ENTRY("glGenPerfMonitorsAMD")"\n"
"\t"STUB_ASM_CODE("833")"\n"

STUB_ASM_ENTRY("glGenProgramPipelines")"\n"
"\t"STUB_ASM_CODE("834")"\n"

STUB_ASM_ENTRY("glGenProgramPipelinesEXT")"\n"
"\t"STUB_ASM_CODE("835")"\n"

STUB_ASM_ENTRY("glGenProgramsARB")"\n"
"\t"STUB_ASM_CODE("836")"\n"

STUB_ASM_ENTRY("glGenProgramsNV")"\n"
"\t"STUB_ASM_CODE("837")"\n"

STUB_ASM_ENTRY("glGenQueries")"\n"
"\t"STUB_ASM_CODE("838")"\n"

STUB_ASM_ENTRY("glGenQueriesARB")"\n"
"\t"STUB_ASM_CODE("839")"\n"

STUB_ASM_ENTRY("glGenQueriesEXT")"\n"
"\t"STUB_ASM_CODE("840")"\n"

STUB_ASM_ENTRY("glGenQueryResourceTagNV")"\n"
"\t"STUB_ASM_CODE("841")"\n"

STUB_ASM_ENTRY("glGenRenderbuffers")"\n"
"\t"STUB_ASM_CODE("842")"\n"

STUB_ASM_ENTRY("glGenRenderbuffersEXT")"\n"
"\t"STUB_ASM_CODE("843")"\n"

STUB_ASM_ENTRY("glGenRenderbuffersOES")"\n"
"\t"STUB_ASM_CODE("844")"\n"

STUB_ASM_ENTRY("glGenSamplers")"\n"
"\t"STUB_ASM_CODE("845")"\n"

STUB_ASM_ENTRY("glGenSemaphoresEXT")"\n"
"\t"STUB_ASM_CODE("846")"\n"

STUB_ASM_ENTRY("glGenSymbolsEXT")"\n"
"\t"STUB_ASM_CODE("847")"\n"

STUB_ASM_ENTRY("glGenTextures")"\n"
"\t"STUB_ASM_CODE("848")"\n"

STUB_ASM_ENTRY("glGenTexturesEXT")"\n"
"\t"STUB_ASM_CODE("849")"\n"

STUB_ASM_ENTRY("glGenTransformFeedbacks")"\n"
"\t"STUB_ASM_CODE("850")"\n"

STUB_ASM_ENTRY("glGenTransformFeedbacksEXT")"\n"
"\t"STUB_ASM_CODE("851")"\n"

STUB_ASM_ENTRY("glGenTransformFeedbacksNV")"\n"
"\t"STUB_ASM_CODE("852")"\n"

STUB_ASM_ENTRY("glGenVertexArrays")"\n"
"\t"STUB_ASM_CODE("853")"\n"

STUB_ASM_ENTRY("glGenVertexArraysAPPLE")"\n"
"\t"STUB_ASM_CODE("854")"\n"

STUB_ASM_ENTRY("glGenVertexArraysOES")"\n"
"\t"STUB_ASM_CODE("855")"\n"

STUB_ASM_ENTRY("glGenVertexShadersEXT")"\n"
"\t"STUB_ASM_CODE("856")"\n"

STUB_ASM_ENTRY("glGenerateMipmap")"\n"
"\t"STUB_ASM_CODE("857")"\n"

STUB_ASM_ENTRY("glGenerateMipmapEXT")"\n"
"\t"STUB_ASM_CODE("858")"\n"

STUB_ASM_ENTRY("glGenerateMipmapOES")"\n"
"\t"STUB_ASM_CODE("859")"\n"

STUB_ASM_ENTRY("glGenerateMultiTexMipmapEXT")"\n"
"\t"STUB_ASM_CODE("860")"\n"

STUB_ASM_ENTRY("glGenerateTextureMipmap")"\n"
"\t"STUB_ASM_CODE("861")"\n"

STUB_ASM_ENTRY("glGenerateTextureMipmapEXT")"\n"
"\t"STUB_ASM_CODE("862")"\n"

STUB_ASM_ENTRY("glGetActiveAtomicCounterBufferiv")"\n"
"\t"STUB_ASM_CODE("863")"\n"

STUB_ASM_ENTRY("glGetActiveAttrib")"\n"
"\t"STUB_ASM_CODE("864")"\n"

STUB_ASM_ENTRY("glGetActiveAttribARB")"\n"
"\t"STUB_ASM_CODE("865")"\n"

STUB_ASM_ENTRY("glGetActiveSubroutineName")"\n"
"\t"STUB_ASM_CODE("866")"\n"

STUB_ASM_ENTRY("glGetActiveSubroutineUniformName")"\n"
"\t"STUB_ASM_CODE("867")"\n"

STUB_ASM_ENTRY("glGetActiveSubroutineUniformiv")"\n"
"\t"STUB_ASM_CODE("868")"\n"

STUB_ASM_ENTRY("glGetActiveUniform")"\n"
"\t"STUB_ASM_CODE("869")"\n"

STUB_ASM_ENTRY("glGetActiveUniformARB")"\n"
"\t"STUB_ASM_CODE("870")"\n"

STUB_ASM_ENTRY("glGetActiveUniformBlockName")"\n"
"\t"STUB_ASM_CODE("871")"\n"

STUB_ASM_ENTRY("glGetActiveUniformBlockiv")"\n"
"\t"STUB_ASM_CODE("872")"\n"

STUB_ASM_ENTRY("glGetActiveUniformName")"\n"
"\t"STUB_ASM_CODE("873")"\n"

STUB_ASM_ENTRY("glGetActiveUniformsiv")"\n"
"\t"STUB_ASM_CODE("874")"\n"

STUB_ASM_ENTRY("glGetActiveVaryingNV")"\n"
"\t"STUB_ASM_CODE("875")"\n"

STUB_ASM_ENTRY("glGetArrayObjectfvATI")"\n"
"\t"STUB_ASM_CODE("876")"\n"

STUB_ASM_ENTRY("glGetArrayObjectivATI")"\n"
"\t"STUB_ASM_CODE("877")"\n"

STUB_ASM_ENTRY("glGetAttachedObjectsARB")"\n"
"\t"STUB_ASM_CODE("878")"\n"

STUB_ASM_ENTRY("glGetAttachedShaders")"\n"
"\t"STUB_ASM_CODE("879")"\n"

STUB_ASM_ENTRY("glGetAttribLocation")"\n"
"\t"STUB_ASM_CODE("880")"\n"

STUB_ASM_ENTRY("glGetAttribLocationARB")"\n"
"\t"STUB_ASM_CODE("881")"\n"

STUB_ASM_ENTRY("glGetBooleanIndexedvEXT")"\n"
"\t"STUB_ASM_CODE("882")"\n"

STUB_ASM_ENTRY("glGetBooleani_v")"\n"
"\t"STUB_ASM_CODE("883")"\n"

STUB_ASM_ENTRY("glGetBooleanv")"\n"
"\t"STUB_ASM_CODE("884")"\n"

STUB_ASM_ENTRY("glGetBufferParameteri64v")"\n"
"\t"STUB_ASM_CODE("885")"\n"

STUB_ASM_ENTRY("glGetBufferParameteriv")"\n"
"\t"STUB_ASM_CODE("886")"\n"

STUB_ASM_ENTRY("glGetBufferParameterivARB")"\n"
"\t"STUB_ASM_CODE("887")"\n"

STUB_ASM_ENTRY("glGetBufferParameterui64vNV")"\n"
"\t"STUB_ASM_CODE("888")"\n"

STUB_ASM_ENTRY("glGetBufferPointerv")"\n"
"\t"STUB_ASM_CODE("889")"\n"

STUB_ASM_ENTRY("glGetBufferPointervARB")"\n"
"\t"STUB_ASM_CODE("890")"\n"

STUB_ASM_ENTRY("glGetBufferPointervOES")"\n"
"\t"STUB_ASM_CODE("891")"\n"

STUB_ASM_ENTRY("glGetBufferSubData")"\n"
"\t"STUB_ASM_CODE("892")"\n"

STUB_ASM_ENTRY("glGetBufferSubDataARB")"\n"
"\t"STUB_ASM_CODE("893")"\n"

STUB_ASM_ENTRY("glGetClipPlane")"\n"
"\t"STUB_ASM_CODE("894")"\n"

STUB_ASM_ENTRY("glGetClipPlanef")"\n"
"\t"STUB_ASM_CODE("895")"\n"

STUB_ASM_ENTRY("glGetClipPlanefOES")"\n"
"\t"STUB_ASM_CODE("896")"\n"

STUB_ASM_ENTRY("glGetClipPlanex")"\n"
"\t"STUB_ASM_CODE("897")"\n"

STUB_ASM_ENTRY("glGetClipPlanexOES")"\n"
"\t"STUB_ASM_CODE("898")"\n"

STUB_ASM_ENTRY("glGetColorTable")"\n"
"\t"STUB_ASM_CODE("899")"\n"

STUB_ASM_ENTRY("glGetColorTableEXT")"\n"
"\t"STUB_ASM_CODE("900")"\n"

STUB_ASM_ENTRY("glGetColorTableParameterfv")"\n"
"\t"STUB_ASM_CODE("901")"\n"

STUB_ASM_ENTRY("glGetColorTableParameterfvEXT")"\n"
"\t"STUB_ASM_CODE("902")"\n"

STUB_ASM_ENTRY("glGetColorTableParameterfvSGI")"\n"
"\t"STUB_ASM_CODE("903")"\n"

STUB_ASM_ENTRY("glGetColorTableParameteriv")"\n"
"\t"STUB_ASM_CODE("904")"\n"

STUB_ASM_ENTRY("glGetColorTableParameterivEXT")"\n"
"\t"STUB_ASM_CODE("905")"\n"

STUB_ASM_ENTRY("glGetColorTableParameterivSGI")"\n"
"\t"STUB_ASM_CODE("906")"\n"

STUB_ASM_ENTRY("glGetColorTableSGI")"\n"
"\t"STUB_ASM_CODE("907")"\n"

STUB_ASM_ENTRY("glGetCombinerInputParameterfvNV")"\n"
"\t"STUB_ASM_CODE("908")"\n"

STUB_ASM_ENTRY("glGetCombinerInputParameterivNV")"\n"
"\t"STUB_ASM_CODE("909")"\n"

STUB_ASM_ENTRY("glGetCombinerOutputParameterfvNV")"\n"
"\t"STUB_ASM_CODE("910")"\n"

STUB_ASM_ENTRY("glGetCombinerOutputParameterivNV")"\n"
"\t"STUB_ASM_CODE("911")"\n"

STUB_ASM_ENTRY("glGetCombinerStageParameterfvNV")"\n"
"\t"STUB_ASM_CODE("912")"\n"

STUB_ASM_ENTRY("glGetCommandHeaderNV")"\n"
"\t"STUB_ASM_CODE("913")"\n"

STUB_ASM_ENTRY("glGetCompressedMultiTexImageEXT")"\n"
"\t"STUB_ASM_CODE("914")"\n"

STUB_ASM_ENTRY("glGetCompressedTexImage")"\n"
"\t"STUB_ASM_CODE("915")"\n"

STUB_ASM_ENTRY("glGetCompressedTexImageARB")"\n"
"\t"STUB_ASM_CODE("916")"\n"

STUB_ASM_ENTRY("glGetCompressedTexImageNV")"\n"
"\t"STUB_ASM_CODE("917")"\n"

STUB_ASM_ENTRY("glGetCompressedTextureImage")"\n"
"\t"STUB_ASM_CODE("918")"\n"

STUB_ASM_ENTRY("glGetCompressedTextureImageEXT")"\n"
"\t"STUB_ASM_CODE("919")"\n"

STUB_ASM_ENTRY("glGetCompressedTextureSubImage")"\n"
"\t"STUB_ASM_CODE("920")"\n"

STUB_ASM_ENTRY("glGetConvolutionFilter")"\n"
"\t"STUB_ASM_CODE("921")"\n"

STUB_ASM_ENTRY("glGetConvolutionFilterEXT")"\n"
"\t"STUB_ASM_CODE("922")"\n"

STUB_ASM_ENTRY("glGetConvolutionParameterfv")"\n"
"\t"STUB_ASM_CODE("923")"\n"

STUB_ASM_ENTRY("glGetConvolutionParameterfvEXT")"\n"
"\t"STUB_ASM_CODE("924")"\n"

STUB_ASM_ENTRY("glGetConvolutionParameteriv")"\n"
"\t"STUB_ASM_CODE("925")"\n"

STUB_ASM_ENTRY("glGetConvolutionParameterivEXT")"\n"
"\t"STUB_ASM_CODE("926")"\n"

STUB_ASM_ENTRY("glGetConvolutionParameterxvOES")"\n"
"\t"STUB_ASM_CODE("927")"\n"

STUB_ASM_ENTRY("glGetCoverageModulationTableNV")"\n"
"\t"STUB_ASM_CODE("928")"\n"

STUB_ASM_ENTRY("glGetDebugMessageLog")"\n"
"\t"STUB_ASM_CODE("929")"\n"

STUB_ASM_ENTRY("glGetDebugMessageLogAMD")"\n"
"\t"STUB_ASM_CODE("930")"\n"

STUB_ASM_ENTRY("glGetDebugMessageLogARB")"\n"
"\t"STUB_ASM_CODE("931")"\n"

STUB_ASM_ENTRY("glGetDebugMessageLogKHR")"\n"
"\t"STUB_ASM_CODE("932")"\n"

STUB_ASM_ENTRY("glGetDebugMessageLogOES")"\n"
"\t"STUB_ASM_CODE("933")"\n"

STUB_ASM_ENTRY("glGetDetailTexFuncSGIS")"\n"
"\t"STUB_ASM_CODE("934")"\n"

STUB_ASM_ENTRY("glGetDoubleIndexedvEXT")"\n"
"\t"STUB_ASM_CODE("935")"\n"

STUB_ASM_ENTRY("glGetDoublei_v")"\n"
"\t"STUB_ASM_CODE("936")"\n"

STUB_ASM_ENTRY("glGetDoublei_vEXT")"\n"
"\t"STUB_ASM_CODE("937")"\n"

STUB_ASM_ENTRY("glGetDoublev")"\n"
"\t"STUB_ASM_CODE("938")"\n"

STUB_ASM_ENTRY("glGetDriverControlStringQCOM")"\n"
"\t"STUB_ASM_CODE("939")"\n"

STUB_ASM_ENTRY("glGetDriverControlsQCOM")"\n"
"\t"STUB_ASM_CODE("940")"\n"

STUB_ASM_ENTRY("glGetError")"\n"
"\t"STUB_ASM_CODE("941")"\n"

STUB_ASM_ENTRY("glGetFenceivNV")"\n"
"\t"STUB_ASM_CODE("942")"\n"

STUB_ASM_ENTRY("glGetFinalCombinerInputParameterfvNV")"\n"
"\t"STUB_ASM_CODE("943")"\n"

STUB_ASM_ENTRY("glGetFinalCombinerInputParameterivNV")"\n"
"\t"STUB_ASM_CODE("944")"\n"

STUB_ASM_ENTRY("glGetFirstPerfQueryIdINTEL")"\n"
"\t"STUB_ASM_CODE("945")"\n"

STUB_ASM_ENTRY("glGetFixedv")"\n"
"\t"STUB_ASM_CODE("946")"\n"

STUB_ASM_ENTRY("glGetFixedvOES")"\n"
"\t"STUB_ASM_CODE("947")"\n"

STUB_ASM_ENTRY("glGetFloatIndexedvEXT")"\n"
"\t"STUB_ASM_CODE("948")"\n"

STUB_ASM_ENTRY("glGetFloati_v")"\n"
"\t"STUB_ASM_CODE("949")"\n"

STUB_ASM_ENTRY("glGetFloati_vEXT")"\n"
"\t"STUB_ASM_CODE("950")"\n"

STUB_ASM_ENTRY("glGetFloati_vNV")"\n"
"\t"STUB_ASM_CODE("951")"\n"

STUB_ASM_ENTRY("glGetFloati_vOES")"\n"
"\t"STUB_ASM_CODE("952")"\n"

STUB_ASM_ENTRY("glGetFloatv")"\n"
"\t"STUB_ASM_CODE("953")"\n"

STUB_ASM_ENTRY("glGetFogFuncSGIS")"\n"
"\t"STUB_ASM_CODE("954")"\n"

STUB_ASM_ENTRY("glGetFragDataIndex")"\n"
"\t"STUB_ASM_CODE("955")"\n"

STUB_ASM_ENTRY("glGetFragDataIndexEXT")"\n"
"\t"STUB_ASM_CODE("956")"\n"

STUB_ASM_ENTRY("glGetFragDataLocation")"\n"
"\t"STUB_ASM_CODE("957")"\n"

STUB_ASM_ENTRY("glGetFragDataLocationEXT")"\n"
"\t"STUB_ASM_CODE("958")"\n"

STUB_ASM_ENTRY("glGetFragmentLightfvSGIX")"\n"
"\t"STUB_ASM_CODE("959")"\n"

STUB_ASM_ENTRY("glGetFragmentLightivSGIX")"\n"
"\t"STUB_ASM_CODE("960")"\n"

STUB_ASM_ENTRY("glGetFragmentMaterialfvSGIX")"\n"
"\t"STUB_ASM_CODE("961")"\n"

STUB_ASM_ENTRY("glGetFragmentMaterialivSGIX")"\n"
"\t"STUB_ASM_CODE("962")"\n"

STUB_ASM_ENTRY("glGetFramebufferAttachmentParameteriv")"\n"
"\t"STUB_ASM_CODE("964")"\n"

STUB_ASM_ENTRY("glGetFramebufferAttachmentParameterivEXT")"\n"
"\t"STUB_ASM_CODE("965")"\n"

STUB_ASM_ENTRY("glGetFramebufferAttachmentParameterivOES")"\n"
"\t"STUB_ASM_CODE("966")"\n"

STUB_ASM_ENTRY("glGetFramebufferParameterfvAMD")"\n"
"\t"STUB_ASM_CODE("967")"\n"

STUB_ASM_ENTRY("glGetFramebufferParameteriv")"\n"
"\t"STUB_ASM_CODE("968")"\n"

STUB_ASM_ENTRY("glGetFramebufferParameterivEXT")"\n"
"\t"STUB_ASM_CODE("969")"\n"

STUB_ASM_ENTRY("glGetFramebufferParameterivMESA")"\n"
"\t"STUB_ASM_CODE("970")"\n"

STUB_ASM_ENTRY("glGetFramebufferPixelLocalStorageSizeEXT")"\n"
"\t"STUB_ASM_CODE("971")"\n"

STUB_ASM_ENTRY("glGetGraphicsResetStatus")"\n"
"\t"STUB_ASM_CODE("972")"\n"

STUB_ASM_ENTRY("glGetGraphicsResetStatusARB")"\n"
"\t"STUB_ASM_CODE("973")"\n"

STUB_ASM_ENTRY("glGetGraphicsResetStatusEXT")"\n"
"\t"STUB_ASM_CODE("974")"\n"

STUB_ASM_ENTRY("glGetGraphicsResetStatusKHR")"\n"
"\t"STUB_ASM_CODE("975")"\n"

STUB_ASM_ENTRY("glGetHandleARB")"\n"
"\t"STUB_ASM_CODE("976")"\n"

STUB_ASM_ENTRY("glGetHistogram")"\n"
"\t"STUB_ASM_CODE("977")"\n"

STUB_ASM_ENTRY("glGetHistogramEXT")"\n"
"\t"STUB_ASM_CODE("978")"\n"

STUB_ASM_ENTRY("glGetHistogramParameterfv")"\n"
"\t"STUB_ASM_CODE("979")"\n"

STUB_ASM_ENTRY("glGetHistogramParameterfvEXT")"\n"
"\t"STUB_ASM_CODE("980")"\n"

STUB_ASM_ENTRY("glGetHistogramParameteriv")"\n"
"\t"STUB_ASM_CODE("981")"\n"

STUB_ASM_ENTRY("glGetHistogramParameterivEXT")"\n"
"\t"STUB_ASM_CODE("982")"\n"

STUB_ASM_ENTRY("glGetHistogramParameterxvOES")"\n"
"\t"STUB_ASM_CODE("983")"\n"

STUB_ASM_ENTRY("glGetImageHandleARB")"\n"
"\t"STUB_ASM_CODE("984")"\n"

STUB_ASM_ENTRY("glGetImageHandleNV")"\n"
"\t"STUB_ASM_CODE("985")"\n"

STUB_ASM_ENTRY("glGetImageTransformParameterfvHP")"\n"
"\t"STUB_ASM_CODE("986")"\n"

STUB_ASM_ENTRY("glGetImageTransformParameterivHP")"\n"
"\t"STUB_ASM_CODE("987")"\n"

STUB_ASM_ENTRY("glGetInfoLogARB")"\n"
"\t"STUB_ASM_CODE("988")"\n"

STUB_ASM_ENTRY("glGetInstrumentsSGIX")"\n"
"\t"STUB_ASM_CODE("989")"\n"

STUB_ASM_ENTRY("glGetInteger64i_v")"\n"
"\t"STUB_ASM_CODE("990")"\n"

STUB_ASM_ENTRY("glGetInteger64v")"\n"
"\t"STUB_ASM_CODE("991")"\n"

STUB_ASM_ENTRY("glGetInteger64vAPPLE")"\n"
"\t"STUB_ASM_CODE("992")"\n"

STUB_ASM_ENTRY("glGetIntegerIndexedvEXT")"\n"
"\t"STUB_ASM_CODE("994")"\n"

STUB_ASM_ENTRY("glGetIntegeri_v")"\n"
"\t"STUB_ASM_CODE("995")"\n"

STUB_ASM_ENTRY("glGetIntegeri_vEXT")"\n"
"\t"STUB_ASM_CODE("996")"\n"

STUB_ASM_ENTRY("glGetIntegerui64i_vNV")"\n"
"\t"STUB_ASM_CODE("997")"\n"

STUB_ASM_ENTRY("glGetIntegerui64vNV")"\n"
"\t"STUB_ASM_CODE("998")"\n"

STUB_ASM_ENTRY("glGetIntegerv")"\n"
"\t"STUB_ASM_CODE("999")"\n"

STUB_ASM_ENTRY("glGetInternalformatSampleivNV")"\n"
"\t"STUB_ASM_CODE("1000")"\n"

STUB_ASM_ENTRY("glGetInternalformati64v")"\n"
"\t"STUB_ASM_CODE("1001")"\n"

STUB_ASM_ENTRY("glGetInternalformativ")"\n"
"\t"STUB_ASM_CODE("1002")"\n"

STUB_ASM_ENTRY("glGetInvariantBooleanvEXT")"\n"
"\t"STUB_ASM_CODE("1003")"\n"

STUB_ASM_ENTRY("glGetInvariantFloatvEXT")"\n"
"\t"STUB_ASM_CODE("1004")"\n"

STUB_ASM_ENTRY("glGetInvariantIntegervEXT")"\n"
"\t"STUB_ASM_CODE("1005")"\n"

STUB_ASM_ENTRY("glGetLightfv")"\n"
"\t"STUB_ASM_CODE("1006")"\n"

STUB_ASM_ENTRY("glGetLightiv")"\n"
"\t"STUB_ASM_CODE("1007")"\n"

STUB_ASM_ENTRY("glGetLightxOES")"\n"
"\t"STUB_ASM_CODE("1008")"\n"

STUB_ASM_ENTRY("glGetLightxv")"\n"
"\t"STUB_ASM_CODE("1009")"\n"

STUB_ASM_ENTRY("glGetLightxvOES")"\n"
"\t"STUB_ASM_CODE("1010")"\n"

STUB_ASM_ENTRY("glGetListParameterfvSGIX")"\n"
"\t"STUB_ASM_CODE("1011")"\n"

STUB_ASM_ENTRY("glGetListParameterivSGIX")"\n"
"\t"STUB_ASM_CODE("1012")"\n"

STUB_ASM_ENTRY("glGetLocalConstantBooleanvEXT")"\n"
"\t"STUB_ASM_CODE("1013")"\n"

STUB_ASM_ENTRY("glGetLocalConstantFloatvEXT")"\n"
"\t"STUB_ASM_CODE("1014")"\n"

STUB_ASM_ENTRY("glGetLocalConstantIntegervEXT")"\n"
"\t"STUB_ASM_CODE("1015")"\n"

STUB_ASM_ENTRY("glGetMapAttribParameterfvNV")"\n"
"\t"STUB_ASM_CODE("1016")"\n"

STUB_ASM_ENTRY("glGetMapAttribParameterivNV")"\n"
"\t"STUB_ASM_CODE("1017")"\n"

STUB_ASM_ENTRY("glGetMapControlPointsNV")"\n"
"\t"STUB_ASM_CODE("1018")"\n"

STUB_ASM_ENTRY("glGetMapParameterfvNV")"\n"
"\t"STUB_ASM_CODE("1019")"\n"

STUB_ASM_ENTRY("glGetMapParameterivNV")"\n"
"\t"STUB_ASM_CODE("1020")"\n"

STUB_ASM_ENTRY("glGetMapdv")"\n"
"\t"STUB_ASM_CODE("1021")"\n"

STUB_ASM_ENTRY("glGetMapfv")"\n"
"\t"STUB_ASM_CODE("1022")"\n"

STUB_ASM_ENTRY("glGetMapiv")"\n"
"\t"STUB_ASM_CODE("1023")"\n"

STUB_ASM_ENTRY("glGetMapxvOES")"\n"
"\t"STUB_ASM_CODE("1024")"\n"

STUB_ASM_ENTRY("glGetMaterialfv")"\n"
"\t"STUB_ASM_CODE("1025")"\n"

STUB_ASM_ENTRY("glGetMaterialiv")"\n"
"\t"STUB_ASM_CODE("1026")"\n"

STUB_ASM_ENTRY("glGetMaterialxOES")"\n"
"\t"STUB_ASM_CODE("1027")"\n"

STUB_ASM_ENTRY("glGetMaterialxv")"\n"
"\t"STUB_ASM_CODE("1028")"\n"

STUB_ASM_ENTRY("glGetMaterialxvOES")"\n"
"\t"STUB_ASM_CODE("1029")"\n"

STUB_ASM_ENTRY("glGetMemoryObjectDetachedResourcesuivNV")"\n"
"\t"STUB_ASM_CODE("1030")"\n"

STUB_ASM_ENTRY("glGetMemoryObjectParameterivEXT")"\n"
"\t"STUB_ASM_CODE("1031")"\n"

STUB_ASM_ENTRY("glGetMinmax")"\n"
"\t"STUB_ASM_CODE("1032")"\n"

STUB_ASM_ENTRY("glGetMinmaxEXT")"\n"
"\t"STUB_ASM_CODE("1033")"\n"

STUB_ASM_ENTRY("glGetMinmaxParameterfv")"\n"
"\t"STUB_ASM_CODE("1034")"\n"

STUB_ASM_ENTRY("glGetMinmaxParameterfvEXT")"\n"
"\t"STUB_ASM_CODE("1035")"\n"

STUB_ASM_ENTRY("glGetMinmaxParameteriv")"\n"
"\t"STUB_ASM_CODE("1036")"\n"

STUB_ASM_ENTRY("glGetMinmaxParameterivEXT")"\n"
"\t"STUB_ASM_CODE("1037")"\n"

STUB_ASM_ENTRY("glGetMultiTexEnvfvEXT")"\n"
"\t"STUB_ASM_CODE("1038")"\n"

STUB_ASM_ENTRY("glGetMultiTexEnvivEXT")"\n"
"\t"STUB_ASM_CODE("1039")"\n"

STUB_ASM_ENTRY("glGetMultiTexGendvEXT")"\n"
"\t"STUB_ASM_CODE("1040")"\n"

STUB_ASM_ENTRY("glGetMultiTexGenfvEXT")"\n"
"\t"STUB_ASM_CODE("1041")"\n"

STUB_ASM_ENTRY("glGetMultiTexGenivEXT")"\n"
"\t"STUB_ASM_CODE("1042")"\n"

STUB_ASM_ENTRY("glGetMultiTexImageEXT")"\n"
"\t"STUB_ASM_CODE("1043")"\n"

STUB_ASM_ENTRY("glGetMultiTexLevelParameterfvEXT")"\n"
"\t"STUB_ASM_CODE("1044")"\n"

STUB_ASM_ENTRY("glGetMultiTexLevelParameterivEXT")"\n"
"\t"STUB_ASM_CODE("1045")"\n"

STUB_ASM_ENTRY("glGetMultiTexParameterIivEXT")"\n"
"\t"STUB_ASM_CODE("1046")"\n"

STUB_ASM_ENTRY("glGetMultiTexParameterIuivEXT")"\n"
"\t"STUB_ASM_CODE("1047")"\n"

STUB_ASM_ENTRY("glGetMultiTexParameterfvEXT")"\n"
"\t"STUB_ASM_CODE("1048")"\n"

STUB_ASM_ENTRY("glGetMultiTexParameterivEXT")"\n"
"\t"STUB_ASM_CODE("1049")"\n"

STUB_ASM_ENTRY("glGetMultisamplefv")"\n"
"\t"STUB_ASM_CODE("1050")"\n"

STUB_ASM_ENTRY("glGetMultisamplefvNV")"\n"
"\t"STUB_ASM_CODE("1051")"\n"

STUB_ASM_ENTRY("glGetNamedBufferParameteri64v")"\n"
"\t"STUB_ASM_CODE("1052")"\n"

STUB_ASM_ENTRY("glGetNamedBufferParameteri64vEXT")"\n"
"\t"STUB_ASM_CODE("1053")"\n"

STUB_ASM_ENTRY("glGetNamedBufferParameteriv")"\n"
"\t"STUB_ASM_CODE("1054")"\n"

STUB_ASM_ENTRY("glGetNamedBufferParameterivEXT")"\n"
"\t"STUB_ASM_CODE("1055")"\n"

STUB_ASM_ENTRY("glGetNamedBufferParameterui64vNV")"\n"
"\t"STUB_ASM_CODE("1056")"\n"

STUB_ASM_ENTRY("glGetNamedBufferPointerv")"\n"
"\t"STUB_ASM_CODE("1057")"\n"

STUB_ASM_ENTRY("glGetNamedBufferPointervEXT")"\n"
"\t"STUB_ASM_CODE("1058")"\n"

STUB_ASM_ENTRY("glGetNamedBufferSubData")"\n"
"\t"STUB_ASM_CODE("1059")"\n"

STUB_ASM_ENTRY("glGetNamedBufferSubDataEXT")"\n"
"\t"STUB_ASM_CODE("1060")"\n"

STUB_ASM_ENTRY("glGetNamedFramebufferAttachmentParameteriv")"\n"
"\t"STUB_ASM_CODE("1061")"\n"

STUB_ASM_ENTRY("glGetNamedFramebufferAttachmentParameterivEXT")"\n"
"\t"STUB_ASM_CODE("1062")"\n"

STUB_ASM_ENTRY("glGetNamedFramebufferParameterfvAMD")"\n"
"\t"STUB_ASM_CODE("1063")"\n"

STUB_ASM_ENTRY("glGetNamedFramebufferParameteriv")"\n"
"\t"STUB_ASM_CODE("1064")"\n"

STUB_ASM_ENTRY("glGetNamedFramebufferParameterivEXT")"\n"
"\t"STUB_ASM_CODE("1065")"\n"

STUB_ASM_ENTRY("glGetNamedProgramLocalParameterIivEXT")"\n"
"\t"STUB_ASM_CODE("1066")"\n"

STUB_ASM_ENTRY("glGetNamedProgramLocalParameterIuivEXT")"\n"
"\t"STUB_ASM_CODE("1067")"\n"

STUB_ASM_ENTRY("glGetNamedProgramLocalParameterdvEXT")"\n"
"\t"STUB_ASM_CODE("1068")"\n"

STUB_ASM_ENTRY("glGetNamedProgramLocalParameterfvEXT")"\n"
"\t"STUB_ASM_CODE("1069")"\n"

STUB_ASM_ENTRY("glGetNamedProgramStringEXT")"\n"
"\t"STUB_ASM_CODE("1070")"\n"

STUB_ASM_ENTRY("glGetNamedProgramivEXT")"\n"
"\t"STUB_ASM_CODE("1071")"\n"

STUB_ASM_ENTRY("glGetNamedRenderbufferParameteriv")"\n"
"\t"STUB_ASM_CODE("1072")"\n"

STUB_ASM_ENTRY("glGetNamedRenderbufferParameterivEXT")"\n"
"\t"STUB_ASM_CODE("1073")"\n"

STUB_ASM_ENTRY("glGetNamedStringARB")"\n"
"\t"STUB_ASM_CODE("1074")"\n"

STUB_ASM_ENTRY("glGetNamedStringivARB")"\n"
"\t"STUB_ASM_CODE("1075")"\n"

STUB_ASM_ENTRY("glGetNextPerfQueryIdINTEL")"\n"
"\t"STUB_ASM_CODE("1076")"\n"

STUB_ASM_ENTRY("glGetObjectBufferfvATI")"\n"
"\t"STUB_ASM_CODE("1077")"\n"

STUB_ASM_ENTRY("glGetObjectBufferivATI")"\n"
"\t"STUB_ASM_CODE("1078")"\n"

STUB_ASM_ENTRY("glGetObjectLabel")"\n"
"\t"STUB_ASM_CODE("1079")"\n"

STUB_ASM_ENTRY("glGetObjectLabelEXT")"\n"
"\t"STUB_ASM_CODE("1080")"\n"

STUB_ASM_ENTRY("glGetObjectLabelKHR")"\n"
"\t"STUB_ASM_CODE("1081")"\n"

STUB_ASM_ENTRY("glGetObjectLabelOES")"\n"
"\t"STUB_ASM_CODE("1082")"\n"

STUB_ASM_ENTRY("glGetObjectParameterfvARB")"\n"
"\t"STUB_ASM_CODE("1083")"\n"

STUB_ASM_ENTRY("glGetObjectParameterivAPPLE")"\n"
"\t"STUB_ASM_CODE("1084")"\n"

STUB_ASM_ENTRY("glGetObjectParameterivARB")"\n"
"\t"STUB_ASM_CODE("1085")"\n"

STUB_ASM_ENTRY("glGetObjectPtrLabel")"\n"
"\t"STUB_ASM_CODE("1086")"\n"

STUB_ASM_ENTRY("glGetObjectPtrLabelKHR")"\n"
"\t"STUB_ASM_CODE("1087")"\n"

STUB_ASM_ENTRY("glGetObjectPtrLabelOES")"\n"
"\t"STUB_ASM_CODE("1088")"\n"

STUB_ASM_ENTRY("glGetOcclusionQueryivNV")"\n"
"\t"STUB_ASM_CODE("1089")"\n"

STUB_ASM_ENTRY("glGetOcclusionQueryuivNV")"\n"
"\t"STUB_ASM_CODE("1090")"\n"

STUB_ASM_ENTRY("glGetPathColorGenfvNV")"\n"
"\t"STUB_ASM_CODE("1091")"\n"

STUB_ASM_ENTRY("glGetPathColorGenivNV")"\n"
"\t"STUB_ASM_CODE("1092")"\n"

STUB_ASM_ENTRY("glGetPathCommandsNV")"\n"
"\t"STUB_ASM_CODE("1093")"\n"

STUB_ASM_ENTRY("glGetPathCoordsNV")"\n"
"\t"STUB_ASM_CODE("1094")"\n"

STUB_ASM_ENTRY("glGetPathDashArrayNV")"\n"
"\t"STUB_ASM_CODE("1095")"\n"

STUB_ASM_ENTRY("glGetPathLengthNV")"\n"
"\t"STUB_ASM_CODE("1096")"\n"

STUB_ASM_ENTRY("glGetPathMetricRangeNV")"\n"
"\t"STUB_ASM_CODE("1097")"\n"

STUB_ASM_ENTRY("glGetPathMetricsNV")"\n"
"\t"STUB_ASM_CODE("1098")"\n"

STUB_ASM_ENTRY("glGetPathParameterfvNV")"\n"
"\t"STUB_ASM_CODE("1099")"\n"

STUB_ASM_ENTRY("glGetPathParameterivNV")"\n"
"\t"STUB_ASM_CODE("1100")"\n"

STUB_ASM_ENTRY("glGetPathSpacingNV")"\n"
"\t"STUB_ASM_CODE("1101")"\n"

STUB_ASM_ENTRY("glGetPathTexGenfvNV")"\n"
"\t"STUB_ASM_CODE("1102")"\n"

STUB_ASM_ENTRY("glGetPathTexGenivNV")"\n"
"\t"STUB_ASM_CODE("1103")"\n"

STUB_ASM_ENTRY("glGetPerfCounterInfoINTEL")"\n"
"\t"STUB_ASM_CODE("1104")"\n"

STUB_ASM_ENTRY("glGetPerfMonitorCounterDataAMD")"\n"
"\t"STUB_ASM_CODE("1105")"\n"

STUB_ASM_ENTRY("glGetPerfMonitorCounterInfoAMD")"\n"
"\t"STUB_ASM_CODE("1106")"\n"

STUB_ASM_ENTRY("glGetPerfMonitorCounterStringAMD")"\n"
"\t"STUB_ASM_CODE("1107")"\n"

STUB_ASM_ENTRY("glGetPerfMonitorCountersAMD")"\n"
"\t"STUB_ASM_CODE("1108")"\n"

STUB_ASM_ENTRY("glGetPerfMonitorGroupStringAMD")"\n"
"\t"STUB_ASM_CODE("1109")"\n"

STUB_ASM_ENTRY("glGetPerfMonitorGroupsAMD")"\n"
"\t"STUB_ASM_CODE("1110")"\n"

STUB_ASM_ENTRY("glGetPerfQueryDataINTEL")"\n"
"\t"STUB_ASM_CODE("1111")"\n"

STUB_ASM_ENTRY("glGetPerfQueryIdByNameINTEL")"\n"
"\t"STUB_ASM_CODE("1112")"\n"

STUB_ASM_ENTRY("glGetPerfQueryInfoINTEL")"\n"
"\t"STUB_ASM_CODE("1113")"\n"

STUB_ASM_ENTRY("glGetPixelMapfv")"\n"
"\t"STUB_ASM_CODE("1114")"\n"

STUB_ASM_ENTRY("glGetPixelMapuiv")"\n"
"\t"STUB_ASM_CODE("1115")"\n"

STUB_ASM_ENTRY("glGetPixelMapusv")"\n"
"\t"STUB_ASM_CODE("1116")"\n"

STUB_ASM_ENTRY("glGetPixelMapxv")"\n"
"\t"STUB_ASM_CODE("1117")"\n"

STUB_ASM_ENTRY("glGetPixelTexGenParameterfvSGIS")"\n"
"\t"STUB_ASM_CODE("1118")"\n"

STUB_ASM_ENTRY("glGetPixelTexGenParameterivSGIS")"\n"
"\t"STUB_ASM_CODE("1119")"\n"

STUB_ASM_ENTRY("glGetPixelTransformParameterfvEXT")"\n"
"\t"STUB_ASM_CODE("1120")"\n"

STUB_ASM_ENTRY("glGetPixelTransformParameterivEXT")"\n"
"\t"STUB_ASM_CODE("1121")"\n"

STUB_ASM_ENTRY("glGetPointerIndexedvEXT")"\n"
"\t"STUB_ASM_CODE("1122")"\n"

STUB_ASM_ENTRY("glGetPointeri_vEXT")"\n"
"\t"STUB_ASM_CODE("1123")"\n"

STUB_ASM_ENTRY("glGetPointerv")"\n"
"\t"STUB_ASM_CODE("1124")"\n"

STUB_ASM_ENTRY("glGetPointervEXT")"\n"
"\t"STUB_ASM_CODE("1125")"\n"

STUB_ASM_ENTRY("glGetPointervKHR")"\n"
"\t"STUB_ASM_CODE("1126")"\n"

STUB_ASM_ENTRY("glGetPointervOES")"\n"
"\t"STUB_ASM_CODE("1127")"\n"

STUB_ASM_ENTRY("glGetPolygonStipple")"\n"
"\t"STUB_ASM_CODE("1128")"\n"

STUB_ASM_ENTRY("glGetProgramBinary")"\n"
"\t"STUB_ASM_CODE("1129")"\n"

STUB_ASM_ENTRY("glGetProgramBinaryOES")"\n"
"\t"STUB_ASM_CODE("1130")"\n"

STUB_ASM_ENTRY("glGetProgramEnvParameterIivNV")"\n"
"\t"STUB_ASM_CODE("1131")"\n"

STUB_ASM_ENTRY("glGetProgramEnvParameterIuivNV")"\n"
"\t"STUB_ASM_CODE("1132")"\n"

STUB_ASM_ENTRY("glGetProgramEnvParameterdvARB")"\n"
"\t"STUB_ASM_CODE("1133")"\n"

STUB_ASM_ENTRY("glGetProgramEnvParameterfvARB")"\n"
"\t"STUB_ASM_CODE("1134")"\n"

STUB_ASM_ENTRY("glGetProgramInfoLog")"\n"
"\t"STUB_ASM_CODE("1135")"\n"

STUB_ASM_ENTRY("glGetProgramInterfaceiv")"\n"
"\t"STUB_ASM_CODE("1136")"\n"

STUB_ASM_ENTRY("glGetProgramLocalParameterIivNV")"\n"
"\t"STUB_ASM_CODE("1137")"\n"

STUB_ASM_ENTRY("glGetProgramLocalParameterIuivNV")"\n"
"\t"STUB_ASM_CODE("1138")"\n"

STUB_ASM_ENTRY("glGetProgramLocalParameterdvARB")"\n"
"\t"STUB_ASM_CODE("1139")"\n"

STUB_ASM_ENTRY("glGetProgramLocalParameterfvARB")"\n"
"\t"STUB_ASM_CODE("1140")"\n"

STUB_ASM_ENTRY("glGetProgramNamedParameterdvNV")"\n"
"\t"STUB_ASM_CODE("1141")"\n"

STUB_ASM_ENTRY("glGetProgramNamedParameterfvNV")"\n"
"\t"STUB_ASM_CODE("1142")"\n"

STUB_ASM_ENTRY("glGetProgramParameterdvNV")"\n"
"\t"STUB_ASM_CODE("1143")"\n"

STUB_ASM_ENTRY("glGetProgramParameterfvNV")"\n"
"\t"STUB_ASM_CODE("1144")"\n"

STUB_ASM_ENTRY("glGetProgramPipelineInfoLog")"\n"
"\t"STUB_ASM_CODE("1145")"\n"

STUB_ASM_ENTRY("glGetProgramPipelineInfoLogEXT")"\n"
"\t"STUB_ASM_CODE("1146")"\n"

STUB_ASM_ENTRY("glGetProgramPipelineiv")"\n"
"\t"STUB_ASM_CODE("1147")"\n"

STUB_ASM_ENTRY("glGetProgramPipelineivEXT")"\n"
"\t"STUB_ASM_CODE("1148")"\n"

STUB_ASM_ENTRY("glGetProgramResourceIndex")"\n"
"\t"STUB_ASM_CODE("1149")"\n"

STUB_ASM_ENTRY("glGetProgramResourceLocation")"\n"
"\t"STUB_ASM_CODE("1150")"\n"

STUB_ASM_ENTRY("glGetProgramResourceLocationIndex")"\n"
"\t"STUB_ASM_CODE("1151")"\n"

STUB_ASM_ENTRY("glGetProgramResourceLocationIndexEXT")"\n"
"\t"STUB_ASM_CODE("1152")"\n"

STUB_ASM_ENTRY("glGetProgramResourceName")"\n"
"\t"STUB_ASM_CODE("1153")"\n"

STUB_ASM_ENTRY("glGetProgramResourcefvNV")"\n"
"\t"STUB_ASM_CODE("1154")"\n"

STUB_ASM_ENTRY("glGetProgramResourceiv")"\n"
"\t"STUB_ASM_CODE("1155")"\n"

STUB_ASM_ENTRY("glGetProgramStageiv")"\n"
"\t"STUB_ASM_CODE("1156")"\n"

STUB_ASM_ENTRY("glGetProgramStringARB")"\n"
"\t"STUB_ASM_CODE("1157")"\n"

STUB_ASM_ENTRY("glGetProgramStringNV")"\n"
"\t"STUB_ASM_CODE("1158")"\n"

STUB_ASM_ENTRY("glGetProgramSubroutineParameteruivNV")"\n"
"\t"STUB_ASM_CODE("1159")"\n"

STUB_ASM_ENTRY("glGetProgramiv")"\n"
"\t"STUB_ASM_CODE("1160")"\n"

STUB_ASM_ENTRY("glGetProgramivARB")"\n"
"\t"STUB_ASM_CODE("1161")"\n"

STUB_ASM_ENTRY("glGetProgramivNV")"\n"
"\t"STUB_ASM_CODE("1162")"\n"

STUB_ASM_ENTRY("glGetQueryBufferObjecti64v")"\n"
"\t"STUB_ASM_CODE("1163")"\n"

STUB_ASM_ENTRY("glGetQueryBufferObjectiv")"\n"
"\t"STUB_ASM_CODE("1164")"\n"

STUB_ASM_ENTRY("glGetQueryBufferObjectui64v")"\n"
"\t"STUB_ASM_CODE("1165")"\n"

STUB_ASM_ENTRY("glGetQueryBufferObjectuiv")"\n"
"\t"STUB_ASM_CODE("1166")"\n"

STUB_ASM_ENTRY("glGetQueryIndexediv")"\n"
"\t"STUB_ASM_CODE("1167")"\n"

STUB_ASM_ENTRY("glGetQueryObjecti64v")"\n"
"\t"STUB_ASM_CODE("1168")"\n"

STUB_ASM_ENTRY("glGetQueryObjecti64vEXT")"\n"
"\t"STUB_ASM_CODE("1169")"\n"

STUB_ASM_ENTRY("glGetQueryObjectiv")"\n"
"\t"STUB_ASM_CODE("1170")"\n"

STUB_ASM_ENTRY("glGetQueryObjectivARB")"\n"
"\t"STUB_ASM_CODE("1171")"\n"

STUB_ASM_ENTRY("glGetQueryObjectivEXT")"\n"
"\t"STUB_ASM_CODE("1172")"\n"

STUB_ASM_ENTRY("glGetQueryObjectui64v")"\n"
"\t"STUB_ASM_CODE("1173")"\n"

STUB_ASM_ENTRY("glGetQueryObjectui64vEXT")"\n"
"\t"STUB_ASM_CODE("1174")"\n"

STUB_ASM_ENTRY("glGetQueryObjectui64vNV")"\n"
"\t"STUB_ASM_CODE("1175")"\n"

STUB_ASM_ENTRY("glGetQueryObjectuiv")"\n"
"\t"STUB_ASM_CODE("1176")"\n"

STUB_ASM_ENTRY("glGetQueryObjectuivARB")"\n"
"\t"STUB_ASM_CODE("1177")"\n"

STUB_ASM_ENTRY("glGetQueryObjectuivEXT")"\n"
"\t"STUB_ASM_CODE("1178")"\n"

STUB_ASM_ENTRY("glGetQueryiv")"\n"
"\t"STUB_ASM_CODE("1179")"\n"

STUB_ASM_ENTRY("glGetQueryivARB")"\n"
"\t"STUB_ASM_CODE("1180")"\n"

STUB_ASM_ENTRY("glGetQueryivEXT")"\n"
"\t"STUB_ASM_CODE("1181")"\n"

STUB_ASM_ENTRY("glGetRenderbufferParameteriv")"\n"
"\t"STUB_ASM_CODE("1182")"\n"

STUB_ASM_ENTRY("glGetRenderbufferParameterivEXT")"\n"
"\t"STUB_ASM_CODE("1183")"\n"

STUB_ASM_ENTRY("glGetRenderbufferParameterivOES")"\n"
"\t"STUB_ASM_CODE("1184")"\n"

STUB_ASM_ENTRY("glGetSamplerParameterIiv")"\n"
"\t"STUB_ASM_CODE("1185")"\n"

STUB_ASM_ENTRY("glGetSamplerParameterIivEXT")"\n"
"\t"STUB_ASM_CODE("1186")"\n"

STUB_ASM_ENTRY("glGetSamplerParameterIivOES")"\n"
"\t"STUB_ASM_CODE("1187")"\n"

STUB_ASM_ENTRY("glGetSamplerParameterIuiv")"\n"
"\t"STUB_ASM_CODE("1188")"\n"

STUB_ASM_ENTRY("glGetSamplerParameterIuivEXT")"\n"
"\t"STUB_ASM_CODE("1189")"\n"

STUB_ASM_ENTRY("glGetSamplerParameterIuivOES")"\n"
"\t"STUB_ASM_CODE("1190")"\n"

STUB_ASM_ENTRY("glGetSamplerParameterfv")"\n"
"\t"STUB_ASM_CODE("1191")"\n"

STUB_ASM_ENTRY("glGetSamplerParameteriv")"\n"
"\t"STUB_ASM_CODE("1192")"\n"

STUB_ASM_ENTRY("glGetSemaphoreParameterui64vEXT")"\n"
"\t"STUB_ASM_CODE("1194")"\n"

STUB_ASM_ENTRY("glGetSeparableFilter")"\n"
"\t"STUB_ASM_CODE("1195")"\n"

STUB_ASM_ENTRY("glGetSeparableFilterEXT")"\n"
"\t"STUB_ASM_CODE("1196")"\n"

STUB_ASM_ENTRY("glGetShaderInfoLog")"\n"
"\t"STUB_ASM_CODE("1197")"\n"

STUB_ASM_ENTRY("glGetShaderPrecisionFormat")"\n"
"\t"STUB_ASM_CODE("1198")"\n"

STUB_ASM_ENTRY("glGetShaderSource")"\n"
"\t"STUB_ASM_CODE("1199")"\n"

STUB_ASM_ENTRY("glGetShaderSourceARB")"\n"
"\t"STUB_ASM_CODE("1200")"\n"

STUB_ASM_ENTRY("glGetShaderiv")"\n"
"\t"STUB_ASM_CODE("1201")"\n"

STUB_ASM_ENTRY("glGetShadingRateImagePaletteNV")"\n"
"\t"STUB_ASM_CODE("1202")"\n"

STUB_ASM_ENTRY("glGetShadingRateSampleLocationivNV")"\n"
"\t"STUB_ASM_CODE("1203")"\n"

STUB_ASM_ENTRY("glGetSharpenTexFuncSGIS")"\n"
"\t"STUB_ASM_CODE("1204")"\n"

STUB_ASM_ENTRY("glGetStageIndexNV")"\n"
"\t"STUB_ASM_CODE("1205")"\n"

STUB_ASM_ENTRY("glGetString")"\n"
"\t"STUB_ASM_CODE("1206")"\n"

STUB_ASM_ENTRY("glGetStringi")"\n"
"\t"STUB_ASM_CODE("1207")"\n"

STUB_ASM_ENTRY("glGetSubroutineIndex")"\n"
"\t"STUB_ASM_CODE("1208")"\n"

STUB_ASM_ENTRY("glGetSubroutineUniformLocation")"\n"
"\t"STUB_ASM_CODE("1209")"\n"

STUB_ASM_ENTRY("glGetSynciv")"\n"
"\t"STUB_ASM_CODE("1210")"\n"

STUB_ASM_ENTRY("glGetSyncivAPPLE")"\n"
"\t"STUB_ASM_CODE("1211")"\n"

STUB_ASM_ENTRY("glGetSyncv64NVX")"\n"
"\t"STUB_ASM_CODE("1212")"\n"

STUB_ASM_ENTRY("glGetTexBumpParameterfvATI")"\n"
"\t"STUB_ASM_CODE("1213")"\n"

STUB_ASM_ENTRY("glGetTexBumpParameterivATI")"\n"
"\t"STUB_ASM_CODE("1214")"\n"

STUB_ASM_ENTRY("glGetTexEnvfv")"\n"
"\t"STUB_ASM_CODE("1215")"\n"

STUB_ASM_ENTRY("glGetTexEnviv")"\n"
"\t"STUB_ASM_CODE("1216")"\n"

STUB_ASM_ENTRY("glGetTexEnvxv")"\n"
"\t"STUB_ASM_CODE("1217")"\n"

STUB_ASM_ENTRY("glGetTexEnvxvOES")"\n"
"\t"STUB_ASM_CODE("1218")"\n"

STUB_ASM_ENTRY("glGetTexFilterFuncSGIS")"\n"
"\t"STUB_ASM_CODE("1219")"\n"

STUB_ASM_ENTRY("glGetTexGendv")"\n"
"\t"STUB_ASM_CODE("1220")"\n"

STUB_ASM_ENTRY("glGetTexGenfv")"\n"
"\t"STUB_ASM_CODE("1221")"\n"

STUB_ASM_ENTRY("glGetTexGenfvOES")"\n"
"\t"STUB_ASM_CODE("1222")"\n"

STUB_ASM_ENTRY("glGetTexGeniv")"\n"
"\t"STUB_ASM_CODE("1223")"\n"

STUB_ASM_ENTRY("glGetTexGenivOES")"\n"
"\t"STUB_ASM_CODE("1224")"\n"

STUB_ASM_ENTRY("glGetTexGenxvOES")"\n"
"\t"STUB_ASM_CODE("1225")"\n"

STUB_ASM_ENTRY("glGetTexImage")"\n"
"\t"STUB_ASM_CODE("1226")"\n"

STUB_ASM_ENTRY("glGetTexImageNV")"\n"
"\t"STUB_ASM_CODE("1227")"\n"

STUB_ASM_ENTRY("glGetTexLevelParameterfv")"\n"
"\t"STUB_ASM_CODE("1228")"\n"

STUB_ASM_ENTRY("glGetTexLevelParameterfvNV")"\n"
"\t"STUB_ASM_CODE("1229")"\n"

STUB_ASM_ENTRY("glGetTexLevelParameteriv")"\n"
"\t"STUB_ASM_CODE("1230")"\n"

STUB_ASM_ENTRY("glGetTexLevelParameterivNV")"\n"
"\t"STUB_ASM_CODE("1231")"\n"

STUB_ASM_ENTRY("glGetTexLevelParameterxvOES")"\n"
"\t"STUB_ASM_CODE("1232")"\n"

STUB_ASM_ENTRY("glGetTexParameterIiv")"\n"
"\t"STUB_ASM_CODE("1233")"\n"

STUB_ASM_ENTRY("glGetTexParameterIivEXT")"\n"
"\t"STUB_ASM_CODE("1234")"\n"

STUB_ASM_ENTRY("glGetTexParameterIivOES")"\n"
"\t"STUB_ASM_CODE("1235")"\n"

STUB_ASM_ENTRY("glGetTexParameterIuiv")"\n"
"\t"STUB_ASM_CODE("1236")"\n"

STUB_ASM_ENTRY("glGetTexParameterIuivEXT")"\n"
"\t"STUB_ASM_CODE("1237")"\n"

STUB_ASM_ENTRY("glGetTexParameterIuivOES")"\n"
"\t"STUB_ASM_CODE("1238")"\n"

STUB_ASM_ENTRY("glGetTexParameterPointervAPPLE")"\n"
"\t"STUB_ASM_CODE("1239")"\n"

STUB_ASM_ENTRY("glGetTexParameterfv")"\n"
"\t"STUB_ASM_CODE("1240")"\n"

STUB_ASM_ENTRY("glGetTexParameteriv")"\n"
"\t"STUB_ASM_CODE("1241")"\n"

STUB_ASM_ENTRY("glGetTexParameterxv")"\n"
"\t"STUB_ASM_CODE("1242")"\n"

STUB_ASM_ENTRY("glGetTexParameterxvOES")"\n"
"\t"STUB_ASM_CODE("1243")"\n"

STUB_ASM_ENTRY("glGetTextureHandleARB")"\n"
"\t"STUB_ASM_CODE("1244")"\n"

STUB_ASM_ENTRY("glGetTextureHandleIMG")"\n"
"\t"STUB_ASM_CODE("1245")"\n"

STUB_ASM_ENTRY("glGetTextureHandleNV")"\n"
"\t"STUB_ASM_CODE("1246")"\n"

STUB_ASM_ENTRY("glGetTextureImage")"\n"
"\t"STUB_ASM_CODE("1247")"\n"

STUB_ASM_ENTRY("glGetTextureImageEXT")"\n"
"\t"STUB_ASM_CODE("1248")"\n"

STUB_ASM_ENTRY("glGetTextureLevelParameterfv")"\n"
"\t"STUB_ASM_CODE("1249")"\n"

STUB_ASM_ENTRY("glGetTextureLevelParameterfvEXT")"\n"
"\t"STUB_ASM_CODE("1250")"\n"

STUB_ASM_ENTRY("glGetTextureLevelParameteriv")"\n"
"\t"STUB_ASM_CODE("1251")"\n"

STUB_ASM_ENTRY("glGetTextureLevelParameterivEXT")"\n"
"\t"STUB_ASM_CODE("1252")"\n"

STUB_ASM_ENTRY("glGetTextureParameterIiv")"\n"
"\t"STUB_ASM_CODE("1253")"\n"

STUB_ASM_ENTRY("glGetTextureParameterIivEXT")"\n"
"\t"STUB_ASM_CODE("1254")"\n"

STUB_ASM_ENTRY("glGetTextureParameterIuiv")"\n"
"\t"STUB_ASM_CODE("1255")"\n"

STUB_ASM_ENTRY("glGetTextureParameterIuivEXT")"\n"
"\t"STUB_ASM_CODE("1256")"\n"

STUB_ASM_ENTRY("glGetTextureParameterfv")"\n"
"\t"STUB_ASM_CODE("1257")"\n"

STUB_ASM_ENTRY("glGetTextureParameterfvEXT")"\n"
"\t"STUB_ASM_CODE("1258")"\n"

STUB_ASM_ENTRY("glGetTextureParameteriv")"\n"
"\t"STUB_ASM_CODE("1259")"\n"

STUB_ASM_ENTRY("glGetTextureParameterivEXT")"\n"
"\t"STUB_ASM_CODE("1260")"\n"

STUB_ASM_ENTRY("glGetTextureSamplerHandleARB")"\n"
"\t"STUB_ASM_CODE("1261")"\n"

STUB_ASM_ENTRY("glGetTextureSamplerHandleIMG")"\n"
"\t"STUB_ASM_CODE("1262")"\n"

STUB_ASM_ENTRY("glGetTextureSamplerHandleNV")"\n"
"\t"STUB_ASM_CODE("1263")"\n"

STUB_ASM_ENTRY("glGetTextureSubImage")"\n"
"\t"STUB_ASM_CODE("1264")"\n"

STUB_ASM_ENTRY("glGetTrackMatrixivNV")"\n"
"\t"STUB_ASM_CODE("1265")"\n"

STUB_ASM_ENTRY("glGetTransformFeedbackVarying")"\n"
"\t"STUB_ASM_CODE("1266")"\n"

STUB_ASM_ENTRY("glGetTransformFeedbackVaryingEXT")"\n"
"\t"STUB_ASM_CODE("1267")"\n"

STUB_ASM_ENTRY("glGetTransformFeedbackVaryingNV")"\n"
"\t"STUB_ASM_CODE("1268")"\n"

STUB_ASM_ENTRY("glGetTransformFeedbacki64_v")"\n"
"\t"STUB_ASM_CODE("1269")"\n"

STUB_ASM_ENTRY("glGetTransformFeedbacki_v")"\n"
"\t"STUB_ASM_CODE("1270")"\n"

STUB_ASM_ENTRY("glGetTransformFeedbackiv")"\n"
"\t"STUB_ASM_CODE("1271")"\n"

STUB_ASM_ENTRY("glGetTranslatedShaderSourceANGLE")"\n"
"\t"STUB_ASM_CODE("1272")"\n"

STUB_ASM_ENTRY("glGetUniformBlockIndex")"\n"
"\t"STUB_ASM_CODE("1273")"\n"

STUB_ASM_ENTRY("glGetUniformBufferSizeEXT")"\n"
"\t"STUB_ASM_CODE("1274")"\n"

STUB_ASM_ENTRY("glGetUniformIndices")"\n"
"\t"STUB_ASM_CODE("1275")"\n"

STUB_ASM_ENTRY("glGetUniformLocation")"\n"
"\t"STUB_ASM_CODE("1276")"\n"

STUB_ASM_ENTRY("glGetUniformLocationARB")"\n"
"\t"STUB_ASM_CODE("1277")"\n"

STUB_ASM_ENTRY("glGetUniformOffsetEXT")"\n"
"\t"STUB_ASM_CODE("1278")"\n"

STUB_ASM_ENTRY("glGetUniformSubroutineuiv")"\n"
"\t"STUB_ASM_CODE("1279")"\n"

STUB_ASM_ENTRY("glGetUniformdv")"\n"
"\t"STUB_ASM_CODE("1280")"\n"

STUB_ASM_ENTRY("glGetUniformfv")"\n"
"\t"STUB_ASM_CODE("1281")"\n"

STUB_ASM_ENTRY("glGetUniformfvARB")"\n"
"\t"STUB_ASM_CODE("1282")"\n"

STUB_ASM_ENTRY("glGetUniformi64vARB")"\n"
"\t"STUB_ASM_CODE("1283")"\n"

STUB_ASM_ENTRY("glGetUniformi64vNV")"\n"
"\t"STUB_ASM_CODE("1284")"\n"

STUB_ASM_ENTRY("glGetUniformiv")"\n"
"\t"STUB_ASM_CODE("1285")"\n"

STUB_ASM_ENTRY("glGetUniformivARB")"\n"
"\t"STUB_ASM_CODE("1286")"\n"

STUB_ASM_ENTRY("glGetUniformui64vARB")"\n"
"\t"STUB_ASM_CODE("1287")"\n"

STUB_ASM_ENTRY("glGetUniformui64vNV")"\n"
"\t"STUB_ASM_CODE("1288")"\n"

STUB_ASM_ENTRY("glGetUniformuiv")"\n"
"\t"STUB_ASM_CODE("1289")"\n"

STUB_ASM_ENTRY("glGetUniformuivEXT")"\n"
"\t"STUB_ASM_CODE("1290")"\n"

STUB_ASM_ENTRY("glGetUnsignedBytei_vEXT")"\n"
"\t"STUB_ASM_CODE("1291")"\n"

STUB_ASM_ENTRY("glGetUnsignedBytevEXT")"\n"
"\t"STUB_ASM_CODE("1292")"\n"

STUB_ASM_ENTRY("glGetVariantArrayObjectfvATI")"\n"
"\t"STUB_ASM_CODE("1293")"\n"

STUB_ASM_ENTRY("glGetVariantArrayObjectivATI")"\n"
"\t"STUB_ASM_CODE("1294")"\n"

STUB_ASM_ENTRY("glGetVariantBooleanvEXT")"\n"
"\t"STUB_ASM_CODE("1295")"\n"

STUB_ASM_ENTRY("glGetVariantFloatvEXT")"\n"
"\t"STUB_ASM_CODE("1296")"\n"

STUB_ASM_ENTRY("glGetVariantIntegervEXT")"\n"
"\t"STUB_ASM_CODE("1297")"\n"

STUB_ASM_ENTRY("glGetVariantPointervEXT")"\n"
"\t"STUB_ASM_CODE("1298")"\n"

STUB_ASM_ENTRY("glGetVaryingLocationNV")"\n"
"\t"STUB_ASM_CODE("1299")"\n"

STUB_ASM_ENTRY("glGetVertexArrayIndexed64iv")"\n"
"\t"STUB_ASM_CODE("1300")"\n"

STUB_ASM_ENTRY("glGetVertexArrayIndexediv")"\n"
"\t"STUB_ASM_CODE("1301")"\n"

STUB_ASM_ENTRY("glGetVertexArrayIntegeri_vEXT")"\n"
"\t"STUB_ASM_CODE("1302")"\n"

STUB_ASM_ENTRY("glGetVertexArrayIntegervEXT")"\n"
"\t"STUB_ASM_CODE("1303")"\n"

STUB_ASM_ENTRY("glGetVertexArrayPointeri_vEXT")"\n"
"\t"STUB_ASM_CODE("1304")"\n"

STUB_ASM_ENTRY("glGetVertexArrayPointervEXT")"\n"
"\t"STUB_ASM_CODE("1305")"\n"

STUB_ASM_ENTRY("glGetVertexArrayiv")"\n"
"\t"STUB_ASM_CODE("1306")"\n"

STUB_ASM_ENTRY("glGetVertexAttribArrayObjectfvATI")"\n"
"\t"STUB_ASM_CODE("1307")"\n"

STUB_ASM_ENTRY("glGetVertexAttribArrayObjectivATI")"\n"
"\t"STUB_ASM_CODE("1308")"\n"

STUB_ASM_ENTRY("glGetVertexAttribIiv")"\n"
"\t"STUB_ASM_CODE("1309")"\n"

STUB_ASM_ENTRY("glGetVertexAttribIivEXT")"\n"
"\t"STUB_ASM_CODE("1310")"\n"

STUB_ASM_ENTRY("glGetVertexAttribIuiv")"\n"
"\t"STUB_ASM_CODE("1311")"\n"

STUB_ASM_ENTRY("glGetVertexAttribIuivEXT")"\n"
"\t"STUB_ASM_CODE("1312")"\n"

STUB_ASM_ENTRY("glGetVertexAttribLdv")"\n"
"\t"STUB_ASM_CODE("1313")"\n"

STUB_ASM_ENTRY("glGetVertexAttribLdvEXT")"\n"
"\t"STUB_ASM_CODE("1314")"\n"

STUB_ASM_ENTRY("glGetVertexAttribLi64vNV")"\n"
"\t"STUB_ASM_CODE("1315")"\n"

STUB_ASM_ENTRY("glGetVertexAttribLui64vARB")"\n"
"\t"STUB_ASM_CODE("1316")"\n"

STUB_ASM_ENTRY("glGetVertexAttribLui64vNV")"\n"
"\t"STUB_ASM_CODE("1317")"\n"

STUB_ASM_ENTRY("glGetVertexAttribPointerv")"\n"
"\t"STUB_ASM_CODE("1318")"\n"

STUB_ASM_ENTRY("glGetVertexAttribPointervARB")"\n"
"\t"STUB_ASM_CODE("1319")"\n"

STUB_ASM_ENTRY("glGetVertexAttribPointervNV")"\n"
"\t"STUB_ASM_CODE("1320")"\n"

STUB_ASM_ENTRY("glGetVertexAttribdv")"\n"
"\t"STUB_ASM_CODE("1321")"\n"

STUB_ASM_ENTRY("glGetVertexAttribdvARB")"\n"
"\t"STUB_ASM_CODE("1322")"\n"

STUB_ASM_ENTRY("glGetVertexAttribdvNV")"\n"
"\t"STUB_ASM_CODE("1323")"\n"

STUB_ASM_ENTRY("glGetVertexAttribfv")"\n"
"\t"STUB_ASM_CODE("1324")"\n"

STUB_ASM_ENTRY("glGetVertexAttribfvARB")"\n"
"\t"STUB_ASM_CODE("1325")"\n"

STUB_ASM_ENTRY("glGetVertexAttribfvNV")"\n"
"\t"STUB_ASM_CODE("1326")"\n"

STUB_ASM_ENTRY("glGetVertexAttribiv")"\n"
"\t"STUB_ASM_CODE("1327")"\n"

STUB_ASM_ENTRY("glGetVertexAttribivARB")"\n"
"\t"STUB_ASM_CODE("1328")"\n"

STUB_ASM_ENTRY("glGetVertexAttribivNV")"\n"
"\t"STUB_ASM_CODE("1329")"\n"

STUB_ASM_ENTRY("glGetVideoCaptureANCStreamivNVX")"\n"
"\t"STUB_ASM_CODE("1330")"\n"

STUB_ASM_ENTRY("glGetVideoCaptureStreamdvNV")"\n"
"\t"STUB_ASM_CODE("1331")"\n"

STUB_ASM_ENTRY("glGetVideoCaptureStreamfvNV")"\n"
"\t"STUB_ASM_CODE("1332")"\n"

STUB_ASM_ENTRY("glGetVideoCaptureStreamivNV")"\n"
"\t"STUB_ASM_CODE("1333")"\n"

STUB_ASM_ENTRY("glGetVideoCaptureivNV")"\n"
"\t"STUB_ASM_CODE("1334")"\n"

STUB_ASM_ENTRY("glGetVideoi64vNV")"\n"
"\t"STUB_ASM_CODE("1335")"\n"

STUB_ASM_ENTRY("glGetVideoivNV")"\n"
"\t"STUB_ASM_CODE("1336")"\n"

STUB_ASM_ENTRY("glGetVideoui64vNV")"\n"
"\t"STUB_ASM_CODE("1337")"\n"

STUB_ASM_ENTRY("glGetVideouivNV")"\n"
"\t"STUB_ASM_CODE("1338")"\n"

STUB_ASM_ENTRY("glGetVkProcAddrNV")"\n"
"\t"STUB_ASM_CODE("1339")"\n"

STUB_ASM_ENTRY("glGetnColorTable")"\n"
"\t"STUB_ASM_CODE("1340")"\n"

STUB_ASM_ENTRY("glGetnColorTableARB")"\n"
"\t"STUB_ASM_CODE("1341")"\n"

STUB_ASM_ENTRY("glGetnCompressedTexImage")"\n"
"\t"STUB_ASM_CODE("1342")"\n"

STUB_ASM_ENTRY("glGetnCompressedTexImageARB")"\n"
"\t"STUB_ASM_CODE("1343")"\n"

STUB_ASM_ENTRY("glGetnConvolutionFilter")"\n"
"\t"STUB_ASM_CODE("1344")"\n"

STUB_ASM_ENTRY("glGetnConvolutionFilterARB")"\n"
"\t"STUB_ASM_CODE("1345")"\n"

STUB_ASM_ENTRY("glGetnHistogram")"\n"
"\t"STUB_ASM_CODE("1346")"\n"

STUB_ASM_ENTRY("glGetnHistogramARB")"\n"
"\t"STUB_ASM_CODE("1347")"\n"

STUB_ASM_ENTRY("glGetnMapdv")"\n"
"\t"STUB_ASM_CODE("1348")"\n"

STUB_ASM_ENTRY("glGetnMapdvARB")"\n"
"\t"STUB_ASM_CODE("1349")"\n"

STUB_ASM_ENTRY("glGetnMapfv")"\n"
"\t"STUB_ASM_CODE("1350")"\n"

STUB_ASM_ENTRY("glGetnMapfvARB")"\n"
"\t"STUB_ASM_CODE("1351")"\n"

STUB_ASM_ENTRY("glGetnMapiv")"\n"
"\t"STUB_ASM_CODE("1352")"\n"

STUB_ASM_ENTRY("glGetnMapivARB")"\n"
"\t"STUB_ASM_CODE("1353")"\n"

STUB_ASM_ENTRY("glGetnMinmax")"\n"
"\t"STUB_ASM_CODE("1354")"\n"

STUB_ASM_ENTRY("glGetnMinmaxARB")"\n"
"\t"STUB_ASM_CODE("1355")"\n"

STUB_ASM_ENTRY("glGetnPixelMapfv")"\n"
"\t"STUB_ASM_CODE("1356")"\n"

STUB_ASM_ENTRY("glGetnPixelMapfvARB")"\n"
"\t"STUB_ASM_CODE("1357")"\n"

STUB_ASM_ENTRY("glGetnPixelMapuiv")"\n"
"\t"STUB_ASM_CODE("1358")"\n"

STUB_ASM_ENTRY("glGetnPixelMapuivARB")"\n"
"\t"STUB_ASM_CODE("1359")"\n"

STUB_ASM_ENTRY("glGetnPixelMapusv")"\n"
"\t"STUB_ASM_CODE("1360")"\n"

STUB_ASM_ENTRY("glGetnPixelMapusvARB")"\n"
"\t"STUB_ASM_CODE("1361")"\n"

STUB_ASM_ENTRY("glGetnPolygonStipple")"\n"
"\t"STUB_ASM_CODE("1362")"\n"

STUB_ASM_ENTRY("glGetnPolygonStippleARB")"\n"
"\t"STUB_ASM_CODE("1363")"\n"

STUB_ASM_ENTRY("glGetnSeparableFilter")"\n"
"\t"STUB_ASM_CODE("1364")"\n"

STUB_ASM_ENTRY("glGetnSeparableFilterARB")"\n"
"\t"STUB_ASM_CODE("1365")"\n"

STUB_ASM_ENTRY("glGetnTexImage")"\n"
"\t"STUB_ASM_CODE("1366")"\n"

STUB_ASM_ENTRY("glGetnTexImageARB")"\n"
"\t"STUB_ASM_CODE("1367")"\n"

STUB_ASM_ENTRY("glGetnUniformdv")"\n"
"\t"STUB_ASM_CODE("1368")"\n"

STUB_ASM_ENTRY("glGetnUniformdvARB")"\n"
"\t"STUB_ASM_CODE("1369")"\n"

STUB_ASM_ENTRY("glGetnUniformfv")"\n"
"\t"STUB_ASM_CODE("1370")"\n"

STUB_ASM_ENTRY("glGetnUniformfvARB")"\n"
"\t"STUB_ASM_CODE("1371")"\n"

STUB_ASM_ENTRY("glGetnUniformfvEXT")"\n"
"\t"STUB_ASM_CODE("1372")"\n"

STUB_ASM_ENTRY("glGetnUniformfvKHR")"\n"
"\t"STUB_ASM_CODE("1373")"\n"

STUB_ASM_ENTRY("glGetnUniformi64vARB")"\n"
"\t"STUB_ASM_CODE("1374")"\n"

STUB_ASM_ENTRY("glGetnUniformiv")"\n"
"\t"STUB_ASM_CODE("1375")"\n"

STUB_ASM_ENTRY("glGetnUniformivARB")"\n"
"\t"STUB_ASM_CODE("1376")"\n"

STUB_ASM_ENTRY("glGetnUniformivEXT")"\n"
"\t"STUB_ASM_CODE("1377")"\n"

STUB_ASM_ENTRY("glGetnUniformivKHR")"\n"
"\t"STUB_ASM_CODE("1378")"\n"

STUB_ASM_ENTRY("glGetnUniformui64vARB")"\n"
"\t"STUB_ASM_CODE("1379")"\n"

STUB_ASM_ENTRY("glGetnUniformuiv")"\n"
"\t"STUB_ASM_CODE("1380")"\n"

STUB_ASM_ENTRY("glGetnUniformuivARB")"\n"
"\t"STUB_ASM_CODE("1381")"\n"

STUB_ASM_ENTRY("glGetnUniformuivKHR")"\n"
"\t"STUB_ASM_CODE("1382")"\n"

STUB_ASM_ENTRY("glGlobalAlphaFactorbSUN")"\n"
"\t"STUB_ASM_CODE("1383")"\n"

STUB_ASM_ENTRY("glGlobalAlphaFactordSUN")"\n"
"\t"STUB_ASM_CODE("1384")"\n"

STUB_ASM_ENTRY("glGlobalAlphaFactorfSUN")"\n"
"\t"STUB_ASM_CODE("1385")"\n"

STUB_ASM_ENTRY("glGlobalAlphaFactoriSUN")"\n"
"\t"STUB_ASM_CODE("1386")"\n"

STUB_ASM_ENTRY("glGlobalAlphaFactorsSUN")"\n"
"\t"STUB_ASM_CODE("1387")"\n"

STUB_ASM_ENTRY("glGlobalAlphaFactorubSUN")"\n"
"\t"STUB_ASM_CODE("1388")"\n"

STUB_ASM_ENTRY("glGlobalAlphaFactoruiSUN")"\n"
"\t"STUB_ASM_CODE("1389")"\n"

STUB_ASM_ENTRY("glGlobalAlphaFactorusSUN")"\n"
"\t"STUB_ASM_CODE("1390")"\n"

STUB_ASM_ENTRY("glGpuSyncAcquireNVX")"\n"
"\t"STUB_ASM_CODE("1391")"\n"

STUB_ASM_ENTRY("glGpuSyncCreateNVX")"\n"
"\t"STUB_ASM_CODE("1392")"\n"

STUB_ASM_ENTRY("glGpuSyncDestroyNVX")"\n"
"\t"STUB_ASM_CODE("1393")"\n"

STUB_ASM_ENTRY("glGpuSyncReleaseNVX")"\n"
"\t"STUB_ASM_CODE("1394")"\n"

STUB_ASM_ENTRY("glHint")"\n"
"\t"STUB_ASM_CODE("1395")"\n"

STUB_ASM_ENTRY("glHintPGI")"\n"
"\t"STUB_ASM_CODE("1396")"\n"

STUB_ASM_ENTRY("glHistogram")"\n"
"\t"STUB_ASM_CODE("1397")"\n"

STUB_ASM_ENTRY("glHistogramEXT")"\n"
"\t"STUB_ASM_CODE("1398")"\n"

STUB_ASM_ENTRY("glIglooInterfaceSGIX")"\n"
"\t"STUB_ASM_CODE("1399")"\n"

STUB_ASM_ENTRY("glImageTransformParameterfHP")"\n"
"\t"STUB_ASM_CODE("1400")"\n"

STUB_ASM_ENTRY("glImageTransformParameterfvHP")"\n"
"\t"STUB_ASM_CODE("1401")"\n"

STUB_ASM_ENTRY("glImageTransformParameteriHP")"\n"
"\t"STUB_ASM_CODE("1402")"\n"

STUB_ASM_ENTRY("glImageTransformParameterivHP")"\n"
"\t"STUB_ASM_CODE("1403")"\n"

STUB_ASM_ENTRY("glImportMemoryFdEXT")"\n"
"\t"STUB_ASM_CODE("1404")"\n"

STUB_ASM_ENTRY("glImportMemoryWin32HandleEXT")"\n"
"\t"STUB_ASM_CODE("1405")"\n"

STUB_ASM_ENTRY("glImportMemoryWin32NameEXT")"\n"
"\t"STUB_ASM_CODE("1406")"\n"

STUB_ASM_ENTRY("glImportSemaphoreFdEXT")"\n"
"\t"STUB_ASM_CODE("1407")"\n"

STUB_ASM_ENTRY("glImportSemaphoreWin32HandleEXT")"\n"
"\t"STUB_ASM_CODE("1408")"\n"

STUB_ASM_ENTRY("glImportSemaphoreWin32NameEXT")"\n"
"\t"STUB_ASM_CODE("1409")"\n"

STUB_ASM_ENTRY("glImportSyncEXT")"\n"
"\t"STUB_ASM_CODE("1410")"\n"

STUB_ASM_ENTRY("glIndexFormatNV")"\n"
"\t"STUB_ASM_CODE("1411")"\n"

STUB_ASM_ENTRY("glIndexFuncEXT")"\n"
"\t"STUB_ASM_CODE("1412")"\n"

STUB_ASM_ENTRY("glIndexMask")"\n"
"\t"STUB_ASM_CODE("1413")"\n"

STUB_ASM_ENTRY("glIndexMaterialEXT")"\n"
"\t"STUB_ASM_CODE("1414")"\n"

STUB_ASM_ENTRY("glIndexPointer")"\n"
"\t"STUB_ASM_CODE("1415")"\n"

STUB_ASM_ENTRY("glIndexPointerEXT")"\n"
"\t"STUB_ASM_CODE("1416")"\n"

STUB_ASM_ENTRY("glIndexPointerListIBM")"\n"
"\t"STUB_ASM_CODE("1417")"\n"

STUB_ASM_ENTRY("glIndexd")"\n"
"\t"STUB_ASM_CODE("1418")"\n"

STUB_ASM_ENTRY("glIndexdv")"\n"
"\t"STUB_ASM_CODE("1419")"\n"

STUB_ASM_ENTRY("glIndexf")"\n"
"\t"STUB_ASM_CODE("1420")"\n"

STUB_ASM_ENTRY("glIndexfv")"\n"
"\t"STUB_ASM_CODE("1421")"\n"

STUB_ASM_ENTRY("glIndexi")"\n"
"\t"STUB_ASM_CODE("1422")"\n"

STUB_ASM_ENTRY("glIndexiv")"\n"
"\t"STUB_ASM_CODE("1423")"\n"

STUB_ASM_ENTRY("glIndexs")"\n"
"\t"STUB_ASM_CODE("1424")"\n"

STUB_ASM_ENTRY("glIndexsv")"\n"
"\t"STUB_ASM_CODE("1425")"\n"

STUB_ASM_ENTRY("glIndexub")"\n"
"\t"STUB_ASM_CODE("1426")"\n"

STUB_ASM_ENTRY("glIndexubv")"\n"
"\t"STUB_ASM_CODE("1427")"\n"

STUB_ASM_ENTRY("glIndexxOES")"\n"
"\t"STUB_ASM_CODE("1428")"\n"

STUB_ASM_ENTRY("glIndexxvOES")"\n"
"\t"STUB_ASM_CODE("1429")"\n"

STUB_ASM_ENTRY("glInitNames")"\n"
"\t"STUB_ASM_CODE("1430")"\n"

STUB_ASM_ENTRY("glInsertComponentEXT")"\n"
"\t"STUB_ASM_CODE("1431")"\n"

STUB_ASM_ENTRY("glInsertEventMarkerEXT")"\n"
"\t"STUB_ASM_CODE("1432")"\n"

STUB_ASM_ENTRY("glInstrumentsBufferSGIX")"\n"
"\t"STUB_ASM_CODE("1433")"\n"

STUB_ASM_ENTRY("glInterleavedArrays")"\n"
"\t"STUB_ASM_CODE("1434")"\n"

STUB_ASM_ENTRY("glInterpolatePathsNV")"\n"
"\t"STUB_ASM_CODE("1435")"\n"

STUB_ASM_ENTRY("glInvalidateBufferData")"\n"
"\t"STUB_ASM_CODE("1436")"\n"

STUB_ASM_ENTRY("glInvalidateBufferSubData")"\n"
"\t"STUB_ASM_CODE("1437")"\n"

STUB_ASM_ENTRY("glInvalidateFramebuffer")"\n"
"\t"STUB_ASM_CODE("1438")"\n"

STUB_ASM_ENTRY("glInvalidateNamedFramebufferData")"\n"
"\t"STUB_ASM_CODE("1439")"\n"

STUB_ASM_ENTRY("glInvalidateNamedFramebufferSubData")"\n"
"\t"STUB_ASM_CODE("1440")"\n"

STUB_ASM_ENTRY("glInvalidateSubFramebuffer")"\n"
"\t"STUB_ASM_CODE("1441")"\n"

STUB_ASM_ENTRY("glInvalidateTexImage")"\n"
"\t"STUB_ASM_CODE("1442")"\n"

STUB_ASM_ENTRY("glInvalidateTexSubImage")"\n"
"\t"STUB_ASM_CODE("1443")"\n"

STUB_ASM_ENTRY("glIsAsyncMarkerSGIX")"\n"
"\t"STUB_ASM_CODE("1444")"\n"

STUB_ASM_ENTRY("glIsBuffer")"\n"
"\t"STUB_ASM_CODE("1445")"\n"

STUB_ASM_ENTRY("glIsBufferARB")"\n"
"\t"STUB_ASM_CODE("1446")"\n"

STUB_ASM_ENTRY("glIsBufferResidentNV")"\n"
"\t"STUB_ASM_CODE("1447")"\n"

STUB_ASM_ENTRY("glIsCommandListNV")"\n"
"\t"STUB_ASM_CODE("1448")"\n"

STUB_ASM_ENTRY("glIsEnabled")"\n"
"\t"STUB_ASM_CODE("1449")"\n"

STUB_ASM_ENTRY("glIsEnabledIndexedEXT")"\n"
"\t"STUB_ASM_CODE("1450")"\n"

STUB_ASM_ENTRY("glIsEnabledi")"\n"
"\t"STUB_ASM_CODE("1451")"\n"

STUB_ASM_ENTRY("glIsEnablediEXT")"\n"
"\t"STUB_ASM_CODE("1452")"\n"

STUB_ASM_ENTRY("glIsEnablediNV")"\n"
"\t"STUB_ASM_CODE("1453")"\n"

STUB_ASM_ENTRY("glIsEnablediOES")"\n"
"\t"STUB_ASM_CODE("1454")"\n"

STUB_ASM_ENTRY("glIsFenceAPPLE")"\n"
"\t"STUB_ASM_CODE("1455")"\n"

STUB_ASM_ENTRY("glIsFenceNV")"\n"
"\t"STUB_ASM_CODE("1456")"\n"

STUB_ASM_ENTRY("glIsFramebuffer")"\n"
"\t"STUB_ASM_CODE("1457")"\n"

STUB_ASM_ENTRY("glIsFramebufferEXT")"\n"
"\t"STUB_ASM_CODE("1458")"\n"

STUB_ASM_ENTRY("glIsFramebufferOES")"\n"
"\t"STUB_ASM_CODE("1459")"\n"

STUB_ASM_ENTRY("glIsImageHandleResidentARB")"\n"
"\t"STUB_ASM_CODE("1460")"\n"

STUB_ASM_ENTRY("glIsImageHandleResidentNV")"\n"
"\t"STUB_ASM_CODE("1461")"\n"

STUB_ASM_ENTRY("glIsList")"\n"
"\t"STUB_ASM_CODE("1462")"\n"

STUB_ASM_ENTRY("glIsMemoryObjectEXT")"\n"
"\t"STUB_ASM_CODE("1463")"\n"

STUB_ASM_ENTRY("glIsNameAMD")"\n"
"\t"STUB_ASM_CODE("1464")"\n"

STUB_ASM_ENTRY("glIsNamedBufferResidentNV")"\n"
"\t"STUB_ASM_CODE("1465")"\n"

STUB_ASM_ENTRY("glIsNamedStringARB")"\n"
"\t"STUB_ASM_CODE("1466")"\n"

STUB_ASM_ENTRY("glIsObjectBufferATI")"\n"
"\t"STUB_ASM_CODE("1467")"\n"

STUB_ASM_ENTRY("glIsOcclusionQueryNV")"\n"
"\t"STUB_ASM_CODE("1468")"\n"

STUB_ASM_ENTRY("glIsPathNV")"\n"
"\t"STUB_ASM_CODE("1469")"\n"

STUB_ASM_ENTRY("glIsPointInFillPathNV")"\n"
"\t"STUB_ASM_CODE("1470")"\n"

STUB_ASM_ENTRY("glIsPointInStrokePathNV")"\n"
"\t"STUB_ASM_CODE("1471")"\n"

STUB_ASM_ENTRY("glIsProgram")"\n"
"\t"STUB_ASM_CODE("1472")"\n"

STUB_ASM_ENTRY("glIsProgramARB")"\n"
"\t"STUB_ASM_CODE("1473")"\n"

STUB_ASM_ENTRY("glIsProgramNV")"\n"
"\t"STUB_ASM_CODE("1474")"\n"

STUB_ASM_ENTRY("glIsProgramPipeline")"\n"
"\t"STUB_ASM_CODE("1475")"\n"

STUB_ASM_ENTRY("glIsProgramPipelineEXT")"\n"
"\t"STUB_ASM_CODE("1476")"\n"

STUB_ASM_ENTRY("glIsQuery")"\n"
"\t"STUB_ASM_CODE("1477")"\n"

STUB_ASM_ENTRY("glIsQueryARB")"\n"
"\t"STUB_ASM_CODE("1478")"\n"

STUB_ASM_ENTRY("glIsQueryEXT")"\n"
"\t"STUB_ASM_CODE("1479")"\n"

STUB_ASM_ENTRY("glIsRenderbuffer")"\n"
"\t"STUB_ASM_CODE("1480")"\n"

STUB_ASM_ENTRY("glIsRenderbufferEXT")"\n"
"\t"STUB_ASM_CODE("1481")"\n"

STUB_ASM_ENTRY("glIsRenderbufferOES")"\n"
"\t"STUB_ASM_CODE("1482")"\n"

STUB_ASM_ENTRY("glIsSampler")"\n"
"\t"STUB_ASM_CODE("1483")"\n"

STUB_ASM_ENTRY("glIsSemaphoreEXT")"\n"
"\t"STUB_ASM_CODE("1484")"\n"

STUB_ASM_ENTRY("glIsShader")"\n"
"\t"STUB_ASM_CODE("1485")"\n"

STUB_ASM_ENTRY("glIsStateNV")"\n"
"\t"STUB_ASM_CODE("1486")"\n"

STUB_ASM_ENTRY("glIsSync")"\n"
"\t"STUB_ASM_CODE("1487")"\n"

STUB_ASM_ENTRY("glIsSyncAPPLE")"\n"
"\t"STUB_ASM_CODE("1488")"\n"

STUB_ASM_ENTRY("glIsTexture")"\n"
"\t"STUB_ASM_CODE("1489")"\n"

STUB_ASM_ENTRY("glIsTextureEXT")"\n"
"\t"STUB_ASM_CODE("1490")"\n"

STUB_ASM_ENTRY("glIsTextureHandleResidentARB")"\n"
"\t"STUB_ASM_CODE("1491")"\n"

STUB_ASM_ENTRY("glIsTextureHandleResidentNV")"\n"
"\t"STUB_ASM_CODE("1492")"\n"

STUB_ASM_ENTRY("glIsTransformFeedback")"\n"
"\t"STUB_ASM_CODE("1493")"\n"

STUB_ASM_ENTRY("glIsTransformFeedbackEXT")"\n"
"\t"STUB_ASM_CODE("1494")"\n"

STUB_ASM_ENTRY("glIsTransformFeedbackNV")"\n"
"\t"STUB_ASM_CODE("1495")"\n"

STUB_ASM_ENTRY("glIsVariantEnabledEXT")"\n"
"\t"STUB_ASM_CODE("1496")"\n"

STUB_ASM_ENTRY("glIsVertexArray")"\n"
"\t"STUB_ASM_CODE("1497")"\n"

STUB_ASM_ENTRY("glIsVertexArrayAPPLE")"\n"
"\t"STUB_ASM_CODE("1498")"\n"

STUB_ASM_ENTRY("glIsVertexArrayOES")"\n"
"\t"STUB_ASM_CODE("1499")"\n"

STUB_ASM_ENTRY("glIsVertexAttribEnabledAPPLE")"\n"
"\t"STUB_ASM_CODE("1500")"\n"

STUB_ASM_ENTRY("glLGPUCopyImageSubDataNVX")"\n"
"\t"STUB_ASM_CODE("1501")"\n"

STUB_ASM_ENTRY("glLGPUInterlockNVX")"\n"
"\t"STUB_ASM_CODE("1502")"\n"

STUB_ASM_ENTRY("glLGPUNamedBufferSubDataNVX")"\n"
"\t"STUB_ASM_CODE("1503")"\n"

STUB_ASM_ENTRY("glLabelObjectEXT")"\n"
"\t"STUB_ASM_CODE("1504")"\n"

STUB_ASM_ENTRY("glLightEnviSGIX")"\n"
"\t"STUB_ASM_CODE("1505")"\n"

STUB_ASM_ENTRY("glLightModelf")"\n"
"\t"STUB_ASM_CODE("1506")"\n"

STUB_ASM_ENTRY("glLightModelfv")"\n"
"\t"STUB_ASM_CODE("1507")"\n"

STUB_ASM_ENTRY("glLightModeli")"\n"
"\t"STUB_ASM_CODE("1508")"\n"

STUB_ASM_ENTRY("glLightModeliv")"\n"
"\t"STUB_ASM_CODE("1509")"\n"

STUB_ASM_ENTRY("glLightModelx")"\n"
"\t"STUB_ASM_CODE("1510")"\n"

STUB_ASM_ENTRY("glLightModelxOES")"\n"
"\t"STUB_ASM_CODE("1511")"\n"

STUB_ASM_ENTRY("glLightModelxv")"\n"
"\t"STUB_ASM_CODE("1512")"\n"

STUB_ASM_ENTRY("glLightModelxvOES")"\n"
"\t"STUB_ASM_CODE("1513")"\n"

STUB_ASM_ENTRY("glLightf")"\n"
"\t"STUB_ASM_CODE("1514")"\n"

STUB_ASM_ENTRY("glLightfv")"\n"
"\t"STUB_ASM_CODE("1515")"\n"

STUB_ASM_ENTRY("glLighti")"\n"
"\t"STUB_ASM_CODE("1516")"\n"

STUB_ASM_ENTRY("glLightiv")"\n"
"\t"STUB_ASM_CODE("1517")"\n"

STUB_ASM_ENTRY("glLightx")"\n"
"\t"STUB_ASM_CODE("1518")"\n"

STUB_ASM_ENTRY("glLightxOES")"\n"
"\t"STUB_ASM_CODE("1519")"\n"

STUB_ASM_ENTRY("glLightxv")"\n"
"\t"STUB_ASM_CODE("1520")"\n"

STUB_ASM_ENTRY("glLightxvOES")"\n"
"\t"STUB_ASM_CODE("1521")"\n"

STUB_ASM_ENTRY("glLineStipple")"\n"
"\t"STUB_ASM_CODE("1522")"\n"

STUB_ASM_ENTRY("glLineWidth")"\n"
"\t"STUB_ASM_CODE("1523")"\n"

STUB_ASM_ENTRY("glLineWidthx")"\n"
"\t"STUB_ASM_CODE("1524")"\n"

STUB_ASM_ENTRY("glLineWidthxOES")"\n"
"\t"STUB_ASM_CODE("1525")"\n"

STUB_ASM_ENTRY("glLinkProgram")"\n"
"\t"STUB_ASM_CODE("1526")"\n"

STUB_ASM_ENTRY("glLinkProgramARB")"\n"
"\t"STUB_ASM_CODE("1527")"\n"

STUB_ASM_ENTRY("glListBase")"\n"
"\t"STUB_ASM_CODE("1528")"\n"

STUB_ASM_ENTRY("glListDrawCommandsStatesClientNV")"\n"
"\t"STUB_ASM_CODE("1529")"\n"

STUB_ASM_ENTRY("glListParameterfSGIX")"\n"
"\t"STUB_ASM_CODE("1530")"\n"

STUB_ASM_ENTRY("glListParameterfvSGIX")"\n"
"\t"STUB_ASM_CODE("1531")"\n"

STUB_ASM_ENTRY("glListParameteriSGIX")"\n"
"\t"STUB_ASM_CODE("1532")"\n"

STUB_ASM_ENTRY("glListParameterivSGIX")"\n"
"\t"STUB_ASM_CODE("1533")"\n"

STUB_ASM_ENTRY("glLoadIdentity")"\n"
"\t"STUB_ASM_CODE("1534")"\n"

STUB_ASM_ENTRY("glLoadIdentityDeformationMapSGIX")"\n"
"\t"STUB_ASM_CODE("1535")"\n"

STUB_ASM_ENTRY("glLoadMatrixd")"\n"
"\t"STUB_ASM_CODE("1536")"\n"

STUB_ASM_ENTRY("glLoadMatrixf")"\n"
"\t"STUB_ASM_CODE("1537")"\n"

STUB_ASM_ENTRY("glLoadMatrixx")"\n"
"\t"STUB_ASM_CODE("1538")"\n"

STUB_ASM_ENTRY("glLoadMatrixxOES")"\n"
"\t"STUB_ASM_CODE("1539")"\n"

STUB_ASM_ENTRY("glLoadName")"\n"
"\t"STUB_ASM_CODE("1540")"\n"

STUB_ASM_ENTRY("glLoadPaletteFromModelViewMatrixOES")"\n"
"\t"STUB_ASM_CODE("1541")"\n"

STUB_ASM_ENTRY("glLoadProgramNV")"\n"
"\t"STUB_ASM_CODE("1542")"\n"

STUB_ASM_ENTRY("glLoadTransformEXT")"\n"
"\t"STUB_ASM_CODE("1543")"\n"

STUB_ASM_ENTRY("glLoadTransposeMatrixd")"\n"
"\t"STUB_ASM_CODE("1544")"\n"

STUB_ASM_ENTRY("glLoadTransposeMatrixdARB")"\n"
"\t"STUB_ASM_CODE("1545")"\n"

STUB_ASM_ENTRY("glLoadTransposeMatrixf")"\n"
"\t"STUB_ASM_CODE("1546")"\n"

STUB_ASM_ENTRY("glLoadTransposeMatrixfARB")"\n"
"\t"STUB_ASM_CODE("1547")"\n"

STUB_ASM_ENTRY("glLoadTransposeMatrixxOES")"\n"
"\t"STUB_ASM_CODE("1548")"\n"

STUB_ASM_ENTRY("glLockArraysEXT")"\n"
"\t"STUB_ASM_CODE("1549")"\n"

STUB_ASM_ENTRY("glLogicOp")"\n"
"\t"STUB_ASM_CODE("1550")"\n"

STUB_ASM_ENTRY("glMakeBufferNonResidentNV")"\n"
"\t"STUB_ASM_CODE("1551")"\n"

STUB_ASM_ENTRY("glMakeBufferResidentNV")"\n"
"\t"STUB_ASM_CODE("1552")"\n"

STUB_ASM_ENTRY("glMakeImageHandleNonResidentARB")"\n"
"\t"STUB_ASM_CODE("1553")"\n"

STUB_ASM_ENTRY("glMakeImageHandleNonResidentNV")"\n"
"\t"STUB_ASM_CODE("1554")"\n"

STUB_ASM_ENTRY("glMakeImageHandleResidentARB")"\n"
"\t"STUB_ASM_CODE("1555")"\n"

STUB_ASM_ENTRY("glMakeImageHandleResidentNV")"\n"
"\t"STUB_ASM_CODE("1556")"\n"

STUB_ASM_ENTRY("glMakeNamedBufferNonResidentNV")"\n"
"\t"STUB_ASM_CODE("1557")"\n"

STUB_ASM_ENTRY("glMakeNamedBufferResidentNV")"\n"
"\t"STUB_ASM_CODE("1558")"\n"

STUB_ASM_ENTRY("glMakeTextureHandleNonResidentARB")"\n"
"\t"STUB_ASM_CODE("1559")"\n"

STUB_ASM_ENTRY("glMakeTextureHandleNonResidentNV")"\n"
"\t"STUB_ASM_CODE("1560")"\n"

STUB_ASM_ENTRY("glMakeTextureHandleResidentARB")"\n"
"\t"STUB_ASM_CODE("1561")"\n"

STUB_ASM_ENTRY("glMakeTextureHandleResidentNV")"\n"
"\t"STUB_ASM_CODE("1562")"\n"

STUB_ASM_ENTRY("glMap1d")"\n"
"\t"STUB_ASM_CODE("1563")"\n"

STUB_ASM_ENTRY("glMap1f")"\n"
"\t"STUB_ASM_CODE("1564")"\n"

STUB_ASM_ENTRY("glMap1xOES")"\n"
"\t"STUB_ASM_CODE("1565")"\n"

STUB_ASM_ENTRY("glMap2d")"\n"
"\t"STUB_ASM_CODE("1566")"\n"

STUB_ASM_ENTRY("glMap2f")"\n"
"\t"STUB_ASM_CODE("1567")"\n"

STUB_ASM_ENTRY("glMap2xOES")"\n"
"\t"STUB_ASM_CODE("1568")"\n"

STUB_ASM_ENTRY("glMapBuffer")"\n"
"\t"STUB_ASM_CODE("1569")"\n"

STUB_ASM_ENTRY("glMapBufferARB")"\n"
"\t"STUB_ASM_CODE("1570")"\n"

STUB_ASM_ENTRY("glMapBufferOES")"\n"
"\t"STUB_ASM_CODE("1571")"\n"

STUB_ASM_ENTRY("glMapBufferRange")"\n"
"\t"STUB_ASM_CODE("1572")"\n"

STUB_ASM_ENTRY("glMapBufferRangeEXT")"\n"
"\t"STUB_ASM_CODE("1573")"\n"

STUB_ASM_ENTRY("glMapControlPointsNV")"\n"
"\t"STUB_ASM_CODE("1574")"\n"

STUB_ASM_ENTRY("glMapGrid1d")"\n"
"\t"STUB_ASM_CODE("1575")"\n"

STUB_ASM_ENTRY("glMapGrid1f")"\n"
"\t"STUB_ASM_CODE("1576")"\n"

STUB_ASM_ENTRY("glMapGrid1xOES")"\n"
"\t"STUB_ASM_CODE("1577")"\n"

STUB_ASM_ENTRY("glMapGrid2d")"\n"
"\t"STUB_ASM_CODE("1578")"\n"

STUB_ASM_ENTRY("glMapGrid2f")"\n"
"\t"STUB_ASM_CODE("1579")"\n"

STUB_ASM_ENTRY("glMapGrid2xOES")"\n"
"\t"STUB_ASM_CODE("1580")"\n"

STUB_ASM_ENTRY("glMapNamedBuffer")"\n"
"\t"STUB_ASM_CODE("1581")"\n"

STUB_ASM_ENTRY("glMapNamedBufferEXT")"\n"
"\t"STUB_ASM_CODE("1582")"\n"

STUB_ASM_ENTRY("glMapNamedBufferRange")"\n"
"\t"STUB_ASM_CODE("1583")"\n"

STUB_ASM_ENTRY("glMapNamedBufferRangeEXT")"\n"
"\t"STUB_ASM_CODE("1584")"\n"

STUB_ASM_ENTRY("glMapObjectBufferATI")"\n"
"\t"STUB_ASM_CODE("1585")"\n"

STUB_ASM_ENTRY("glMapParameterfvNV")"\n"
"\t"STUB_ASM_CODE("1586")"\n"

STUB_ASM_ENTRY("glMapParameterivNV")"\n"
"\t"STUB_ASM_CODE("1587")"\n"

STUB_ASM_ENTRY("glMapTexture2DINTEL")"\n"
"\t"STUB_ASM_CODE("1588")"\n"

STUB_ASM_ENTRY("glMapVertexAttrib1dAPPLE")"\n"
"\t"STUB_ASM_CODE("1589")"\n"

STUB_ASM_ENTRY("glMapVertexAttrib1fAPPLE")"\n"
"\t"STUB_ASM_CODE("1590")"\n"

STUB_ASM_ENTRY("glMapVertexAttrib2dAPPLE")"\n"
"\t"STUB_ASM_CODE("1591")"\n"

STUB_ASM_ENTRY("glMapVertexAttrib2fAPPLE")"\n"
"\t"STUB_ASM_CODE("1592")"\n"

STUB_ASM_ENTRY("glMaterialf")"\n"
"\t"STUB_ASM_CODE("1593")"\n"

STUB_ASM_ENTRY("glMaterialfv")"\n"
"\t"STUB_ASM_CODE("1594")"\n"

STUB_ASM_ENTRY("glMateriali")"\n"
"\t"STUB_ASM_CODE("1595")"\n"

STUB_ASM_ENTRY("glMaterialiv")"\n"
"\t"STUB_ASM_CODE("1596")"\n"

STUB_ASM_ENTRY("glMaterialx")"\n"
"\t"STUB_ASM_CODE("1597")"\n"

STUB_ASM_ENTRY("glMaterialxOES")"\n"
"\t"STUB_ASM_CODE("1598")"\n"

STUB_ASM_ENTRY("glMaterialxv")"\n"
"\t"STUB_ASM_CODE("1599")"\n"

STUB_ASM_ENTRY("glMaterialxvOES")"\n"
"\t"STUB_ASM_CODE("1600")"\n"

STUB_ASM_ENTRY("glMatrixFrustumEXT")"\n"
"\t"STUB_ASM_CODE("1601")"\n"

STUB_ASM_ENTRY("glMatrixIndexPointerARB")"\n"
"\t"STUB_ASM_CODE("1602")"\n"

STUB_ASM_ENTRY("glMatrixIndexPointerOES")"\n"
"\t"STUB_ASM_CODE("1603")"\n"

STUB_ASM_ENTRY("glMatrixIndexubvARB")"\n"
"\t"STUB_ASM_CODE("1604")"\n"

STUB_ASM_ENTRY("glMatrixIndexuivARB")"\n"
"\t"STUB_ASM_CODE("1605")"\n"

STUB_ASM_ENTRY("glMatrixIndexusvARB")"\n"
"\t"STUB_ASM_CODE("1606")"\n"

STUB_ASM_ENTRY("glMatrixLoad3x2fNV")"\n"
"\t"STUB_ASM_CODE("1607")"\n"

STUB_ASM_ENTRY("glMatrixLoad3x3fNV")"\n"
"\t"STUB_ASM_CODE("1608")"\n"

STUB_ASM_ENTRY("glMatrixLoadIdentityEXT")"\n"
"\t"STUB_ASM_CODE("1609")"\n"

STUB_ASM_ENTRY("glMatrixLoadTranspose3x3fNV")"\n"
"\t"STUB_ASM_CODE("1610")"\n"

STUB_ASM_ENTRY("glMatrixLoadTransposedEXT")"\n"
"\t"STUB_ASM_CODE("1611")"\n"

STUB_ASM_ENTRY("glMatrixLoadTransposefEXT")"\n"
"\t"STUB_ASM_CODE("1612")"\n"

STUB_ASM_ENTRY("glMatrixLoaddEXT")"\n"
"\t"STUB_ASM_CODE("1613")"\n"

STUB_ASM_ENTRY("glMatrixLoadfEXT")"\n"
"\t"STUB_ASM_CODE("1614")"\n"

STUB_ASM_ENTRY("glMatrixMode")"\n"
"\t"STUB_ASM_CODE("1615")"\n"

STUB_ASM_ENTRY("glMatrixMult3x2fNV")"\n"
"\t"STUB_ASM_CODE("1616")"\n"

STUB_ASM_ENTRY("glMatrixMult3x3fNV")"\n"
"\t"STUB_ASM_CODE("1617")"\n"

STUB_ASM_ENTRY("glMatrixMultTranspose3x3fNV")"\n"
"\t"STUB_ASM_CODE("1618")"\n"

STUB_ASM_ENTRY("glMatrixMultTransposedEXT")"\n"
"\t"STUB_ASM_CODE("1619")"\n"

STUB_ASM_ENTRY("glMatrixMultTransposefEXT")"\n"
"\t"STUB_ASM_CODE("1620")"\n"

STUB_ASM_ENTRY("glMatrixMultdEXT")"\n"
"\t"STUB_ASM_CODE("1621")"\n"

STUB_ASM_ENTRY("glMatrixMultfEXT")"\n"
"\t"STUB_ASM_CODE("1622")"\n"

STUB_ASM_ENTRY("glMatrixOrthoEXT")"\n"
"\t"STUB_ASM_CODE("1623")"\n"

STUB_ASM_ENTRY("glMatrixPopEXT")"\n"
"\t"STUB_ASM_CODE("1624")"\n"

STUB_ASM_ENTRY("glMatrixPushEXT")"\n"
"\t"STUB_ASM_CODE("1625")"\n"

STUB_ASM_ENTRY("glMatrixRotatedEXT")"\n"
"\t"STUB_ASM_CODE("1626")"\n"

STUB_ASM_ENTRY("glMatrixRotatefEXT")"\n"
"\t"STUB_ASM_CODE("1627")"\n"

STUB_ASM_ENTRY("glMatrixScaledEXT")"\n"
"\t"STUB_ASM_CODE("1628")"\n"

STUB_ASM_ENTRY("glMatrixScalefEXT")"\n"
"\t"STUB_ASM_CODE("1629")"\n"

STUB_ASM_ENTRY("glMatrixTranslatedEXT")"\n"
"\t"STUB_ASM_CODE("1630")"\n"

STUB_ASM_ENTRY("glMatrixTranslatefEXT")"\n"
"\t"STUB_ASM_CODE("1631")"\n"

STUB_ASM_ENTRY("glMaxShaderCompilerThreadsARB")"\n"
"\t"STUB_ASM_CODE("1632")"\n"

STUB_ASM_ENTRY("glMaxShaderCompilerThreadsKHR")"\n"
"\t"STUB_ASM_CODE("1633")"\n"

STUB_ASM_ENTRY("glMemoryBarrier")"\n"
"\t"STUB_ASM_CODE("1634")"\n"

STUB_ASM_ENTRY("glMemoryBarrierByRegion")"\n"
"\t"STUB_ASM_CODE("1635")"\n"

STUB_ASM_ENTRY("glMemoryBarrierEXT")"\n"
"\t"STUB_ASM_CODE("1636")"\n"

STUB_ASM_ENTRY("glMemoryObjectParameterivEXT")"\n"
"\t"STUB_ASM_CODE("1637")"\n"

STUB_ASM_ENTRY("glMinSampleShading")"\n"
"\t"STUB_ASM_CODE("1638")"\n"

STUB_ASM_ENTRY("glMinSampleShadingARB")"\n"
"\t"STUB_ASM_CODE("1639")"\n"

STUB_ASM_ENTRY("glMinSampleShadingOES")"\n"
"\t"STUB_ASM_CODE("1640")"\n"

STUB_ASM_ENTRY("glMinmax")"\n"
"\t"STUB_ASM_CODE("1641")"\n"

STUB_ASM_ENTRY("glMinmaxEXT")"\n"
"\t"STUB_ASM_CODE("1642")"\n"

STUB_ASM_ENTRY("glMultMatrixd")"\n"
"\t"STUB_ASM_CODE("1643")"\n"

STUB_ASM_ENTRY("glMultMatrixf")"\n"
"\t"STUB_ASM_CODE("1644")"\n"

STUB_ASM_ENTRY("glMultMatrixx")"\n"
"\t"STUB_ASM_CODE("1645")"\n"

STUB_ASM_ENTRY("glMultMatrixxOES")"\n"
"\t"STUB_ASM_CODE("1646")"\n"

STUB_ASM_ENTRY("glMultTransformEXT")"\n"
"\t"STUB_ASM_CODE("1647")"\n"

STUB_ASM_ENTRY("glMultTransposeMatrixd")"\n"
"\t"STUB_ASM_CODE("1648")"\n"

STUB_ASM_ENTRY("glMultTransposeMatrixdARB")"\n"
"\t"STUB_ASM_CODE("1649")"\n"

STUB_ASM_ENTRY("glMultTransposeMatrixf")"\n"
"\t"STUB_ASM_CODE("1650")"\n"

STUB_ASM_ENTRY("glMultTransposeMatrixfARB")"\n"
"\t"STUB_ASM_CODE("1651")"\n"

STUB_ASM_ENTRY("glMultTransposeMatrixxOES")"\n"
"\t"STUB_ASM_CODE("1652")"\n"

STUB_ASM_ENTRY("glMultiDrawArrays")"\n"
"\t"STUB_ASM_CODE("1653")"\n"

STUB_ASM_ENTRY("glMultiDrawArraysEXT")"\n"
"\t"STUB_ASM_CODE("1654")"\n"

STUB_ASM_ENTRY("glMultiDrawArraysIndirect")"\n"
"\t"STUB_ASM_CODE("1655")"\n"

STUB_ASM_ENTRY("glMultiDrawArraysIndirectAMD")"\n"
"\t"STUB_ASM_CODE("1656")"\n"

STUB_ASM_ENTRY("glMultiDrawArraysIndirectBindlessCountNV")"\n"
"\t"STUB_ASM_CODE("1657")"\n"

STUB_ASM_ENTRY("glMultiDrawArraysIndirectBindlessNV")"\n"
"\t"STUB_ASM_CODE("1658")"\n"

STUB_ASM_ENTRY("glMultiDrawArraysIndirectCount")"\n"
"\t"STUB_ASM_CODE("1659")"\n"

STUB_ASM_ENTRY("glMultiDrawArraysIndirectCountARB")"\n"
"\t"STUB_ASM_CODE("1660")"\n"

STUB_ASM_ENTRY("glMultiDrawArraysIndirectEXT")"\n"
"\t"STUB_ASM_CODE("1661")"\n"

STUB_ASM_ENTRY("glMultiDrawElementArrayAPPLE")"\n"
"\t"STUB_ASM_CODE("1662")"\n"

STUB_ASM_ENTRY("glMultiDrawElements")"\n"
"\t"STUB_ASM_CODE("1663")"\n"

STUB_ASM_ENTRY("glMultiDrawElementsBaseVertex")"\n"
"\t"STUB_ASM_CODE("1664")"\n"

STUB_ASM_ENTRY("glMultiDrawElementsBaseVertexEXT")"\n"
"\t"STUB_ASM_CODE("1665")"\n"

STUB_ASM_ENTRY("glMultiDrawElementsEXT")"\n"
"\t"STUB_ASM_CODE("1666")"\n"

STUB_ASM_ENTRY("glMultiDrawElementsIndirect")"\n"
"\t"STUB_ASM_CODE("1667")"\n"

STUB_ASM_ENTRY("glMultiDrawElementsIndirectAMD")"\n"
"\t"STUB_ASM_CODE("1668")"\n"

STUB_ASM_ENTRY("glMultiDrawElementsIndirectBindlessCountNV")"\n"
"\t"STUB_ASM_CODE("1669")"\n"

STUB_ASM_ENTRY("glMultiDrawElementsIndirectBindlessNV")"\n"
"\t"STUB_ASM_CODE("1670")"\n"

STUB_ASM_ENTRY("glMultiDrawElementsIndirectCount")"\n"
"\t"STUB_ASM_CODE("1671")"\n"

STUB_ASM_ENTRY("glMultiDrawElementsIndirectCountARB")"\n"
"\t"STUB_ASM_CODE("1672")"\n"

STUB_ASM_ENTRY("glMultiDrawElementsIndirectEXT")"\n"
"\t"STUB_ASM_CODE("1673")"\n"

STUB_ASM_ENTRY("glMultiDrawMeshTasksIndirectCountNV")"\n"
"\t"STUB_ASM_CODE("1674")"\n"

STUB_ASM_ENTRY("glMultiDrawMeshTasksIndirectNV")"\n"
"\t"STUB_ASM_CODE("1675")"\n"

STUB_ASM_ENTRY("glMultiDrawRangeElementArrayAPPLE")"\n"
"\t"STUB_ASM_CODE("1676")"\n"

STUB_ASM_ENTRY("glMultiModeDrawArraysIBM")"\n"
"\t"STUB_ASM_CODE("1677")"\n"

STUB_ASM_ENTRY("glMultiModeDrawElementsIBM")"\n"
"\t"STUB_ASM_CODE("1678")"\n"

STUB_ASM_ENTRY("glMultiTexBufferEXT")"\n"
"\t"STUB_ASM_CODE("1679")"\n"

STUB_ASM_ENTRY("glMultiTexCoord1bOES")"\n"
"\t"STUB_ASM_CODE("1680")"\n"

STUB_ASM_ENTRY("glMultiTexCoord1bvOES")"\n"
"\t"STUB_ASM_CODE("1681")"\n"

STUB_ASM_ENTRY("glMultiTexCoord1d")"\n"
"\t"STUB_ASM_CODE("1682")"\n"

STUB_ASM_ENTRY("glMultiTexCoord1dARB")"\n"
"\t"STUB_ASM_CODE("1683")"\n"

STUB_ASM_ENTRY("glMultiTexCoord1dv")"\n"
"\t"STUB_ASM_CODE("1684")"\n"

STUB_ASM_ENTRY("glMultiTexCoord1dvARB")"\n"
"\t"STUB_ASM_CODE("1685")"\n"

STUB_ASM_ENTRY("glMultiTexCoord1f")"\n"
"\t"STUB_ASM_CODE("1686")"\n"

STUB_ASM_ENTRY("glMultiTexCoord1fARB")"\n"
"\t"STUB_ASM_CODE("1687")"\n"

STUB_ASM_ENTRY("glMultiTexCoord1fv")"\n"
"\t"STUB_ASM_CODE("1688")"\n"

STUB_ASM_ENTRY("glMultiTexCoord1fvARB")"\n"
"\t"STUB_ASM_CODE("1689")"\n"

STUB_ASM_ENTRY("glMultiTexCoord1hNV")"\n"
"\t"STUB_ASM_CODE("1690")"\n"

STUB_ASM_ENTRY("glMultiTexCoord1hvNV")"\n"
"\t"STUB_ASM_CODE("1691")"\n"

STUB_ASM_ENTRY("glMultiTexCoord1i")"\n"
"\t"STUB_ASM_CODE("1692")"\n"

STUB_ASM_ENTRY("glMultiTexCoord1iARB")"\n"
"\t"STUB_ASM_CODE("1693")"\n"

STUB_ASM_ENTRY("glMultiTexCoord1iv")"\n"
"\t"STUB_ASM_CODE("1694")"\n"

STUB_ASM_ENTRY("glMultiTexCoord1ivARB")"\n"
"\t"STUB_ASM_CODE("1695")"\n"

STUB_ASM_ENTRY("glMultiTexCoord1s")"\n"
"\t"STUB_ASM_CODE("1696")"\n"

STUB_ASM_ENTRY("glMultiTexCoord1sARB")"\n"
"\t"STUB_ASM_CODE("1697")"\n"

STUB_ASM_ENTRY("glMultiTexCoord1sv")"\n"
"\t"STUB_ASM_CODE("1698")"\n"

STUB_ASM_ENTRY("glMultiTexCoord1svARB")"\n"
"\t"STUB_ASM_CODE("1699")"\n"

STUB_ASM_ENTRY("glMultiTexCoord1x")"\n"
"\t"STUB_ASM_CODE("1700")"\n"

STUB_ASM_ENTRY("glMultiTexCoord1xOES")"\n"
"\t"STUB_ASM_CODE("1701")"\n"

STUB_ASM_ENTRY("glMultiTexCoord1xv")"\n"
"\t"STUB_ASM_CODE("1702")"\n"

STUB_ASM_ENTRY("glMultiTexCoord1xvOES")"\n"
"\t"STUB_ASM_CODE("1703")"\n"

STUB_ASM_ENTRY("glMultiTexCoord2bOES")"\n"
"\t"STUB_ASM_CODE("1704")"\n"

STUB_ASM_ENTRY("glMultiTexCoord2bvOES")"\n"
"\t"STUB_ASM_CODE("1705")"\n"

STUB_ASM_ENTRY("glMultiTexCoord2d")"\n"
"\t"STUB_ASM_CODE("1706")"\n"

STUB_ASM_ENTRY("glMultiTexCoord2dARB")"\n"
"\t"STUB_ASM_CODE("1707")"\n"

STUB_ASM_ENTRY("glMultiTexCoord2dv")"\n"
"\t"STUB_ASM_CODE("1708")"\n"

STUB_ASM_ENTRY("glMultiTexCoord2dvARB")"\n"
"\t"STUB_ASM_CODE("1709")"\n"

STUB_ASM_ENTRY("glMultiTexCoord2f")"\n"
"\t"STUB_ASM_CODE("1710")"\n"

STUB_ASM_ENTRY("glMultiTexCoord2fARB")"\n"
"\t"STUB_ASM_CODE("1711")"\n"

STUB_ASM_ENTRY("glMultiTexCoord2fv")"\n"
"\t"STUB_ASM_CODE("1712")"\n"

STUB_ASM_ENTRY("glMultiTexCoord2fvARB")"\n"
"\t"STUB_ASM_CODE("1713")"\n"

STUB_ASM_ENTRY("glMultiTexCoord2hNV")"\n"
"\t"STUB_ASM_CODE("1714")"\n"

STUB_ASM_ENTRY("glMultiTexCoord2hvNV")"\n"
"\t"STUB_ASM_CODE("1715")"\n"

STUB_ASM_ENTRY("glMultiTexCoord2i")"\n"
"\t"STUB_ASM_CODE("1716")"\n"

STUB_ASM_ENTRY("glMultiTexCoord2iARB")"\n"
"\t"STUB_ASM_CODE("1717")"\n"

STUB_ASM_ENTRY("glMultiTexCoord2iv")"\n"
"\t"STUB_ASM_CODE("1718")"\n"

STUB_ASM_ENTRY("glMultiTexCoord2ivARB")"\n"
"\t"STUB_ASM_CODE("1719")"\n"

STUB_ASM_ENTRY("glMultiTexCoord2s")"\n"
"\t"STUB_ASM_CODE("1720")"\n"

STUB_ASM_ENTRY("glMultiTexCoord2sARB")"\n"
"\t"STUB_ASM_CODE("1721")"\n"

STUB_ASM_ENTRY("glMultiTexCoord2sv")"\n"
"\t"STUB_ASM_CODE("1722")"\n"

STUB_ASM_ENTRY("glMultiTexCoord2svARB")"\n"
"\t"STUB_ASM_CODE("1723")"\n"

STUB_ASM_ENTRY("glMultiTexCoord2x")"\n"
"\t"STUB_ASM_CODE("1724")"\n"

STUB_ASM_ENTRY("glMultiTexCoord2xOES")"\n"
"\t"STUB_ASM_CODE("1725")"\n"

STUB_ASM_ENTRY("glMultiTexCoord2xv")"\n"
"\t"STUB_ASM_CODE("1726")"\n"

STUB_ASM_ENTRY("glMultiTexCoord2xvOES")"\n"
"\t"STUB_ASM_CODE("1727")"\n"

STUB_ASM_ENTRY("glMultiTexCoord3bOES")"\n"
"\t"STUB_ASM_CODE("1728")"\n"

STUB_ASM_ENTRY("glMultiTexCoord3bvOES")"\n"
"\t"STUB_ASM_CODE("1729")"\n"

STUB_ASM_ENTRY("glMultiTexCoord3d")"\n"
"\t"STUB_ASM_CODE("1730")"\n"

STUB_ASM_ENTRY("glMultiTexCoord3dARB")"\n"
"\t"STUB_ASM_CODE("1731")"\n"

STUB_ASM_ENTRY("glMultiTexCoord3dv")"\n"
"\t"STUB_ASM_CODE("1732")"\n"

STUB_ASM_ENTRY("glMultiTexCoord3dvARB")"\n"
"\t"STUB_ASM_CODE("1733")"\n"

STUB_ASM_ENTRY("glMultiTexCoord3f")"\n"
"\t"STUB_ASM_CODE("1734")"\n"

STUB_ASM_ENTRY("glMultiTexCoord3fARB")"\n"
"\t"STUB_ASM_CODE("1735")"\n"

STUB_ASM_ENTRY("glMultiTexCoord3fv")"\n"
"\t"STUB_ASM_CODE("1736")"\n"

STUB_ASM_ENTRY("glMultiTexCoord3fvARB")"\n"
"\t"STUB_ASM_CODE("1737")"\n"

STUB_ASM_ENTRY("glMultiTexCoord3hNV")"\n"
"\t"STUB_ASM_CODE("1738")"\n"

STUB_ASM_ENTRY("glMultiTexCoord3hvNV")"\n"
"\t"STUB_ASM_CODE("1739")"\n"

STUB_ASM_ENTRY("glMultiTexCoord3i")"\n"
"\t"STUB_ASM_CODE("1740")"\n"

STUB_ASM_ENTRY("glMultiTexCoord3iARB")"\n"
"\t"STUB_ASM_CODE("1741")"\n"

STUB_ASM_ENTRY("glMultiTexCoord3iv")"\n"
"\t"STUB_ASM_CODE("1742")"\n"

STUB_ASM_ENTRY("glMultiTexCoord3ivARB")"\n"
"\t"STUB_ASM_CODE("1743")"\n"

STUB_ASM_ENTRY("glMultiTexCoord3s")"\n"
"\t"STUB_ASM_CODE("1744")"\n"

STUB_ASM_ENTRY("glMultiTexCoord3sARB")"\n"
"\t"STUB_ASM_CODE("1745")"\n"

STUB_ASM_ENTRY("glMultiTexCoord3sv")"\n"
"\t"STUB_ASM_CODE("1746")"\n"

STUB_ASM_ENTRY("glMultiTexCoord3svARB")"\n"
"\t"STUB_ASM_CODE("1747")"\n"

STUB_ASM_ENTRY("glMultiTexCoord3x")"\n"
"\t"STUB_ASM_CODE("1748")"\n"

STUB_ASM_ENTRY("glMultiTexCoord3xOES")"\n"
"\t"STUB_ASM_CODE("1749")"\n"

STUB_ASM_ENTRY("glMultiTexCoord3xv")"\n"
"\t"STUB_ASM_CODE("1750")"\n"

STUB_ASM_ENTRY("glMultiTexCoord3xvOES")"\n"
"\t"STUB_ASM_CODE("1751")"\n"

STUB_ASM_ENTRY("glMultiTexCoord4bOES")"\n"
"\t"STUB_ASM_CODE("1752")"\n"

STUB_ASM_ENTRY("glMultiTexCoord4bvOES")"\n"
"\t"STUB_ASM_CODE("1753")"\n"

STUB_ASM_ENTRY("glMultiTexCoord4d")"\n"
"\t"STUB_ASM_CODE("1754")"\n"

STUB_ASM_ENTRY("glMultiTexCoord4dARB")"\n"
"\t"STUB_ASM_CODE("1755")"\n"

STUB_ASM_ENTRY("glMultiTexCoord4dv")"\n"
"\t"STUB_ASM_CODE("1756")"\n"

STUB_ASM_ENTRY("glMultiTexCoord4dvARB")"\n"
"\t"STUB_ASM_CODE("1757")"\n"

STUB_ASM_ENTRY("glMultiTexCoord4f")"\n"
"\t"STUB_ASM_CODE("1758")"\n"

STUB_ASM_ENTRY("glMultiTexCoord4fARB")"\n"
"\t"STUB_ASM_CODE("1759")"\n"

STUB_ASM_ENTRY("glMultiTexCoord4fv")"\n"
"\t"STUB_ASM_CODE("1760")"\n"

STUB_ASM_ENTRY("glMultiTexCoord4fvARB")"\n"
"\t"STUB_ASM_CODE("1761")"\n"

STUB_ASM_ENTRY("glMultiTexCoord4hNV")"\n"
"\t"STUB_ASM_CODE("1762")"\n"

STUB_ASM_ENTRY("glMultiTexCoord4hvNV")"\n"
"\t"STUB_ASM_CODE("1763")"\n"

STUB_ASM_ENTRY("glMultiTexCoord4i")"\n"
"\t"STUB_ASM_CODE("1764")"\n"

STUB_ASM_ENTRY("glMultiTexCoord4iARB")"\n"
"\t"STUB_ASM_CODE("1765")"\n"

STUB_ASM_ENTRY("glMultiTexCoord4iv")"\n"
"\t"STUB_ASM_CODE("1766")"\n"

STUB_ASM_ENTRY("glMultiTexCoord4ivARB")"\n"
"\t"STUB_ASM_CODE("1767")"\n"

STUB_ASM_ENTRY("glMultiTexCoord4s")"\n"
"\t"STUB_ASM_CODE("1768")"\n"

STUB_ASM_ENTRY("glMultiTexCoord4sARB")"\n"
"\t"STUB_ASM_CODE("1769")"\n"

STUB_ASM_ENTRY("glMultiTexCoord4sv")"\n"
"\t"STUB_ASM_CODE("1770")"\n"

STUB_ASM_ENTRY("glMultiTexCoord4svARB")"\n"
"\t"STUB_ASM_CODE("1771")"\n"

STUB_ASM_ENTRY("glMultiTexCoord4x")"\n"
"\t"STUB_ASM_CODE("1772")"\n"

STUB_ASM_ENTRY("glMultiTexCoord4xOES")"\n"
"\t"STUB_ASM_CODE("1773")"\n"

STUB_ASM_ENTRY("glMultiTexCoord4xv")"\n"
"\t"STUB_ASM_CODE("1774")"\n"

STUB_ASM_ENTRY("glMultiTexCoord4xvOES")"\n"
"\t"STUB_ASM_CODE("1775")"\n"

STUB_ASM_ENTRY("glMultiTexCoordP1ui")"\n"
"\t"STUB_ASM_CODE("1776")"\n"

STUB_ASM_ENTRY("glMultiTexCoordP1uiv")"\n"
"\t"STUB_ASM_CODE("1777")"\n"

STUB_ASM_ENTRY("glMultiTexCoordP2ui")"\n"
"\t"STUB_ASM_CODE("1778")"\n"

STUB_ASM_ENTRY("glMultiTexCoordP2uiv")"\n"
"\t"STUB_ASM_CODE("1779")"\n"

STUB_ASM_ENTRY("glMultiTexCoordP3ui")"\n"
"\t"STUB_ASM_CODE("1780")"\n"

STUB_ASM_ENTRY("glMultiTexCoordP3uiv")"\n"
"\t"STUB_ASM_CODE("1781")"\n"

STUB_ASM_ENTRY("glMultiTexCoordP4ui")"\n"
"\t"STUB_ASM_CODE("1782")"\n"

STUB_ASM_ENTRY("glMultiTexCoordP4uiv")"\n"
"\t"STUB_ASM_CODE("1783")"\n"

STUB_ASM_ENTRY("glMultiTexCoordPointerEXT")"\n"
"\t"STUB_ASM_CODE("1784")"\n"

STUB_ASM_ENTRY("glMultiTexEnvfEXT")"\n"
"\t"STUB_ASM_CODE("1785")"\n"

STUB_ASM_ENTRY("glMultiTexEnvfvEXT")"\n"
"\t"STUB_ASM_CODE("1786")"\n"

STUB_ASM_ENTRY("glMultiTexEnviEXT")"\n"
"\t"STUB_ASM_CODE("1787")"\n"

STUB_ASM_ENTRY("glMultiTexEnvivEXT")"\n"
"\t"STUB_ASM_CODE("1788")"\n"

STUB_ASM_ENTRY("glMultiTexGendEXT")"\n"
"\t"STUB_ASM_CODE("1789")"\n"

STUB_ASM_ENTRY("glMultiTexGendvEXT")"\n"
"\t"STUB_ASM_CODE("1790")"\n"

STUB_ASM_ENTRY("glMultiTexGenfEXT")"\n"
"\t"STUB_ASM_CODE("1791")"\n"

STUB_ASM_ENTRY("glMultiTexGenfvEXT")"\n"
"\t"STUB_ASM_CODE("1792")"\n"

STUB_ASM_ENTRY("glMultiTexGeniEXT")"\n"
"\t"STUB_ASM_CODE("1793")"\n"

STUB_ASM_ENTRY("glMultiTexGenivEXT")"\n"
"\t"STUB_ASM_CODE("1794")"\n"

STUB_ASM_ENTRY("glMultiTexImage1DEXT")"\n"
"\t"STUB_ASM_CODE("1795")"\n"

STUB_ASM_ENTRY("glMultiTexImage2DEXT")"\n"
"\t"STUB_ASM_CODE("1796")"\n"

STUB_ASM_ENTRY("glMultiTexImage3DEXT")"\n"
"\t"STUB_ASM_CODE("1797")"\n"

STUB_ASM_ENTRY("glMultiTexParameterIivEXT")"\n"
"\t"STUB_ASM_CODE("1798")"\n"

STUB_ASM_ENTRY("glMultiTexParameterIuivEXT")"\n"
"\t"STUB_ASM_CODE("1799")"\n"

STUB_ASM_ENTRY("glMultiTexParameterfEXT")"\n"
"\t"STUB_ASM_CODE("1800")"\n"

STUB_ASM_ENTRY("glMultiTexParameterfvEXT")"\n"
"\t"STUB_ASM_CODE("1801")"\n"

STUB_ASM_ENTRY("glMultiTexParameteriEXT")"\n"
"\t"STUB_ASM_CODE("1802")"\n"

STUB_ASM_ENTRY("glMultiTexParameterivEXT")"\n"
"\t"STUB_ASM_CODE("1803")"\n"

STUB_ASM_ENTRY("glMultiTexRenderbufferEXT")"\n"
"\t"STUB_ASM_CODE("1804")"\n"

STUB_ASM_ENTRY("glMultiTexSubImage1DEXT")"\n"
"\t"STUB_ASM_CODE("1805")"\n"

STUB_ASM_ENTRY("glMultiTexSubImage2DEXT")"\n"
"\t"STUB_ASM_CODE("1806")"\n"

STUB_ASM_ENTRY("glMultiTexSubImage3DEXT")"\n"
"\t"STUB_ASM_CODE("1807")"\n"

STUB_ASM_ENTRY("glMulticastBarrierNV")"\n"
"\t"STUB_ASM_CODE("1808")"\n"

STUB_ASM_ENTRY("glMulticastBlitFramebufferNV")"\n"
"\t"STUB_ASM_CODE("1809")"\n"

STUB_ASM_ENTRY("glMulticastBufferSubDataNV")"\n"
"\t"STUB_ASM_CODE("1810")"\n"

STUB_ASM_ENTRY("glMulticastCopyBufferSubDataNV")"\n"
"\t"STUB_ASM_CODE("1811")"\n"

STUB_ASM_ENTRY("glMulticastCopyImageSubDataNV")"\n"
"\t"STUB_ASM_CODE("1812")"\n"

STUB_ASM_ENTRY("glMulticastFramebufferSampleLocationsfvNV")"\n"
"\t"STUB_ASM_CODE("1813")"\n"

STUB_ASM_ENTRY("glMulticastGetQueryObjecti64vNV")"\n"
"\t"STUB_ASM_CODE("1814")"\n"

STUB_ASM_ENTRY("glMulticastGetQueryObjectivNV")"\n"
"\t"STUB_ASM_CODE("1815")"\n"

STUB_ASM_ENTRY("glMulticastGetQueryObjectui64vNV")"\n"
"\t"STUB_ASM_CODE("1816")"\n"

STUB_ASM_ENTRY("glMulticastGetQueryObjectuivNV")"\n"
"\t"STUB_ASM_CODE("1817")"\n"

STUB_ASM_ENTRY("glMulticastScissorArrayvNVX")"\n"
"\t"STUB_ASM_CODE("1818")"\n"

STUB_ASM_ENTRY("glMulticastViewportArrayvNVX")"\n"
"\t"STUB_ASM_CODE("1819")"\n"

STUB_ASM_ENTRY("glMulticastViewportPositionWScaleNVX")"\n"
"\t"STUB_ASM_CODE("1820")"\n"

STUB_ASM_ENTRY("glMulticastWaitSyncNV")"\n"
"\t"STUB_ASM_CODE("1821")"\n"

STUB_ASM_ENTRY("glNVENCInterOpFunctionNVX")"\n"
"\t"STUB_ASM_CODE("1822")"\n"

STUB_ASM_ENTRY("glNamedBufferAttachMemoryNV")"\n"
"\t"STUB_ASM_CODE("1823")"\n"

STUB_ASM_ENTRY("glNamedBufferData")"\n"
"\t"STUB_ASM_CODE("1824")"\n"

STUB_ASM_ENTRY("glNamedBufferDataEXT")"\n"
"\t"STUB_ASM_CODE("1825")"\n"

STUB_ASM_ENTRY("glNamedBufferPageCommitmentARB")"\n"
"\t"STUB_ASM_CODE("1826")"\n"

STUB_ASM_ENTRY("glNamedBufferPageCommitmentEXT")"\n"
"\t"STUB_ASM_CODE("1827")"\n"

STUB_ASM_ENTRY("glNamedBufferStorage")"\n"
"\t"STUB_ASM_CODE("1829")"\n"

STUB_ASM_ENTRY("glNamedBufferStorageEXT")"\n"
"\t"STUB_ASM_CODE("1830")"\n"

STUB_ASM_ENTRY("glNamedBufferStorageExternalEXT")"\n"
"\t"STUB_ASM_CODE("1831")"\n"

STUB_ASM_ENTRY("glNamedBufferStorageMemEXT")"\n"
"\t"STUB_ASM_CODE("1832")"\n"

STUB_ASM_ENTRY("glNamedBufferSubData")"\n"
"\t"STUB_ASM_CODE("1833")"\n"

STUB_ASM_ENTRY("glNamedBufferSubDataEXT")"\n"
"\t"STUB_ASM_CODE("1834")"\n"

STUB_ASM_ENTRY("glNamedCopyBufferSubDataEXT")"\n"
"\t"STUB_ASM_CODE("1835")"\n"

STUB_ASM_ENTRY("glNamedFramebufferDrawBuffer")"\n"
"\t"STUB_ASM_CODE("1836")"\n"

STUB_ASM_ENTRY("glNamedFramebufferDrawBuffers")"\n"
"\t"STUB_ASM_CODE("1837")"\n"

STUB_ASM_ENTRY("glNamedFramebufferParameteri")"\n"
"\t"STUB_ASM_CODE("1838")"\n"

STUB_ASM_ENTRY("glNamedFramebufferParameteriEXT")"\n"
"\t"STUB_ASM_CODE("1839")"\n"

STUB_ASM_ENTRY("glNamedFramebufferReadBuffer")"\n"
"\t"STUB_ASM_CODE("1840")"\n"

STUB_ASM_ENTRY("glNamedFramebufferRenderbuffer")"\n"
"\t"STUB_ASM_CODE("1841")"\n"

STUB_ASM_ENTRY("glNamedFramebufferRenderbufferEXT")"\n"
"\t"STUB_ASM_CODE("1842")"\n"

STUB_ASM_ENTRY("glNamedFramebufferSampleLocationsfvARB")"\n"
"\t"STUB_ASM_CODE("1843")"\n"

STUB_ASM_ENTRY("glNamedFramebufferSampleLocationsfvNV")"\n"
"\t"STUB_ASM_CODE("1844")"\n"

STUB_ASM_ENTRY("glNamedFramebufferSamplePositionsfvAMD")"\n"
"\t"STUB_ASM_CODE("1845")"\n"

STUB_ASM_ENTRY("glNamedFramebufferTexture")"\n"
"\t"STUB_ASM_CODE("1846")"\n"

STUB_ASM_ENTRY("glNamedFramebufferTexture1DEXT")"\n"
"\t"STUB_ASM_CODE("1847")"\n"

STUB_ASM_ENTRY("glNamedFramebufferTexture2DEXT")"\n"
"\t"STUB_ASM_CODE("1848")"\n"

STUB_ASM_ENTRY("glNamedFramebufferTexture3DEXT")"\n"
"\t"STUB_ASM_CODE("1849")"\n"

STUB_ASM_ENTRY("glNamedFramebufferTextureEXT")"\n"
"\t"STUB_ASM_CODE("1850")"\n"

STUB_ASM_ENTRY("glNamedFramebufferTextureFaceEXT")"\n"
"\t"STUB_ASM_CODE("1851")"\n"

STUB_ASM_ENTRY("glNamedFramebufferTextureLayer")"\n"
"\t"STUB_ASM_CODE("1852")"\n"

STUB_ASM_ENTRY("glNamedFramebufferTextureLayerEXT")"\n"
"\t"STUB_ASM_CODE("1853")"\n"

STUB_ASM_ENTRY("glNamedProgramLocalParameter4dEXT")"\n"
"\t"STUB_ASM_CODE("1854")"\n"

STUB_ASM_ENTRY("glNamedProgramLocalParameter4dvEXT")"\n"
"\t"STUB_ASM_CODE("1855")"\n"

STUB_ASM_ENTRY("glNamedProgramLocalParameter4fEXT")"\n"
"\t"STUB_ASM_CODE("1856")"\n"

STUB_ASM_ENTRY("glNamedProgramLocalParameter4fvEXT")"\n"
"\t"STUB_ASM_CODE("1857")"\n"

STUB_ASM_ENTRY("glNamedProgramLocalParameterI4iEXT")"\n"
"\t"STUB_ASM_CODE("1858")"\n"

STUB_ASM_ENTRY("glNamedProgramLocalParameterI4ivEXT")"\n"
"\t"STUB_ASM_CODE("1859")"\n"

STUB_ASM_ENTRY("glNamedProgramLocalParameterI4uiEXT")"\n"
"\t"STUB_ASM_CODE("1860")"\n"

STUB_ASM_ENTRY("glNamedProgramLocalParameterI4uivEXT")"\n"
"\t"STUB_ASM_CODE("1861")"\n"

STUB_ASM_ENTRY("glNamedProgramLocalParameters4fvEXT")"\n"
"\t"STUB_ASM_CODE("1862")"\n"

STUB_ASM_ENTRY("glNamedProgramLocalParametersI4ivEXT")"\n"
"\t"STUB_ASM_CODE("1863")"\n"

STUB_ASM_ENTRY("glNamedProgramLocalParametersI4uivEXT")"\n"
"\t"STUB_ASM_CODE("1864")"\n"

STUB_ASM_ENTRY("glNamedProgramStringEXT")"\n"
"\t"STUB_ASM_CODE("1865")"\n"

STUB_ASM_ENTRY("glNamedRenderbufferStorage")"\n"
"\t"STUB_ASM_CODE("1866")"\n"

STUB_ASM_ENTRY("glNamedRenderbufferStorageEXT")"\n"
"\t"STUB_ASM_CODE("1867")"\n"

STUB_ASM_ENTRY("glNamedRenderbufferStorageMultisample")"\n"
"\t"STUB_ASM_CODE("1868")"\n"

STUB_ASM_ENTRY("glNamedRenderbufferStorageMultisampleAdvancedAMD")"\n"
"\t"STUB_ASM_CODE("1869")"\n"

STUB_ASM_ENTRY("glNamedRenderbufferStorageMultisampleCoverageEXT")"\n"
"\t"STUB_ASM_CODE("1870")"\n"

STUB_ASM_ENTRY("glNamedRenderbufferStorageMultisampleEXT")"\n"
"\t"STUB_ASM_CODE("1871")"\n"

STUB_ASM_ENTRY("glNamedStringARB")"\n"
"\t"STUB_ASM_CODE("1872")"\n"

STUB_ASM_ENTRY("glNewList")"\n"
"\t"STUB_ASM_CODE("1873")"\n"

STUB_ASM_ENTRY("glNewObjectBufferATI")"\n"
"\t"STUB_ASM_CODE("1874")"\n"

STUB_ASM_ENTRY("glNormal3b")"\n"
"\t"STUB_ASM_CODE("1875")"\n"

STUB_ASM_ENTRY("glNormal3bv")"\n"
"\t"STUB_ASM_CODE("1876")"\n"

STUB_ASM_ENTRY("glNormal3d")"\n"
"\t"STUB_ASM_CODE("1877")"\n"

STUB_ASM_ENTRY("glNormal3dv")"\n"
"\t"STUB_ASM_CODE("1878")"\n"

STUB_ASM_ENTRY("glNormal3f")"\n"
"\t"STUB_ASM_CODE("1879")"\n"

STUB_ASM_ENTRY("glNormal3fVertex3fSUN")"\n"
"\t"STUB_ASM_CODE("1880")"\n"

STUB_ASM_ENTRY("glNormal3fVertex3fvSUN")"\n"
"\t"STUB_ASM_CODE("1881")"\n"

STUB_ASM_ENTRY("glNormal3fv")"\n"
"\t"STUB_ASM_CODE("1882")"\n"

STUB_ASM_ENTRY("glNormal3hNV")"\n"
"\t"STUB_ASM_CODE("1883")"\n"

STUB_ASM_ENTRY("glNormal3hvNV")"\n"
"\t"STUB_ASM_CODE("1884")"\n"

STUB_ASM_ENTRY("glNormal3i")"\n"
"\t"STUB_ASM_CODE("1885")"\n"

STUB_ASM_ENTRY("glNormal3iv")"\n"
"\t"STUB_ASM_CODE("1886")"\n"

STUB_ASM_ENTRY("glNormal3s")"\n"
"\t"STUB_ASM_CODE("1887")"\n"

STUB_ASM_ENTRY("glNormal3sv")"\n"
"\t"STUB_ASM_CODE("1888")"\n"

STUB_ASM_ENTRY("glNormal3x")"\n"
"\t"STUB_ASM_CODE("1889")"\n"

STUB_ASM_ENTRY("glNormal3xOES")"\n"
"\t"STUB_ASM_CODE("1890")"\n"

STUB_ASM_ENTRY("glNormal3xvOES")"\n"
"\t"STUB_ASM_CODE("1891")"\n"

STUB_ASM_ENTRY("glNormalFormatNV")"\n"
"\t"STUB_ASM_CODE("1892")"\n"

STUB_ASM_ENTRY("glNormalP3ui")"\n"
"\t"STUB_ASM_CODE("1893")"\n"

STUB_ASM_ENTRY("glNormalP3uiv")"\n"
"\t"STUB_ASM_CODE("1894")"\n"

STUB_ASM_ENTRY("glNormalPointer")"\n"
"\t"STUB_ASM_CODE("1895")"\n"

STUB_ASM_ENTRY("glNormalPointerEXT")"\n"
"\t"STUB_ASM_CODE("1896")"\n"

STUB_ASM_ENTRY("glNormalPointerListIBM")"\n"
"\t"STUB_ASM_CODE("1897")"\n"

STUB_ASM_ENTRY("glNormalPointervINTEL")"\n"
"\t"STUB_ASM_CODE("1898")"\n"

STUB_ASM_ENTRY("glNormalStream3bATI")"\n"
"\t"STUB_ASM_CODE("1899")"\n"

STUB_ASM_ENTRY("glNormalStream3bvATI")"\n"
"\t"STUB_ASM_CODE("1900")"\n"

STUB_ASM_ENTRY("glNormalStream3dATI")"\n"
"\t"STUB_ASM_CODE("1901")"\n"

STUB_ASM_ENTRY("glNormalStream3dvATI")"\n"
"\t"STUB_ASM_CODE("1902")"\n"

STUB_ASM_ENTRY("glNormalStream3fATI")"\n"
"\t"STUB_ASM_CODE("1903")"\n"

STUB_ASM_ENTRY("glNormalStream3fvATI")"\n"
"\t"STUB_ASM_CODE("1904")"\n"

STUB_ASM_ENTRY("glNormalStream3iATI")"\n"
"\t"STUB_ASM_CODE("1905")"\n"

STUB_ASM_ENTRY("glNormalStream3ivATI")"\n"
"\t"STUB_ASM_CODE("1906")"\n"

STUB_ASM_ENTRY("glNormalStream3sATI")"\n"
"\t"STUB_ASM_CODE("1907")"\n"

STUB_ASM_ENTRY("glNormalStream3svATI")"\n"
"\t"STUB_ASM_CODE("1908")"\n"

STUB_ASM_ENTRY("glObjectLabel")"\n"
"\t"STUB_ASM_CODE("1909")"\n"

STUB_ASM_ENTRY("glObjectLabelKHR")"\n"
"\t"STUB_ASM_CODE("1910")"\n"

STUB_ASM_ENTRY("glObjectLabelOES")"\n"
"\t"STUB_ASM_CODE("1911")"\n"

STUB_ASM_ENTRY("glObjectPtrLabel")"\n"
"\t"STUB_ASM_CODE("1912")"\n"

STUB_ASM_ENTRY("glObjectPtrLabelKHR")"\n"
"\t"STUB_ASM_CODE("1913")"\n"

STUB_ASM_ENTRY("glObjectPtrLabelOES")"\n"
"\t"STUB_ASM_CODE("1914")"\n"

STUB_ASM_ENTRY("glObjectPurgeableAPPLE")"\n"
"\t"STUB_ASM_CODE("1915")"\n"

STUB_ASM_ENTRY("glObjectUnpurgeableAPPLE")"\n"
"\t"STUB_ASM_CODE("1916")"\n"

STUB_ASM_ENTRY("glOrtho")"\n"
"\t"STUB_ASM_CODE("1917")"\n"

STUB_ASM_ENTRY("glOrthof")"\n"
"\t"STUB_ASM_CODE("1918")"\n"

STUB_ASM_ENTRY("glOrthofOES")"\n"
"\t"STUB_ASM_CODE("1919")"\n"

STUB_ASM_ENTRY("glOrthox")"\n"
"\t"STUB_ASM_CODE("1920")"\n"

STUB_ASM_ENTRY("glOrthoxOES")"\n"
"\t"STUB_ASM_CODE("1921")"\n"

STUB_ASM_ENTRY("glPNTrianglesfATI")"\n"
"\t"STUB_ASM_CODE("1922")"\n"

STUB_ASM_ENTRY("glPNTrianglesiATI")"\n"
"\t"STUB_ASM_CODE("1923")"\n"

STUB_ASM_ENTRY("glPassTexCoordATI")"\n"
"\t"STUB_ASM_CODE("1924")"\n"

STUB_ASM_ENTRY("glPassThrough")"\n"
"\t"STUB_ASM_CODE("1925")"\n"

STUB_ASM_ENTRY("glPassThroughxOES")"\n"
"\t"STUB_ASM_CODE("1926")"\n"

STUB_ASM_ENTRY("glPatchParameterfv")"\n"
"\t"STUB_ASM_CODE("1927")"\n"

STUB_ASM_ENTRY("glPatchParameterfvEXT")"\n"
"\t"STUB_ASM_CODE("1928")"\n"

STUB_ASM_ENTRY("glPatchParameterfvNV")"\n"
"\t"STUB_ASM_CODE("1929")"\n"

STUB_ASM_ENTRY("glPatchParameteri")"\n"
"\t"STUB_ASM_CODE("1930")"\n"

STUB_ASM_ENTRY("glPatchParameteriEXT")"\n"
"\t"STUB_ASM_CODE("1931")"\n"

STUB_ASM_ENTRY("glPatchParameteriNV")"\n"
"\t"STUB_ASM_CODE("1932")"\n"

STUB_ASM_ENTRY("glPatchParameteriOES")"\n"
"\t"STUB_ASM_CODE("1933")"\n"

STUB_ASM_ENTRY("glPathColorGenNV")"\n"
"\t"STUB_ASM_CODE("1934")"\n"

STUB_ASM_ENTRY("glPathCommandsNV")"\n"
"\t"STUB_ASM_CODE("1935")"\n"

STUB_ASM_ENTRY("glPathCoordsNV")"\n"
"\t"STUB_ASM_CODE("1936")"\n"

STUB_ASM_ENTRY("glPathCoverDepthFuncNV")"\n"
"\t"STUB_ASM_CODE("1937")"\n"

STUB_ASM_ENTRY("glPathDashArrayNV")"\n"
"\t"STUB_ASM_CODE("1938")"\n"

STUB_ASM_ENTRY("glPathFogGenNV")"\n"
"\t"STUB_ASM_CODE("1939")"\n"

STUB_ASM_ENTRY("glPathGlyphIndexArrayNV")"\n"
"\t"STUB_ASM_CODE("1940")"\n"

STUB_ASM_ENTRY("glPathGlyphIndexRangeNV")"\n"
"\t"STUB_ASM_CODE("1941")"\n"

STUB_ASM_ENTRY("glPathGlyphRangeNV")"\n"
"\t"STUB_ASM_CODE("1942")"\n"

STUB_ASM_ENTRY("glPathGlyphsNV")"\n"
"\t"STUB_ASM_CODE("1943")"\n"

STUB_ASM_ENTRY("glPathMemoryGlyphIndexArrayNV")"\n"
"\t"STUB_ASM_CODE("1944")"\n"

STUB_ASM_ENTRY("glPathParameterfNV")"\n"
"\t"STUB_ASM_CODE("1945")"\n"

STUB_ASM_ENTRY("glPathParameterfvNV")"\n"
"\t"STUB_ASM_CODE("1946")"\n"

STUB_ASM_ENTRY("glPathParameteriNV")"\n"
"\t"STUB_ASM_CODE("1947")"\n"

STUB_ASM_ENTRY("glPathParameterivNV")"\n"
"\t"STUB_ASM_CODE("1948")"\n"

STUB_ASM_ENTRY("glPathStencilDepthOffsetNV")"\n"
"\t"STUB_ASM_CODE("1949")"\n"

STUB_ASM_ENTRY("glPathStencilFuncNV")"\n"
"\t"STUB_ASM_CODE("1950")"\n"

STUB_ASM_ENTRY("glPathStringNV")"\n"
"\t"STUB_ASM_CODE("1951")"\n"

STUB_ASM_ENTRY("glPathSubCommandsNV")"\n"
"\t"STUB_ASM_CODE("1952")"\n"

STUB_ASM_ENTRY("glPathSubCoordsNV")"\n"
"\t"STUB_ASM_CODE("1953")"\n"

STUB_ASM_ENTRY("glPathTexGenNV")"\n"
"\t"STUB_ASM_CODE("1954")"\n"

STUB_ASM_ENTRY("glPauseTransformFeedback")"\n"
"\t"STUB_ASM_CODE("1955")"\n"

STUB_ASM_ENTRY("glPauseTransformFeedbackEXT")"\n"
"\t"STUB_ASM_CODE("1956")"\n"

STUB_ASM_ENTRY("glPauseTransformFeedbackNV")"\n"
"\t"STUB_ASM_CODE("1957")"\n"

STUB_ASM_ENTRY("glPixelDataRangeNV")"\n"
"\t"STUB_ASM_CODE("1958")"\n"

STUB_ASM_ENTRY("glPixelMapfv")"\n"
"\t"STUB_ASM_CODE("1959")"\n"

STUB_ASM_ENTRY("glPixelMapuiv")"\n"
"\t"STUB_ASM_CODE("1960")"\n"

STUB_ASM_ENTRY("glPixelMapusv")"\n"
"\t"STUB_ASM_CODE("1961")"\n"

STUB_ASM_ENTRY("glPixelMapx")"\n"
"\t"STUB_ASM_CODE("1962")"\n"

STUB_ASM_ENTRY("glPixelStoref")"\n"
"\t"STUB_ASM_CODE("1963")"\n"

STUB_ASM_ENTRY("glPixelStorei")"\n"
"\t"STUB_ASM_CODE("1964")"\n"

STUB_ASM_ENTRY("glPixelStorex")"\n"
"\t"STUB_ASM_CODE("1965")"\n"

STUB_ASM_ENTRY("glPixelTexGenParameterfSGIS")"\n"
"\t"STUB_ASM_CODE("1966")"\n"

STUB_ASM_ENTRY("glPixelTexGenParameterfvSGIS")"\n"
"\t"STUB_ASM_CODE("1967")"\n"

STUB_ASM_ENTRY("glPixelTexGenParameteriSGIS")"\n"
"\t"STUB_ASM_CODE("1968")"\n"

STUB_ASM_ENTRY("glPixelTexGenParameterivSGIS")"\n"
"\t"STUB_ASM_CODE("1969")"\n"

STUB_ASM_ENTRY("glPixelTexGenSGIX")"\n"
"\t"STUB_ASM_CODE("1970")"\n"

STUB_ASM_ENTRY("glPixelTransferf")"\n"
"\t"STUB_ASM_CODE("1971")"\n"

STUB_ASM_ENTRY("glPixelTransferi")"\n"
"\t"STUB_ASM_CODE("1972")"\n"

STUB_ASM_ENTRY("glPixelTransferxOES")"\n"
"\t"STUB_ASM_CODE("1973")"\n"

STUB_ASM_ENTRY("glPixelTransformParameterfEXT")"\n"
"\t"STUB_ASM_CODE("1974")"\n"

STUB_ASM_ENTRY("glPixelTransformParameterfvEXT")"\n"
"\t"STUB_ASM_CODE("1975")"\n"

STUB_ASM_ENTRY("glPixelTransformParameteriEXT")"\n"
"\t"STUB_ASM_CODE("1976")"\n"

STUB_ASM_ENTRY("glPixelTransformParameterivEXT")"\n"
"\t"STUB_ASM_CODE("1977")"\n"

STUB_ASM_ENTRY("glPixelZoom")"\n"
"\t"STUB_ASM_CODE("1978")"\n"

STUB_ASM_ENTRY("glPixelZoomxOES")"\n"
"\t"STUB_ASM_CODE("1979")"\n"

STUB_ASM_ENTRY("glPointAlongPathNV")"\n"
"\t"STUB_ASM_CODE("1980")"\n"

STUB_ASM_ENTRY("glPointParameterf")"\n"
"\t"STUB_ASM_CODE("1981")"\n"

STUB_ASM_ENTRY("glPointParameterfARB")"\n"
"\t"STUB_ASM_CODE("1982")"\n"

STUB_ASM_ENTRY("glPointParameterfEXT")"\n"
"\t"STUB_ASM_CODE("1983")"\n"

STUB_ASM_ENTRY("glPointParameterfSGIS")"\n"
"\t"STUB_ASM_CODE("1984")"\n"

STUB_ASM_ENTRY("glPointParameterfv")"\n"
"\t"STUB_ASM_CODE("1985")"\n"

STUB_ASM_ENTRY("glPointParameterfvARB")"\n"
"\t"STUB_ASM_CODE("1986")"\n"

STUB_ASM_ENTRY("glPointParameterfvEXT")"\n"
"\t"STUB_ASM_CODE("1987")"\n"

STUB_ASM_ENTRY("glPointParameterfvSGIS")"\n"
"\t"STUB_ASM_CODE("1988")"\n"

STUB_ASM_ENTRY("glPointParameteri")"\n"
"\t"STUB_ASM_CODE("1989")"\n"

STUB_ASM_ENTRY("glPointParameteriNV")"\n"
"\t"STUB_ASM_CODE("1990")"\n"

STUB_ASM_ENTRY("glPointParameteriv")"\n"
"\t"STUB_ASM_CODE("1991")"\n"

STUB_ASM_ENTRY("glPointParameterivNV")"\n"
"\t"STUB_ASM_CODE("1992")"\n"

STUB_ASM_ENTRY("glPointParameterx")"\n"
"\t"STUB_ASM_CODE("1993")"\n"

STUB_ASM_ENTRY("glPointParameterxOES")"\n"
"\t"STUB_ASM_CODE("1994")"\n"

STUB_ASM_ENTRY("glPointParameterxv")"\n"
"\t"STUB_ASM_CODE("1995")"\n"

STUB_ASM_ENTRY("glPointParameterxvOES")"\n"
"\t"STUB_ASM_CODE("1996")"\n"

STUB_ASM_ENTRY("glPointSize")"\n"
"\t"STUB_ASM_CODE("1997")"\n"

STUB_ASM_ENTRY("glPointSizePointerOES")"\n"
"\t"STUB_ASM_CODE("1998")"\n"

STUB_ASM_ENTRY("glPointSizex")"\n"
"\t"STUB_ASM_CODE("1999")"\n"

STUB_ASM_ENTRY("glPointSizexOES")"\n"
"\t"STUB_ASM_CODE("2000")"\n"

STUB_ASM_ENTRY("glPollAsyncSGIX")"\n"
"\t"STUB_ASM_CODE("2001")"\n"

STUB_ASM_ENTRY("glPollInstrumentsSGIX")"\n"
"\t"STUB_ASM_CODE("2002")"\n"

STUB_ASM_ENTRY("glPolygonMode")"\n"
"\t"STUB_ASM_CODE("2003")"\n"

STUB_ASM_ENTRY("glPolygonModeNV")"\n"
"\t"STUB_ASM_CODE("2004")"\n"

STUB_ASM_ENTRY("glPolygonOffset")"\n"
"\t"STUB_ASM_CODE("2005")"\n"

STUB_ASM_ENTRY("glPolygonOffsetClamp")"\n"
"\t"STUB_ASM_CODE("2006")"\n"

STUB_ASM_ENTRY("glPolygonOffsetClampEXT")"\n"
"\t"STUB_ASM_CODE("2007")"\n"

STUB_ASM_ENTRY("glPolygonOffsetEXT")"\n"
"\t"STUB_ASM_CODE("2008")"\n"

STUB_ASM_ENTRY("glPolygonOffsetx")"\n"
"\t"STUB_ASM_CODE("2009")"\n"

STUB_ASM_ENTRY("glPolygonOffsetxOES")"\n"
"\t"STUB_ASM_CODE("2010")"\n"

STUB_ASM_ENTRY("glPolygonStipple")"\n"
"\t"STUB_ASM_CODE("2011")"\n"

STUB_ASM_ENTRY("glPopAttrib")"\n"
"\t"STUB_ASM_CODE("2012")"\n"

STUB_ASM_ENTRY("glPopClientAttrib")"\n"
"\t"STUB_ASM_CODE("2013")"\n"

STUB_ASM_ENTRY("glPopDebugGroup")"\n"
"\t"STUB_ASM_CODE("2014")"\n"

STUB_ASM_ENTRY("glPopDebugGroupKHR")"\n"
"\t"STUB_ASM_CODE("2015")"\n"

STUB_ASM_ENTRY("glPopDebugGroupOES")"\n"
"\t"STUB_ASM_CODE("2016")"\n"

STUB_ASM_ENTRY("glPopGroupMarkerEXT")"\n"
"\t"STUB_ASM_CODE("2017")"\n"

STUB_ASM_ENTRY("glPopMatrix")"\n"
"\t"STUB_ASM_CODE("2018")"\n"

STUB_ASM_ENTRY("glPopName")"\n"
"\t"STUB_ASM_CODE("2019")"\n"

STUB_ASM_ENTRY("glPresentFrameDualFillNV")"\n"
"\t"STUB_ASM_CODE("2020")"\n"

STUB_ASM_ENTRY("glPresentFrameKeyedNV")"\n"
"\t"STUB_ASM_CODE("2021")"\n"

STUB_ASM_ENTRY("glPrimitiveBoundingBox")"\n"
"\t"STUB_ASM_CODE("2022")"\n"

STUB_ASM_ENTRY("glPrimitiveBoundingBoxARB")"\n"
"\t"STUB_ASM_CODE("2023")"\n"

STUB_ASM_ENTRY("glPrimitiveBoundingBoxEXT")"\n"
"\t"STUB_ASM_CODE("2024")"\n"

STUB_ASM_ENTRY("glPrimitiveBoundingBoxOES")"\n"
"\t"STUB_ASM_CODE("2025")"\n"

STUB_ASM_ENTRY("glPrimitiveRestart")"\n"
"\t"STUB_ASM_CODE("2026")"\n"

STUB_ASM_ENTRY("glPrimitiveRestartIndex")"\n"
"\t"STUB_ASM_CODE("2027")"\n"

STUB_ASM_ENTRY("glPrimitiveRestartIndexNV")"\n"
"\t"STUB_ASM_CODE("2028")"\n"

STUB_ASM_ENTRY("glPrimitiveRestartNV")"\n"
"\t"STUB_ASM_CODE("2029")"\n"

STUB_ASM_ENTRY("glPrioritizeTextures")"\n"
"\t"STUB_ASM_CODE("2030")"\n"

STUB_ASM_ENTRY("glPrioritizeTexturesEXT")"\n"
"\t"STUB_ASM_CODE("2031")"\n"

STUB_ASM_ENTRY("glPrioritizeTexturesxOES")"\n"
"\t"STUB_ASM_CODE("2032")"\n"

STUB_ASM_ENTRY("glProgramBinary")"\n"
"\t"STUB_ASM_CODE("2033")"\n"

STUB_ASM_ENTRY("glProgramBinaryOES")"\n"
"\t"STUB_ASM_CODE("2034")"\n"

STUB_ASM_ENTRY("glProgramBufferParametersIivNV")"\n"
"\t"STUB_ASM_CODE("2035")"\n"

STUB_ASM_ENTRY("glProgramBufferParametersIuivNV")"\n"
"\t"STUB_ASM_CODE("2036")"\n"

STUB_ASM_ENTRY("glProgramBufferParametersfvNV")"\n"
"\t"STUB_ASM_CODE("2037")"\n"

STUB_ASM_ENTRY("glProgramEnvParameter4dARB")"\n"
"\t"STUB_ASM_CODE("2038")"\n"

STUB_ASM_ENTRY("glProgramEnvParameter4dvARB")"\n"
"\t"STUB_ASM_CODE("2039")"\n"

STUB_ASM_ENTRY("glProgramEnvParameter4fARB")"\n"
"\t"STUB_ASM_CODE("2040")"\n"

STUB_ASM_ENTRY("glProgramEnvParameter4fvARB")"\n"
"\t"STUB_ASM_CODE("2041")"\n"

STUB_ASM_ENTRY("glProgramEnvParameterI4iNV")"\n"
"\t"STUB_ASM_CODE("2042")"\n"

STUB_ASM_ENTRY("glProgramEnvParameterI4ivNV")"\n"
"\t"STUB_ASM_CODE("2043")"\n"

STUB_ASM_ENTRY("glProgramEnvParameterI4uiNV")"\n"
"\t"STUB_ASM_CODE("2044")"\n"

STUB_ASM_ENTRY("glProgramEnvParameterI4uivNV")"\n"
"\t"STUB_ASM_CODE("2045")"\n"

STUB_ASM_ENTRY("glProgramEnvParameters4fvEXT")"\n"
"\t"STUB_ASM_CODE("2046")"\n"

STUB_ASM_ENTRY("glProgramEnvParametersI4ivNV")"\n"
"\t"STUB_ASM_CODE("2047")"\n"

STUB_ASM_ENTRY("glProgramEnvParametersI4uivNV")"\n"
"\t"STUB_ASM_CODE("2048")"\n"

STUB_ASM_ENTRY("glProgramLocalParameter4dARB")"\n"
"\t"STUB_ASM_CODE("2049")"\n"

STUB_ASM_ENTRY("glProgramLocalParameter4dvARB")"\n"
"\t"STUB_ASM_CODE("2050")"\n"

STUB_ASM_ENTRY("glProgramLocalParameter4fARB")"\n"
"\t"STUB_ASM_CODE("2051")"\n"

STUB_ASM_ENTRY("glProgramLocalParameter4fvARB")"\n"
"\t"STUB_ASM_CODE("2052")"\n"

STUB_ASM_ENTRY("glProgramLocalParameterI4iNV")"\n"
"\t"STUB_ASM_CODE("2053")"\n"

STUB_ASM_ENTRY("glProgramLocalParameterI4ivNV")"\n"
"\t"STUB_ASM_CODE("2054")"\n"

STUB_ASM_ENTRY("glProgramLocalParameterI4uiNV")"\n"
"\t"STUB_ASM_CODE("2055")"\n"

STUB_ASM_ENTRY("glProgramLocalParameterI4uivNV")"\n"
"\t"STUB_ASM_CODE("2056")"\n"

STUB_ASM_ENTRY("glProgramLocalParameters4fvEXT")"\n"
"\t"STUB_ASM_CODE("2057")"\n"

STUB_ASM_ENTRY("glProgramLocalParametersI4ivNV")"\n"
"\t"STUB_ASM_CODE("2058")"\n"

STUB_ASM_ENTRY("glProgramLocalParametersI4uivNV")"\n"
"\t"STUB_ASM_CODE("2059")"\n"

STUB_ASM_ENTRY("glProgramNamedParameter4dNV")"\n"
"\t"STUB_ASM_CODE("2060")"\n"

STUB_ASM_ENTRY("glProgramNamedParameter4dvNV")"\n"
"\t"STUB_ASM_CODE("2061")"\n"

STUB_ASM_ENTRY("glProgramNamedParameter4fNV")"\n"
"\t"STUB_ASM_CODE("2062")"\n"

STUB_ASM_ENTRY("glProgramNamedParameter4fvNV")"\n"
"\t"STUB_ASM_CODE("2063")"\n"

STUB_ASM_ENTRY("glProgramParameter4dNV")"\n"
"\t"STUB_ASM_CODE("2064")"\n"

STUB_ASM_ENTRY("glProgramParameter4dvNV")"\n"
"\t"STUB_ASM_CODE("2065")"\n"

STUB_ASM_ENTRY("glProgramParameter4fNV")"\n"
"\t"STUB_ASM_CODE("2066")"\n"

STUB_ASM_ENTRY("glProgramParameter4fvNV")"\n"
"\t"STUB_ASM_CODE("2067")"\n"

STUB_ASM_ENTRY("glProgramParameteri")"\n"
"\t"STUB_ASM_CODE("2068")"\n"

STUB_ASM_ENTRY("glProgramParameteriARB")"\n"
"\t"STUB_ASM_CODE("2069")"\n"

STUB_ASM_ENTRY("glProgramParameteriEXT")"\n"
"\t"STUB_ASM_CODE("2070")"\n"

STUB_ASM_ENTRY("glProgramParameters4dvNV")"\n"
"\t"STUB_ASM_CODE("2071")"\n"

STUB_ASM_ENTRY("glProgramParameters4fvNV")"\n"
"\t"STUB_ASM_CODE("2072")"\n"

STUB_ASM_ENTRY("glProgramPathFragmentInputGenNV")"\n"
"\t"STUB_ASM_CODE("2073")"\n"

STUB_ASM_ENTRY("glProgramStringARB")"\n"
"\t"STUB_ASM_CODE("2074")"\n"

STUB_ASM_ENTRY("glProgramSubroutineParametersuivNV")"\n"
"\t"STUB_ASM_CODE("2075")"\n"

STUB_ASM_ENTRY("glProgramUniform1d")"\n"
"\t"STUB_ASM_CODE("2076")"\n"

STUB_ASM_ENTRY("glProgramUniform1dEXT")"\n"
"\t"STUB_ASM_CODE("2077")"\n"

STUB_ASM_ENTRY("glProgramUniform1dv")"\n"
"\t"STUB_ASM_CODE("2078")"\n"

STUB_ASM_ENTRY("glProgramUniform1dvEXT")"\n"
"\t"STUB_ASM_CODE("2079")"\n"

STUB_ASM_ENTRY("glProgramUniform1f")"\n"
"\t"STUB_ASM_CODE("2080")"\n"

STUB_ASM_ENTRY("glProgramUniform1fEXT")"\n"
"\t"STUB_ASM_CODE("2081")"\n"

STUB_ASM_ENTRY("glProgramUniform1fv")"\n"
"\t"STUB_ASM_CODE("2082")"\n"

STUB_ASM_ENTRY("glProgramUniform1fvEXT")"\n"
"\t"STUB_ASM_CODE("2083")"\n"

STUB_ASM_ENTRY("glProgramUniform1i")"\n"
"\t"STUB_ASM_CODE("2084")"\n"

STUB_ASM_ENTRY("glProgramUniform1i64ARB")"\n"
"\t"STUB_ASM_CODE("2085")"\n"

STUB_ASM_ENTRY("glProgramUniform1i64NV")"\n"
"\t"STUB_ASM_CODE("2086")"\n"

STUB_ASM_ENTRY("glProgramUniform1i64vARB")"\n"
"\t"STUB_ASM_CODE("2087")"\n"

STUB_ASM_ENTRY("glProgramUniform1i64vNV")"\n"
"\t"STUB_ASM_CODE("2088")"\n"

STUB_ASM_ENTRY("glProgramUniform1iEXT")"\n"
"\t"STUB_ASM_CODE("2089")"\n"

STUB_ASM_ENTRY("glProgramUniform1iv")"\n"
"\t"STUB_ASM_CODE("2090")"\n"

STUB_ASM_ENTRY("glProgramUniform1ivEXT")"\n"
"\t"STUB_ASM_CODE("2091")"\n"

STUB_ASM_ENTRY("glProgramUniform1ui")"\n"
"\t"STUB_ASM_CODE("2092")"\n"

STUB_ASM_ENTRY("glProgramUniform1ui64ARB")"\n"
"\t"STUB_ASM_CODE("2093")"\n"

STUB_ASM_ENTRY("glProgramUniform1ui64NV")"\n"
"\t"STUB_ASM_CODE("2094")"\n"

STUB_ASM_ENTRY("glProgramUniform1ui64vARB")"\n"
"\t"STUB_ASM_CODE("2095")"\n"

STUB_ASM_ENTRY("glProgramUniform1ui64vNV")"\n"
"\t"STUB_ASM_CODE("2096")"\n"

STUB_ASM_ENTRY("glProgramUniform1uiEXT")"\n"
"\t"STUB_ASM_CODE("2097")"\n"

STUB_ASM_ENTRY("glProgramUniform1uiv")"\n"
"\t"STUB_ASM_CODE("2098")"\n"

STUB_ASM_ENTRY("glProgramUniform1uivEXT")"\n"
"\t"STUB_ASM_CODE("2099")"\n"

STUB_ASM_ENTRY("glProgramUniform2d")"\n"
"\t"STUB_ASM_CODE("2100")"\n"

STUB_ASM_ENTRY("glProgramUniform2dEXT")"\n"
"\t"STUB_ASM_CODE("2101")"\n"

STUB_ASM_ENTRY("glProgramUniform2dv")"\n"
"\t"STUB_ASM_CODE("2102")"\n"

STUB_ASM_ENTRY("glProgramUniform2dvEXT")"\n"
"\t"STUB_ASM_CODE("2103")"\n"

STUB_ASM_ENTRY("glProgramUniform2f")"\n"
"\t"STUB_ASM_CODE("2104")"\n"

STUB_ASM_ENTRY("glProgramUniform2fEXT")"\n"
"\t"STUB_ASM_CODE("2105")"\n"

STUB_ASM_ENTRY("glProgramUniform2fv")"\n"
"\t"STUB_ASM_CODE("2106")"\n"

STUB_ASM_ENTRY("glProgramUniform2fvEXT")"\n"
"\t"STUB_ASM_CODE("2107")"\n"

STUB_ASM_ENTRY("glProgramUniform2i")"\n"
"\t"STUB_ASM_CODE("2108")"\n"

STUB_ASM_ENTRY("glProgramUniform2i64ARB")"\n"
"\t"STUB_ASM_CODE("2109")"\n"

STUB_ASM_ENTRY("glProgramUniform2i64NV")"\n"
"\t"STUB_ASM_CODE("2110")"\n"

STUB_ASM_ENTRY("glProgramUniform2i64vARB")"\n"
"\t"STUB_ASM_CODE("2111")"\n"

STUB_ASM_ENTRY("glProgramUniform2i64vNV")"\n"
"\t"STUB_ASM_CODE("2112")"\n"

STUB_ASM_ENTRY("glProgramUniform2iEXT")"\n"
"\t"STUB_ASM_CODE("2113")"\n"

STUB_ASM_ENTRY("glProgramUniform2iv")"\n"
"\t"STUB_ASM_CODE("2114")"\n"

STUB_ASM_ENTRY("glProgramUniform2ivEXT")"\n"
"\t"STUB_ASM_CODE("2115")"\n"

STUB_ASM_ENTRY("glProgramUniform2ui")"\n"
"\t"STUB_ASM_CODE("2116")"\n"

STUB_ASM_ENTRY("glProgramUniform2ui64ARB")"\n"
"\t"STUB_ASM_CODE("2117")"\n"

STUB_ASM_ENTRY("glProgramUniform2ui64NV")"\n"
"\t"STUB_ASM_CODE("2118")"\n"

STUB_ASM_ENTRY("glProgramUniform2ui64vARB")"\n"
"\t"STUB_ASM_CODE("2119")"\n"

STUB_ASM_ENTRY("glProgramUniform2ui64vNV")"\n"
"\t"STUB_ASM_CODE("2120")"\n"

STUB_ASM_ENTRY("glProgramUniform2uiEXT")"\n"
"\t"STUB_ASM_CODE("2121")"\n"

STUB_ASM_ENTRY("glProgramUniform2uiv")"\n"
"\t"STUB_ASM_CODE("2122")"\n"

STUB_ASM_ENTRY("glProgramUniform2uivEXT")"\n"
"\t"STUB_ASM_CODE("2123")"\n"

STUB_ASM_ENTRY("glProgramUniform3d")"\n"
"\t"STUB_ASM_CODE("2124")"\n"

STUB_ASM_ENTRY("glProgramUniform3dEXT")"\n"
"\t"STUB_ASM_CODE("2125")"\n"

STUB_ASM_ENTRY("glProgramUniform3dv")"\n"
"\t"STUB_ASM_CODE("2126")"\n"

STUB_ASM_ENTRY("glProgramUniform3dvEXT")"\n"
"\t"STUB_ASM_CODE("2127")"\n"

STUB_ASM_ENTRY("glProgramUniform3f")"\n"
"\t"STUB_ASM_CODE("2128")"\n"

STUB_ASM_ENTRY("glProgramUniform3fEXT")"\n"
"\t"STUB_ASM_CODE("2129")"\n"

STUB_ASM_ENTRY("glProgramUniform3fv")"\n"
"\t"STUB_ASM_CODE("2130")"\n"

STUB_ASM_ENTRY("glProgramUniform3fvEXT")"\n"
"\t"STUB_ASM_CODE("2131")"\n"

STUB_ASM_ENTRY("glProgramUniform3i")"\n"
"\t"STUB_ASM_CODE("2132")"\n"

STUB_ASM_ENTRY("glProgramUniform3i64ARB")"\n"
"\t"STUB_ASM_CODE("2133")"\n"

STUB_ASM_ENTRY("glProgramUniform3i64NV")"\n"
"\t"STUB_ASM_CODE("2134")"\n"

STUB_ASM_ENTRY("glProgramUniform3i64vARB")"\n"
"\t"STUB_ASM_CODE("2135")"\n"

STUB_ASM_ENTRY("glProgramUniform3i64vNV")"\n"
"\t"STUB_ASM_CODE("2136")"\n"

STUB_ASM_ENTRY("glProgramUniform3iEXT")"\n"
"\t"STUB_ASM_CODE("2137")"\n"

STUB_ASM_ENTRY("glProgramUniform3iv")"\n"
"\t"STUB_ASM_CODE("2138")"\n"

STUB_ASM_ENTRY("glProgramUniform3ivEXT")"\n"
"\t"STUB_ASM_CODE("2139")"\n"

STUB_ASM_ENTRY("glProgramUniform3ui")"\n"
"\t"STUB_ASM_CODE("2140")"\n"

STUB_ASM_ENTRY("glProgramUniform3ui64ARB")"\n"
"\t"STUB_ASM_CODE("2141")"\n"

STUB_ASM_ENTRY("glProgramUniform3ui64NV")"\n"
"\t"STUB_ASM_CODE("2142")"\n"

STUB_ASM_ENTRY("glProgramUniform3ui64vARB")"\n"
"\t"STUB_ASM_CODE("2143")"\n"

STUB_ASM_ENTRY("glProgramUniform3ui64vNV")"\n"
"\t"STUB_ASM_CODE("2144")"\n"

STUB_ASM_ENTRY("glProgramUniform3uiEXT")"\n"
"\t"STUB_ASM_CODE("2145")"\n"

STUB_ASM_ENTRY("glProgramUniform3uiv")"\n"
"\t"STUB_ASM_CODE("2146")"\n"

STUB_ASM_ENTRY("glProgramUniform3uivEXT")"\n"
"\t"STUB_ASM_CODE("2147")"\n"

STUB_ASM_ENTRY("glProgramUniform4d")"\n"
"\t"STUB_ASM_CODE("2148")"\n"

STUB_ASM_ENTRY("glProgramUniform4dEXT")"\n"
"\t"STUB_ASM_CODE("2149")"\n"

STUB_ASM_ENTRY("glProgramUniform4dv")"\n"
"\t"STUB_ASM_CODE("2150")"\n"

STUB_ASM_ENTRY("glProgramUniform4dvEXT")"\n"
"\t"STUB_ASM_CODE("2151")"\n"

STUB_ASM_ENTRY("glProgramUniform4f")"\n"
"\t"STUB_ASM_CODE("2152")"\n"

STUB_ASM_ENTRY("glProgramUniform4fEXT")"\n"
"\t"STUB_ASM_CODE("2153")"\n"

STUB_ASM_ENTRY("glProgramUniform4fv")"\n"
"\t"STUB_ASM_CODE("2154")"\n"

STUB_ASM_ENTRY("glProgramUniform4fvEXT")"\n"
"\t"STUB_ASM_CODE("2155")"\n"

STUB_ASM_ENTRY("glProgramUniform4i")"\n"
"\t"STUB_ASM_CODE("2156")"\n"

STUB_ASM_ENTRY("glProgramUniform4i64ARB")"\n"
"\t"STUB_ASM_CODE("2157")"\n"

STUB_ASM_ENTRY("glProgramUniform4i64NV")"\n"
"\t"STUB_ASM_CODE("2158")"\n"

STUB_ASM_ENTRY("glProgramUniform4i64vARB")"\n"
"\t"STUB_ASM_CODE("2159")"\n"

STUB_ASM_ENTRY("glProgramUniform4i64vNV")"\n"
"\t"STUB_ASM_CODE("2160")"\n"

STUB_ASM_ENTRY("glProgramUniform4iEXT")"\n"
"\t"STUB_ASM_CODE("2161")"\n"

STUB_ASM_ENTRY("glProgramUniform4iv")"\n"
"\t"STUB_ASM_CODE("2162")"\n"

STUB_ASM_ENTRY("glProgramUniform4ivEXT")"\n"
"\t"STUB_ASM_CODE("2163")"\n"

STUB_ASM_ENTRY("glProgramUniform4ui")"\n"
"\t"STUB_ASM_CODE("2164")"\n"

STUB_ASM_ENTRY("glProgramUniform4ui64ARB")"\n"
"\t"STUB_ASM_CODE("2165")"\n"

STUB_ASM_ENTRY("glProgramUniform4ui64NV")"\n"
"\t"STUB_ASM_CODE("2166")"\n"

STUB_ASM_ENTRY("glProgramUniform4ui64vARB")"\n"
"\t"STUB_ASM_CODE("2167")"\n"

STUB_ASM_ENTRY("glProgramUniform4ui64vNV")"\n"
"\t"STUB_ASM_CODE("2168")"\n"

STUB_ASM_ENTRY("glProgramUniform4uiEXT")"\n"
"\t"STUB_ASM_CODE("2169")"\n"

STUB_ASM_ENTRY("glProgramUniform4uiv")"\n"
"\t"STUB_ASM_CODE("2170")"\n"

STUB_ASM_ENTRY("glProgramUniform4uivEXT")"\n"
"\t"STUB_ASM_CODE("2171")"\n"

STUB_ASM_ENTRY("glProgramUniformHandleui64ARB")"\n"
"\t"STUB_ASM_CODE("2172")"\n"

STUB_ASM_ENTRY("glProgramUniformHandleui64IMG")"\n"
"\t"STUB_ASM_CODE("2173")"\n"

STUB_ASM_ENTRY("glProgramUniformHandleui64NV")"\n"
"\t"STUB_ASM_CODE("2174")"\n"

STUB_ASM_ENTRY("glProgramUniformHandleui64vARB")"\n"
"\t"STUB_ASM_CODE("2175")"\n"

STUB_ASM_ENTRY("glProgramUniformHandleui64vIMG")"\n"
"\t"STUB_ASM_CODE("2176")"\n"

STUB_ASM_ENTRY("glProgramUniformHandleui64vNV")"\n"
"\t"STUB_ASM_CODE("2177")"\n"

STUB_ASM_ENTRY("glProgramUniformMatrix2dv")"\n"
"\t"STUB_ASM_CODE("2178")"\n"

STUB_ASM_ENTRY("glProgramUniformMatrix2dvEXT")"\n"
"\t"STUB_ASM_CODE("2179")"\n"

STUB_ASM_ENTRY("glProgramUniformMatrix2fv")"\n"
"\t"STUB_ASM_CODE("2180")"\n"

STUB_ASM_ENTRY("glProgramUniformMatrix2fvEXT")"\n"
"\t"STUB_ASM_CODE("2181")"\n"

STUB_ASM_ENTRY("glProgramUniformMatrix2x3dv")"\n"
"\t"STUB_ASM_CODE("2182")"\n"

STUB_ASM_ENTRY("glProgramUniformMatrix2x3dvEXT")"\n"
"\t"STUB_ASM_CODE("2183")"\n"

STUB_ASM_ENTRY("glProgramUniformMatrix2x3fv")"\n"
"\t"STUB_ASM_CODE("2184")"\n"

STUB_ASM_ENTRY("glProgramUniformMatrix2x3fvEXT")"\n"
"\t"STUB_ASM_CODE("2185")"\n"

STUB_ASM_ENTRY("glProgramUniformMatrix2x4dv")"\n"
"\t"STUB_ASM_CODE("2186")"\n"

STUB_ASM_ENTRY("glProgramUniformMatrix2x4dvEXT")"\n"
"\t"STUB_ASM_CODE("2187")"\n"

STUB_ASM_ENTRY("glProgramUniformMatrix2x4fv")"\n"
"\t"STUB_ASM_CODE("2188")"\n"

STUB_ASM_ENTRY("glProgramUniformMatrix2x4fvEXT")"\n"
"\t"STUB_ASM_CODE("2189")"\n"

STUB_ASM_ENTRY("glProgramUniformMatrix3dv")"\n"
"\t"STUB_ASM_CODE("2190")"\n"

STUB_ASM_ENTRY("glProgramUniformMatrix3dvEXT")"\n"
"\t"STUB_ASM_CODE("2191")"\n"

STUB_ASM_ENTRY("glProgramUniformMatrix3fv")"\n"
"\t"STUB_ASM_CODE("2192")"\n"

STUB_ASM_ENTRY("glProgramUniformMatrix3fvEXT")"\n"
"\t"STUB_ASM_CODE("2193")"\n"

STUB_ASM_ENTRY("glProgramUniformMatrix3x2dv")"\n"
"\t"STUB_ASM_CODE("2194")"\n"

STUB_ASM_ENTRY("glProgramUniformMatrix3x2dvEXT")"\n"
"\t"STUB_ASM_CODE("2195")"\n"

STUB_ASM_ENTRY("glProgramUniformMatrix3x2fv")"\n"
"\t"STUB_ASM_CODE("2196")"\n"

STUB_ASM_ENTRY("glProgramUniformMatrix3x2fvEXT")"\n"
"\t"STUB_ASM_CODE("2197")"\n"

STUB_ASM_ENTRY("glProgramUniformMatrix3x4dv")"\n"
"\t"STUB_ASM_CODE("2198")"\n"

STUB_ASM_ENTRY("glProgramUniformMatrix3x4dvEXT")"\n"
"\t"STUB_ASM_CODE("2199")"\n"

STUB_ASM_ENTRY("glProgramUniformMatrix3x4fv")"\n"
"\t"STUB_ASM_CODE("2200")"\n"

STUB_ASM_ENTRY("glProgramUniformMatrix3x4fvEXT")"\n"
"\t"STUB_ASM_CODE("2201")"\n"

STUB_ASM_ENTRY("glProgramUniformMatrix4dv")"\n"
"\t"STUB_ASM_CODE("2202")"\n"

STUB_ASM_ENTRY("glProgramUniformMatrix4dvEXT")"\n"
"\t"STUB_ASM_CODE("2203")"\n"

STUB_ASM_ENTRY("glProgramUniformMatrix4fv")"\n"
"\t"STUB_ASM_CODE("2204")"\n"

STUB_ASM_ENTRY("glProgramUniformMatrix4fvEXT")"\n"
"\t"STUB_ASM_CODE("2205")"\n"

STUB_ASM_ENTRY("glProgramUniformMatrix4x2dv")"\n"
"\t"STUB_ASM_CODE("2206")"\n"

STUB_ASM_ENTRY("glProgramUniformMatrix4x2dvEXT")"\n"
"\t"STUB_ASM_CODE("2207")"\n"

STUB_ASM_ENTRY("glProgramUniformMatrix4x2fv")"\n"
"\t"STUB_ASM_CODE("2208")"\n"

STUB_ASM_ENTRY("glProgramUniformMatrix4x2fvEXT")"\n"
"\t"STUB_ASM_CODE("2209")"\n"

STUB_ASM_ENTRY("glProgramUniformMatrix4x3dv")"\n"
"\t"STUB_ASM_CODE("2210")"\n"

STUB_ASM_ENTRY("glProgramUniformMatrix4x3dvEXT")"\n"
"\t"STUB_ASM_CODE("2211")"\n"

STUB_ASM_ENTRY("glProgramUniformMatrix4x3fv")"\n"
"\t"STUB_ASM_CODE("2212")"\n"

STUB_ASM_ENTRY("glProgramUniformMatrix4x3fvEXT")"\n"
"\t"STUB_ASM_CODE("2213")"\n"

STUB_ASM_ENTRY("glProgramUniformui64NV")"\n"
"\t"STUB_ASM_CODE("2214")"\n"

STUB_ASM_ENTRY("glProgramUniformui64vNV")"\n"
"\t"STUB_ASM_CODE("2215")"\n"

STUB_ASM_ENTRY("glProgramVertexLimitNV")"\n"
"\t"STUB_ASM_CODE("2216")"\n"

STUB_ASM_ENTRY("glProvokingVertex")"\n"
"\t"STUB_ASM_CODE("2217")"\n"

STUB_ASM_ENTRY("glProvokingVertexEXT")"\n"
"\t"STUB_ASM_CODE("2218")"\n"

STUB_ASM_ENTRY("glPushAttrib")"\n"
"\t"STUB_ASM_CODE("2219")"\n"

STUB_ASM_ENTRY("glPushClientAttrib")"\n"
"\t"STUB_ASM_CODE("2220")"\n"

STUB_ASM_ENTRY("glPushClientAttribDefaultEXT")"\n"
"\t"STUB_ASM_CODE("2221")"\n"

STUB_ASM_ENTRY("glPushDebugGroup")"\n"
"\t"STUB_ASM_CODE("2222")"\n"

STUB_ASM_ENTRY("glPushDebugGroupKHR")"\n"
"\t"STUB_ASM_CODE("2223")"\n"

STUB_ASM_ENTRY("glPushDebugGroupOES")"\n"
"\t"STUB_ASM_CODE("2224")"\n"

STUB_ASM_ENTRY("glPushGroupMarkerEXT")"\n"
"\t"STUB_ASM_CODE("2225")"\n"

STUB_ASM_ENTRY("glPushMatrix")"\n"
"\t"STUB_ASM_CODE("2226")"\n"

STUB_ASM_ENTRY("glPushName")"\n"
"\t"STUB_ASM_CODE("2227")"\n"

STUB_ASM_ENTRY("glQueryCounter")"\n"
"\t"STUB_ASM_CODE("2228")"\n"

STUB_ASM_ENTRY("glQueryCounterEXT")"\n"
"\t"STUB_ASM_CODE("2229")"\n"

STUB_ASM_ENTRY("glQueryCounterNV")"\n"
"\t"STUB_ASM_CODE("2230")"\n"

STUB_ASM_ENTRY("glQueryMatrixxOES")"\n"
"\t"STUB_ASM_CODE("2231")"\n"

STUB_ASM_ENTRY("glQueryObjectParameteruiAMD")"\n"
"\t"STUB_ASM_CODE("2232")"\n"

STUB_ASM_ENTRY("glQueryResourceNV")"\n"
"\t"STUB_ASM_CODE("2233")"\n"

STUB_ASM_ENTRY("glQueryResourceTagNV")"\n"
"\t"STUB_ASM_CODE("2234")"\n"

STUB_ASM_ENTRY("glRasterPos2d")"\n"
"\t"STUB_ASM_CODE("2235")"\n"

STUB_ASM_ENTRY("glRasterPos2dv")"\n"
"\t"STUB_ASM_CODE("2236")"\n"

STUB_ASM_ENTRY("glRasterPos2f")"\n"
"\t"STUB_ASM_CODE("2237")"\n"

STUB_ASM_ENTRY("glRasterPos2fv")"\n"
"\t"STUB_ASM_CODE("2238")"\n"

STUB_ASM_ENTRY("glRasterPos2i")"\n"
"\t"STUB_ASM_CODE("2239")"\n"

STUB_ASM_ENTRY("glRasterPos2iv")"\n"
"\t"STUB_ASM_CODE("2240")"\n"

STUB_ASM_ENTRY("glRasterPos2s")"\n"
"\t"STUB_ASM_CODE("2241")"\n"

STUB_ASM_ENTRY("glRasterPos2sv")"\n"
"\t"STUB_ASM_CODE("2242")"\n"

STUB_ASM_ENTRY("glRasterPos2xOES")"\n"
"\t"STUB_ASM_CODE("2243")"\n"

STUB_ASM_ENTRY("glRasterPos2xvOES")"\n"
"\t"STUB_ASM_CODE("2244")"\n"

STUB_ASM_ENTRY("glRasterPos3d")"\n"
"\t"STUB_ASM_CODE("2245")"\n"

STUB_ASM_ENTRY("glRasterPos3dv")"\n"
"\t"STUB_ASM_CODE("2246")"\n"

STUB_ASM_ENTRY("glRasterPos3f")"\n"
"\t"STUB_ASM_CODE("2247")"\n"

STUB_ASM_ENTRY("glRasterPos3fv")"\n"
"\t"STUB_ASM_CODE("2248")"\n"

STUB_ASM_ENTRY("glRasterPos3i")"\n"
"\t"STUB_ASM_CODE("2249")"\n"

STUB_ASM_ENTRY("glRasterPos3iv")"\n"
"\t"STUB_ASM_CODE("2250")"\n"

STUB_ASM_ENTRY("glRasterPos3s")"\n"
"\t"STUB_ASM_CODE("2251")"\n"

STUB_ASM_ENTRY("glRasterPos3sv")"\n"
"\t"STUB_ASM_CODE("2252")"\n"

STUB_ASM_ENTRY("glRasterPos3xOES")"\n"
"\t"STUB_ASM_CODE("2253")"\n"

STUB_ASM_ENTRY("glRasterPos3xvOES")"\n"
"\t"STUB_ASM_CODE("2254")"\n"

STUB_ASM_ENTRY("glRasterPos4d")"\n"
"\t"STUB_ASM_CODE("2255")"\n"

STUB_ASM_ENTRY("glRasterPos4dv")"\n"
"\t"STUB_ASM_CODE("2256")"\n"

STUB_ASM_ENTRY("glRasterPos4f")"\n"
"\t"STUB_ASM_CODE("2257")"\n"

STUB_ASM_ENTRY("glRasterPos4fv")"\n"
"\t"STUB_ASM_CODE("2258")"\n"

STUB_ASM_ENTRY("glRasterPos4i")"\n"
"\t"STUB_ASM_CODE("2259")"\n"

STUB_ASM_ENTRY("glRasterPos4iv")"\n"
"\t"STUB_ASM_CODE("2260")"\n"

STUB_ASM_ENTRY("glRasterPos4s")"\n"
"\t"STUB_ASM_CODE("2261")"\n"

STUB_ASM_ENTRY("glRasterPos4sv")"\n"
"\t"STUB_ASM_CODE("2262")"\n"

STUB_ASM_ENTRY("glRasterPos4xOES")"\n"
"\t"STUB_ASM_CODE("2263")"\n"

STUB_ASM_ENTRY("glRasterPos4xvOES")"\n"
"\t"STUB_ASM_CODE("2264")"\n"

STUB_ASM_ENTRY("glRasterSamplesEXT")"\n"
"\t"STUB_ASM_CODE("2265")"\n"

STUB_ASM_ENTRY("glReadBuffer")"\n"
"\t"STUB_ASM_CODE("2266")"\n"

STUB_ASM_ENTRY("glReadBufferIndexedEXT")"\n"
"\t"STUB_ASM_CODE("2267")"\n"

STUB_ASM_ENTRY("glReadBufferNV")"\n"
"\t"STUB_ASM_CODE("2268")"\n"

STUB_ASM_ENTRY("glReadInstrumentsSGIX")"\n"
"\t"STUB_ASM_CODE("2269")"\n"

STUB_ASM_ENTRY("glReadPixels")"\n"
"\t"STUB_ASM_CODE("2270")"\n"

STUB_ASM_ENTRY("glReadnPixels")"\n"
"\t"STUB_ASM_CODE("2271")"\n"

STUB_ASM_ENTRY("glReadnPixelsARB")"\n"
"\t"STUB_ASM_CODE("2272")"\n"

STUB_ASM_ENTRY("glReadnPixelsEXT")"\n"
"\t"STUB_ASM_CODE("2273")"\n"

STUB_ASM_ENTRY("glReadnPixelsKHR")"\n"
"\t"STUB_ASM_CODE("2274")"\n"

STUB_ASM_ENTRY("glRectd")"\n"
"\t"STUB_ASM_CODE("2275")"\n"

STUB_ASM_ENTRY("glRectdv")"\n"
"\t"STUB_ASM_CODE("2276")"\n"

STUB_ASM_ENTRY("glRectf")"\n"
"\t"STUB_ASM_CODE("2277")"\n"

STUB_ASM_ENTRY("glRectfv")"\n"
"\t"STUB_ASM_CODE("2278")"\n"

STUB_ASM_ENTRY("glRecti")"\n"
"\t"STUB_ASM_CODE("2279")"\n"

STUB_ASM_ENTRY("glRectiv")"\n"
"\t"STUB_ASM_CODE("2280")"\n"

STUB_ASM_ENTRY("glRects")"\n"
"\t"STUB_ASM_CODE("2281")"\n"

STUB_ASM_ENTRY("glRectsv")"\n"
"\t"STUB_ASM_CODE("2282")"\n"

STUB_ASM_ENTRY("glRectxOES")"\n"
"\t"STUB_ASM_CODE("2283")"\n"

STUB_ASM_ENTRY("glRectxvOES")"\n"
"\t"STUB_ASM_CODE("2284")"\n"

STUB_ASM_ENTRY("glReferencePlaneSGIX")"\n"
"\t"STUB_ASM_CODE("2285")"\n"

STUB_ASM_ENTRY("glReleaseKeyedMutexWin32EXT")"\n"
"\t"STUB_ASM_CODE("2286")"\n"

STUB_ASM_ENTRY("glReleaseShaderCompiler")"\n"
"\t"STUB_ASM_CODE("2287")"\n"

STUB_ASM_ENTRY("glRenderGpuMaskNV")"\n"
"\t"STUB_ASM_CODE("2288")"\n"

STUB_ASM_ENTRY("glRenderMode")"\n"
"\t"STUB_ASM_CODE("2289")"\n"

STUB_ASM_ENTRY("glRenderbufferStorage")"\n"
"\t"STUB_ASM_CODE("2290")"\n"

STUB_ASM_ENTRY("glRenderbufferStorageEXT")"\n"
"\t"STUB_ASM_CODE("2291")"\n"

STUB_ASM_ENTRY("glRenderbufferStorageMultisample")"\n"
"\t"STUB_ASM_CODE("2292")"\n"

STUB_ASM_ENTRY("glRenderbufferStorageMultisampleANGLE")"\n"
"\t"STUB_ASM_CODE("2293")"\n"

STUB_ASM_ENTRY("glRenderbufferStorageMultisampleAPPLE")"\n"
"\t"STUB_ASM_CODE("2294")"\n"

STUB_ASM_ENTRY("glRenderbufferStorageMultisampleAdvancedAMD")"\n"
"\t"STUB_ASM_CODE("2295")"\n"

STUB_ASM_ENTRY("glRenderbufferStorageMultisampleCoverageNV")"\n"
"\t"STUB_ASM_CODE("2296")"\n"

STUB_ASM_ENTRY("glRenderbufferStorageMultisampleEXT")"\n"
"\t"STUB_ASM_CODE("2297")"\n"

STUB_ASM_ENTRY("glRenderbufferStorageMultisampleIMG")"\n"
"\t"STUB_ASM_CODE("2298")"\n"

STUB_ASM_ENTRY("glRenderbufferStorageMultisampleNV")"\n"
"\t"STUB_ASM_CODE("2299")"\n"

STUB_ASM_ENTRY("glRenderbufferStorageOES")"\n"
"\t"STUB_ASM_CODE("2300")"\n"

STUB_ASM_ENTRY("glReplacementCodePointerSUN")"\n"
"\t"STUB_ASM_CODE("2301")"\n"

STUB_ASM_ENTRY("glReplacementCodeubSUN")"\n"
"\t"STUB_ASM_CODE("2302")"\n"

STUB_ASM_ENTRY("glReplacementCodeubvSUN")"\n"
"\t"STUB_ASM_CODE("2303")"\n"

STUB_ASM_ENTRY("glReplacementCodeuiColor3fVertex3fSUN")"\n"
"\t"STUB_ASM_CODE("2304")"\n"

STUB_ASM_ENTRY("glReplacementCodeuiColor3fVertex3fvSUN")"\n"
"\t"STUB_ASM_CODE("2305")"\n"

STUB_ASM_ENTRY("glReplacementCodeuiColor4fNormal3fVertex3fSUN")"\n"
"\t"STUB_ASM_CODE("2306")"\n"

STUB_ASM_ENTRY("glReplacementCodeuiColor4fNormal3fVertex3fvSUN")"\n"
"\t"STUB_ASM_CODE("2307")"\n"

STUB_ASM_ENTRY("glReplacementCodeuiColor4ubVertex3fSUN")"\n"
"\t"STUB_ASM_CODE("2308")"\n"

STUB_ASM_ENTRY("glReplacementCodeuiColor4ubVertex3fvSUN")"\n"
"\t"STUB_ASM_CODE("2309")"\n"

STUB_ASM_ENTRY("glReplacementCodeuiNormal3fVertex3fSUN")"\n"
"\t"STUB_ASM_CODE("2310")"\n"

STUB_ASM_ENTRY("glReplacementCodeuiNormal3fVertex3fvSUN")"\n"
"\t"STUB_ASM_CODE("2311")"\n"

STUB_ASM_ENTRY("glReplacementCodeuiSUN")"\n"
"\t"STUB_ASM_CODE("2312")"\n"

STUB_ASM_ENTRY("glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fSUN")"\n"
"\t"STUB_ASM_CODE("2313")"\n"

STUB_ASM_ENTRY("glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fvSUN")"\n"
"\t"STUB_ASM_CODE("2314")"\n"

STUB_ASM_ENTRY("glReplacementCodeuiTexCoord2fNormal3fVertex3fSUN")"\n"
"\t"STUB_ASM_CODE("2315")"\n"

STUB_ASM_ENTRY("glReplacementCodeuiTexCoord2fNormal3fVertex3fvSUN")"\n"
"\t"STUB_ASM_CODE("2316")"\n"

STUB_ASM_ENTRY("glReplacementCodeuiTexCoord2fVertex3fSUN")"\n"
"\t"STUB_ASM_CODE("2317")"\n"

STUB_ASM_ENTRY("glReplacementCodeuiTexCoord2fVertex3fvSUN")"\n"
"\t"STUB_ASM_CODE("2318")"\n"

STUB_ASM_ENTRY("glReplacementCodeuiVertex3fSUN")"\n"
"\t"STUB_ASM_CODE("2319")"\n"

STUB_ASM_ENTRY("glReplacementCodeuiVertex3fvSUN")"\n"
"\t"STUB_ASM_CODE("2320")"\n"

STUB_ASM_ENTRY("glReplacementCodeuivSUN")"\n"
"\t"STUB_ASM_CODE("2321")"\n"

STUB_ASM_ENTRY("glReplacementCodeusSUN")"\n"
"\t"STUB_ASM_CODE("2322")"\n"

STUB_ASM_ENTRY("glReplacementCodeusvSUN")"\n"
"\t"STUB_ASM_CODE("2323")"\n"

STUB_ASM_ENTRY("glRequestResidentProgramsNV")"\n"
"\t"STUB_ASM_CODE("2324")"\n"

STUB_ASM_ENTRY("glResetHistogram")"\n"
"\t"STUB_ASM_CODE("2325")"\n"

STUB_ASM_ENTRY("glResetHistogramEXT")"\n"
"\t"STUB_ASM_CODE("2326")"\n"

STUB_ASM_ENTRY("glResetMemoryObjectParameterNV")"\n"
"\t"STUB_ASM_CODE("2327")"\n"

STUB_ASM_ENTRY("glResetMinmax")"\n"
"\t"STUB_ASM_CODE("2328")"\n"

STUB_ASM_ENTRY("glResetMinmaxEXT")"\n"
"\t"STUB_ASM_CODE("2329")"\n"

STUB_ASM_ENTRY("glResizeBuffersMESA")"\n"
"\t"STUB_ASM_CODE("2330")"\n"

STUB_ASM_ENTRY("glResolveDepthValuesNV")"\n"
"\t"STUB_ASM_CODE("2331")"\n"

STUB_ASM_ENTRY("glResolveMultisampleFramebufferAPPLE")"\n"
"\t"STUB_ASM_CODE("2332")"\n"

STUB_ASM_ENTRY("glResumeTransformFeedback")"\n"
"\t"STUB_ASM_CODE("2333")"\n"

STUB_ASM_ENTRY("glResumeTransformFeedbackEXT")"\n"
"\t"STUB_ASM_CODE("2334")"\n"

STUB_ASM_ENTRY("glResumeTransformFeedbackNV")"\n"
"\t"STUB_ASM_CODE("2335")"\n"

STUB_ASM_ENTRY("glRotated")"\n"
"\t"STUB_ASM_CODE("2336")"\n"

STUB_ASM_ENTRY("glRotatef")"\n"
"\t"STUB_ASM_CODE("2337")"\n"

STUB_ASM_ENTRY("glRotatex")"\n"
"\t"STUB_ASM_CODE("2338")"\n"

STUB_ASM_ENTRY("glRotatexOES")"\n"
"\t"STUB_ASM_CODE("2339")"\n"

STUB_ASM_ENTRY("glSampleCoverage")"\n"
"\t"STUB_ASM_CODE("2340")"\n"

STUB_ASM_ENTRY("glSampleCoverageARB")"\n"
"\t"STUB_ASM_CODE("2341")"\n"

STUB_ASM_ENTRY("glSampleCoveragex")"\n"
"\t"STUB_ASM_CODE("2342")"\n"

STUB_ASM_ENTRY("glSampleCoveragexOES")"\n"
"\t"STUB_ASM_CODE("2343")"\n"

STUB_ASM_ENTRY("glSampleMapATI")"\n"
"\t"STUB_ASM_CODE("2344")"\n"

STUB_ASM_ENTRY("glSampleMaskEXT")"\n"
"\t"STUB_ASM_CODE("2345")"\n"

STUB_ASM_ENTRY("glSampleMaskIndexedNV")"\n"
"\t"STUB_ASM_CODE("2346")"\n"

STUB_ASM_ENTRY("glSampleMaskSGIS")"\n"
"\t"STUB_ASM_CODE("2347")"\n"

STUB_ASM_ENTRY("glSampleMaski")"\n"
"\t"STUB_ASM_CODE("2348")"\n"

STUB_ASM_ENTRY("glSamplePatternEXT")"\n"
"\t"STUB_ASM_CODE("2349")"\n"

STUB_ASM_ENTRY("glSamplePatternSGIS")"\n"
"\t"STUB_ASM_CODE("2350")"\n"

STUB_ASM_ENTRY("glSamplerParameterIiv")"\n"
"\t"STUB_ASM_CODE("2351")"\n"

STUB_ASM_ENTRY("glSamplerParameterIivEXT")"\n"
"\t"STUB_ASM_CODE("2352")"\n"

STUB_ASM_ENTRY("glSamplerParameterIivOES")"\n"
"\t"STUB_ASM_CODE("2353")"\n"

STUB_ASM_ENTRY("glSamplerParameterIuiv")"\n"
"\t"STUB_ASM_CODE("2354")"\n"

STUB_ASM_ENTRY("glSamplerParameterIuivEXT")"\n"
"\t"STUB_ASM_CODE("2355")"\n"

STUB_ASM_ENTRY("glSamplerParameterIuivOES")"\n"
"\t"STUB_ASM_CODE("2356")"\n"

STUB_ASM_ENTRY("glSamplerParameterf")"\n"
"\t"STUB_ASM_CODE("2357")"\n"

STUB_ASM_ENTRY("glSamplerParameterfv")"\n"
"\t"STUB_ASM_CODE("2358")"\n"

STUB_ASM_ENTRY("glSamplerParameteri")"\n"
"\t"STUB_ASM_CODE("2359")"\n"

STUB_ASM_ENTRY("glSamplerParameteriv")"\n"
"\t"STUB_ASM_CODE("2360")"\n"

STUB_ASM_ENTRY("glScaled")"\n"
"\t"STUB_ASM_CODE("2361")"\n"

STUB_ASM_ENTRY("glScalef")"\n"
"\t"STUB_ASM_CODE("2362")"\n"

STUB_ASM_ENTRY("glScalex")"\n"
"\t"STUB_ASM_CODE("2363")"\n"

STUB_ASM_ENTRY("glScalexOES")"\n"
"\t"STUB_ASM_CODE("2364")"\n"

STUB_ASM_ENTRY("glScissor")"\n"
"\t"STUB_ASM_CODE("2365")"\n"

STUB_ASM_ENTRY("glScissorArrayv")"\n"
"\t"STUB_ASM_CODE("2366")"\n"

STUB_ASM_ENTRY("glScissorArrayvNV")"\n"
"\t"STUB_ASM_CODE("2367")"\n"

STUB_ASM_ENTRY("glScissorArrayvOES")"\n"
"\t"STUB_ASM_CODE("2368")"\n"

STUB_ASM_ENTRY("glScissorExclusiveArrayvNV")"\n"
"\t"STUB_ASM_CODE("2369")"\n"

STUB_ASM_ENTRY("glScissorExclusiveNV")"\n"
"\t"STUB_ASM_CODE("2370")"\n"

STUB_ASM_ENTRY("glScissorIndexed")"\n"
"\t"STUB_ASM_CODE("2371")"\n"

STUB_ASM_ENTRY("glScissorIndexedNV")"\n"
"\t"STUB_ASM_CODE("2372")"\n"

STUB_ASM_ENTRY("glScissorIndexedOES")"\n"
"\t"STUB_ASM_CODE("2373")"\n"

STUB_ASM_ENTRY("glScissorIndexedv")"\n"
"\t"STUB_ASM_CODE("2374")"\n"

STUB_ASM_ENTRY("glScissorIndexedvNV")"\n"
"\t"STUB_ASM_CODE("2375")"\n"

STUB_ASM_ENTRY("glScissorIndexedvOES")"\n"
"\t"STUB_ASM_CODE("2376")"\n"

STUB_ASM_ENTRY("glSecondaryColor3b")"\n"
"\t"STUB_ASM_CODE("2377")"\n"

STUB_ASM_ENTRY("glSecondaryColor3bEXT")"\n"
"\t"STUB_ASM_CODE("2378")"\n"

STUB_ASM_ENTRY("glSecondaryColor3bv")"\n"
"\t"STUB_ASM_CODE("2379")"\n"

STUB_ASM_ENTRY("glSecondaryColor3bvEXT")"\n"
"\t"STUB_ASM_CODE("2380")"\n"

STUB_ASM_ENTRY("glSecondaryColor3d")"\n"
"\t"STUB_ASM_CODE("2381")"\n"

STUB_ASM_ENTRY("glSecondaryColor3dEXT")"\n"
"\t"STUB_ASM_CODE("2382")"\n"

STUB_ASM_ENTRY("glSecondaryColor3dv")"\n"
"\t"STUB_ASM_CODE("2383")"\n"

STUB_ASM_ENTRY("glSecondaryColor3dvEXT")"\n"
"\t"STUB_ASM_CODE("2384")"\n"

STUB_ASM_ENTRY("glSecondaryColor3f")"\n"
"\t"STUB_ASM_CODE("2385")"\n"

STUB_ASM_ENTRY("glSecondaryColor3fEXT")"\n"
"\t"STUB_ASM_CODE("2386")"\n"

STUB_ASM_ENTRY("glSecondaryColor3fv")"\n"
"\t"STUB_ASM_CODE("2387")"\n"

STUB_ASM_ENTRY("glSecondaryColor3fvEXT")"\n"
"\t"STUB_ASM_CODE("2388")"\n"

STUB_ASM_ENTRY("glSecondaryColor3hNV")"\n"
"\t"STUB_ASM_CODE("2389")"\n"

STUB_ASM_ENTRY("glSecondaryColor3hvNV")"\n"
"\t"STUB_ASM_CODE("2390")"\n"

STUB_ASM_ENTRY("glSecondaryColor3i")"\n"
"\t"STUB_ASM_CODE("2391")"\n"

STUB_ASM_ENTRY("glSecondaryColor3iEXT")"\n"
"\t"STUB_ASM_CODE("2392")"\n"

STUB_ASM_ENTRY("glSecondaryColor3iv")"\n"
"\t"STUB_ASM_CODE("2393")"\n"

STUB_ASM_ENTRY("glSecondaryColor3ivEXT")"\n"
"\t"STUB_ASM_CODE("2394")"\n"

STUB_ASM_ENTRY("glSecondaryColor3s")"\n"
"\t"STUB_ASM_CODE("2395")"\n"

STUB_ASM_ENTRY("glSecondaryColor3sEXT")"\n"
"\t"STUB_ASM_CODE("2396")"\n"

STUB_ASM_ENTRY("glSecondaryColor3sv")"\n"
"\t"STUB_ASM_CODE("2397")"\n"

STUB_ASM_ENTRY("glSecondaryColor3svEXT")"\n"
"\t"STUB_ASM_CODE("2398")"\n"

STUB_ASM_ENTRY("glSecondaryColor3ub")"\n"
"\t"STUB_ASM_CODE("2399")"\n"

STUB_ASM_ENTRY("glSecondaryColor3ubEXT")"\n"
"\t"STUB_ASM_CODE("2400")"\n"

STUB_ASM_ENTRY("glSecondaryColor3ubv")"\n"
"\t"STUB_ASM_CODE("2401")"\n"

STUB_ASM_ENTRY("glSecondaryColor3ubvEXT")"\n"
"\t"STUB_ASM_CODE("2402")"\n"

STUB_ASM_ENTRY("glSecondaryColor3ui")"\n"
"\t"STUB_ASM_CODE("2403")"\n"

STUB_ASM_ENTRY("glSecondaryColor3uiEXT")"\n"
"\t"STUB_ASM_CODE("2404")"\n"

STUB_ASM_ENTRY("glSecondaryColor3uiv")"\n"
"\t"STUB_ASM_CODE("2405")"\n"

STUB_ASM_ENTRY("glSecondaryColor3uivEXT")"\n"
"\t"STUB_ASM_CODE("2406")"\n"

STUB_ASM_ENTRY("glSecondaryColor3us")"\n"
"\t"STUB_ASM_CODE("2407")"\n"

STUB_ASM_ENTRY("glSecondaryColor3usEXT")"\n"
"\t"STUB_ASM_CODE("2408")"\n"

STUB_ASM_ENTRY("glSecondaryColor3usv")"\n"
"\t"STUB_ASM_CODE("2409")"\n"

STUB_ASM_ENTRY("glSecondaryColor3usvEXT")"\n"
"\t"STUB_ASM_CODE("2410")"\n"

STUB_ASM_ENTRY("glSecondaryColorFormatNV")"\n"
"\t"STUB_ASM_CODE("2411")"\n"

STUB_ASM_ENTRY("glSecondaryColorP3ui")"\n"
"\t"STUB_ASM_CODE("2412")"\n"

STUB_ASM_ENTRY("glSecondaryColorP3uiv")"\n"
"\t"STUB_ASM_CODE("2413")"\n"

STUB_ASM_ENTRY("glSecondaryColorPointer")"\n"
"\t"STUB_ASM_CODE("2414")"\n"

STUB_ASM_ENTRY("glSecondaryColorPointerEXT")"\n"
"\t"STUB_ASM_CODE("2415")"\n"

STUB_ASM_ENTRY("glSecondaryColorPointerListIBM")"\n"
"\t"STUB_ASM_CODE("2416")"\n"

STUB_ASM_ENTRY("glSelectBuffer")"\n"
"\t"STUB_ASM_CODE("2417")"\n"

STUB_ASM_ENTRY("glSelectPerfMonitorCountersAMD")"\n"
"\t"STUB_ASM_CODE("2418")"\n"

STUB_ASM_ENTRY("glSemaphoreParameterui64vEXT")"\n"
"\t"STUB_ASM_CODE("2420")"\n"

STUB_ASM_ENTRY("glSeparableFilter2D")"\n"
"\t"STUB_ASM_CODE("2421")"\n"

STUB_ASM_ENTRY("glSeparableFilter2DEXT")"\n"
"\t"STUB_ASM_CODE("2422")"\n"

STUB_ASM_ENTRY("glSetFenceAPPLE")"\n"
"\t"STUB_ASM_CODE("2423")"\n"

STUB_ASM_ENTRY("glSetFenceNV")"\n"
"\t"STUB_ASM_CODE("2424")"\n"

STUB_ASM_ENTRY("glSetFragmentShaderConstantATI")"\n"
"\t"STUB_ASM_CODE("2425")"\n"

STUB_ASM_ENTRY("glSetInvariantEXT")"\n"
"\t"STUB_ASM_CODE("2426")"\n"

STUB_ASM_ENTRY("glSetLocalConstantEXT")"\n"
"\t"STUB_ASM_CODE("2427")"\n"

STUB_ASM_ENTRY("glSetMultisamplefvAMD")"\n"
"\t"STUB_ASM_CODE("2428")"\n"

STUB_ASM_ENTRY("glShadeModel")"\n"
"\t"STUB_ASM_CODE("2429")"\n"

STUB_ASM_ENTRY("glShaderBinary")"\n"
"\t"STUB_ASM_CODE("2430")"\n"

STUB_ASM_ENTRY("glShaderOp1EXT")"\n"
"\t"STUB_ASM_CODE("2431")"\n"

STUB_ASM_ENTRY("glShaderOp2EXT")"\n"
"\t"STUB_ASM_CODE("2432")"\n"

STUB_ASM_ENTRY("glShaderOp3EXT")"\n"
"\t"STUB_ASM_CODE("2433")"\n"

STUB_ASM_ENTRY("glShaderSource")"\n"
"\t"STUB_ASM_CODE("2434")"\n"

STUB_ASM_ENTRY("glShaderSourceARB")"\n"
"\t"STUB_ASM_CODE("2435")"\n"

STUB_ASM_ENTRY("glShaderStorageBlockBinding")"\n"
"\t"STUB_ASM_CODE("2436")"\n"

STUB_ASM_ENTRY("glShadingRateImageBarrierNV")"\n"
"\t"STUB_ASM_CODE("2439")"\n"

STUB_ASM_ENTRY("glShadingRateImagePaletteNV")"\n"
"\t"STUB_ASM_CODE("2440")"\n"

STUB_ASM_ENTRY("glShadingRateSampleOrderCustomNV")"\n"
"\t"STUB_ASM_CODE("2442")"\n"

STUB_ASM_ENTRY("glShadingRateSampleOrderNV")"\n"
"\t"STUB_ASM_CODE("2443")"\n"

STUB_ASM_ENTRY("glSharpenTexFuncSGIS")"\n"
"\t"STUB_ASM_CODE("2444")"\n"

STUB_ASM_ENTRY("glSignalSemaphoreEXT")"\n"
"\t"STUB_ASM_CODE("2445")"\n"

STUB_ASM_ENTRY("glSignalSemaphoreui64NVX")"\n"
"\t"STUB_ASM_CODE("2446")"\n"

STUB_ASM_ENTRY("glSignalVkFenceNV")"\n"
"\t"STUB_ASM_CODE("2447")"\n"

STUB_ASM_ENTRY("glSignalVkSemaphoreNV")"\n"
"\t"STUB_ASM_CODE("2448")"\n"

STUB_ASM_ENTRY("glSpecializeShader")"\n"
"\t"STUB_ASM_CODE("2449")"\n"

STUB_ASM_ENTRY("glSpecializeShaderARB")"\n"
"\t"STUB_ASM_CODE("2450")"\n"

STUB_ASM_ENTRY("glSpriteParameterfSGIX")"\n"
"\t"STUB_ASM_CODE("2451")"\n"

STUB_ASM_ENTRY("glSpriteParameterfvSGIX")"\n"
"\t"STUB_ASM_CODE("2452")"\n"

STUB_ASM_ENTRY("glSpriteParameteriSGIX")"\n"
"\t"STUB_ASM_CODE("2453")"\n"

STUB_ASM_ENTRY("glSpriteParameterivSGIX")"\n"
"\t"STUB_ASM_CODE("2454")"\n"

STUB_ASM_ENTRY("glStartInstrumentsSGIX")"\n"
"\t"STUB_ASM_CODE("2455")"\n"

STUB_ASM_ENTRY("glStartTilingQCOM")"\n"
"\t"STUB_ASM_CODE("2456")"\n"

STUB_ASM_ENTRY("glStateCaptureNV")"\n"
"\t"STUB_ASM_CODE("2457")"\n"

STUB_ASM_ENTRY("glStencilClearTagEXT")"\n"
"\t"STUB_ASM_CODE("2458")"\n"

STUB_ASM_ENTRY("glStencilFillPathInstancedNV")"\n"
"\t"STUB_ASM_CODE("2459")"\n"

STUB_ASM_ENTRY("glStencilFillPathNV")"\n"
"\t"STUB_ASM_CODE("2460")"\n"

STUB_ASM_ENTRY("glStencilFunc")"\n"
"\t"STUB_ASM_CODE("2461")"\n"

STUB_ASM_ENTRY("glStencilFuncSeparate")"\n"
"\t"STUB_ASM_CODE("2462")"\n"

STUB_ASM_ENTRY("glStencilFuncSeparateATI")"\n"
"\t"STUB_ASM_CODE("2463")"\n"

STUB_ASM_ENTRY("glStencilMask")"\n"
"\t"STUB_ASM_CODE("2464")"\n"

STUB_ASM_ENTRY("glStencilMaskSeparate")"\n"
"\t"STUB_ASM_CODE("2465")"\n"

STUB_ASM_ENTRY("glStencilOp")"\n"
"\t"STUB_ASM_CODE("2466")"\n"

STUB_ASM_ENTRY("glStencilOpSeparate")"\n"
"\t"STUB_ASM_CODE("2467")"\n"

STUB_ASM_ENTRY("glStencilOpSeparateATI")"\n"
"\t"STUB_ASM_CODE("2468")"\n"

STUB_ASM_ENTRY("glStencilOpValueAMD")"\n"
"\t"STUB_ASM_CODE("2469")"\n"

STUB_ASM_ENTRY("glStencilStrokePathInstancedNV")"\n"
"\t"STUB_ASM_CODE("2470")"\n"

STUB_ASM_ENTRY("glStencilStrokePathNV")"\n"
"\t"STUB_ASM_CODE("2471")"\n"

STUB_ASM_ENTRY("glStencilThenCoverFillPathInstancedNV")"\n"
"\t"STUB_ASM_CODE("2472")"\n"

STUB_ASM_ENTRY("glStencilThenCoverFillPathNV")"\n"
"\t"STUB_ASM_CODE("2473")"\n"

STUB_ASM_ENTRY("glStencilThenCoverStrokePathInstancedNV")"\n"
"\t"STUB_ASM_CODE("2474")"\n"

STUB_ASM_ENTRY("glStencilThenCoverStrokePathNV")"\n"
"\t"STUB_ASM_CODE("2475")"\n"

STUB_ASM_ENTRY("glStopInstrumentsSGIX")"\n"
"\t"STUB_ASM_CODE("2476")"\n"

STUB_ASM_ENTRY("glStringMarkerGREMEDY")"\n"
"\t"STUB_ASM_CODE("2477")"\n"

STUB_ASM_ENTRY("glSubpixelPrecisionBiasNV")"\n"
"\t"STUB_ASM_CODE("2478")"\n"

STUB_ASM_ENTRY("glSwizzleEXT")"\n"
"\t"STUB_ASM_CODE("2479")"\n"

STUB_ASM_ENTRY("glSyncTextureINTEL")"\n"
"\t"STUB_ASM_CODE("2480")"\n"

STUB_ASM_ENTRY("glTagSampleBufferSGIX")"\n"
"\t"STUB_ASM_CODE("2481")"\n"

STUB_ASM_ENTRY("glTangent3bEXT")"\n"
"\t"STUB_ASM_CODE("2482")"\n"

STUB_ASM_ENTRY("glTangent3bvEXT")"\n"
"\t"STUB_ASM_CODE("2483")"\n"

STUB_ASM_ENTRY("glTangent3dEXT")"\n"
"\t"STUB_ASM_CODE("2484")"\n"

STUB_ASM_ENTRY("glTangent3dvEXT")"\n"
"\t"STUB_ASM_CODE("2485")"\n"

STUB_ASM_ENTRY("glTangent3fEXT")"\n"
"\t"STUB_ASM_CODE("2486")"\n"

STUB_ASM_ENTRY("glTangent3fvEXT")"\n"
"\t"STUB_ASM_CODE("2487")"\n"

STUB_ASM_ENTRY("glTangent3iEXT")"\n"
"\t"STUB_ASM_CODE("2488")"\n"

STUB_ASM_ENTRY("glTangent3ivEXT")"\n"
"\t"STUB_ASM_CODE("2489")"\n"

STUB_ASM_ENTRY("glTangent3sEXT")"\n"
"\t"STUB_ASM_CODE("2490")"\n"

STUB_ASM_ENTRY("glTangent3svEXT")"\n"
"\t"STUB_ASM_CODE("2491")"\n"

STUB_ASM_ENTRY("glTangentPointerEXT")"\n"
"\t"STUB_ASM_CODE("2492")"\n"

STUB_ASM_ENTRY("glTbufferMask3DFX")"\n"
"\t"STUB_ASM_CODE("2493")"\n"

STUB_ASM_ENTRY("glTessellationFactorAMD")"\n"
"\t"STUB_ASM_CODE("2494")"\n"

STUB_ASM_ENTRY("glTessellationModeAMD")"\n"
"\t"STUB_ASM_CODE("2495")"\n"

STUB_ASM_ENTRY("glTestFenceAPPLE")"\n"
"\t"STUB_ASM_CODE("2496")"\n"

STUB_ASM_ENTRY("glTestFenceNV")"\n"
"\t"STUB_ASM_CODE("2497")"\n"

STUB_ASM_ENTRY("glTestObjectAPPLE")"\n"
"\t"STUB_ASM_CODE("2498")"\n"

STUB_ASM_ENTRY("glTexAttachMemoryNV")"\n"
"\t"STUB_ASM_CODE("2499")"\n"

STUB_ASM_ENTRY("glTexBuffer")"\n"
"\t"STUB_ASM_CODE("2500")"\n"

STUB_ASM_ENTRY("glTexBufferARB")"\n"
"\t"STUB_ASM_CODE("2501")"\n"

STUB_ASM_ENTRY("glTexBufferEXT")"\n"
"\t"STUB_ASM_CODE("2502")"\n"

STUB_ASM_ENTRY("glTexBufferOES")"\n"
"\t"STUB_ASM_CODE("2503")"\n"

STUB_ASM_ENTRY("glTexBufferRange")"\n"
"\t"STUB_ASM_CODE("2504")"\n"

STUB_ASM_ENTRY("glTexBufferRangeEXT")"\n"
"\t"STUB_ASM_CODE("2505")"\n"

STUB_ASM_ENTRY("glTexBufferRangeOES")"\n"
"\t"STUB_ASM_CODE("2506")"\n"

STUB_ASM_ENTRY("glTexBumpParameterfvATI")"\n"
"\t"STUB_ASM_CODE("2507")"\n"

STUB_ASM_ENTRY("glTexBumpParameterivATI")"\n"
"\t"STUB_ASM_CODE("2508")"\n"

STUB_ASM_ENTRY("glTexCoord1bOES")"\n"
"\t"STUB_ASM_CODE("2509")"\n"

STUB_ASM_ENTRY("glTexCoord1bvOES")"\n"
"\t"STUB_ASM_CODE("2510")"\n"

STUB_ASM_ENTRY("glTexCoord1d")"\n"
"\t"STUB_ASM_CODE("2511")"\n"

STUB_ASM_ENTRY("glTexCoord1dv")"\n"
"\t"STUB_ASM_CODE("2512")"\n"

STUB_ASM_ENTRY("glTexCoord1f")"\n"
"\t"STUB_ASM_CODE("2513")"\n"

STUB_ASM_ENTRY("glTexCoord1fv")"\n"
"\t"STUB_ASM_CODE("2514")"\n"

STUB_ASM_ENTRY("glTexCoord1hNV")"\n"
"\t"STUB_ASM_CODE("2515")"\n"

STUB_ASM_ENTRY("glTexCoord1hvNV")"\n"
"\t"STUB_ASM_CODE("2516")"\n"

STUB_ASM_ENTRY("glTexCoord1i")"\n"
"\t"STUB_ASM_CODE("2517")"\n"

STUB_ASM_ENTRY("glTexCoord1iv")"\n"
"\t"STUB_ASM_CODE("2518")"\n"

STUB_ASM_ENTRY("glTexCoord1s")"\n"
"\t"STUB_ASM_CODE("2519")"\n"

STUB_ASM_ENTRY("glTexCoord1sv")"\n"
"\t"STUB_ASM_CODE("2520")"\n"

STUB_ASM_ENTRY("glTexCoord1xOES")"\n"
"\t"STUB_ASM_CODE("2521")"\n"

STUB_ASM_ENTRY("glTexCoord1xvOES")"\n"
"\t"STUB_ASM_CODE("2522")"\n"

STUB_ASM_ENTRY("glTexCoord2bOES")"\n"
"\t"STUB_ASM_CODE("2523")"\n"

STUB_ASM_ENTRY("glTexCoord2bvOES")"\n"
"\t"STUB_ASM_CODE("2524")"\n"

STUB_ASM_ENTRY("glTexCoord2d")"\n"
"\t"STUB_ASM_CODE("2525")"\n"

STUB_ASM_ENTRY("glTexCoord2dv")"\n"
"\t"STUB_ASM_CODE("2526")"\n"

STUB_ASM_ENTRY("glTexCoord2f")"\n"
"\t"STUB_ASM_CODE("2527")"\n"

STUB_ASM_ENTRY("glTexCoord2fColor3fVertex3fSUN")"\n"
"\t"STUB_ASM_CODE("2528")"\n"

STUB_ASM_ENTRY("glTexCoord2fColor3fVertex3fvSUN")"\n"
"\t"STUB_ASM_CODE("2529")"\n"

STUB_ASM_ENTRY("glTexCoord2fColor4fNormal3fVertex3fSUN")"\n"
"\t"STUB_ASM_CODE("2530")"\n"

STUB_ASM_ENTRY("glTexCoord2fColor4fNormal3fVertex3fvSUN")"\n"
"\t"STUB_ASM_CODE("2531")"\n"

STUB_ASM_ENTRY("glTexCoord2fColor4ubVertex3fSUN")"\n"
"\t"STUB_ASM_CODE("2532")"\n"

STUB_ASM_ENTRY("glTexCoord2fColor4ubVertex3fvSUN")"\n"
"\t"STUB_ASM_CODE("2533")"\n"

STUB_ASM_ENTRY("glTexCoord2fNormal3fVertex3fSUN")"\n"
"\t"STUB_ASM_CODE("2534")"\n"

STUB_ASM_ENTRY("glTexCoord2fNormal3fVertex3fvSUN")"\n"
"\t"STUB_ASM_CODE("2535")"\n"

STUB_ASM_ENTRY("glTexCoord2fVertex3fSUN")"\n"
"\t"STUB_ASM_CODE("2536")"\n"

STUB_ASM_ENTRY("glTexCoord2fVertex3fvSUN")"\n"
"\t"STUB_ASM_CODE("2537")"\n"

STUB_ASM_ENTRY("glTexCoord2fv")"\n"
"\t"STUB_ASM_CODE("2538")"\n"

STUB_ASM_ENTRY("glTexCoord2hNV")"\n"
"\t"STUB_ASM_CODE("2539")"\n"

STUB_ASM_ENTRY("glTexCoord2hvNV")"\n"
"\t"STUB_ASM_CODE("2540")"\n"

STUB_ASM_ENTRY("glTexCoord2i")"\n"
"\t"STUB_ASM_CODE("2541")"\n"

STUB_ASM_ENTRY("glTexCoord2iv")"\n"
"\t"STUB_ASM_CODE("2542")"\n"

STUB_ASM_ENTRY("glTexCoord2s")"\n"
"\t"STUB_ASM_CODE("2543")"\n"

STUB_ASM_ENTRY("glTexCoord2sv")"\n"
"\t"STUB_ASM_CODE("2544")"\n"

STUB_ASM_ENTRY("glTexCoord2xOES")"\n"
"\t"STUB_ASM_CODE("2545")"\n"

STUB_ASM_ENTRY("glTexCoord2xvOES")"\n"
"\t"STUB_ASM_CODE("2546")"\n"

STUB_ASM_ENTRY("glTexCoord3bOES")"\n"
"\t"STUB_ASM_CODE("2547")"\n"

STUB_ASM_ENTRY("glTexCoord3bvOES")"\n"
"\t"STUB_ASM_CODE("2548")"\n"

STUB_ASM_ENTRY("glTexCoord3d")"\n"
"\t"STUB_ASM_CODE("2549")"\n"

STUB_ASM_ENTRY("glTexCoord3dv")"\n"
"\t"STUB_ASM_CODE("2550")"\n"

STUB_ASM_ENTRY("glTexCoord3f")"\n"
"\t"STUB_ASM_CODE("2551")"\n"

STUB_ASM_ENTRY("glTexCoord3fv")"\n"
"\t"STUB_ASM_CODE("2552")"\n"

STUB_ASM_ENTRY("glTexCoord3hNV")"\n"
"\t"STUB_ASM_CODE("2553")"\n"

STUB_ASM_ENTRY("glTexCoord3hvNV")"\n"
"\t"STUB_ASM_CODE("2554")"\n"

STUB_ASM_ENTRY("glTexCoord3i")"\n"
"\t"STUB_ASM_CODE("2555")"\n"

STUB_ASM_ENTRY("glTexCoord3iv")"\n"
"\t"STUB_ASM_CODE("2556")"\n"

STUB_ASM_ENTRY("glTexCoord3s")"\n"
"\t"STUB_ASM_CODE("2557")"\n"

STUB_ASM_ENTRY("glTexCoord3sv")"\n"
"\t"STUB_ASM_CODE("2558")"\n"

STUB_ASM_ENTRY("glTexCoord3xOES")"\n"
"\t"STUB_ASM_CODE("2559")"\n"

STUB_ASM_ENTRY("glTexCoord3xvOES")"\n"
"\t"STUB_ASM_CODE("2560")"\n"

STUB_ASM_ENTRY("glTexCoord4bOES")"\n"
"\t"STUB_ASM_CODE("2561")"\n"

STUB_ASM_ENTRY("glTexCoord4bvOES")"\n"
"\t"STUB_ASM_CODE("2562")"\n"

STUB_ASM_ENTRY("glTexCoord4d")"\n"
"\t"STUB_ASM_CODE("2563")"\n"

STUB_ASM_ENTRY("glTexCoord4dv")"\n"
"\t"STUB_ASM_CODE("2564")"\n"

STUB_ASM_ENTRY("glTexCoord4f")"\n"
"\t"STUB_ASM_CODE("2565")"\n"

STUB_ASM_ENTRY("glTexCoord4fColor4fNormal3fVertex4fSUN")"\n"
"\t"STUB_ASM_CODE("2566")"\n"

STUB_ASM_ENTRY("glTexCoord4fColor4fNormal3fVertex4fvSUN")"\n"
"\t"STUB_ASM_CODE("2567")"\n"

STUB_ASM_ENTRY("glTexCoord4fVertex4fSUN")"\n"
"\t"STUB_ASM_CODE("2568")"\n"

STUB_ASM_ENTRY("glTexCoord4fVertex4fvSUN")"\n"
"\t"STUB_ASM_CODE("2569")"\n"

STUB_ASM_ENTRY("glTexCoord4fv")"\n"
"\t"STUB_ASM_CODE("2570")"\n"

STUB_ASM_ENTRY("glTexCoord4hNV")"\n"
"\t"STUB_ASM_CODE("2571")"\n"

STUB_ASM_ENTRY("glTexCoord4hvNV")"\n"
"\t"STUB_ASM_CODE("2572")"\n"

STUB_ASM_ENTRY("glTexCoord4i")"\n"
"\t"STUB_ASM_CODE("2573")"\n"

STUB_ASM_ENTRY("glTexCoord4iv")"\n"
"\t"STUB_ASM_CODE("2574")"\n"

STUB_ASM_ENTRY("glTexCoord4s")"\n"
"\t"STUB_ASM_CODE("2575")"\n"

STUB_ASM_ENTRY("glTexCoord4sv")"\n"
"\t"STUB_ASM_CODE("2576")"\n"

STUB_ASM_ENTRY("glTexCoord4xOES")"\n"
"\t"STUB_ASM_CODE("2577")"\n"

STUB_ASM_ENTRY("glTexCoord4xvOES")"\n"
"\t"STUB_ASM_CODE("2578")"\n"

STUB_ASM_ENTRY("glTexCoordFormatNV")"\n"
"\t"STUB_ASM_CODE("2579")"\n"

STUB_ASM_ENTRY("glTexCoordP1ui")"\n"
"\t"STUB_ASM_CODE("2580")"\n"

STUB_ASM_ENTRY("glTexCoordP1uiv")"\n"
"\t"STUB_ASM_CODE("2581")"\n"

STUB_ASM_ENTRY("glTexCoordP2ui")"\n"
"\t"STUB_ASM_CODE("2582")"\n"

STUB_ASM_ENTRY("glTexCoordP2uiv")"\n"
"\t"STUB_ASM_CODE("2583")"\n"

STUB_ASM_ENTRY("glTexCoordP3ui")"\n"
"\t"STUB_ASM_CODE("2584")"\n"

STUB_ASM_ENTRY("glTexCoordP3uiv")"\n"
"\t"STUB_ASM_CODE("2585")"\n"

STUB_ASM_ENTRY("glTexCoordP4ui")"\n"
"\t"STUB_ASM_CODE("2586")"\n"

STUB_ASM_ENTRY("glTexCoordP4uiv")"\n"
"\t"STUB_ASM_CODE("2587")"\n"

STUB_ASM_ENTRY("glTexCoordPointer")"\n"
"\t"STUB_ASM_CODE("2588")"\n"

STUB_ASM_ENTRY("glTexCoordPointerEXT")"\n"
"\t"STUB_ASM_CODE("2589")"\n"

STUB_ASM_ENTRY("glTexCoordPointerListIBM")"\n"
"\t"STUB_ASM_CODE("2590")"\n"

STUB_ASM_ENTRY("glTexCoordPointervINTEL")"\n"
"\t"STUB_ASM_CODE("2591")"\n"

STUB_ASM_ENTRY("glTexEnvf")"\n"
"\t"STUB_ASM_CODE("2592")"\n"

STUB_ASM_ENTRY("glTexEnvfv")"\n"
"\t"STUB_ASM_CODE("2593")"\n"

STUB_ASM_ENTRY("glTexEnvi")"\n"
"\t"STUB_ASM_CODE("2594")"\n"

STUB_ASM_ENTRY("glTexEnviv")"\n"
"\t"STUB_ASM_CODE("2595")"\n"

STUB_ASM_ENTRY("glTexEnvx")"\n"
"\t"STUB_ASM_CODE("2596")"\n"

STUB_ASM_ENTRY("glTexEnvxOES")"\n"
"\t"STUB_ASM_CODE("2597")"\n"

STUB_ASM_ENTRY("glTexEnvxv")"\n"
"\t"STUB_ASM_CODE("2598")"\n"

STUB_ASM_ENTRY("glTexEnvxvOES")"\n"
"\t"STUB_ASM_CODE("2599")"\n"

STUB_ASM_ENTRY("glTexFilterFuncSGIS")"\n"
"\t"STUB_ASM_CODE("2602")"\n"

STUB_ASM_ENTRY("glTexGend")"\n"
"\t"STUB_ASM_CODE("2603")"\n"

STUB_ASM_ENTRY("glTexGendv")"\n"
"\t"STUB_ASM_CODE("2604")"\n"

STUB_ASM_ENTRY("glTexGenf")"\n"
"\t"STUB_ASM_CODE("2605")"\n"

STUB_ASM_ENTRY("glTexGenfOES")"\n"
"\t"STUB_ASM_CODE("2606")"\n"

STUB_ASM_ENTRY("glTexGenfv")"\n"
"\t"STUB_ASM_CODE("2607")"\n"

STUB_ASM_ENTRY("glTexGenfvOES")"\n"
"\t"STUB_ASM_CODE("2608")"\n"

STUB_ASM_ENTRY("glTexGeni")"\n"
"\t"STUB_ASM_CODE("2609")"\n"

STUB_ASM_ENTRY("glTexGeniOES")"\n"
"\t"STUB_ASM_CODE("2610")"\n"

STUB_ASM_ENTRY("glTexGeniv")"\n"
"\t"STUB_ASM_CODE("2611")"\n"

STUB_ASM_ENTRY("glTexGenivOES")"\n"
"\t"STUB_ASM_CODE("2612")"\n"

STUB_ASM_ENTRY("glTexGenxOES")"\n"
"\t"STUB_ASM_CODE("2613")"\n"

STUB_ASM_ENTRY("glTexGenxvOES")"\n"
"\t"STUB_ASM_CODE("2614")"\n"

STUB_ASM_ENTRY("glTexImage1D")"\n"
"\t"STUB_ASM_CODE("2615")"\n"

STUB_ASM_ENTRY("glTexImage2D")"\n"
"\t"STUB_ASM_CODE("2616")"\n"

STUB_ASM_ENTRY("glTexImage2DMultisample")"\n"
"\t"STUB_ASM_CODE("2617")"\n"

STUB_ASM_ENTRY("glTexImage2DMultisampleCoverageNV")"\n"
"\t"STUB_ASM_CODE("2618")"\n"

STUB_ASM_ENTRY("glTexImage3D")"\n"
"\t"STUB_ASM_CODE("2619")"\n"

STUB_ASM_ENTRY("glTexImage3DEXT")"\n"
"\t"STUB_ASM_CODE("2620")"\n"

STUB_ASM_ENTRY("glTexImage3DMultisample")"\n"
"\t"STUB_ASM_CODE("2621")"\n"

STUB_ASM_ENTRY("glTexImage3DMultisampleCoverageNV")"\n"
"\t"STUB_ASM_CODE("2622")"\n"

STUB_ASM_ENTRY("glTexImage3DNV")"\n"
"\t"STUB_ASM_CODE("2623")"\n"

STUB_ASM_ENTRY("glTexImage3DOES")"\n"
"\t"STUB_ASM_CODE("2624")"\n"

STUB_ASM_ENTRY("glTexImage4DSGIS")"\n"
"\t"STUB_ASM_CODE("2625")"\n"

STUB_ASM_ENTRY("glTexPageCommitmentARB")"\n"
"\t"STUB_ASM_CODE("2626")"\n"

STUB_ASM_ENTRY("glTexPageCommitmentEXT")"\n"
"\t"STUB_ASM_CODE("2627")"\n"

STUB_ASM_ENTRY("glTexParameterIiv")"\n"
"\t"STUB_ASM_CODE("2629")"\n"

STUB_ASM_ENTRY("glTexParameterIivEXT")"\n"
"\t"STUB_ASM_CODE("2630")"\n"

STUB_ASM_ENTRY("glTexParameterIivOES")"\n"
"\t"STUB_ASM_CODE("2631")"\n"

STUB_ASM_ENTRY("glTexParameterIuiv")"\n"
"\t"STUB_ASM_CODE("2632")"\n"

STUB_ASM_ENTRY("glTexParameterIuivEXT")"\n"
"\t"STUB_ASM_CODE("2633")"\n"

STUB_ASM_ENTRY("glTexParameterIuivOES")"\n"
"\t"STUB_ASM_CODE("2634")"\n"

STUB_ASM_ENTRY("glTexParameterf")"\n"
"\t"STUB_ASM_CODE("2635")"\n"

STUB_ASM_ENTRY("glTexParameterfv")"\n"
"\t"STUB_ASM_CODE("2636")"\n"

STUB_ASM_ENTRY("glTexParameteri")"\n"
"\t"STUB_ASM_CODE("2637")"\n"

STUB_ASM_ENTRY("glTexParameteriv")"\n"
"\t"STUB_ASM_CODE("2638")"\n"

STUB_ASM_ENTRY("glTexParameterx")"\n"
"\t"STUB_ASM_CODE("2639")"\n"

STUB_ASM_ENTRY("glTexParameterxOES")"\n"
"\t"STUB_ASM_CODE("2640")"\n"

STUB_ASM_ENTRY("glTexParameterxv")"\n"
"\t"STUB_ASM_CODE("2641")"\n"

STUB_ASM_ENTRY("glTexParameterxvOES")"\n"
"\t"STUB_ASM_CODE("2642")"\n"

STUB_ASM_ENTRY("glTexRenderbufferNV")"\n"
"\t"STUB_ASM_CODE("2643")"\n"

STUB_ASM_ENTRY("glTexStorage1D")"\n"
"\t"STUB_ASM_CODE("2644")"\n"

STUB_ASM_ENTRY("glTexStorage1DEXT")"\n"
"\t"STUB_ASM_CODE("2645")"\n"

STUB_ASM_ENTRY("glTexStorage2D")"\n"
"\t"STUB_ASM_CODE("2646")"\n"

STUB_ASM_ENTRY("glTexStorage2DEXT")"\n"
"\t"STUB_ASM_CODE("2647")"\n"

STUB_ASM_ENTRY("glTexStorage2DMultisample")"\n"
"\t"STUB_ASM_CODE("2648")"\n"

STUB_ASM_ENTRY("glTexStorage3D")"\n"
"\t"STUB_ASM_CODE("2649")"\n"

STUB_ASM_ENTRY("glTexStorage3DEXT")"\n"
"\t"STUB_ASM_CODE("2650")"\n"

STUB_ASM_ENTRY("glTexStorage3DMultisample")"\n"
"\t"STUB_ASM_CODE("2651")"\n"

STUB_ASM_ENTRY("glTexStorage3DMultisampleOES")"\n"
"\t"STUB_ASM_CODE("2652")"\n"

STUB_ASM_ENTRY("glTexStorageMem1DEXT")"\n"
"\t"STUB_ASM_CODE("2655")"\n"

STUB_ASM_ENTRY("glTexStorageMem2DEXT")"\n"
"\t"STUB_ASM_CODE("2656")"\n"

STUB_ASM_ENTRY("glTexStorageMem2DMultisampleEXT")"\n"
"\t"STUB_ASM_CODE("2657")"\n"

STUB_ASM_ENTRY("glTexStorageMem3DEXT")"\n"
"\t"STUB_ASM_CODE("2658")"\n"

STUB_ASM_ENTRY("glTexStorageMem3DMultisampleEXT")"\n"
"\t"STUB_ASM_CODE("2659")"\n"

STUB_ASM_ENTRY("glTexStorageSparseAMD")"\n"
"\t"STUB_ASM_CODE("2660")"\n"

STUB_ASM_ENTRY("glTexSubImage1D")"\n"
"\t"STUB_ASM_CODE("2661")"\n"

STUB_ASM_ENTRY("glTexSubImage1DEXT")"\n"
"\t"STUB_ASM_CODE("2662")"\n"

STUB_ASM_ENTRY("glTexSubImage2D")"\n"
"\t"STUB_ASM_CODE("2663")"\n"

STUB_ASM_ENTRY("glTexSubImage2DEXT")"\n"
"\t"STUB_ASM_CODE("2664")"\n"

STUB_ASM_ENTRY("glTexSubImage3D")"\n"
"\t"STUB_ASM_CODE("2665")"\n"

STUB_ASM_ENTRY("glTexSubImage3DEXT")"\n"
"\t"STUB_ASM_CODE("2666")"\n"

STUB_ASM_ENTRY("glTexSubImage3DNV")"\n"
"\t"STUB_ASM_CODE("2667")"\n"

STUB_ASM_ENTRY("glTexSubImage3DOES")"\n"
"\t"STUB_ASM_CODE("2668")"\n"

STUB_ASM_ENTRY("glTexSubImage4DSGIS")"\n"
"\t"STUB_ASM_CODE("2669")"\n"

STUB_ASM_ENTRY("glTextureAttachMemoryNV")"\n"
"\t"STUB_ASM_CODE("2670")"\n"

STUB_ASM_ENTRY("glTextureBarrier")"\n"
"\t"STUB_ASM_CODE("2671")"\n"

STUB_ASM_ENTRY("glTextureBarrierNV")"\n"
"\t"STUB_ASM_CODE("2672")"\n"

STUB_ASM_ENTRY("glTextureBuffer")"\n"
"\t"STUB_ASM_CODE("2673")"\n"

STUB_ASM_ENTRY("glTextureBufferEXT")"\n"
"\t"STUB_ASM_CODE("2674")"\n"

STUB_ASM_ENTRY("glTextureBufferRange")"\n"
"\t"STUB_ASM_CODE("2675")"\n"

STUB_ASM_ENTRY("glTextureBufferRangeEXT")"\n"
"\t"STUB_ASM_CODE("2676")"\n"

STUB_ASM_ENTRY("glTextureColorMaskSGIS")"\n"
"\t"STUB_ASM_CODE("2677")"\n"

STUB_ASM_ENTRY("glTextureFoveationParametersQCOM")"\n"
"\t"STUB_ASM_CODE("2678")"\n"

STUB_ASM_ENTRY("glTextureImage1DEXT")"\n"
"\t"STUB_ASM_CODE("2679")"\n"

STUB_ASM_ENTRY("glTextureImage2DEXT")"\n"
"\t"STUB_ASM_CODE("2680")"\n"

STUB_ASM_ENTRY("glTextureImage2DMultisampleCoverageNV")"\n"
"\t"STUB_ASM_CODE("2681")"\n"

STUB_ASM_ENTRY("glTextureImage2DMultisampleNV")"\n"
"\t"STUB_ASM_CODE("2682")"\n"

STUB_ASM_ENTRY("glTextureImage3DEXT")"\n"
"\t"STUB_ASM_CODE("2683")"\n"

STUB_ASM_ENTRY("glTextureImage3DMultisampleCoverageNV")"\n"
"\t"STUB_ASM_CODE("2684")"\n"

STUB_ASM_ENTRY("glTextureImage3DMultisampleNV")"\n"
"\t"STUB_ASM_CODE("2685")"\n"

STUB_ASM_ENTRY("glTextureLightEXT")"\n"
"\t"STUB_ASM_CODE("2686")"\n"

STUB_ASM_ENTRY("glTextureMaterialEXT")"\n"
"\t"STUB_ASM_CODE("2687")"\n"

STUB_ASM_ENTRY("glTextureNormalEXT")"\n"
"\t"STUB_ASM_CODE("2688")"\n"

STUB_ASM_ENTRY("glTexturePageCommitmentEXT")"\n"
"\t"STUB_ASM_CODE("2689")"\n"

STUB_ASM_ENTRY("glTextureParameterIiv")"\n"
"\t"STUB_ASM_CODE("2691")"\n"

STUB_ASM_ENTRY("glTextureParameterIivEXT")"\n"
"\t"STUB_ASM_CODE("2692")"\n"

STUB_ASM_ENTRY("glTextureParameterIuiv")"\n"
"\t"STUB_ASM_CODE("2693")"\n"

STUB_ASM_ENTRY("glTextureParameterIuivEXT")"\n"
"\t"STUB_ASM_CODE("2694")"\n"

STUB_ASM_ENTRY("glTextureParameterf")"\n"
"\t"STUB_ASM_CODE("2695")"\n"

STUB_ASM_ENTRY("glTextureParameterfEXT")"\n"
"\t"STUB_ASM_CODE("2696")"\n"

STUB_ASM_ENTRY("glTextureParameterfv")"\n"
"\t"STUB_ASM_CODE("2697")"\n"

STUB_ASM_ENTRY("glTextureParameterfvEXT")"\n"
"\t"STUB_ASM_CODE("2698")"\n"

STUB_ASM_ENTRY("glTextureParameteri")"\n"
"\t"STUB_ASM_CODE("2699")"\n"

STUB_ASM_ENTRY("glTextureParameteriEXT")"\n"
"\t"STUB_ASM_CODE("2700")"\n"

STUB_ASM_ENTRY("glTextureParameteriv")"\n"
"\t"STUB_ASM_CODE("2701")"\n"

STUB_ASM_ENTRY("glTextureParameterivEXT")"\n"
"\t"STUB_ASM_CODE("2702")"\n"

STUB_ASM_ENTRY("glTextureRangeAPPLE")"\n"
"\t"STUB_ASM_CODE("2703")"\n"

STUB_ASM_ENTRY("glTextureRenderbufferEXT")"\n"
"\t"STUB_ASM_CODE("2704")"\n"

STUB_ASM_ENTRY("glTextureStorage1D")"\n"
"\t"STUB_ASM_CODE("2705")"\n"

STUB_ASM_ENTRY("glTextureStorage1DEXT")"\n"
"\t"STUB_ASM_CODE("2706")"\n"

STUB_ASM_ENTRY("glTextureStorage2D")"\n"
"\t"STUB_ASM_CODE("2707")"\n"

STUB_ASM_ENTRY("glTextureStorage2DEXT")"\n"
"\t"STUB_ASM_CODE("2708")"\n"

STUB_ASM_ENTRY("glTextureStorage2DMultisample")"\n"
"\t"STUB_ASM_CODE("2709")"\n"

STUB_ASM_ENTRY("glTextureStorage2DMultisampleEXT")"\n"
"\t"STUB_ASM_CODE("2710")"\n"

STUB_ASM_ENTRY("glTextureStorage3D")"\n"
"\t"STUB_ASM_CODE("2711")"\n"

STUB_ASM_ENTRY("glTextureStorage3DEXT")"\n"
"\t"STUB_ASM_CODE("2712")"\n"

STUB_ASM_ENTRY("glTextureStorage3DMultisample")"\n"
"\t"STUB_ASM_CODE("2713")"\n"

STUB_ASM_ENTRY("glTextureStorage3DMultisampleEXT")"\n"
"\t"STUB_ASM_CODE("2714")"\n"

STUB_ASM_ENTRY("glTextureStorageMem1DEXT")"\n"
"\t"STUB_ASM_CODE("2715")"\n"

STUB_ASM_ENTRY("glTextureStorageMem2DEXT")"\n"
"\t"STUB_ASM_CODE("2716")"\n"

STUB_ASM_ENTRY("glTextureStorageMem2DMultisampleEXT")"\n"
"\t"STUB_ASM_CODE("2717")"\n"

STUB_ASM_ENTRY("glTextureStorageMem3DEXT")"\n"
"\t"STUB_ASM_CODE("2718")"\n"

STUB_ASM_ENTRY("glTextureStorageMem3DMultisampleEXT")"\n"
"\t"STUB_ASM_CODE("2719")"\n"

STUB_ASM_ENTRY("glTextureStorageSparseAMD")"\n"
"\t"STUB_ASM_CODE("2720")"\n"

STUB_ASM_ENTRY("glTextureSubImage1D")"\n"
"\t"STUB_ASM_CODE("2721")"\n"

STUB_ASM_ENTRY("glTextureSubImage1DEXT")"\n"
"\t"STUB_ASM_CODE("2722")"\n"

STUB_ASM_ENTRY("glTextureSubImage2D")"\n"
"\t"STUB_ASM_CODE("2723")"\n"

STUB_ASM_ENTRY("glTextureSubImage2DEXT")"\n"
"\t"STUB_ASM_CODE("2724")"\n"

STUB_ASM_ENTRY("glTextureSubImage3D")"\n"
"\t"STUB_ASM_CODE("2725")"\n"

STUB_ASM_ENTRY("glTextureSubImage3DEXT")"\n"
"\t"STUB_ASM_CODE("2726")"\n"

STUB_ASM_ENTRY("glTextureView")"\n"
"\t"STUB_ASM_CODE("2727")"\n"

STUB_ASM_ENTRY("glTextureViewEXT")"\n"
"\t"STUB_ASM_CODE("2728")"\n"

STUB_ASM_ENTRY("glTextureViewOES")"\n"
"\t"STUB_ASM_CODE("2729")"\n"

STUB_ASM_ENTRY("glTrackMatrixNV")"\n"
"\t"STUB_ASM_CODE("2730")"\n"

STUB_ASM_ENTRY("glTransformFeedbackAttribsNV")"\n"
"\t"STUB_ASM_CODE("2731")"\n"

STUB_ASM_ENTRY("glTransformFeedbackBufferBase")"\n"
"\t"STUB_ASM_CODE("2732")"\n"

STUB_ASM_ENTRY("glTransformFeedbackBufferRange")"\n"
"\t"STUB_ASM_CODE("2733")"\n"

STUB_ASM_ENTRY("glTransformFeedbackStreamAttribsNV")"\n"
"\t"STUB_ASM_CODE("2734")"\n"

STUB_ASM_ENTRY("glTransformFeedbackVaryings")"\n"
"\t"STUB_ASM_CODE("2735")"\n"

STUB_ASM_ENTRY("glTransformFeedbackVaryingsEXT")"\n"
"\t"STUB_ASM_CODE("2736")"\n"

STUB_ASM_ENTRY("glTransformFeedbackVaryingsNV")"\n"
"\t"STUB_ASM_CODE("2737")"\n"

STUB_ASM_ENTRY("glTransformPathNV")"\n"
"\t"STUB_ASM_CODE("2738")"\n"

STUB_ASM_ENTRY("glTranslated")"\n"
"\t"STUB_ASM_CODE("2739")"\n"

STUB_ASM_ENTRY("glTranslatef")"\n"
"\t"STUB_ASM_CODE("2740")"\n"

STUB_ASM_ENTRY("glTranslatex")"\n"
"\t"STUB_ASM_CODE("2741")"\n"

STUB_ASM_ENTRY("glTranslatexOES")"\n"
"\t"STUB_ASM_CODE("2742")"\n"

STUB_ASM_ENTRY("glUniform1d")"\n"
"\t"STUB_ASM_CODE("2743")"\n"

STUB_ASM_ENTRY("glUniform1dv")"\n"
"\t"STUB_ASM_CODE("2744")"\n"

STUB_ASM_ENTRY("glUniform1f")"\n"
"\t"STUB_ASM_CODE("2745")"\n"

STUB_ASM_ENTRY("glUniform1fARB")"\n"
"\t"STUB_ASM_CODE("2746")"\n"

STUB_ASM_ENTRY("glUniform1fv")"\n"
"\t"STUB_ASM_CODE("2747")"\n"

STUB_ASM_ENTRY("glUniform1fvARB")"\n"
"\t"STUB_ASM_CODE("2748")"\n"

STUB_ASM_ENTRY("glUniform1i")"\n"
"\t"STUB_ASM_CODE("2749")"\n"

STUB_ASM_ENTRY("glUniform1i64ARB")"\n"
"\t"STUB_ASM_CODE("2750")"\n"

STUB_ASM_ENTRY("glUniform1i64NV")"\n"
"\t"STUB_ASM_CODE("2751")"\n"

STUB_ASM_ENTRY("glUniform1i64vARB")"\n"
"\t"STUB_ASM_CODE("2752")"\n"

STUB_ASM_ENTRY("glUniform1i64vNV")"\n"
"\t"STUB_ASM_CODE("2753")"\n"

STUB_ASM_ENTRY("glUniform1iARB")"\n"
"\t"STUB_ASM_CODE("2754")"\n"

STUB_ASM_ENTRY("glUniform1iv")"\n"
"\t"STUB_ASM_CODE("2755")"\n"

STUB_ASM_ENTRY("glUniform1ivARB")"\n"
"\t"STUB_ASM_CODE("2756")"\n"

STUB_ASM_ENTRY("glUniform1ui")"\n"
"\t"STUB_ASM_CODE("2757")"\n"

STUB_ASM_ENTRY("glUniform1ui64ARB")"\n"
"\t"STUB_ASM_CODE("2758")"\n"

STUB_ASM_ENTRY("glUniform1ui64NV")"\n"
"\t"STUB_ASM_CODE("2759")"\n"

STUB_ASM_ENTRY("glUniform1ui64vARB")"\n"
"\t"STUB_ASM_CODE("2760")"\n"

STUB_ASM_ENTRY("glUniform1ui64vNV")"\n"
"\t"STUB_ASM_CODE("2761")"\n"

STUB_ASM_ENTRY("glUniform1uiEXT")"\n"
"\t"STUB_ASM_CODE("2762")"\n"

STUB_ASM_ENTRY("glUniform1uiv")"\n"
"\t"STUB_ASM_CODE("2763")"\n"

STUB_ASM_ENTRY("glUniform1uivEXT")"\n"
"\t"STUB_ASM_CODE("2764")"\n"

STUB_ASM_ENTRY("glUniform2d")"\n"
"\t"STUB_ASM_CODE("2765")"\n"

STUB_ASM_ENTRY("glUniform2dv")"\n"
"\t"STUB_ASM_CODE("2766")"\n"

STUB_ASM_ENTRY("glUniform2f")"\n"
"\t"STUB_ASM_CODE("2767")"\n"

STUB_ASM_ENTRY("glUniform2fARB")"\n"
"\t"STUB_ASM_CODE("2768")"\n"

STUB_ASM_ENTRY("glUniform2fv")"\n"
"\t"STUB_ASM_CODE("2769")"\n"

STUB_ASM_ENTRY("glUniform2fvARB")"\n"
"\t"STUB_ASM_CODE("2770")"\n"

STUB_ASM_ENTRY("glUniform2i")"\n"
"\t"STUB_ASM_CODE("2771")"\n"

STUB_ASM_ENTRY("glUniform2i64ARB")"\n"
"\t"STUB_ASM_CODE("2772")"\n"

STUB_ASM_ENTRY("glUniform2i64NV")"\n"
"\t"STUB_ASM_CODE("2773")"\n"

STUB_ASM_ENTRY("glUniform2i64vARB")"\n"
"\t"STUB_ASM_CODE("2774")"\n"

STUB_ASM_ENTRY("glUniform2i64vNV")"\n"
"\t"STUB_ASM_CODE("2775")"\n"

STUB_ASM_ENTRY("glUniform2iARB")"\n"
"\t"STUB_ASM_CODE("2776")"\n"

STUB_ASM_ENTRY("glUniform2iv")"\n"
"\t"STUB_ASM_CODE("2777")"\n"

STUB_ASM_ENTRY("glUniform2ivARB")"\n"
"\t"STUB_ASM_CODE("2778")"\n"

STUB_ASM_ENTRY("glUniform2ui")"\n"
"\t"STUB_ASM_CODE("2779")"\n"

STUB_ASM_ENTRY("glUniform2ui64ARB")"\n"
"\t"STUB_ASM_CODE("2780")"\n"

STUB_ASM_ENTRY("glUniform2ui64NV")"\n"
"\t"STUB_ASM_CODE("2781")"\n"

STUB_ASM_ENTRY("glUniform2ui64vARB")"\n"
"\t"STUB_ASM_CODE("2782")"\n"

STUB_ASM_ENTRY("glUniform2ui64vNV")"\n"
"\t"STUB_ASM_CODE("2783")"\n"

STUB_ASM_ENTRY("glUniform2uiEXT")"\n"
"\t"STUB_ASM_CODE("2784")"\n"

STUB_ASM_ENTRY("glUniform2uiv")"\n"
"\t"STUB_ASM_CODE("2785")"\n"

STUB_ASM_ENTRY("glUniform2uivEXT")"\n"
"\t"STUB_ASM_CODE("2786")"\n"

STUB_ASM_ENTRY("glUniform3d")"\n"
"\t"STUB_ASM_CODE("2787")"\n"

STUB_ASM_ENTRY("glUniform3dv")"\n"
"\t"STUB_ASM_CODE("2788")"\n"

STUB_ASM_ENTRY("glUniform3f")"\n"
"\t"STUB_ASM_CODE("2789")"\n"

STUB_ASM_ENTRY("glUniform3fARB")"\n"
"\t"STUB_ASM_CODE("2790")"\n"

STUB_ASM_ENTRY("glUniform3fv")"\n"
"\t"STUB_ASM_CODE("2791")"\n"

STUB_ASM_ENTRY("glUniform3fvARB")"\n"
"\t"STUB_ASM_CODE("2792")"\n"

STUB_ASM_ENTRY("glUniform3i")"\n"
"\t"STUB_ASM_CODE("2793")"\n"

STUB_ASM_ENTRY("glUniform3i64ARB")"\n"
"\t"STUB_ASM_CODE("2794")"\n"

STUB_ASM_ENTRY("glUniform3i64NV")"\n"
"\t"STUB_ASM_CODE("2795")"\n"

STUB_ASM_ENTRY("glUniform3i64vARB")"\n"
"\t"STUB_ASM_CODE("2796")"\n"

STUB_ASM_ENTRY("glUniform3i64vNV")"\n"
"\t"STUB_ASM_CODE("2797")"\n"

STUB_ASM_ENTRY("glUniform3iARB")"\n"
"\t"STUB_ASM_CODE("2798")"\n"

STUB_ASM_ENTRY("glUniform3iv")"\n"
"\t"STUB_ASM_CODE("2799")"\n"

STUB_ASM_ENTRY("glUniform3ivARB")"\n"
"\t"STUB_ASM_CODE("2800")"\n"

STUB_ASM_ENTRY("glUniform3ui")"\n"
"\t"STUB_ASM_CODE("2801")"\n"

STUB_ASM_ENTRY("glUniform3ui64ARB")"\n"
"\t"STUB_ASM_CODE("2802")"\n"

STUB_ASM_ENTRY("glUniform3ui64NV")"\n"
"\t"STUB_ASM_CODE("2803")"\n"

STUB_ASM_ENTRY("glUniform3ui64vARB")"\n"
"\t"STUB_ASM_CODE("2804")"\n"

STUB_ASM_ENTRY("glUniform3ui64vNV")"\n"
"\t"STUB_ASM_CODE("2805")"\n"

STUB_ASM_ENTRY("glUniform3uiEXT")"\n"
"\t"STUB_ASM_CODE("2806")"\n"

STUB_ASM_ENTRY("glUniform3uiv")"\n"
"\t"STUB_ASM_CODE("2807")"\n"

STUB_ASM_ENTRY("glUniform3uivEXT")"\n"
"\t"STUB_ASM_CODE("2808")"\n"

STUB_ASM_ENTRY("glUniform4d")"\n"
"\t"STUB_ASM_CODE("2809")"\n"

STUB_ASM_ENTRY("glUniform4dv")"\n"
"\t"STUB_ASM_CODE("2810")"\n"

STUB_ASM_ENTRY("glUniform4f")"\n"
"\t"STUB_ASM_CODE("2811")"\n"

STUB_ASM_ENTRY("glUniform4fARB")"\n"
"\t"STUB_ASM_CODE("2812")"\n"

STUB_ASM_ENTRY("glUniform4fv")"\n"
"\t"STUB_ASM_CODE("2813")"\n"

STUB_ASM_ENTRY("glUniform4fvARB")"\n"
"\t"STUB_ASM_CODE("2814")"\n"

STUB_ASM_ENTRY("glUniform4i")"\n"
"\t"STUB_ASM_CODE("2815")"\n"

STUB_ASM_ENTRY("glUniform4i64ARB")"\n"
"\t"STUB_ASM_CODE("2816")"\n"

STUB_ASM_ENTRY("glUniform4i64NV")"\n"
"\t"STUB_ASM_CODE("2817")"\n"

STUB_ASM_ENTRY("glUniform4i64vARB")"\n"
"\t"STUB_ASM_CODE("2818")"\n"

STUB_ASM_ENTRY("glUniform4i64vNV")"\n"
"\t"STUB_ASM_CODE("2819")"\n"

STUB_ASM_ENTRY("glUniform4iARB")"\n"
"\t"STUB_ASM_CODE("2820")"\n"

STUB_ASM_ENTRY("glUniform4iv")"\n"
"\t"STUB_ASM_CODE("2821")"\n"

STUB_ASM_ENTRY("glUniform4ivARB")"\n"
"\t"STUB_ASM_CODE("2822")"\n"

STUB_ASM_ENTRY("glUniform4ui")"\n"
"\t"STUB_ASM_CODE("2823")"\n"

STUB_ASM_ENTRY("glUniform4ui64ARB")"\n"
"\t"STUB_ASM_CODE("2824")"\n"

STUB_ASM_ENTRY("glUniform4ui64NV")"\n"
"\t"STUB_ASM_CODE("2825")"\n"

STUB_ASM_ENTRY("glUniform4ui64vARB")"\n"
"\t"STUB_ASM_CODE("2826")"\n"

STUB_ASM_ENTRY("glUniform4ui64vNV")"\n"
"\t"STUB_ASM_CODE("2827")"\n"

STUB_ASM_ENTRY("glUniform4uiEXT")"\n"
"\t"STUB_ASM_CODE("2828")"\n"

STUB_ASM_ENTRY("glUniform4uiv")"\n"
"\t"STUB_ASM_CODE("2829")"\n"

STUB_ASM_ENTRY("glUniform4uivEXT")"\n"
"\t"STUB_ASM_CODE("2830")"\n"

STUB_ASM_ENTRY("glUniformBlockBinding")"\n"
"\t"STUB_ASM_CODE("2831")"\n"

STUB_ASM_ENTRY("glUniformBufferEXT")"\n"
"\t"STUB_ASM_CODE("2832")"\n"

STUB_ASM_ENTRY("glUniformHandleui64ARB")"\n"
"\t"STUB_ASM_CODE("2833")"\n"

STUB_ASM_ENTRY("glUniformHandleui64IMG")"\n"
"\t"STUB_ASM_CODE("2834")"\n"

STUB_ASM_ENTRY("glUniformHandleui64NV")"\n"
"\t"STUB_ASM_CODE("2835")"\n"

STUB_ASM_ENTRY("glUniformHandleui64vARB")"\n"
"\t"STUB_ASM_CODE("2836")"\n"

STUB_ASM_ENTRY("glUniformHandleui64vIMG")"\n"
"\t"STUB_ASM_CODE("2837")"\n"

STUB_ASM_ENTRY("glUniformHandleui64vNV")"\n"
"\t"STUB_ASM_CODE("2838")"\n"

STUB_ASM_ENTRY("glUniformMatrix2dv")"\n"
"\t"STUB_ASM_CODE("2839")"\n"

STUB_ASM_ENTRY("glUniformMatrix2fv")"\n"
"\t"STUB_ASM_CODE("2840")"\n"

STUB_ASM_ENTRY("glUniformMatrix2fvARB")"\n"
"\t"STUB_ASM_CODE("2841")"\n"

STUB_ASM_ENTRY("glUniformMatrix2x3dv")"\n"
"\t"STUB_ASM_CODE("2842")"\n"

STUB_ASM_ENTRY("glUniformMatrix2x3fv")"\n"
"\t"STUB_ASM_CODE("2843")"\n"

STUB_ASM_ENTRY("glUniformMatrix2x3fvNV")"\n"
"\t"STUB_ASM_CODE("2844")"\n"

STUB_ASM_ENTRY("glUniformMatrix2x4dv")"\n"
"\t"STUB_ASM_CODE("2845")"\n"

STUB_ASM_ENTRY("glUniformMatrix2x4fv")"\n"
"\t"STUB_ASM_CODE("2846")"\n"

STUB_ASM_ENTRY("glUniformMatrix2x4fvNV")"\n"
"\t"STUB_ASM_CODE("2847")"\n"

STUB_ASM_ENTRY("glUniformMatrix3dv")"\n"
"\t"STUB_ASM_CODE("2848")"\n"

STUB_ASM_ENTRY("glUniformMatrix3fv")"\n"
"\t"STUB_ASM_CODE("2849")"\n"

STUB_ASM_ENTRY("glUniformMatrix3fvARB")"\n"
"\t"STUB_ASM_CODE("2850")"\n"

STUB_ASM_ENTRY("glUniformMatrix3x2dv")"\n"
"\t"STUB_ASM_CODE("2851")"\n"

STUB_ASM_ENTRY("glUniformMatrix3x2fv")"\n"
"\t"STUB_ASM_CODE("2852")"\n"

STUB_ASM_ENTRY("glUniformMatrix3x2fvNV")"\n"
"\t"STUB_ASM_CODE("2853")"\n"

STUB_ASM_ENTRY("glUniformMatrix3x4dv")"\n"
"\t"STUB_ASM_CODE("2854")"\n"

STUB_ASM_ENTRY("glUniformMatrix3x4fv")"\n"
"\t"STUB_ASM_CODE("2855")"\n"

STUB_ASM_ENTRY("glUniformMatrix3x4fvNV")"\n"
"\t"STUB_ASM_CODE("2856")"\n"

STUB_ASM_ENTRY("glUniformMatrix4dv")"\n"
"\t"STUB_ASM_CODE("2857")"\n"

STUB_ASM_ENTRY("glUniformMatrix4fv")"\n"
"\t"STUB_ASM_CODE("2858")"\n"

STUB_ASM_ENTRY("glUniformMatrix4fvARB")"\n"
"\t"STUB_ASM_CODE("2859")"\n"

STUB_ASM_ENTRY("glUniformMatrix4x2dv")"\n"
"\t"STUB_ASM_CODE("2860")"\n"

STUB_ASM_ENTRY("glUniformMatrix4x2fv")"\n"
"\t"STUB_ASM_CODE("2861")"\n"

STUB_ASM_ENTRY("glUniformMatrix4x2fvNV")"\n"
"\t"STUB_ASM_CODE("2862")"\n"

STUB_ASM_ENTRY("glUniformMatrix4x3dv")"\n"
"\t"STUB_ASM_CODE("2863")"\n"

STUB_ASM_ENTRY("glUniformMatrix4x3fv")"\n"
"\t"STUB_ASM_CODE("2864")"\n"

STUB_ASM_ENTRY("glUniformMatrix4x3fvNV")"\n"
"\t"STUB_ASM_CODE("2865")"\n"

STUB_ASM_ENTRY("glUniformSubroutinesuiv")"\n"
"\t"STUB_ASM_CODE("2866")"\n"

STUB_ASM_ENTRY("glUniformui64NV")"\n"
"\t"STUB_ASM_CODE("2867")"\n"

STUB_ASM_ENTRY("glUniformui64vNV")"\n"
"\t"STUB_ASM_CODE("2868")"\n"

STUB_ASM_ENTRY("glUnlockArraysEXT")"\n"
"\t"STUB_ASM_CODE("2869")"\n"

STUB_ASM_ENTRY("glUnmapBuffer")"\n"
"\t"STUB_ASM_CODE("2870")"\n"

STUB_ASM_ENTRY("glUnmapBufferARB")"\n"
"\t"STUB_ASM_CODE("2871")"\n"

STUB_ASM_ENTRY("glUnmapBufferOES")"\n"
"\t"STUB_ASM_CODE("2872")"\n"

STUB_ASM_ENTRY("glUnmapNamedBuffer")"\n"
"\t"STUB_ASM_CODE("2873")"\n"

STUB_ASM_ENTRY("glUnmapNamedBufferEXT")"\n"
"\t"STUB_ASM_CODE("2874")"\n"

STUB_ASM_ENTRY("glUnmapObjectBufferATI")"\n"
"\t"STUB_ASM_CODE("2875")"\n"

STUB_ASM_ENTRY("glUnmapTexture2DINTEL")"\n"
"\t"STUB_ASM_CODE("2876")"\n"

STUB_ASM_ENTRY("glUpdateObjectBufferATI")"\n"
"\t"STUB_ASM_CODE("2877")"\n"

STUB_ASM_ENTRY("glUploadGpuMaskNVX")"\n"
"\t"STUB_ASM_CODE("2878")"\n"

STUB_ASM_ENTRY("glUseProgram")"\n"
"\t"STUB_ASM_CODE("2879")"\n"

STUB_ASM_ENTRY("glUseProgramObjectARB")"\n"
"\t"STUB_ASM_CODE("2880")"\n"

STUB_ASM_ENTRY("glUseProgramStages")"\n"
"\t"STUB_ASM_CODE("2881")"\n"

STUB_ASM_ENTRY("glUseProgramStagesEXT")"\n"
"\t"STUB_ASM_CODE("2882")"\n"

STUB_ASM_ENTRY("glUseShaderProgramEXT")"\n"
"\t"STUB_ASM_CODE("2883")"\n"

STUB_ASM_ENTRY("glVDPAUFiniNV")"\n"
"\t"STUB_ASM_CODE("2884")"\n"

STUB_ASM_ENTRY("glVDPAUGetSurfaceivNV")"\n"
"\t"STUB_ASM_CODE("2885")"\n"

STUB_ASM_ENTRY("glVDPAUInitNV")"\n"
"\t"STUB_ASM_CODE("2886")"\n"

STUB_ASM_ENTRY("glVDPAUIsSurfaceNV")"\n"
"\t"STUB_ASM_CODE("2887")"\n"

STUB_ASM_ENTRY("glVDPAUMapSurfacesNV")"\n"
"\t"STUB_ASM_CODE("2888")"\n"

STUB_ASM_ENTRY("glVDPAURegisterOutputSurfaceNV")"\n"
"\t"STUB_ASM_CODE("2889")"\n"

STUB_ASM_ENTRY("glVDPAURegisterVideoSurfaceNV")"\n"
"\t"STUB_ASM_CODE("2890")"\n"

STUB_ASM_ENTRY("glVDPAURegisterVideoSurfaceWithPictureStructureNV")"\n"
"\t"STUB_ASM_CODE("2891")"\n"

STUB_ASM_ENTRY("glVDPAUSurfaceAccessNV")"\n"
"\t"STUB_ASM_CODE("2892")"\n"

STUB_ASM_ENTRY("glVDPAUUnmapSurfacesNV")"\n"
"\t"STUB_ASM_CODE("2893")"\n"

STUB_ASM_ENTRY("glVDPAUUnregisterSurfaceNV")"\n"
"\t"STUB_ASM_CODE("2894")"\n"

STUB_ASM_ENTRY("glValidBackBufferHintAutodesk")"\n"
"\t"STUB_ASM_CODE("2895")"\n"

STUB_ASM_ENTRY("glValidateProgram")"\n"
"\t"STUB_ASM_CODE("2896")"\n"

STUB_ASM_ENTRY("glValidateProgramARB")"\n"
"\t"STUB_ASM_CODE("2897")"\n"

STUB_ASM_ENTRY("glValidateProgramPipeline")"\n"
"\t"STUB_ASM_CODE("2898")"\n"

STUB_ASM_ENTRY("glValidateProgramPipelineEXT")"\n"
"\t"STUB_ASM_CODE("2899")"\n"

STUB_ASM_ENTRY("glVariantArrayObjectATI")"\n"
"\t"STUB_ASM_CODE("2900")"\n"

STUB_ASM_ENTRY("glVariantPointerEXT")"\n"
"\t"STUB_ASM_CODE("2901")"\n"

STUB_ASM_ENTRY("glVariantbvEXT")"\n"
"\t"STUB_ASM_CODE("2902")"\n"

STUB_ASM_ENTRY("glVariantdvEXT")"\n"
"\t"STUB_ASM_CODE("2903")"\n"

STUB_ASM_ENTRY("glVariantfvEXT")"\n"
"\t"STUB_ASM_CODE("2904")"\n"

STUB_ASM_ENTRY("glVariantivEXT")"\n"
"\t"STUB_ASM_CODE("2905")"\n"

STUB_ASM_ENTRY("glVariantsvEXT")"\n"
"\t"STUB_ASM_CODE("2906")"\n"

STUB_ASM_ENTRY("glVariantubvEXT")"\n"
"\t"STUB_ASM_CODE("2907")"\n"

STUB_ASM_ENTRY("glVariantuivEXT")"\n"
"\t"STUB_ASM_CODE("2908")"\n"

STUB_ASM_ENTRY("glVariantusvEXT")"\n"
"\t"STUB_ASM_CODE("2909")"\n"

STUB_ASM_ENTRY("glVertex2bOES")"\n"
"\t"STUB_ASM_CODE("2910")"\n"

STUB_ASM_ENTRY("glVertex2bvOES")"\n"
"\t"STUB_ASM_CODE("2911")"\n"

STUB_ASM_ENTRY("glVertex2d")"\n"
"\t"STUB_ASM_CODE("2912")"\n"

STUB_ASM_ENTRY("glVertex2dv")"\n"
"\t"STUB_ASM_CODE("2913")"\n"

STUB_ASM_ENTRY("glVertex2f")"\n"
"\t"STUB_ASM_CODE("2914")"\n"

STUB_ASM_ENTRY("glVertex2fv")"\n"
"\t"STUB_ASM_CODE("2915")"\n"

STUB_ASM_ENTRY("glVertex2hNV")"\n"
"\t"STUB_ASM_CODE("2916")"\n"

STUB_ASM_ENTRY("glVertex2hvNV")"\n"
"\t"STUB_ASM_CODE("2917")"\n"

STUB_ASM_ENTRY("glVertex2i")"\n"
"\t"STUB_ASM_CODE("2918")"\n"

STUB_ASM_ENTRY("glVertex2iv")"\n"
"\t"STUB_ASM_CODE("2919")"\n"

STUB_ASM_ENTRY("glVertex2s")"\n"
"\t"STUB_ASM_CODE("2920")"\n"

STUB_ASM_ENTRY("glVertex2sv")"\n"
"\t"STUB_ASM_CODE("2921")"\n"

STUB_ASM_ENTRY("glVertex2xOES")"\n"
"\t"STUB_ASM_CODE("2922")"\n"

STUB_ASM_ENTRY("glVertex2xvOES")"\n"
"\t"STUB_ASM_CODE("2923")"\n"

STUB_ASM_ENTRY("glVertex3bOES")"\n"
"\t"STUB_ASM_CODE("2924")"\n"

STUB_ASM_ENTRY("glVertex3bvOES")"\n"
"\t"STUB_ASM_CODE("2925")"\n"

STUB_ASM_ENTRY("glVertex3d")"\n"
"\t"STUB_ASM_CODE("2926")"\n"

STUB_ASM_ENTRY("glVertex3dv")"\n"
"\t"STUB_ASM_CODE("2927")"\n"

STUB_ASM_ENTRY("glVertex3f")"\n"
"\t"STUB_ASM_CODE("2928")"\n"

STUB_ASM_ENTRY("glVertex3fv")"\n"
"\t"STUB_ASM_CODE("2929")"\n"

STUB_ASM_ENTRY("glVertex3hNV")"\n"
"\t"STUB_ASM_CODE("2930")"\n"

STUB_ASM_ENTRY("glVertex3hvNV")"\n"
"\t"STUB_ASM_CODE("2931")"\n"

STUB_ASM_ENTRY("glVertex3i")"\n"
"\t"STUB_ASM_CODE("2932")"\n"

STUB_ASM_ENTRY("glVertex3iv")"\n"
"\t"STUB_ASM_CODE("2933")"\n"

STUB_ASM_ENTRY("glVertex3s")"\n"
"\t"STUB_ASM_CODE("2934")"\n"

STUB_ASM_ENTRY("glVertex3sv")"\n"
"\t"STUB_ASM_CODE("2935")"\n"

STUB_ASM_ENTRY("glVertex3xOES")"\n"
"\t"STUB_ASM_CODE("2936")"\n"

STUB_ASM_ENTRY("glVertex3xvOES")"\n"
"\t"STUB_ASM_CODE("2937")"\n"

STUB_ASM_ENTRY("glVertex4bOES")"\n"
"\t"STUB_ASM_CODE("2938")"\n"

STUB_ASM_ENTRY("glVertex4bvOES")"\n"
"\t"STUB_ASM_CODE("2939")"\n"

STUB_ASM_ENTRY("glVertex4d")"\n"
"\t"STUB_ASM_CODE("2940")"\n"

STUB_ASM_ENTRY("glVertex4dv")"\n"
"\t"STUB_ASM_CODE("2941")"\n"

STUB_ASM_ENTRY("glVertex4f")"\n"
"\t"STUB_ASM_CODE("2942")"\n"

STUB_ASM_ENTRY("glVertex4fv")"\n"
"\t"STUB_ASM_CODE("2943")"\n"

STUB_ASM_ENTRY("glVertex4hNV")"\n"
"\t"STUB_ASM_CODE("2944")"\n"

STUB_ASM_ENTRY("glVertex4hvNV")"\n"
"\t"STUB_ASM_CODE("2945")"\n"

STUB_ASM_ENTRY("glVertex4i")"\n"
"\t"STUB_ASM_CODE("2946")"\n"

STUB_ASM_ENTRY("glVertex4iv")"\n"
"\t"STUB_ASM_CODE("2947")"\n"

STUB_ASM_ENTRY("glVertex4s")"\n"
"\t"STUB_ASM_CODE("2948")"\n"

STUB_ASM_ENTRY("glVertex4sv")"\n"
"\t"STUB_ASM_CODE("2949")"\n"

STUB_ASM_ENTRY("glVertex4xOES")"\n"
"\t"STUB_ASM_CODE("2950")"\n"

STUB_ASM_ENTRY("glVertex4xvOES")"\n"
"\t"STUB_ASM_CODE("2951")"\n"

STUB_ASM_ENTRY("glVertexArrayAttribBinding")"\n"
"\t"STUB_ASM_CODE("2952")"\n"

STUB_ASM_ENTRY("glVertexArrayAttribFormat")"\n"
"\t"STUB_ASM_CODE("2953")"\n"

STUB_ASM_ENTRY("glVertexArrayAttribIFormat")"\n"
"\t"STUB_ASM_CODE("2954")"\n"

STUB_ASM_ENTRY("glVertexArrayAttribLFormat")"\n"
"\t"STUB_ASM_CODE("2955")"\n"

STUB_ASM_ENTRY("glVertexArrayBindVertexBufferEXT")"\n"
"\t"STUB_ASM_CODE("2956")"\n"

STUB_ASM_ENTRY("glVertexArrayBindingDivisor")"\n"
"\t"STUB_ASM_CODE("2957")"\n"

STUB_ASM_ENTRY("glVertexArrayColorOffsetEXT")"\n"
"\t"STUB_ASM_CODE("2958")"\n"

STUB_ASM_ENTRY("glVertexArrayEdgeFlagOffsetEXT")"\n"
"\t"STUB_ASM_CODE("2959")"\n"

STUB_ASM_ENTRY("glVertexArrayElementBuffer")"\n"
"\t"STUB_ASM_CODE("2960")"\n"

STUB_ASM_ENTRY("glVertexArrayFogCoordOffsetEXT")"\n"
"\t"STUB_ASM_CODE("2961")"\n"

STUB_ASM_ENTRY("glVertexArrayIndexOffsetEXT")"\n"
"\t"STUB_ASM_CODE("2962")"\n"

STUB_ASM_ENTRY("glVertexArrayMultiTexCoordOffsetEXT")"\n"
"\t"STUB_ASM_CODE("2963")"\n"

STUB_ASM_ENTRY("glVertexArrayNormalOffsetEXT")"\n"
"\t"STUB_ASM_CODE("2964")"\n"

STUB_ASM_ENTRY("glVertexArrayParameteriAPPLE")"\n"
"\t"STUB_ASM_CODE("2965")"\n"

STUB_ASM_ENTRY("glVertexArrayRangeAPPLE")"\n"
"\t"STUB_ASM_CODE("2966")"\n"

STUB_ASM_ENTRY("glVertexArrayRangeNV")"\n"
"\t"STUB_ASM_CODE("2967")"\n"

STUB_ASM_ENTRY("glVertexArraySecondaryColorOffsetEXT")"\n"
"\t"STUB_ASM_CODE("2968")"\n"

STUB_ASM_ENTRY("glVertexArrayTexCoordOffsetEXT")"\n"
"\t"STUB_ASM_CODE("2969")"\n"

STUB_ASM_ENTRY("glVertexArrayVertexAttribBindingEXT")"\n"
"\t"STUB_ASM_CODE("2970")"\n"

STUB_ASM_ENTRY("glVertexArrayVertexAttribDivisorEXT")"\n"
"\t"STUB_ASM_CODE("2971")"\n"

STUB_ASM_ENTRY("glVertexArrayVertexAttribFormatEXT")"\n"
"\t"STUB_ASM_CODE("2972")"\n"

STUB_ASM_ENTRY("glVertexArrayVertexAttribIFormatEXT")"\n"
"\t"STUB_ASM_CODE("2973")"\n"

STUB_ASM_ENTRY("glVertexArrayVertexAttribIOffsetEXT")"\n"
"\t"STUB_ASM_CODE("2974")"\n"

STUB_ASM_ENTRY("glVertexArrayVertexAttribLFormatEXT")"\n"
"\t"STUB_ASM_CODE("2975")"\n"

STUB_ASM_ENTRY("glVertexArrayVertexAttribLOffsetEXT")"\n"
"\t"STUB_ASM_CODE("2976")"\n"

STUB_ASM_ENTRY("glVertexArrayVertexAttribOffsetEXT")"\n"
"\t"STUB_ASM_CODE("2977")"\n"

STUB_ASM_ENTRY("glVertexArrayVertexBindingDivisorEXT")"\n"
"\t"STUB_ASM_CODE("2978")"\n"

STUB_ASM_ENTRY("glVertexArrayVertexBuffer")"\n"
"\t"STUB_ASM_CODE("2979")"\n"

STUB_ASM_ENTRY("glVertexArrayVertexBuffers")"\n"
"\t"STUB_ASM_CODE("2980")"\n"

STUB_ASM_ENTRY("glVertexArrayVertexOffsetEXT")"\n"
"\t"STUB_ASM_CODE("2981")"\n"

STUB_ASM_ENTRY("glVertexAttrib1d")"\n"
"\t"STUB_ASM_CODE("2982")"\n"

STUB_ASM_ENTRY("glVertexAttrib1dARB")"\n"
"\t"STUB_ASM_CODE("2983")"\n"

STUB_ASM_ENTRY("glVertexAttrib1dNV")"\n"
"\t"STUB_ASM_CODE("2984")"\n"

STUB_ASM_ENTRY("glVertexAttrib1dv")"\n"
"\t"STUB_ASM_CODE("2985")"\n"

STUB_ASM_ENTRY("glVertexAttrib1dvARB")"\n"
"\t"STUB_ASM_CODE("2986")"\n"

STUB_ASM_ENTRY("glVertexAttrib1dvNV")"\n"
"\t"STUB_ASM_CODE("2987")"\n"

STUB_ASM_ENTRY("glVertexAttrib1f")"\n"
"\t"STUB_ASM_CODE("2988")"\n"

STUB_ASM_ENTRY("glVertexAttrib1fARB")"\n"
"\t"STUB_ASM_CODE("2989")"\n"

STUB_ASM_ENTRY("glVertexAttrib1fNV")"\n"
"\t"STUB_ASM_CODE("2990")"\n"

STUB_ASM_ENTRY("glVertexAttrib1fv")"\n"
"\t"STUB_ASM_CODE("2991")"\n"

STUB_ASM_ENTRY("glVertexAttrib1fvARB")"\n"
"\t"STUB_ASM_CODE("2992")"\n"

STUB_ASM_ENTRY("glVertexAttrib1fvNV")"\n"
"\t"STUB_ASM_CODE("2993")"\n"

STUB_ASM_ENTRY("glVertexAttrib1hNV")"\n"
"\t"STUB_ASM_CODE("2994")"\n"

STUB_ASM_ENTRY("glVertexAttrib1hvNV")"\n"
"\t"STUB_ASM_CODE("2995")"\n"

STUB_ASM_ENTRY("glVertexAttrib1s")"\n"
"\t"STUB_ASM_CODE("2996")"\n"

STUB_ASM_ENTRY("glVertexAttrib1sARB")"\n"
"\t"STUB_ASM_CODE("2997")"\n"

STUB_ASM_ENTRY("glVertexAttrib1sNV")"\n"
"\t"STUB_ASM_CODE("2998")"\n"

STUB_ASM_ENTRY("glVertexAttrib1sv")"\n"
"\t"STUB_ASM_CODE("2999")"\n"

STUB_ASM_ENTRY("glVertexAttrib1svARB")"\n"
"\t"STUB_ASM_CODE("3000")"\n"

STUB_ASM_ENTRY("glVertexAttrib1svNV")"\n"
"\t"STUB_ASM_CODE("3001")"\n"

STUB_ASM_ENTRY("glVertexAttrib2d")"\n"
"\t"STUB_ASM_CODE("3002")"\n"

STUB_ASM_ENTRY("glVertexAttrib2dARB")"\n"
"\t"STUB_ASM_CODE("3003")"\n"

STUB_ASM_ENTRY("glVertexAttrib2dNV")"\n"
"\t"STUB_ASM_CODE("3004")"\n"

STUB_ASM_ENTRY("glVertexAttrib2dv")"\n"
"\t"STUB_ASM_CODE("3005")"\n"

STUB_ASM_ENTRY("glVertexAttrib2dvARB")"\n"
"\t"STUB_ASM_CODE("3006")"\n"

STUB_ASM_ENTRY("glVertexAttrib2dvNV")"\n"
"\t"STUB_ASM_CODE("3007")"\n"

STUB_ASM_ENTRY("glVertexAttrib2f")"\n"
"\t"STUB_ASM_CODE("3008")"\n"

STUB_ASM_ENTRY("glVertexAttrib2fARB")"\n"
"\t"STUB_ASM_CODE("3009")"\n"

STUB_ASM_ENTRY("glVertexAttrib2fNV")"\n"
"\t"STUB_ASM_CODE("3010")"\n"

STUB_ASM_ENTRY("glVertexAttrib2fv")"\n"
"\t"STUB_ASM_CODE("3011")"\n"

STUB_ASM_ENTRY("glVertexAttrib2fvARB")"\n"
"\t"STUB_ASM_CODE("3012")"\n"

STUB_ASM_ENTRY("glVertexAttrib2fvNV")"\n"
"\t"STUB_ASM_CODE("3013")"\n"

STUB_ASM_ENTRY("glVertexAttrib2hNV")"\n"
"\t"STUB_ASM_CODE("3014")"\n"

STUB_ASM_ENTRY("glVertexAttrib2hvNV")"\n"
"\t"STUB_ASM_CODE("3015")"\n"

STUB_ASM_ENTRY("glVertexAttrib2s")"\n"
"\t"STUB_ASM_CODE("3016")"\n"

STUB_ASM_ENTRY("glVertexAttrib2sARB")"\n"
"\t"STUB_ASM_CODE("3017")"\n"

STUB_ASM_ENTRY("glVertexAttrib2sNV")"\n"
"\t"STUB_ASM_CODE("3018")"\n"

STUB_ASM_ENTRY("glVertexAttrib2sv")"\n"
"\t"STUB_ASM_CODE("3019")"\n"

STUB_ASM_ENTRY("glVertexAttrib2svARB")"\n"
"\t"STUB_ASM_CODE("3020")"\n"

STUB_ASM_ENTRY("glVertexAttrib2svNV")"\n"
"\t"STUB_ASM_CODE("3021")"\n"

STUB_ASM_ENTRY("glVertexAttrib3d")"\n"
"\t"STUB_ASM_CODE("3022")"\n"

STUB_ASM_ENTRY("glVertexAttrib3dARB")"\n"
"\t"STUB_ASM_CODE("3023")"\n"

STUB_ASM_ENTRY("glVertexAttrib3dNV")"\n"
"\t"STUB_ASM_CODE("3024")"\n"

STUB_ASM_ENTRY("glVertexAttrib3dv")"\n"
"\t"STUB_ASM_CODE("3025")"\n"

STUB_ASM_ENTRY("glVertexAttrib3dvARB")"\n"
"\t"STUB_ASM_CODE("3026")"\n"

STUB_ASM_ENTRY("glVertexAttrib3dvNV")"\n"
"\t"STUB_ASM_CODE("3027")"\n"

STUB_ASM_ENTRY("glVertexAttrib3f")"\n"
"\t"STUB_ASM_CODE("3028")"\n"

STUB_ASM_ENTRY("glVertexAttrib3fARB")"\n"
"\t"STUB_ASM_CODE("3029")"\n"

STUB_ASM_ENTRY("glVertexAttrib3fNV")"\n"
"\t"STUB_ASM_CODE("3030")"\n"

STUB_ASM_ENTRY("glVertexAttrib3fv")"\n"
"\t"STUB_ASM_CODE("3031")"\n"

STUB_ASM_ENTRY("glVertexAttrib3fvARB")"\n"
"\t"STUB_ASM_CODE("3032")"\n"

STUB_ASM_ENTRY("glVertexAttrib3fvNV")"\n"
"\t"STUB_ASM_CODE("3033")"\n"

STUB_ASM_ENTRY("glVertexAttrib3hNV")"\n"
"\t"STUB_ASM_CODE("3034")"\n"

STUB_ASM_ENTRY("glVertexAttrib3hvNV")"\n"
"\t"STUB_ASM_CODE("3035")"\n"

STUB_ASM_ENTRY("glVertexAttrib3s")"\n"
"\t"STUB_ASM_CODE("3036")"\n"

STUB_ASM_ENTRY("glVertexAttrib3sARB")"\n"
"\t"STUB_ASM_CODE("3037")"\n"

STUB_ASM_ENTRY("glVertexAttrib3sNV")"\n"
"\t"STUB_ASM_CODE("3038")"\n"

STUB_ASM_ENTRY("glVertexAttrib3sv")"\n"
"\t"STUB_ASM_CODE("3039")"\n"

STUB_ASM_ENTRY("glVertexAttrib3svARB")"\n"
"\t"STUB_ASM_CODE("3040")"\n"

STUB_ASM_ENTRY("glVertexAttrib3svNV")"\n"
"\t"STUB_ASM_CODE("3041")"\n"

STUB_ASM_ENTRY("glVertexAttrib4Nbv")"\n"
"\t"STUB_ASM_CODE("3042")"\n"

STUB_ASM_ENTRY("glVertexAttrib4NbvARB")"\n"
"\t"STUB_ASM_CODE("3043")"\n"

STUB_ASM_ENTRY("glVertexAttrib4Niv")"\n"
"\t"STUB_ASM_CODE("3044")"\n"

STUB_ASM_ENTRY("glVertexAttrib4NivARB")"\n"
"\t"STUB_ASM_CODE("3045")"\n"

STUB_ASM_ENTRY("glVertexAttrib4Nsv")"\n"
"\t"STUB_ASM_CODE("3046")"\n"

STUB_ASM_ENTRY("glVertexAttrib4NsvARB")"\n"
"\t"STUB_ASM_CODE("3047")"\n"

STUB_ASM_ENTRY("glVertexAttrib4Nub")"\n"
"\t"STUB_ASM_CODE("3048")"\n"

STUB_ASM_ENTRY("glVertexAttrib4NubARB")"\n"
"\t"STUB_ASM_CODE("3049")"\n"

STUB_ASM_ENTRY("glVertexAttrib4Nubv")"\n"
"\t"STUB_ASM_CODE("3050")"\n"

STUB_ASM_ENTRY("glVertexAttrib4NubvARB")"\n"
"\t"STUB_ASM_CODE("3051")"\n"

STUB_ASM_ENTRY("glVertexAttrib4Nuiv")"\n"
"\t"STUB_ASM_CODE("3052")"\n"

STUB_ASM_ENTRY("glVertexAttrib4NuivARB")"\n"
"\t"STUB_ASM_CODE("3053")"\n"

STUB_ASM_ENTRY("glVertexAttrib4Nusv")"\n"
"\t"STUB_ASM_CODE("3054")"\n"

STUB_ASM_ENTRY("glVertexAttrib4NusvARB")"\n"
"\t"STUB_ASM_CODE("3055")"\n"

STUB_ASM_ENTRY("glVertexAttrib4bv")"\n"
"\t"STUB_ASM_CODE("3056")"\n"

STUB_ASM_ENTRY("glVertexAttrib4bvARB")"\n"
"\t"STUB_ASM_CODE("3057")"\n"

STUB_ASM_ENTRY("glVertexAttrib4d")"\n"
"\t"STUB_ASM_CODE("3058")"\n"

STUB_ASM_ENTRY("glVertexAttrib4dARB")"\n"
"\t"STUB_ASM_CODE("3059")"\n"

STUB_ASM_ENTRY("glVertexAttrib4dNV")"\n"
"\t"STUB_ASM_CODE("3060")"\n"

STUB_ASM_ENTRY("glVertexAttrib4dv")"\n"
"\t"STUB_ASM_CODE("3061")"\n"

STUB_ASM_ENTRY("glVertexAttrib4dvARB")"\n"
"\t"STUB_ASM_CODE("3062")"\n"

STUB_ASM_ENTRY("glVertexAttrib4dvNV")"\n"
"\t"STUB_ASM_CODE("3063")"\n"

STUB_ASM_ENTRY("glVertexAttrib4f")"\n"
"\t"STUB_ASM_CODE("3064")"\n"

STUB_ASM_ENTRY("glVertexAttrib4fARB")"\n"
"\t"STUB_ASM_CODE("3065")"\n"

STUB_ASM_ENTRY("glVertexAttrib4fNV")"\n"
"\t"STUB_ASM_CODE("3066")"\n"

STUB_ASM_ENTRY("glVertexAttrib4fv")"\n"
"\t"STUB_ASM_CODE("3067")"\n"

STUB_ASM_ENTRY("glVertexAttrib4fvARB")"\n"
"\t"STUB_ASM_CODE("3068")"\n"

STUB_ASM_ENTRY("glVertexAttrib4fvNV")"\n"
"\t"STUB_ASM_CODE("3069")"\n"

STUB_ASM_ENTRY("glVertexAttrib4hNV")"\n"
"\t"STUB_ASM_CODE("3070")"\n"

STUB_ASM_ENTRY("glVertexAttrib4hvNV")"\n"
"\t"STUB_ASM_CODE("3071")"\n"

STUB_ASM_ENTRY("glVertexAttrib4iv")"\n"
"\t"STUB_ASM_CODE("3072")"\n"

STUB_ASM_ENTRY("glVertexAttrib4ivARB")"\n"
"\t"STUB_ASM_CODE("3073")"\n"

STUB_ASM_ENTRY("glVertexAttrib4s")"\n"
"\t"STUB_ASM_CODE("3074")"\n"

STUB_ASM_ENTRY("glVertexAttrib4sARB")"\n"
"\t"STUB_ASM_CODE("3075")"\n"

STUB_ASM_ENTRY("glVertexAttrib4sNV")"\n"
"\t"STUB_ASM_CODE("3076")"\n"

STUB_ASM_ENTRY("glVertexAttrib4sv")"\n"
"\t"STUB_ASM_CODE("3077")"\n"

STUB_ASM_ENTRY("glVertexAttrib4svARB")"\n"
"\t"STUB_ASM_CODE("3078")"\n"

STUB_ASM_ENTRY("glVertexAttrib4svNV")"\n"
"\t"STUB_ASM_CODE("3079")"\n"

STUB_ASM_ENTRY("glVertexAttrib4ubNV")"\n"
"\t"STUB_ASM_CODE("3080")"\n"

STUB_ASM_ENTRY("glVertexAttrib4ubv")"\n"
"\t"STUB_ASM_CODE("3081")"\n"

STUB_ASM_ENTRY("glVertexAttrib4ubvARB")"\n"
"\t"STUB_ASM_CODE("3082")"\n"

STUB_ASM_ENTRY("glVertexAttrib4ubvNV")"\n"
"\t"STUB_ASM_CODE("3083")"\n"

STUB_ASM_ENTRY("glVertexAttrib4uiv")"\n"
"\t"STUB_ASM_CODE("3084")"\n"

STUB_ASM_ENTRY("glVertexAttrib4uivARB")"\n"
"\t"STUB_ASM_CODE("3085")"\n"

STUB_ASM_ENTRY("glVertexAttrib4usv")"\n"
"\t"STUB_ASM_CODE("3086")"\n"

STUB_ASM_ENTRY("glVertexAttrib4usvARB")"\n"
"\t"STUB_ASM_CODE("3087")"\n"

STUB_ASM_ENTRY("glVertexAttribArrayObjectATI")"\n"
"\t"STUB_ASM_CODE("3088")"\n"

STUB_ASM_ENTRY("glVertexAttribBinding")"\n"
"\t"STUB_ASM_CODE("3089")"\n"

STUB_ASM_ENTRY("glVertexAttribDivisor")"\n"
"\t"STUB_ASM_CODE("3090")"\n"

STUB_ASM_ENTRY("glVertexAttribDivisorANGLE")"\n"
"\t"STUB_ASM_CODE("3091")"\n"

STUB_ASM_ENTRY("glVertexAttribDivisorARB")"\n"
"\t"STUB_ASM_CODE("3092")"\n"

STUB_ASM_ENTRY("glVertexAttribDivisorEXT")"\n"
"\t"STUB_ASM_CODE("3093")"\n"

STUB_ASM_ENTRY("glVertexAttribDivisorNV")"\n"
"\t"STUB_ASM_CODE("3094")"\n"

STUB_ASM_ENTRY("glVertexAttribFormat")"\n"
"\t"STUB_ASM_CODE("3095")"\n"

STUB_ASM_ENTRY("glVertexAttribFormatNV")"\n"
"\t"STUB_ASM_CODE("3096")"\n"

STUB_ASM_ENTRY("glVertexAttribI1i")"\n"
"\t"STUB_ASM_CODE("3097")"\n"

STUB_ASM_ENTRY("glVertexAttribI1iEXT")"\n"
"\t"STUB_ASM_CODE("3098")"\n"

STUB_ASM_ENTRY("glVertexAttribI1iv")"\n"
"\t"STUB_ASM_CODE("3099")"\n"

STUB_ASM_ENTRY("glVertexAttribI1ivEXT")"\n"
"\t"STUB_ASM_CODE("3100")"\n"

STUB_ASM_ENTRY("glVertexAttribI1ui")"\n"
"\t"STUB_ASM_CODE("3101")"\n"

STUB_ASM_ENTRY("glVertexAttribI1uiEXT")"\n"
"\t"STUB_ASM_CODE("3102")"\n"

STUB_ASM_ENTRY("glVertexAttribI1uiv")"\n"
"\t"STUB_ASM_CODE("3103")"\n"

STUB_ASM_ENTRY("glVertexAttribI1uivEXT")"\n"
"\t"STUB_ASM_CODE("3104")"\n"

STUB_ASM_ENTRY("glVertexAttribI2i")"\n"
"\t"STUB_ASM_CODE("3105")"\n"

STUB_ASM_ENTRY("glVertexAttribI2iEXT")"\n"
"\t"STUB_ASM_CODE("3106")"\n"

STUB_ASM_ENTRY("glVertexAttribI2iv")"\n"
"\t"STUB_ASM_CODE("3107")"\n"

STUB_ASM_ENTRY("glVertexAttribI2ivEXT")"\n"
"\t"STUB_ASM_CODE("3108")"\n"

STUB_ASM_ENTRY("glVertexAttribI2ui")"\n"
"\t"STUB_ASM_CODE("3109")"\n"

STUB_ASM_ENTRY("glVertexAttribI2uiEXT")"\n"
"\t"STUB_ASM_CODE("3110")"\n"

STUB_ASM_ENTRY("glVertexAttribI2uiv")"\n"
"\t"STUB_ASM_CODE("3111")"\n"

STUB_ASM_ENTRY("glVertexAttribI2uivEXT")"\n"
"\t"STUB_ASM_CODE("3112")"\n"

STUB_ASM_ENTRY("glVertexAttribI3i")"\n"
"\t"STUB_ASM_CODE("3113")"\n"

STUB_ASM_ENTRY("glVertexAttribI3iEXT")"\n"
"\t"STUB_ASM_CODE("3114")"\n"

STUB_ASM_ENTRY("glVertexAttribI3iv")"\n"
"\t"STUB_ASM_CODE("3115")"\n"

STUB_ASM_ENTRY("glVertexAttribI3ivEXT")"\n"
"\t"STUB_ASM_CODE("3116")"\n"

STUB_ASM_ENTRY("glVertexAttribI3ui")"\n"
"\t"STUB_ASM_CODE("3117")"\n"

STUB_ASM_ENTRY("glVertexAttribI3uiEXT")"\n"
"\t"STUB_ASM_CODE("3118")"\n"

STUB_ASM_ENTRY("glVertexAttribI3uiv")"\n"
"\t"STUB_ASM_CODE("3119")"\n"

STUB_ASM_ENTRY("glVertexAttribI3uivEXT")"\n"
"\t"STUB_ASM_CODE("3120")"\n"

STUB_ASM_ENTRY("glVertexAttribI4bv")"\n"
"\t"STUB_ASM_CODE("3121")"\n"

STUB_ASM_ENTRY("glVertexAttribI4bvEXT")"\n"
"\t"STUB_ASM_CODE("3122")"\n"

STUB_ASM_ENTRY("glVertexAttribI4i")"\n"
"\t"STUB_ASM_CODE("3123")"\n"

STUB_ASM_ENTRY("glVertexAttribI4iEXT")"\n"
"\t"STUB_ASM_CODE("3124")"\n"

STUB_ASM_ENTRY("glVertexAttribI4iv")"\n"
"\t"STUB_ASM_CODE("3125")"\n"

STUB_ASM_ENTRY("glVertexAttribI4ivEXT")"\n"
"\t"STUB_ASM_CODE("3126")"\n"

STUB_ASM_ENTRY("glVertexAttribI4sv")"\n"
"\t"STUB_ASM_CODE("3127")"\n"

STUB_ASM_ENTRY("glVertexAttribI4svEXT")"\n"
"\t"STUB_ASM_CODE("3128")"\n"

STUB_ASM_ENTRY("glVertexAttribI4ubv")"\n"
"\t"STUB_ASM_CODE("3129")"\n"

STUB_ASM_ENTRY("glVertexAttribI4ubvEXT")"\n"
"\t"STUB_ASM_CODE("3130")"\n"

STUB_ASM_ENTRY("glVertexAttribI4ui")"\n"
"\t"STUB_ASM_CODE("3131")"\n"

STUB_ASM_ENTRY("glVertexAttribI4uiEXT")"\n"
"\t"STUB_ASM_CODE("3132")"\n"

STUB_ASM_ENTRY("glVertexAttribI4uiv")"\n"
"\t"STUB_ASM_CODE("3133")"\n"

STUB_ASM_ENTRY("glVertexAttribI4uivEXT")"\n"
"\t"STUB_ASM_CODE("3134")"\n"

STUB_ASM_ENTRY("glVertexAttribI4usv")"\n"
"\t"STUB_ASM_CODE("3135")"\n"

STUB_ASM_ENTRY("glVertexAttribI4usvEXT")"\n"
"\t"STUB_ASM_CODE("3136")"\n"

STUB_ASM_ENTRY("glVertexAttribIFormat")"\n"
"\t"STUB_ASM_CODE("3137")"\n"

STUB_ASM_ENTRY("glVertexAttribIFormatNV")"\n"
"\t"STUB_ASM_CODE("3138")"\n"

STUB_ASM_ENTRY("glVertexAttribIPointer")"\n"
"\t"STUB_ASM_CODE("3139")"\n"

STUB_ASM_ENTRY("glVertexAttribIPointerEXT")"\n"
"\t"STUB_ASM_CODE("3140")"\n"

STUB_ASM_ENTRY("glVertexAttribL1d")"\n"
"\t"STUB_ASM_CODE("3141")"\n"

STUB_ASM_ENTRY("glVertexAttribL1dEXT")"\n"
"\t"STUB_ASM_CODE("3142")"\n"

STUB_ASM_ENTRY("glVertexAttribL1dv")"\n"
"\t"STUB_ASM_CODE("3143")"\n"

STUB_ASM_ENTRY("glVertexAttribL1dvEXT")"\n"
"\t"STUB_ASM_CODE("3144")"\n"

STUB_ASM_ENTRY("glVertexAttribL1i64NV")"\n"
"\t"STUB_ASM_CODE("3145")"\n"

STUB_ASM_ENTRY("glVertexAttribL1i64vNV")"\n"
"\t"STUB_ASM_CODE("3146")"\n"

STUB_ASM_ENTRY("glVertexAttribL1ui64ARB")"\n"
"\t"STUB_ASM_CODE("3147")"\n"

STUB_ASM_ENTRY("glVertexAttribL1ui64NV")"\n"
"\t"STUB_ASM_CODE("3148")"\n"

STUB_ASM_ENTRY("glVertexAttribL1ui64vARB")"\n"
"\t"STUB_ASM_CODE("3149")"\n"

STUB_ASM_ENTRY("glVertexAttribL1ui64vNV")"\n"
"\t"STUB_ASM_CODE("3150")"\n"

STUB_ASM_ENTRY("glVertexAttribL2d")"\n"
"\t"STUB_ASM_CODE("3151")"\n"

STUB_ASM_ENTRY("glVertexAttribL2dEXT")"\n"
"\t"STUB_ASM_CODE("3152")"\n"

STUB_ASM_ENTRY("glVertexAttribL2dv")"\n"
"\t"STUB_ASM_CODE("3153")"\n"

STUB_ASM_ENTRY("glVertexAttribL2dvEXT")"\n"
"\t"STUB_ASM_CODE("3154")"\n"

STUB_ASM_ENTRY("glVertexAttribL2i64NV")"\n"
"\t"STUB_ASM_CODE("3155")"\n"

STUB_ASM_ENTRY("glVertexAttribL2i64vNV")"\n"
"\t"STUB_ASM_CODE("3156")"\n"

STUB_ASM_ENTRY("glVertexAttribL2ui64NV")"\n"
"\t"STUB_ASM_CODE("3157")"\n"

STUB_ASM_ENTRY("glVertexAttribL2ui64vNV")"\n"
"\t"STUB_ASM_CODE("3158")"\n"

STUB_ASM_ENTRY("glVertexAttribL3d")"\n"
"\t"STUB_ASM_CODE("3159")"\n"

STUB_ASM_ENTRY("glVertexAttribL3dEXT")"\n"
"\t"STUB_ASM_CODE("3160")"\n"

STUB_ASM_ENTRY("glVertexAttribL3dv")"\n"
"\t"STUB_ASM_CODE("3161")"\n"

STUB_ASM_ENTRY("glVertexAttribL3dvEXT")"\n"
"\t"STUB_ASM_CODE("3162")"\n"

STUB_ASM_ENTRY("glVertexAttribL3i64NV")"\n"
"\t"STUB_ASM_CODE("3163")"\n"

STUB_ASM_ENTRY("glVertexAttribL3i64vNV")"\n"
"\t"STUB_ASM_CODE("3164")"\n"

STUB_ASM_ENTRY("glVertexAttribL3ui64NV")"\n"
"\t"STUB_ASM_CODE("3165")"\n"

STUB_ASM_ENTRY("glVertexAttribL3ui64vNV")"\n"
"\t"STUB_ASM_CODE("3166")"\n"

STUB_ASM_ENTRY("glVertexAttribL4d")"\n"
"\t"STUB_ASM_CODE("3167")"\n"

STUB_ASM_ENTRY("glVertexAttribL4dEXT")"\n"
"\t"STUB_ASM_CODE("3168")"\n"

STUB_ASM_ENTRY("glVertexAttribL4dv")"\n"
"\t"STUB_ASM_CODE("3169")"\n"

STUB_ASM_ENTRY("glVertexAttribL4dvEXT")"\n"
"\t"STUB_ASM_CODE("3170")"\n"

STUB_ASM_ENTRY("glVertexAttribL4i64NV")"\n"
"\t"STUB_ASM_CODE("3171")"\n"

STUB_ASM_ENTRY("glVertexAttribL4i64vNV")"\n"
"\t"STUB_ASM_CODE("3172")"\n"

STUB_ASM_ENTRY("glVertexAttribL4ui64NV")"\n"
"\t"STUB_ASM_CODE("3173")"\n"

STUB_ASM_ENTRY("glVertexAttribL4ui64vNV")"\n"
"\t"STUB_ASM_CODE("3174")"\n"

STUB_ASM_ENTRY("glVertexAttribLFormat")"\n"
"\t"STUB_ASM_CODE("3175")"\n"

STUB_ASM_ENTRY("glVertexAttribLFormatNV")"\n"
"\t"STUB_ASM_CODE("3176")"\n"

STUB_ASM_ENTRY("glVertexAttribLPointer")"\n"
"\t"STUB_ASM_CODE("3177")"\n"

STUB_ASM_ENTRY("glVertexAttribLPointerEXT")"\n"
"\t"STUB_ASM_CODE("3178")"\n"

STUB_ASM_ENTRY("glVertexAttribP1ui")"\n"
"\t"STUB_ASM_CODE("3179")"\n"

STUB_ASM_ENTRY("glVertexAttribP1uiv")"\n"
"\t"STUB_ASM_CODE("3180")"\n"

STUB_ASM_ENTRY("glVertexAttribP2ui")"\n"
"\t"STUB_ASM_CODE("3181")"\n"

STUB_ASM_ENTRY("glVertexAttribP2uiv")"\n"
"\t"STUB_ASM_CODE("3182")"\n"

STUB_ASM_ENTRY("glVertexAttribP3ui")"\n"
"\t"STUB_ASM_CODE("3183")"\n"

STUB_ASM_ENTRY("glVertexAttribP3uiv")"\n"
"\t"STUB_ASM_CODE("3184")"\n"

STUB_ASM_ENTRY("glVertexAttribP4ui")"\n"
"\t"STUB_ASM_CODE("3185")"\n"

STUB_ASM_ENTRY("glVertexAttribP4uiv")"\n"
"\t"STUB_ASM_CODE("3186")"\n"

STUB_ASM_ENTRY("glVertexAttribParameteriAMD")"\n"
"\t"STUB_ASM_CODE("3187")"\n"

STUB_ASM_ENTRY("glVertexAttribPointer")"\n"
"\t"STUB_ASM_CODE("3188")"\n"

STUB_ASM_ENTRY("glVertexAttribPointerARB")"\n"
"\t"STUB_ASM_CODE("3189")"\n"

STUB_ASM_ENTRY("glVertexAttribPointerNV")"\n"
"\t"STUB_ASM_CODE("3190")"\n"

STUB_ASM_ENTRY("glVertexAttribs1dvNV")"\n"
"\t"STUB_ASM_CODE("3191")"\n"

STUB_ASM_ENTRY("glVertexAttribs1fvNV")"\n"
"\t"STUB_ASM_CODE("3192")"\n"

STUB_ASM_ENTRY("glVertexAttribs1hvNV")"\n"
"\t"STUB_ASM_CODE("3193")"\n"

STUB_ASM_ENTRY("glVertexAttribs1svNV")"\n"
"\t"STUB_ASM_CODE("3194")"\n"

STUB_ASM_ENTRY("glVertexAttribs2dvNV")"\n"
"\t"STUB_ASM_CODE("3195")"\n"

STUB_ASM_ENTRY("glVertexAttribs2fvNV")"\n"
"\t"STUB_ASM_CODE("3196")"\n"

STUB_ASM_ENTRY("glVertexAttribs2hvNV")"\n"
"\t"STUB_ASM_CODE("3197")"\n"

STUB_ASM_ENTRY("glVertexAttribs2svNV")"\n"
"\t"STUB_ASM_CODE("3198")"\n"

STUB_ASM_ENTRY("glVertexAttribs3dvNV")"\n"
"\t"STUB_ASM_CODE("3199")"\n"

STUB_ASM_ENTRY("glVertexAttribs3fvNV")"\n"
"\t"STUB_ASM_CODE("3200")"\n"

STUB_ASM_ENTRY("glVertexAttribs3hvNV")"\n"
"\t"STUB_ASM_CODE("3201")"\n"

STUB_ASM_ENTRY("glVertexAttribs3svNV")"\n"
"\t"STUB_ASM_CODE("3202")"\n"

STUB_ASM_ENTRY("glVertexAttribs4dvNV")"\n"
"\t"STUB_ASM_CODE("3203")"\n"

STUB_ASM_ENTRY("glVertexAttribs4fvNV")"\n"
"\t"STUB_ASM_CODE("3204")"\n"

STUB_ASM_ENTRY("glVertexAttribs4hvNV")"\n"
"\t"STUB_ASM_CODE("3205")"\n"

STUB_ASM_ENTRY("glVertexAttribs4svNV")"\n"
"\t"STUB_ASM_CODE("3206")"\n"

STUB_ASM_ENTRY("glVertexAttribs4ubvNV")"\n"
"\t"STUB_ASM_CODE("3207")"\n"

STUB_ASM_ENTRY("glVertexBindingDivisor")"\n"
"\t"STUB_ASM_CODE("3208")"\n"

STUB_ASM_ENTRY("glVertexBlendARB")"\n"
"\t"STUB_ASM_CODE("3209")"\n"

STUB_ASM_ENTRY("glVertexBlendEnvfATI")"\n"
"\t"STUB_ASM_CODE("3210")"\n"

STUB_ASM_ENTRY("glVertexBlendEnviATI")"\n"
"\t"STUB_ASM_CODE("3211")"\n"

STUB_ASM_ENTRY("glVertexFormatNV")"\n"
"\t"STUB_ASM_CODE("3212")"\n"

STUB_ASM_ENTRY("glVertexP2ui")"\n"
"\t"STUB_ASM_CODE("3213")"\n"

STUB_ASM_ENTRY("glVertexP2uiv")"\n"
"\t"STUB_ASM_CODE("3214")"\n"

STUB_ASM_ENTRY("glVertexP3ui")"\n"
"\t"STUB_ASM_CODE("3215")"\n"

STUB_ASM_ENTRY("glVertexP3uiv")"\n"
"\t"STUB_ASM_CODE("3216")"\n"

STUB_ASM_ENTRY("glVertexP4ui")"\n"
"\t"STUB_ASM_CODE("3217")"\n"

STUB_ASM_ENTRY("glVertexP4uiv")"\n"
"\t"STUB_ASM_CODE("3218")"\n"

STUB_ASM_ENTRY("glVertexPointer")"\n"
"\t"STUB_ASM_CODE("3219")"\n"

STUB_ASM_ENTRY("glVertexPointerEXT")"\n"
"\t"STUB_ASM_CODE("3220")"\n"

STUB_ASM_ENTRY("glVertexPointerListIBM")"\n"
"\t"STUB_ASM_CODE("3221")"\n"

STUB_ASM_ENTRY("glVertexPointervINTEL")"\n"
"\t"STUB_ASM_CODE("3222")"\n"

STUB_ASM_ENTRY("glVertexStream1dATI")"\n"
"\t"STUB_ASM_CODE("3223")"\n"

STUB_ASM_ENTRY("glVertexStream1dvATI")"\n"
"\t"STUB_ASM_CODE("3224")"\n"

STUB_ASM_ENTRY("glVertexStream1fATI")"\n"
"\t"STUB_ASM_CODE("3225")"\n"

STUB_ASM_ENTRY("glVertexStream1fvATI")"\n"
"\t"STUB_ASM_CODE("3226")"\n"

STUB_ASM_ENTRY("glVertexStream1iATI")"\n"
"\t"STUB_ASM_CODE("3227")"\n"

STUB_ASM_ENTRY("glVertexStream1ivATI")"\n"
"\t"STUB_ASM_CODE("3228")"\n"

STUB_ASM_ENTRY("glVertexStream1sATI")"\n"
"\t"STUB_ASM_CODE("3229")"\n"

STUB_ASM_ENTRY("glVertexStream1svATI")"\n"
"\t"STUB_ASM_CODE("3230")"\n"

STUB_ASM_ENTRY("glVertexStream2dATI")"\n"
"\t"STUB_ASM_CODE("3231")"\n"

STUB_ASM_ENTRY("glVertexStream2dvATI")"\n"
"\t"STUB_ASM_CODE("3232")"\n"

STUB_ASM_ENTRY("glVertexStream2fATI")"\n"
"\t"STUB_ASM_CODE("3233")"\n"

STUB_ASM_ENTRY("glVertexStream2fvATI")"\n"
"\t"STUB_ASM_CODE("3234")"\n"

STUB_ASM_ENTRY("glVertexStream2iATI")"\n"
"\t"STUB_ASM_CODE("3235")"\n"

STUB_ASM_ENTRY("glVertexStream2ivATI")"\n"
"\t"STUB_ASM_CODE("3236")"\n"

STUB_ASM_ENTRY("glVertexStream2sATI")"\n"
"\t"STUB_ASM_CODE("3237")"\n"

STUB_ASM_ENTRY("glVertexStream2svATI")"\n"
"\t"STUB_ASM_CODE("3238")"\n"

STUB_ASM_ENTRY("glVertexStream3dATI")"\n"
"\t"STUB_ASM_CODE("3239")"\n"

STUB_ASM_ENTRY("glVertexStream3dvATI")"\n"
"\t"STUB_ASM_CODE("3240")"\n"

STUB_ASM_ENTRY("glVertexStream3fATI")"\n"
"\t"STUB_ASM_CODE("3241")"\n"

STUB_ASM_ENTRY("glVertexStream3fvATI")"\n"
"\t"STUB_ASM_CODE("3242")"\n"

STUB_ASM_ENTRY("glVertexStream3iATI")"\n"
"\t"STUB_ASM_CODE("3243")"\n"

STUB_ASM_ENTRY("glVertexStream3ivATI")"\n"
"\t"STUB_ASM_CODE("3244")"\n"

STUB_ASM_ENTRY("glVertexStream3sATI")"\n"
"\t"STUB_ASM_CODE("3245")"\n"

STUB_ASM_ENTRY("glVertexStream3svATI")"\n"
"\t"STUB_ASM_CODE("3246")"\n"

STUB_ASM_ENTRY("glVertexStream4dATI")"\n"
"\t"STUB_ASM_CODE("3247")"\n"

STUB_ASM_ENTRY("glVertexStream4dvATI")"\n"
"\t"STUB_ASM_CODE("3248")"\n"

STUB_ASM_ENTRY("glVertexStream4fATI")"\n"
"\t"STUB_ASM_CODE("3249")"\n"

STUB_ASM_ENTRY("glVertexStream4fvATI")"\n"
"\t"STUB_ASM_CODE("3250")"\n"

STUB_ASM_ENTRY("glVertexStream4iATI")"\n"
"\t"STUB_ASM_CODE("3251")"\n"

STUB_ASM_ENTRY("glVertexStream4ivATI")"\n"
"\t"STUB_ASM_CODE("3252")"\n"

STUB_ASM_ENTRY("glVertexStream4sATI")"\n"
"\t"STUB_ASM_CODE("3253")"\n"

STUB_ASM_ENTRY("glVertexStream4svATI")"\n"
"\t"STUB_ASM_CODE("3254")"\n"

STUB_ASM_ENTRY("glVertexWeightPointerEXT")"\n"
"\t"STUB_ASM_CODE("3255")"\n"

STUB_ASM_ENTRY("glVertexWeightfEXT")"\n"
"\t"STUB_ASM_CODE("3256")"\n"

STUB_ASM_ENTRY("glVertexWeightfvEXT")"\n"
"\t"STUB_ASM_CODE("3257")"\n"

STUB_ASM_ENTRY("glVertexWeighthNV")"\n"
"\t"STUB_ASM_CODE("3258")"\n"

STUB_ASM_ENTRY("glVertexWeighthvNV")"\n"
"\t"STUB_ASM_CODE("3259")"\n"

STUB_ASM_ENTRY("glVideoCaptureNV")"\n"
"\t"STUB_ASM_CODE("3260")"\n"

STUB_ASM_ENTRY("glVideoCaptureStreamParameterdvNV")"\n"
"\t"STUB_ASM_CODE("3261")"\n"

STUB_ASM_ENTRY("glVideoCaptureStreamParameterfvNV")"\n"
"\t"STUB_ASM_CODE("3262")"\n"

STUB_ASM_ENTRY("glVideoCaptureStreamParameterivNV")"\n"
"\t"STUB_ASM_CODE("3263")"\n"

STUB_ASM_ENTRY("glViewport")"\n"
"\t"STUB_ASM_CODE("3264")"\n"

STUB_ASM_ENTRY("glViewportArrayv")"\n"
"\t"STUB_ASM_CODE("3265")"\n"

STUB_ASM_ENTRY("glViewportArrayvNV")"\n"
"\t"STUB_ASM_CODE("3266")"\n"

STUB_ASM_ENTRY("glViewportArrayvOES")"\n"
"\t"STUB_ASM_CODE("3267")"\n"

STUB_ASM_ENTRY("glViewportIndexedf")"\n"
"\t"STUB_ASM_CODE("3268")"\n"

STUB_ASM_ENTRY("glViewportIndexedfNV")"\n"
"\t"STUB_ASM_CODE("3269")"\n"

STUB_ASM_ENTRY("glViewportIndexedfOES")"\n"
"\t"STUB_ASM_CODE("3270")"\n"

STUB_ASM_ENTRY("glViewportIndexedfv")"\n"
"\t"STUB_ASM_CODE("3271")"\n"

STUB_ASM_ENTRY("glViewportIndexedfvNV")"\n"
"\t"STUB_ASM_CODE("3272")"\n"

STUB_ASM_ENTRY("glViewportIndexedfvOES")"\n"
"\t"STUB_ASM_CODE("3273")"\n"

STUB_ASM_ENTRY("glViewportPositionWScaleNV")"\n"
"\t"STUB_ASM_CODE("3274")"\n"

STUB_ASM_ENTRY("glViewportSwizzleNV")"\n"
"\t"STUB_ASM_CODE("3275")"\n"

STUB_ASM_ENTRY("glWaitSemaphoreEXT")"\n"
"\t"STUB_ASM_CODE("3276")"\n"

STUB_ASM_ENTRY("glWaitSemaphoreui64NVX")"\n"
"\t"STUB_ASM_CODE("3277")"\n"

STUB_ASM_ENTRY("glWaitSync")"\n"
"\t"STUB_ASM_CODE("3278")"\n"

STUB_ASM_ENTRY("glWaitSyncAPPLE")"\n"
"\t"STUB_ASM_CODE("3279")"\n"

STUB_ASM_ENTRY("glWaitSyncValueuiNVX")"\n"
"\t"STUB_ASM_CODE("3280")"\n"

STUB_ASM_ENTRY("glWaitVkSemaphoreNV")"\n"
"\t"STUB_ASM_CODE("3281")"\n"

STUB_ASM_ENTRY("glWeightPathsNV")"\n"
"\t"STUB_ASM_CODE("3282")"\n"

STUB_ASM_ENTRY("glWeightPointerARB")"\n"
"\t"STUB_ASM_CODE("3283")"\n"

STUB_ASM_ENTRY("glWeightPointerOES")"\n"
"\t"STUB_ASM_CODE("3284")"\n"

STUB_ASM_ENTRY("glWeightbvARB")"\n"
"\t"STUB_ASM_CODE("3285")"\n"

STUB_ASM_ENTRY("glWeightdvARB")"\n"
"\t"STUB_ASM_CODE("3286")"\n"

STUB_ASM_ENTRY("glWeightfvARB")"\n"
"\t"STUB_ASM_CODE("3287")"\n"

STUB_ASM_ENTRY("glWeightivARB")"\n"
"\t"STUB_ASM_CODE("3288")"\n"

STUB_ASM_ENTRY("glWeightsvARB")"\n"
"\t"STUB_ASM_CODE("3289")"\n"

STUB_ASM_ENTRY("glWeightubvARB")"\n"
"\t"STUB_ASM_CODE("3290")"\n"

STUB_ASM_ENTRY("glWeightuivARB")"\n"
"\t"STUB_ASM_CODE("3291")"\n"

STUB_ASM_ENTRY("glWeightusvARB")"\n"
"\t"STUB_ASM_CODE("3292")"\n"

STUB_ASM_ENTRY("glWindowBackBufferHintAutodesk")"\n"
"\t"STUB_ASM_CODE("3293")"\n"

STUB_ASM_ENTRY("glWindowPos2d")"\n"
"\t"STUB_ASM_CODE("3294")"\n"

STUB_ASM_ENTRY("glWindowPos2dARB")"\n"
"\t"STUB_ASM_CODE("3295")"\n"

STUB_ASM_ENTRY("glWindowPos2dMESA")"\n"
"\t"STUB_ASM_CODE("3296")"\n"

STUB_ASM_ENTRY("glWindowPos2dv")"\n"
"\t"STUB_ASM_CODE("3297")"\n"

STUB_ASM_ENTRY("glWindowPos2dvARB")"\n"
"\t"STUB_ASM_CODE("3298")"\n"

STUB_ASM_ENTRY("glWindowPos2dvMESA")"\n"
"\t"STUB_ASM_CODE("3299")"\n"

STUB_ASM_ENTRY("glWindowPos2f")"\n"
"\t"STUB_ASM_CODE("3300")"\n"

STUB_ASM_ENTRY("glWindowPos2fARB")"\n"
"\t"STUB_ASM_CODE("3301")"\n"

STUB_ASM_ENTRY("glWindowPos2fMESA")"\n"
"\t"STUB_ASM_CODE("3302")"\n"

STUB_ASM_ENTRY("glWindowPos2fv")"\n"
"\t"STUB_ASM_CODE("3303")"\n"

STUB_ASM_ENTRY("glWindowPos2fvARB")"\n"
"\t"STUB_ASM_CODE("3304")"\n"

STUB_ASM_ENTRY("glWindowPos2fvMESA")"\n"
"\t"STUB_ASM_CODE("3305")"\n"

STUB_ASM_ENTRY("glWindowPos2i")"\n"
"\t"STUB_ASM_CODE("3306")"\n"

STUB_ASM_ENTRY("glWindowPos2iARB")"\n"
"\t"STUB_ASM_CODE("3307")"\n"

STUB_ASM_ENTRY("glWindowPos2iMESA")"\n"
"\t"STUB_ASM_CODE("3308")"\n"

STUB_ASM_ENTRY("glWindowPos2iv")"\n"
"\t"STUB_ASM_CODE("3309")"\n"

STUB_ASM_ENTRY("glWindowPos2ivARB")"\n"
"\t"STUB_ASM_CODE("3310")"\n"

STUB_ASM_ENTRY("glWindowPos2ivMESA")"\n"
"\t"STUB_ASM_CODE("3311")"\n"

STUB_ASM_ENTRY("glWindowPos2s")"\n"
"\t"STUB_ASM_CODE("3312")"\n"

STUB_ASM_ENTRY("glWindowPos2sARB")"\n"
"\t"STUB_ASM_CODE("3313")"\n"

STUB_ASM_ENTRY("glWindowPos2sMESA")"\n"
"\t"STUB_ASM_CODE("3314")"\n"

STUB_ASM_ENTRY("glWindowPos2sv")"\n"
"\t"STUB_ASM_CODE("3315")"\n"

STUB_ASM_ENTRY("glWindowPos2svARB")"\n"
"\t"STUB_ASM_CODE("3316")"\n"

STUB_ASM_ENTRY("glWindowPos2svMESA")"\n"
"\t"STUB_ASM_CODE("3317")"\n"

STUB_ASM_ENTRY("glWindowPos3d")"\n"
"\t"STUB_ASM_CODE("3318")"\n"

STUB_ASM_ENTRY("glWindowPos3dARB")"\n"
"\t"STUB_ASM_CODE("3319")"\n"

STUB_ASM_ENTRY("glWindowPos3dMESA")"\n"
"\t"STUB_ASM_CODE("3320")"\n"

STUB_ASM_ENTRY("glWindowPos3dv")"\n"
"\t"STUB_ASM_CODE("3321")"\n"

STUB_ASM_ENTRY("glWindowPos3dvARB")"\n"
"\t"STUB_ASM_CODE("3322")"\n"

STUB_ASM_ENTRY("glWindowPos3dvMESA")"\n"
"\t"STUB_ASM_CODE("3323")"\n"

STUB_ASM_ENTRY("glWindowPos3f")"\n"
"\t"STUB_ASM_CODE("3324")"\n"

STUB_ASM_ENTRY("glWindowPos3fARB")"\n"
"\t"STUB_ASM_CODE("3325")"\n"

STUB_ASM_ENTRY("glWindowPos3fMESA")"\n"
"\t"STUB_ASM_CODE("3326")"\n"

STUB_ASM_ENTRY("glWindowPos3fv")"\n"
"\t"STUB_ASM_CODE("3327")"\n"

STUB_ASM_ENTRY("glWindowPos3fvARB")"\n"
"\t"STUB_ASM_CODE("3328")"\n"

STUB_ASM_ENTRY("glWindowPos3fvMESA")"\n"
"\t"STUB_ASM_CODE("3329")"\n"

STUB_ASM_ENTRY("glWindowPos3i")"\n"
"\t"STUB_ASM_CODE("3330")"\n"

STUB_ASM_ENTRY("glWindowPos3iARB")"\n"
"\t"STUB_ASM_CODE("3331")"\n"

STUB_ASM_ENTRY("glWindowPos3iMESA")"\n"
"\t"STUB_ASM_CODE("3332")"\n"

STUB_ASM_ENTRY("glWindowPos3iv")"\n"
"\t"STUB_ASM_CODE("3333")"\n"

STUB_ASM_ENTRY("glWindowPos3ivARB")"\n"
"\t"STUB_ASM_CODE("3334")"\n"

STUB_ASM_ENTRY("glWindowPos3ivMESA")"\n"
"\t"STUB_ASM_CODE("3335")"\n"

STUB_ASM_ENTRY("glWindowPos3s")"\n"
"\t"STUB_ASM_CODE("3336")"\n"

STUB_ASM_ENTRY("glWindowPos3sARB")"\n"
"\t"STUB_ASM_CODE("3337")"\n"

STUB_ASM_ENTRY("glWindowPos3sMESA")"\n"
"\t"STUB_ASM_CODE("3338")"\n"

STUB_ASM_ENTRY("glWindowPos3sv")"\n"
"\t"STUB_ASM_CODE("3339")"\n"

STUB_ASM_ENTRY("glWindowPos3svARB")"\n"
"\t"STUB_ASM_CODE("3340")"\n"

STUB_ASM_ENTRY("glWindowPos3svMESA")"\n"
"\t"STUB_ASM_CODE("3341")"\n"

STUB_ASM_ENTRY("glWindowPos4dMESA")"\n"
"\t"STUB_ASM_CODE("3342")"\n"

STUB_ASM_ENTRY("glWindowPos4dvMESA")"\n"
"\t"STUB_ASM_CODE("3343")"\n"

STUB_ASM_ENTRY("glWindowPos4fMESA")"\n"
"\t"STUB_ASM_CODE("3344")"\n"

STUB_ASM_ENTRY("glWindowPos4fvMESA")"\n"
"\t"STUB_ASM_CODE("3345")"\n"

STUB_ASM_ENTRY("glWindowPos4iMESA")"\n"
"\t"STUB_ASM_CODE("3346")"\n"

STUB_ASM_ENTRY("glWindowPos4ivMESA")"\n"
"\t"STUB_ASM_CODE("3347")"\n"

STUB_ASM_ENTRY("glWindowPos4sMESA")"\n"
"\t"STUB_ASM_CODE("3348")"\n"

STUB_ASM_ENTRY("glWindowPos4svMESA")"\n"
"\t"STUB_ASM_CODE("3349")"\n"

STUB_ASM_ENTRY("glWindowRectanglesEXT")"\n"
"\t"STUB_ASM_CODE("3350")"\n"

STUB_ASM_ENTRY("glWriteMaskEXT")"\n"
"\t"STUB_ASM_CODE("3351")"\n"

);
#undef MAPI_TMP_STUB_ASM_GCC
#endif /* MAPI_TMP_STUB_ASM_GCC */

